@@ -23,372 +23,65 @@
 #include <krandom.h>
 #include <kdebug.h>
 #include <klocale.h>
-#include <ksimpleconfig.h>
+#include <kconfig.h>
 #include <kstandarddirs.h>
-#include <kstaticdeleter.h>
 
-#include <QFile>
-#include <QTextStream>
+#include <QtCore/QFile>
+#include <QtCore/QMap>
+#include <QtCore/QTextStream>
+#include <QtCore/QSharedData>
 
 using namespace KABC;
 
-QMap<QString, QString> *Address::mISOMap = 0;
-static KStaticDeleter< QMap<QString, QString> > isoMapDeleter;
+// template tags for address formatting localization
+#define KABC_FMTTAG_realname   QString("%n")
+#define KABC_FMTTAG_REALNAME   QString("%N")
+#define KABC_FMTTAG_company    QString("%cm")
+#define KABC_FMTTAG_COMPANY    QString("%CM")
+#define KABC_FMTTAG_pobox      QString("%p")
+#define KABC_FMTTAG_street     QString("%s")
+#define KABC_FMTTAG_STREET     QString("%S")
+#define KABC_FMTTAG_zipcode    QString("%z")
+#define KABC_FMTTAG_location   QString("%l")
+#define KABC_FMTTAG_LOCATION   QString("%L")
+#define KABC_FMTTAG_region     QString("%r")
+#define KABC_FMTTAG_REGION     QString("%R")
+#define KABC_FMTTAG_newline    QString("\\n")
+#define KABC_FMTTAG_condcomma  QString("%,")
+#define KABC_FMTTAG_condwhite  QString("%w")
+#define KABC_FMTTAG_purgeempty QString("%0")
 
-Address::Address() :
-  mEmpty( true ), mType( 0 )
+/**
+  Finds the balanced closing bracket starting from the opening bracket at
+  pos in tsection.
+  @return  position of closing bracket, -1 for unbalanced brackets
+*/
+static int findBalancedBracket( const QString &tsection, int pos )
 {
-  mId = KRandom::randomString( 10 );
-}
-
-Address::Address( int type ) :
-  mEmpty( true ), mType( type )
-{
-  mId = KRandom::randomString( 10 );
-}
-
-bool Address::operator==( const Address &a ) const
-{
-  if ( mPostOfficeBox != a.mPostOfficeBox ) return false;
-  if ( mExtended != a.mExtended ) return false;
-  if ( mStreet != a.mStreet ) return false;
-  if ( mLocality != a.mLocality ) return false;
-  if ( mRegion != a.mRegion ) return false;
-  if ( mPostalCode != a.mPostalCode ) return false;
-  if ( mCountry != a.mCountry ) return false;
-  if ( mLabel != a.mLabel ) return false;
-
-  return true;
-}
-
-bool Address::operator!=( const Address &a ) const
-{
-  return !( a == *this );
-}
-
-bool Address::isEmpty() const
-{
-  if ( mPostOfficeBox.isEmpty() &&
-       mExtended.isEmpty() &&
-       mStreet.isEmpty() &&
-       mLocality.isEmpty() &&
-       mRegion.isEmpty() &&
-       mPostalCode.isEmpty() &&
-       mCountry.isEmpty() &&
-       mLabel.isEmpty() ) {
-    return true;
-  }
-  return false;
-}
-
-void Address::clear()
-{
-  *this = Address();
-}
-
-void Address::setId( const QString &id )
-{
-  mEmpty = false;
-
-  mId = id;
-}
-
-QString Address::id() const
-{
-  return mId;
-}
-
-void Address::setType( int type )
-{
-  mEmpty = false;
-
-  mType = type;
-}
-
-int Address::type() const
-{
-  return mType;
-}
-
-QString Address::typeLabel() const
-{
-  QString label;
-  bool first = true;
-
-  const TypeList list = typeList();
-
-  TypeList::ConstIterator it;
-  for ( it = list.begin(); it != list.end(); ++it ) {
-    if ( ( type() & (*it) ) && ( (*it) != Pref ) ) {
-      label.append( ( first ? "" : "/" ) + typeLabel( *it ) );
-      if ( first )
-        first = false;
+  int balancecounter = 0;
+  for ( int i = pos + 1; i < tsection.length(); i++ ) {
+    if ( ')' == tsection[i] && 0 == balancecounter ) {
+      // found end of brackets
+      return i;
+    } else {
+      if ( '(' == tsection[i] ) {
+        // nested brackets
+        balancecounter++;
+      }
     }
   }
-
-  return label;
+  return -1;
 }
 
-void Address::setPostOfficeBox( const QString &s )
-{
-  mEmpty = false;
-
-  mPostOfficeBox = s;
-}
-
-QString Address::postOfficeBox() const
-{
-  return mPostOfficeBox;
-}
-
-QString Address::postOfficeBoxLabel()
-{
-  return i18n("Post Office Box");
-}
-
-
-void Address::setExtended( const QString &s )
-{
-  mEmpty = false;
-
-  mExtended = s;
-}
-
-QString Address::extended() const
-{
-  return mExtended;
-}
-
-QString Address::extendedLabel()
-{
-  return i18n("Extended Address Information");
-}
-
-
-void Address::setStreet( const QString &s )
-{
-  mEmpty = false;
-
-  mStreet = s;
-}
-
-QString Address::street() const
-{
-  return mStreet;
-}
-
-QString Address::streetLabel()
-{
-  return i18n("Street");
-}
-
-
-void Address::setLocality( const QString &s )
-{
-  mEmpty = false;
-
-  mLocality = s;
-}
-
-QString Address::locality() const
-{
-  return mLocality;
-}
-
-QString Address::localityLabel()
-{
-  return i18n("Locality");
-}
-
-
-void Address::setRegion( const QString &s )
-{
-  mEmpty = false;
-
-  mRegion = s;
-}
-
-QString Address::region() const
-{
-  return mRegion;
-}
-
-QString Address::regionLabel()
-{
-  return i18n("Region");
-}
-
-
-void Address::setPostalCode( const QString &s )
-{
-  mEmpty = false;
-
-  mPostalCode = s;
-}
-
-QString Address::postalCode() const
-{
-  return mPostalCode;
-}
-
-QString Address::postalCodeLabel()
-{
-  return i18n("Postal Code");
-}
-
-
-void Address::setCountry( const QString &s )
-{
-  mEmpty = false;
-
-  mCountry = s;
-}
-
-QString Address::country() const
-{
-  return mCountry;
-}
-
-QString Address::countryLabel()
-{
-  return i18n("Country");
-}
-
-
-void Address::setLabel( const QString &s )
-{
-  mEmpty = false;
-
-  mLabel = s;
-}
-
-QString Address::label() const
-{
-  return mLabel;
-}
-
-QString Address::labelLabel()
-{
-  return i18n("Delivery Label");
-}
-
-Address::TypeList Address::typeList()
-{
-  static TypeList list;
-
-  if ( list.isEmpty() )
-    list << Dom << Intl << Postal << Parcel << Home << Work << Pref;
-
-  return list;
-}
-
-QString Address::typeLabel( int type )
-{
-  if ( type & Pref )
-    return i18nc( "Preferred address", "Preferred" );
-
-  switch ( type ) {
-    case Dom:
-      return i18n("Domestic");
-      break;
-    case Intl:
-      return i18n("International");
-      break;
-    case Postal:
-      return i18n("Postal");
-      break;
-    case Parcel:
-      return i18n("Parcel");
-      break;
-    case Home:
-      return i18nc("Home Address", "Home");
-      break;
-    case Work:
-      return i18nc("Work Address", "Work");
-      break;
-    case Pref:
-      return i18n("Preferred Address");
-      break;
-    default:
-      return i18n("Other");
-      break;
-  }
-}
-
-void Address::dump() const
-{
-  kDebug(5700) << "  Address {" << endl;
-  kDebug(5700) << "    Id: " << id() << endl;
-  kDebug(5700) << "    Extended: " << extended() << endl;
-  kDebug(5700) << "    Street: " << street() << endl;
-  kDebug(5700) << "    Postal Code: " << postalCode() << endl;
-  kDebug(5700) << "    Locality: " << locality() << endl;
-  kDebug(5700) << "  }" << endl;
-}
-
-
-QString Address::formattedAddress( const QString &realName,
-                                   const QString &orgaName ) const
-{
-  QString ciso;
-  QString addrTemplate;
-  QString ret;
-
-  // FIXME: first check for iso-country-field and prefer that one
-  if ( !country().isEmpty() ) {
-    ciso = countryToISO( country() );
-  } else {
-    // fall back to our own country
-    ciso = KGlobal::locale()->country();
-  }
-  KSimpleConfig entry( KStandardDirs::locate( "locale",
-        QString( "l10n/" ) + ciso + QString( "/entry.desktop" ) ) );
-  entry.setGroup( "KCM Locale" );
-
-  // decide whether this needs special business address formatting
-  if ( orgaName.isEmpty() ) {
-    addrTemplate = entry.readEntry( "AddressFormat" );
-  } else {
-    addrTemplate = entry.readEntry( "BusinessAddressFormat" );
-    if ( addrTemplate.isEmpty() )
-      addrTemplate = entry.readEntry( "AddressFormat" );
-  }
-
-  // in the case there's no format found at all, default to what we've always
-  // used:
-  if ( addrTemplate.isEmpty() ) {
-    kWarning(5700) << "address format database incomplete "
-        << "(no format for locale " << ciso
-        << " found). Using default address formatting." << endl;
-    addrTemplate = "%0(%n\\n)%0(%cm\\n)%0(%s\\n)%0(PO BOX %p\\n)%0(%l%w%r)%,%z";
-  }
-
-  // scan
-  parseAddressTemplateSection( addrTemplate, ret, realName, orgaName );
-
-  // now add the country line if needed (formatting this time according to
-  // the rules of our own system country )
-  if ( !country().isEmpty() ) {
-    KSimpleConfig entry( KStandardDirs::locate( "locale", QString( "l10n/" )
-          + KGlobal::locale()->country() + QString( "/entry.desktop" ) ) );
-    entry.setGroup( "KCM Locale" );
-    QString cpos = entry.readEntry( "AddressCountryPosition" );
-    if ( "BELOW" == cpos || cpos.isEmpty() ) {
-      ret = ret + "\n\n" + country().toUpper();
-    } else if ( "below" == cpos ) {
-      ret = ret + "\n\n" + country();
-    } else if ( "ABOVE" == cpos ) {
-      ret = country().toUpper() + "\n\n" + ret;
-    } else if ( "above" == cpos ) {
-      ret = country() + "\n\n" + ret;
-    }
-  }
-
-  return ret;
-}
-
-bool Address::parseAddressTemplateSection( const QString &tsection,
-    QString &result, const QString &realName, const QString &orgaName ) const
+/**
+  Parses a snippet of an address template
+  @param tsection   the template string to be parsed
+  @param result     QString reference in which the result will be stored
+  @return           true if at least one tag evaluated positively, else false
+*/
+static bool parseAddressTemplateSection( const QString &tsection, QString &result,
+                                         const QString &realName, const QString &orgaName,
+                                         const KABC::Address &address )
 {
   // This method first parses and substitutes any bracketed sections and
   // after that replaces any tags with their values. If a bracketed section
@@ -413,7 +106,7 @@ bool Address::parseAddressTemplateSection( const QString &tsection,
         QString rplstr;
         bool purge = !parseAddressTemplateSection( result.mid( bpos1+1,
                                                    bpos2-bpos1-1 ), rplstr,
-                                                   realName, orgaName );
+                                                   realName, orgaName, address );
         if ( purge ) {
           // purge -> remove all
           // replace with !_P_!, so conditional tags work later
@@ -439,8 +132,8 @@ bool Address::parseAddressTemplateSection( const QString &tsection,
   // The following macro needs QString for R_FIELD
   // It substitutes !_P_! for empty fields so conditional tags work later
 #define REPLTAG(R_TAG,R_FIELD) \
-  if ( result.indexOf(R_TAG, false) != -1 ) { \
-    QString rpl = R_FIELD.isEmpty() ? QString("!_P_!") : R_FIELD; \
+  if ( result.indexOf( R_TAG, false ) != -1 ) { \
+    QString rpl = R_FIELD.isEmpty() ? QString( "!_P_!" ) : R_FIELD; \
     result.replace( R_TAG, rpl ); \
     if ( !R_FIELD.isEmpty() ) { \
       ret = true; \
@@ -450,14 +143,14 @@ bool Address::parseAddressTemplateSection( const QString &tsection,
   REPLTAG( KABC_FMTTAG_REALNAME, realName.toUpper() );
   REPLTAG( KABC_FMTTAG_company, orgaName );
   REPLTAG( KABC_FMTTAG_COMPANY, orgaName.toUpper() );
-  REPLTAG( KABC_FMTTAG_pobox, postOfficeBox() );
-  REPLTAG( KABC_FMTTAG_street, street() );
-  REPLTAG( KABC_FMTTAG_STREET, street().toUpper() );
-  REPLTAG( KABC_FMTTAG_zipcode, postalCode() );
-  REPLTAG( KABC_FMTTAG_location, locality() );
-  REPLTAG( KABC_FMTTAG_LOCATION, locality().toUpper() );
-  REPLTAG( KABC_FMTTAG_region, region() );
-  REPLTAG( KABC_FMTTAG_REGION, region().toUpper() );
+  REPLTAG( KABC_FMTTAG_pobox, address.postOfficeBox() );
+  REPLTAG( KABC_FMTTAG_street, address.street() );
+  REPLTAG( KABC_FMTTAG_STREET, address.street().toUpper() );
+  REPLTAG( KABC_FMTTAG_zipcode, address.postalCode() );
+  REPLTAG( KABC_FMTTAG_location, address.locality() );
+  REPLTAG( KABC_FMTTAG_LOCATION, address.locality().toUpper() );
+  REPLTAG( KABC_FMTTAG_region, address.region() );
+  REPLTAG( KABC_FMTTAG_REGION, address.region().toUpper() );
   result.replace( KABC_FMTTAG_newline, "\n" );
 #undef REPLTAG
 
@@ -492,20 +185,422 @@ bool Address::parseAddressTemplateSection( const QString &tsection,
   return ret;
 }
 
-int Address::findBalancedBracket( const QString &tsection, int pos ) const
+class Address::Private : public QSharedData
 {
-  int balancecounter = 0;
-  for ( int i = pos + 1; i < tsection.length(); i++ ) {
-    if ( ')' == tsection[i] && 0 == balancecounter ) {
-      // found end of brackets
-      return i;
-    } else
-    if ( '(' == tsection[i] ) {
-      // nested brackets
-      balancecounter++;
+  public:
+    Private()
+      : mEmpty( true ), mType( 0 )
+    {
+      mId = KRandom::randomString( 10 );
+    }
+
+    Private( const Private &other )
+      : QSharedData( other )
+    {
+      mEmpty = other.mEmpty;
+      mId = other.mId;
+      mType = other.mType;
+
+      mPostOfficeBox = other.mPostOfficeBox;
+      mExtended = other.mExtended;
+      mStreet = other.mStreet;
+      mLocality = other.mLocality;
+      mRegion = other.mRegion;
+      mPostalCode = other.mPostalCode;
+      mCountry = other.mCountry;
+      mLabel = other.mLabel;
+    }
+
+    bool mEmpty;
+    QString mId;
+    Type mType;
+
+    QString mPostOfficeBox;
+    QString mExtended;
+    QString mStreet;
+    QString mLocality;
+    QString mRegion;
+    QString mPostalCode;
+    QString mCountry;
+    QString mLabel;
+};
+
+Address::Address()
+  : d( new Private )
+{
+}
+
+Address::Address( Type type )
+  : d( new Private )
+{
+  d->mType = type;
+}
+
+Address::Address( const Address &other )
+  : d( other.d )
+{
+}
+
+Address::~Address()
+{
+}
+
+Address &Address::operator=( const Address &other )
+{
+  if ( this != &other ) {
+    d = other.d;
+  }
+
+  return *this;
+}
+
+bool Address::operator==( const Address &other ) const
+{
+  if ( d->mId != other.d->mId ) {
+    return false;
+  }
+  if ( d->mType != other.d->mType ) {
+    return false;
+  }
+  if ( d->mPostOfficeBox != other.d->mPostOfficeBox ) {
+    return false;
+  }
+  if ( d->mExtended != other.d->mExtended ) {
+    return false;
+  }
+  if ( d->mStreet != other.d->mStreet ) {
+    return false;
+  }
+  if ( d->mLocality != other.d->mLocality ) {
+    return false;
+  }
+  if ( d->mRegion != other.d->mRegion ) {
+    return false;
+  }
+  if ( d->mPostalCode != other.d->mPostalCode ) {
+    return false;
+  }
+  if ( d->mCountry != other.d->mCountry ) {
+    return false;
+  }
+  if ( d->mLabel != other.d->mLabel ) {
+    return false;
+  }
+
+  return true;
+}
+
+bool Address::operator!=( const Address &a ) const
+{
+  return !( a == *this );
+}
+
+bool Address::isEmpty() const
+{
+  return d->mEmpty;
+}
+
+void Address::clear()
+{
+  *this = Address();
+}
+
+void Address::setId( const QString &id )
+{
+  d->mEmpty = false;
+  d->mId = id;
+}
+
+QString Address::id() const
+{
+  return d->mId;
+}
+
+void Address::setType( Type type )
+{
+  d->mEmpty = false;
+  d->mType = type;
+}
+
+Address::Type Address::type() const
+{
+  return d->mType;
+}
+
+QString Address::typeLabel() const
+{
+  QString label;
+  bool first = true;
+
+  const TypeList list = typeList();
+
+  TypeList::ConstIterator it;
+  for ( it = list.begin(); it != list.end(); ++it ) {
+    if ( ( type() & (*it) ) && ( (*it) != Pref ) ) {
+      label.append( ( first ? "" : "/" ) + typeLabel( *it ) );
+      if ( first ) {
+        first = false;
+      }
     }
   }
-  return -1;
+
+  return label;
+}
+
+void Address::setPostOfficeBox( const QString &postOfficeBox )
+{
+  d->mEmpty = false;
+  d->mPostOfficeBox = postOfficeBox;
+}
+
+QString Address::postOfficeBox() const
+{
+  return d->mPostOfficeBox;
+}
+
+QString Address::postOfficeBoxLabel()
+{
+  return i18n( "Post Office Box" );
+}
+
+void Address::setExtended( const QString &extended )
+{
+  d->mEmpty = false;
+  d->mExtended = extended;
+}
+
+QString Address::extended() const
+{
+  return d->mExtended;
+}
+
+QString Address::extendedLabel()
+{
+  return i18n( "Extended Address Information" );
+}
+
+void Address::setStreet( const QString &street )
+{
+  d->mEmpty = false;
+  d->mStreet = street;
+}
+
+QString Address::street() const
+{
+  return d->mStreet;
+}
+
+QString Address::streetLabel()
+{
+  return i18n( "Street" );
+}
+
+void Address::setLocality( const QString &locality )
+{
+  d->mEmpty = false;
+  d->mLocality = locality;
+}
+
+QString Address::locality() const
+{
+  return d->mLocality;
+}
+
+QString Address::localityLabel()
+{
+  return i18n( "Locality" );
+}
+
+void Address::setRegion( const QString &region )
+{
+  d->mEmpty = false;
+  d->mRegion = region;
+}
+
+QString Address::region() const
+{
+  return d->mRegion;
+}
+
+QString Address::regionLabel()
+{
+  return i18n( "Region" );
+}
+
+void Address::setPostalCode( const QString &postalCode )
+{
+  d->mEmpty = false;
+  d->mPostalCode = postalCode;
+}
+
+QString Address::postalCode() const
+{
+  return d->mPostalCode;
+}
+
+QString Address::postalCodeLabel()
+{
+  return i18n( "Postal Code" );
+}
+
+void Address::setCountry( const QString &country )
+{
+  d->mEmpty = false;
+  d->mCountry = country;
+}
+
+QString Address::country() const
+{
+  return d->mCountry;
+}
+
+QString Address::countryLabel()
+{
+  return i18n( "Country" );
+}
+
+void Address::setLabel( const QString &label )
+{
+  d->mEmpty = false;
+  d->mLabel = label;
+}
+
+QString Address::label() const
+{
+  return d->mLabel;
+}
+
+QString Address::labelLabel()
+{
+  return i18n( "Delivery Label" );
+}
+
+Address::TypeList Address::typeList()
+{
+  static TypeList list;
+
+  if ( list.isEmpty() ) {
+    list << Dom << Intl << Postal << Parcel << Home << Work << Pref;
+  }
+
+  return list;
+}
+
+QString Address::typeLabel( Type type )
+{
+  if ( type & Pref ) {
+    return i18nc( "Preferred address", "Preferred" );
+  }
+
+  switch ( type ) {
+    case Dom:
+      return i18n( "Domestic" );
+      break;
+    case Intl:
+      return i18n( "International" );
+      break;
+    case Postal:
+      return i18n( "Postal" );
+      break;
+    case Parcel:
+      return i18n( "Parcel" );
+      break;
+    case Home:
+      return i18nc( "Home Address", "Home" );
+      break;
+    case Work:
+      return i18nc( "Work Address", "Work" );
+      break;
+    case Pref:
+      return i18n( "Preferred Address" );
+      break;
+    default:
+      return i18n( "Other" );
+      break;
+  }
+}
+
+QString Address::toString() const
+{
+  QString str;
+
+  str += QString( "Address {\n" );
+  str += QString( "  IsEmpty: %1\n" ).arg( d->mEmpty ? "true" : "false" );
+  str += QString( "  Id: %1\n" ).arg( d->mId );
+  str += QString( "  Type: %1\n" ).arg( typeLabel( d->mType ) );
+  str += QString( "  Post Office Box: %1\n" ).arg( d->mPostOfficeBox );
+  str += QString( "  Extended: %1\n" ).arg( d->mExtended );
+  str += QString( "  Street: %1\n" ).arg( d->mStreet );
+  str += QString( "  Locality: %1\n" ).arg( d->mLocality );
+  str += QString( "  Region: %1\n" ).arg( d->mRegion );
+  str += QString( "  Postal Code: %1\n" ).arg( d->mPostalCode );
+  str += QString( "  Country: %1\n" ).arg( d->mCountry );
+  str += QString( "  Label: %1\n" ).arg( d->mLabel );
+  str += QString( "}\n" );
+
+  return str;
+}
+
+QString Address::formattedAddress( const QString &realName,
+                                   const QString &orgaName ) const
+{
+  QString ciso;
+  QString addrTemplate;
+  QString ret;
+
+  // FIXME: first check for iso-country-field and prefer that one
+  if ( !country().isEmpty() ) {
+    ciso = countryToISO( country() );
+  } else {
+    // fall back to our own country
+    ciso = KGlobal::locale()->country();
+  }
+  KConfig entry( KStandardDirs::locate( "locale",
+        QString( "l10n/" ) + ciso + QString( "/entry.desktop" ) ) );
+
+  KConfigGroup group = entry.group( "KCM Locale" );
+  // decide whether this needs special business address formatting
+  if ( orgaName.isEmpty() ) {
+    addrTemplate = group.readEntry( "AddressFormat" );
+  } else {
+    addrTemplate = group.readEntry( "BusinessAddressFormat" );
+    if ( addrTemplate.isEmpty() ) {
+      addrTemplate = group.readEntry( "AddressFormat" );
+    }
+  }
+
+  // in the case there's no format found at all, default to what we've always
+  // used:
+  if ( addrTemplate.isEmpty() ) {
+    kWarning(5700) << "address format database incomplete"
+        << "(no format for locale" << ciso
+        << "found). Using default address formatting.";
+    addrTemplate = "%0(%n\\n)%0(%cm\\n)%0(%s\\n)%0(PO BOX %p\\n)%0(%l%w%r)%,%z";
+  }
+
+  // scan
+  parseAddressTemplateSection( addrTemplate, ret, realName, orgaName, *this );
+
+  // now add the country line if needed (formatting this time according to
+  // the rules of our own system country )
+  if ( !country().isEmpty() ) {
+    KConfig entry( KStandardDirs::locate( "locale", QString( "l10n/" ) +
+                                          KGlobal::locale()->country() +
+                                          QString( "/entry.desktop" ) ) );
+    KConfigGroup group = entry.group( "KCM Locale" );
+    QString cpos = group.readEntry( "AddressCountryPosition" );
+    if ( "BELOW" == cpos || cpos.isEmpty() ) {
+      ret = ret + "\n\n" + country().toUpper();
+    } else if ( "below" == cpos ) {
+      ret = ret + "\n\n" + country();
+    } else if ( "ABOVE" == cpos ) {
+      ret = country().toUpper() + "\n\n" + ret;
+    } else if ( "above" == cpos ) {
+      ret = country() + "\n\n" + ret;
+    }
+  }
+
+  return ret;
 }
 
 QString Address::countryToISO( const QString &cname )
@@ -513,13 +608,14 @@ QString Address::countryToISO( const QString &cname )
   // we search a map file for translations from country names to
   // iso codes, storing caching things in a QMap for faster future
   // access.
-  if ( !mISOMap )
-    isoMapDeleter.setObject( mISOMap, new QMap<QString, QString>() );
+  typedef QMap<QString, QString> stringMap;
+  K_GLOBAL_STATIC( stringMap, sISOMap )
 
   QMap<QString, QString>::ConstIterator it;
-  it = mISOMap->find( cname );
-  if ( it != mISOMap->end() )
+  it = sISOMap->find( cname );
+  if ( it != sISOMap->end() ) {
     return it.value();
+  }
 
   QString mapfile = KGlobal::dirs()->findResource( "data",
           QLatin1String( "kabc/countrytransl.map" ) );
@@ -532,7 +628,7 @@ QString Address::countryToISO( const QString &cname )
       QStringList countryInfo = strbuf.split( '\t', QString::KeepEmptyParts );
       if ( countryInfo[ 0 ] == cname ) {
         file.close();
-        mISOMap->insert( cname, countryInfo[ 1 ] );
+        sISOMap->insert( cname, countryInfo[ 1 ] );
         return countryInfo[ 1 ];
       }
       strbuf = s.readLine();
@@ -541,15 +637,16 @@ QString Address::countryToISO( const QString &cname )
   }
 
   // fall back to system country
-  mISOMap->insert( cname, KGlobal::locale()->country() );
+  sISOMap->insert( cname, KGlobal::locale()->country() );
   return KGlobal::locale()->country();
 }
 
 QString Address::ISOtoCountry( const QString &ISOname )
 {
   // get country name from ISO country code (e.g. "no" -> i18n("Norway"))
-  if ( ISOname.simplified().isEmpty() )
+  if ( ISOname.simplified().isEmpty() ) {
     return QString();
+  }
 
   QString mapfile = KGlobal::dirs()->findResource( "data",
           QLatin1String( "kabc/countrytransl.map" ) );
@@ -561,7 +658,7 @@ QString Address::ISOtoCountry( const QString &ISOname )
     QString strbuf = s.readLine();
     int pos;
     while ( !strbuf.isEmpty() ) {
-      if ( (pos = strbuf.indexOf( searchStr )) != -1 ) {
+      if ( ( pos = strbuf.indexOf( searchStr ) ) != -1 ) {
         file.close();
         return i18n( strbuf.left( pos ).toUtf8() );
       }
@@ -575,19 +672,21 @@ QString Address::ISOtoCountry( const QString &ISOname )
 
 QDataStream &KABC::operator<<( QDataStream &s, const Address &addr )
 {
-  return s << addr.mId << addr.mType << addr.mPostOfficeBox <<
-              addr.mExtended << addr.mStreet << addr.mLocality <<
-              addr.mRegion << addr.mPostalCode << addr.mCountry <<
-              addr.mLabel;
+  return s << addr.d->mId << (uint)addr.d->mType << addr.d->mPostOfficeBox
+           << addr.d->mExtended << addr.d->mStreet << addr.d->mLocality
+           << addr.d->mRegion << addr.d->mPostalCode << addr.d->mCountry
+           << addr.d->mLabel << addr.d->mEmpty;
 }
 
 QDataStream &KABC::operator>>( QDataStream &s, Address &addr )
 {
-  s >> addr.mId >> addr.mType >> addr.mPostOfficeBox >> addr.mExtended >>
-       addr.mStreet >> addr.mLocality >> addr.mRegion >>
-       addr.mPostalCode >> addr.mCountry >> addr.mLabel;
+  uint type;
+  s >> addr.d->mId >> type >> addr.d->mPostOfficeBox >> addr.d->mExtended
+    >> addr.d->mStreet >> addr.d->mLocality >> addr.d->mRegion
+    >> addr.d->mPostalCode >> addr.d->mCountry >> addr.d->mLabel
+    >> addr.d->mEmpty;
 
-  addr.mEmpty = false;
+  addr.d->mType = Address::Type( type );
 
   return s;
 }
