@@ -18,29 +18,30 @@
     Boston, MA 02110-1301, USA.
 */
 
+#include "addressbook.h"
+#include "errorhandler.h"
+#include "resource.h"
+
 #include <kdebug.h>
 #include <kglobal.h>
 #include <kcomponentdata.h>
 #include <klocale.h>
 #include <kstandarddirs.h>
 
-#include "errorhandler.h"
-#include "resource.h"
-
-#include "addressbook.h"
 #include "addressbook.moc"
 
 using namespace KABC;
 
-struct AddressBook::AddressBookData
+class AddressBook::Private
 {
-  Field::List mAllFields;
-  ErrorHandler *mErrorHandler;
-  KConfig *mConfig;
-  KRES::Manager<Resource> *mManager;
-  QList<Resource*> mPendingLoadResources;
-  QList<Resource*> mPendingSaveResources;
-  Iterator end;
+  public:
+    Field::List mAllFields;
+    ErrorHandler *mErrorHandler;
+    KConfig *mConfig;
+    KRES::Manager<Resource> *mManager;
+    QList<Resource*> mPendingLoadResources;
+    QList<Resource*> mPendingSaveResources;
+    Iterator end;
 };
 
 struct AddressBook::Iterator::IteratorData
@@ -70,13 +71,13 @@ AddressBook::Iterator::Iterator( const AddressBook::Iterator &i )
   d->mCurrRes = i.d->mCurrRes;
 }
 
-AddressBook::Iterator &AddressBook::Iterator::operator=( const AddressBook::Iterator &i )
+AddressBook::Iterator &AddressBook::Iterator::operator=
+  ( const AddressBook::Iterator &i )
 {
-  if ( this == &i )
+  if ( this == &i ) {
     return *this; // guard against self assignment
+  }
 
-  delete d; // delete the old data the Iterator was completely constructed before
-  d = new IteratorData;
   d->mIt = i.d->mIt;
   d->mResources = i.d->mResources;
   d->mCurrRes = i.d->mCurrRes;
@@ -87,7 +88,6 @@ AddressBook::Iterator &AddressBook::Iterator::operator=( const AddressBook::Iter
 AddressBook::Iterator::~Iterator()
 {
   delete d;
-  d = 0;
 }
 
 const Addressee &AddressBook::Iterator::operator*() const
@@ -109,7 +109,8 @@ AddressBook::Iterator &AddressBook::Iterator::operator++()
 {
   do {
     bool jumped = false;
-    while ( d->mIt == (d->mResources[ d->mCurrRes ])->end() ) { // at end of addressee list of resource
+    while ( d->mIt == ( d->mResources[ d->mCurrRes ] )->end() ) {
+      // at end of addressee list of resource
       if ( d->mCurrRes == d->mResources.count() - 1 ) {
         return *this;
       }
@@ -117,13 +118,14 @@ AddressBook::Iterator &AddressBook::Iterator::operator++()
       d->mCurrRes++; // jump to next resource
 
       jumped = true;
-      d->mIt = (d->mResources[ d->mCurrRes ])->begin();
+      d->mIt = ( d->mResources[ d->mCurrRes ] )->begin();
     }
 
-    if ( !jumped )
+    if ( !jumped ) {
       (d->mIt)++;
+    }
 
-  } while ( d->mIt == (d->mResources[ d->mCurrRes ])->end() );
+  } while ( d->mIt == ( d->mResources[ d->mCurrRes ] )->end() );
 
   return *this;
 }
@@ -132,7 +134,8 @@ AddressBook::Iterator &AddressBook::Iterator::operator++( int )
 {
   do {
     bool jumped = false;
-    while ( d->mIt == (d->mResources[ d->mCurrRes ])->end() ) { // at end of addressee list of resource
+    while ( d->mIt == ( d->mResources[ d->mCurrRes ] )->end() ) {
+      // at end of addressee list of resource
       if ( d->mCurrRes == d->mResources.count() - 1 ) {
         return *this;
       }
@@ -140,13 +143,14 @@ AddressBook::Iterator &AddressBook::Iterator::operator++( int )
       d->mCurrRes++; // jump to next resource
 
       jumped = true;
-        d->mIt = (d->mResources[ d->mCurrRes ])->begin();
+      d->mIt = ( d->mResources[ d->mCurrRes ] )->begin();
     }
 
-    if ( !jumped )
+    if ( !jumped ) {
       (d->mIt)++;
+    }
 
-  } while ( d->mIt == (d->mResources[ d->mCurrRes ])->end() );
+  } while ( d->mIt == ( d->mResources[ d->mCurrRes ] )->end() );
 
   return *this;
 }
@@ -167,15 +171,14 @@ AddressBook::Iterator &AddressBook::Iterator::operator--( int )
 
 bool AddressBook::Iterator::operator==( const Iterator &it ) const
 {
-  return ( d->mIt == it.d->mIt );
+  return d->mIt == it.d->mIt;
 }
 
 bool AddressBook::Iterator::operator!=( const Iterator &it ) const
 {
-  return ( d->mIt != it.d->mIt );
+  return d->mIt != it.d->mIt;
 }
 
-
 AddressBook::ConstIterator::ConstIterator()
   : d( new ConstIteratorData )
 {
@@ -190,20 +193,20 @@ AddressBook::ConstIterator::ConstIterator( const AddressBook::ConstIterator &i )
 }
 
 AddressBook::ConstIterator::ConstIterator( const AddressBook::Iterator &i )
+  :d( new ConstIteratorData )
 {
-  d = new ConstIteratorData;
   d->mIt = i.d->mIt;
   d->mResources = i.d->mResources;
   d->mCurrRes = i.d->mCurrRes;
 }
 
-AddressBook::ConstIterator &AddressBook::ConstIterator::operator=( const AddressBook::ConstIterator &i )
+AddressBook::ConstIterator &AddressBook::ConstIterator::operator=
+  ( const AddressBook::ConstIterator &i )
 {
-  if ( this  == &i )
+  if ( this  == &i ) {
     return *this; // guard for self assignment
+  }
 
-  delete d; // delete the old data because the Iterator was really constructed before
-  d = new ConstIteratorData;
   d->mIt = i.d->mIt;
   d->mResources = i.d->mResources;
   d->mCurrRes = i.d->mCurrRes;
@@ -214,7 +217,6 @@ AddressBook::ConstIterator &AddressBook::ConstIterator::operator=( const Address
 AddressBook::ConstIterator::~ConstIterator()
 {
   delete d;
-  d = 0;
 }
 
 const Addressee &AddressBook::ConstIterator::operator*() const
@@ -222,7 +224,7 @@ const Addressee &AddressBook::ConstIterator::operator*() const
   return *(d->mIt);
 }
 
-const Addressee* AddressBook::ConstIterator::operator->() const
+const Addressee *AddressBook::ConstIterator::operator->() const
 {
   return &(*(d->mIt));
 }
@@ -231,7 +233,8 @@ AddressBook::ConstIterator &AddressBook::ConstIterator::operator++()
 {
   do {
     bool jumped = false;
-    while ( d->mIt == (d->mResources[ d->mCurrRes ])->end() ) { // at end of addressee list of resource
+    while ( d->mIt == ( d->mResources[ d->mCurrRes ] )->end() ) {
+      // at end of addressee list of resource
       if ( d->mCurrRes == d->mResources.count() - 1 ) {
         return *this;
       }
@@ -239,13 +242,14 @@ AddressBook::ConstIterator &AddressBook::ConstIterator::operator++()
       d->mCurrRes++; // jump to next resource
 
       jumped = true;
-      d->mIt = (d->mResources[ d->mCurrRes ])->begin();
+      d->mIt = ( d->mResources[ d->mCurrRes ] )->begin();
     }
 
-    if ( !jumped )
+    if ( !jumped ) {
       (d->mIt)++;
+    }
 
-  } while ( d->mIt == (d->mResources[ d->mCurrRes ])->end() );
+  } while ( d->mIt == ( d->mResources[ d->mCurrRes ] )->end() );
 
   return *this;
 }
@@ -254,7 +258,8 @@ AddressBook::ConstIterator &AddressBook::ConstIterator::operator++(int)
 {
   do {
     bool jumped = false;
-    while ( d->mIt == (d->mResources[ d->mCurrRes ])->end() ) { // at end of addressee list of resource
+    while ( d->mIt == ( d->mResources[ d->mCurrRes ] )->end() ) {
+      // at end of addressee list of resource
       if ( d->mCurrRes == d->mResources.count() - 1 ) {
         return *this;
       }
@@ -262,13 +267,14 @@ AddressBook::ConstIterator &AddressBook::ConstIterator::operator++(int)
       d->mCurrRes++; // jump to next resource
 
       jumped = true;
-      d->mIt = (d->mResources[ d->mCurrRes ])->begin();
+      d->mIt = ( d->mResources[ d->mCurrRes ] )->begin();
     }
 
-    if ( !jumped )
+    if ( !jumped ) {
       (d->mIt)++;
+    }
 
-  } while ( d->mIt == (d->mResources[ d->mCurrRes ])->end() );
+  } while ( d->mIt == ( d->mResources[ d->mCurrRes ] )->end() );
 
   return *this;
 }
@@ -287,17 +293,16 @@ AddressBook::ConstIterator &AddressBook::ConstIterator::operator--(int)
 
 bool AddressBook::ConstIterator::operator==( const ConstIterator &it ) const
 {
-  return ( d->mIt == it.d->mIt );
+  return d->mIt == it.d->mIt;
 }
 
 bool AddressBook::ConstIterator::operator!=( const ConstIterator &it ) const
 {
-  return ( d->mIt != it.d->mIt );
+  return d->mIt != it.d->mIt;
 }
 
-
 AddressBook::AddressBook()
-  : d( new AddressBookData )
+  : d( new Private )
 {
   d->mErrorHandler = 0;
   d->mConfig = 0;
@@ -307,13 +312,14 @@ AddressBook::AddressBook()
 }
 
 AddressBook::AddressBook( const QString &config )
-  : d( new AddressBookData )
+  : d( new Private )
 {
   d->mErrorHandler = 0;
-  if ( config.isEmpty() )
+  if ( config.isEmpty() ) {
     d->mConfig = 0;
-  else
+  } else {
     d->mConfig = new KConfig( config );
+  }
   d->mManager = new KRES::Manager<Resource>( "contact" );
   d->mManager->readConfig( d->mConfig );
   d->end.d->mResources = QList<Resource*>();
@@ -322,15 +328,18 @@ AddressBook::AddressBook( const QString &config )
 
 AddressBook::~AddressBook()
 {
-  delete d->mManager; d->mManager = 0;
-  delete d->mConfig; d->mConfig = 0;
-  delete d->mErrorHandler; d->mErrorHandler = 0;
-  delete d; d = 0;
+  delete d->mManager;
+  d->mManager = 0;
+  delete d->mConfig;
+  d->mConfig = 0;
+  delete d->mErrorHandler;
+  d->mErrorHandler = 0;
+  delete d;
 }
 
 bool AddressBook::load()
 {
-  kDebug(5700) << "AddressBook::load()" << endl;
+  kDebug(5700) << "AddressBook::load()";
 
   clear();
 
@@ -338,7 +347,7 @@ bool AddressBook::load()
   bool ok = true;
   for ( it = d->mManager->activeBegin(); it != d->mManager->activeEnd(); ++it ) {
     if ( !(*it)->load() ) {
-      error( i18n("Unable to load resource '%1'",  (*it)->resourceName() ) );
+      error( i18n( "Unable to load resource '%1'", (*it)->resourceName() ) );
       ok = false;
     }
   }
@@ -348,7 +357,7 @@ bool AddressBook::load()
 
 bool AddressBook::asyncLoad()
 {
-  kDebug(5700) << "AddressBook::asyncLoad()" << endl;
+  kDebug(5700) << "AddressBook::asyncLoad()";
 
   clear();
 
@@ -357,7 +366,7 @@ bool AddressBook::asyncLoad()
   for ( it = d->mManager->activeBegin(); it != d->mManager->activeEnd(); ++it ) {
     d->mPendingLoadResources.append( *it );
     if ( !(*it)->asyncLoad() ) {
-      error( i18n("Unable to load resource '%1'",  (*it)->resourceName() ) );
+      error( i18n( "Unable to load resource '%1'", (*it)->resourceName() ) );
       ok = false;
     }
   }
@@ -367,12 +376,13 @@ bool AddressBook::asyncLoad()
 
 bool AddressBook::save( Ticket *ticket )
 {
-  kDebug(5700) << "AddressBook::save()"<< endl;
+  kDebug(5700) << "AddressBook::save()";
 
   if ( ticket->resource() ) {
-    deleteRemovedAddressees();
     bool ok = ticket->resource()->save( ticket );
-    if ( ok ) ticket->resource()->releaseSaveTicket( ticket );
+    if ( ok ) {
+      ticket->resource()->releaseSaveTicket( ticket );
+    }
     return ok;
   }
 
@@ -381,12 +391,14 @@ bool AddressBook::save( Ticket *ticket )
 
 bool AddressBook::asyncSave( Ticket *ticket )
 {
-  kDebug(5700) << "AddressBook::asyncSave()"<< endl;
+  kDebug(5700) << "AddressBook::asyncSave()";
 
   if ( ticket->resource() ) {
     d->mPendingSaveResources.append( ticket->resource() );
     bool ok = ticket->resource()->asyncSave( ticket );
-    if ( ok ) ticket->resource()->releaseSaveTicket( ticket );
+    if ( ok ) {
+      ticket->resource()->releaseSaveTicket( ticket );
+    }
     return ok;
   }
 
@@ -397,24 +409,28 @@ AddressBook::Iterator AddressBook::begin()
 {
   QList<Resource*> list;
   KRES::Manager<Resource>::ActiveIterator resIt;
-  for ( resIt = d->mManager->activeBegin(); resIt != d->mManager->activeEnd(); ++resIt )
+  for ( resIt = d->mManager->activeBegin();
+        resIt != d->mManager->activeEnd(); ++resIt ) {
     list.append( *resIt );
+  }
 
-  if ( list.count() == 0 )
+  if ( list.count() == 0 ) {
     return end();
+  }
 
   Iterator it = Iterator();
   it.d->mResources = list;
   it.d->mCurrRes = 0;
-  it.d->mIt = (it.d->mResources[ it.d->mCurrRes ])->begin();
+  it.d->mIt = ( it.d->mResources[ it.d->mCurrRes ] )->begin();
 
-  while ( it.d->mIt == (it.d->mResources[ it.d->mCurrRes ])->end() ) {
-    if ( it.d->mCurrRes == it.d->mResources.count() - 1 )
+  while ( it.d->mIt == ( it.d->mResources[ it.d->mCurrRes ] )->end() ) {
+    if ( it.d->mCurrRes == it.d->mResources.count() - 1 ) {
       return end();
+    }
 
     it.d->mCurrRes++;
 
-    it.d->mIt = (it.d->mResources[ it.d->mCurrRes ])->begin();
+    it.d->mIt = ( it.d->mResources[ it.d->mCurrRes ] )->begin();
   }
 
   return it;
@@ -424,24 +440,28 @@ AddressBook::ConstIterator AddressBook::begin() const
 {
   QList<Resource*> list;
   KRES::Manager<Resource>::ActiveIterator resIt;
-  for ( resIt = d->mManager->activeBegin(); resIt != d->mManager->activeEnd(); ++resIt )
+  for ( resIt = d->mManager->activeBegin();
+        resIt != d->mManager->activeEnd(); ++resIt ) {
     list.append( *resIt );
+  }
 
-  if ( list.count() == 0 )
+  if ( list.count() == 0 ) {
     return end();
+  }
 
   Iterator it = Iterator();
   it.d->mResources = list;
   it.d->mCurrRes = 0;
-  it.d->mIt = (it.d->mResources[ it.d->mCurrRes ])->begin();
+  it.d->mIt = ( it.d->mResources[ it.d->mCurrRes ] )->begin();
 
-  while ( it.d->mIt == (it.d->mResources[ it.d->mCurrRes ])->end() ) {
-    if ( it.d->mCurrRes == it.d->mResources.count() - 1 )
+  while ( it.d->mIt == ( it.d->mResources[ it.d->mCurrRes ] )->end() ) {
+    if ( it.d->mCurrRes == it.d->mResources.count() - 1 ) {
       return end();
+    }
 
     it.d->mCurrRes++;
 
-    it.d->mIt = (it.d->mResources[ it.d->mCurrRes ])->begin();
+    it.d->mIt = ( it.d->mResources[ it.d->mCurrRes ] )->begin();
   }
 
   return it;
@@ -451,7 +471,8 @@ AddressBook::Iterator AddressBook::end()
 {
   KRES::Manager<Resource>::ActiveIterator resIt = d->mManager->activeEnd();
 
-  if ( resIt == d->mManager->activeBegin() || ! *(--resIt) ) { // no resource available
+  if ( resIt == d->mManager->activeBegin() || ! *(--resIt) ) {
+    // no resource available
     d->end.d->mIt = Resource::Iterator();
   } else {
     d->end.d->mIt = (*resIt)->end();
@@ -464,7 +485,8 @@ AddressBook::ConstIterator AddressBook::end() const
 {
   KRES::Manager<Resource>::ActiveIterator resIt = d->mManager->activeEnd();
 
-  if ( resIt == d->mManager->activeBegin() || ! *(--resIt) ) { // no resource available
+  if ( resIt == d->mManager->activeBegin() || ! *(--resIt) ) {
+    // no resource available
     d->end.d->mIt = Resource::Iterator();
   } else {
     d->end.d->mIt = (*resIt)->end();
@@ -476,24 +498,27 @@ AddressBook::ConstIterator AddressBook::end() const
 void AddressBook::clear()
 {
   KRES::Manager<Resource>::ActiveIterator it;
-  for ( it = d->mManager->activeBegin(); it != d->mManager->activeEnd(); ++it )
+  for ( it = d->mManager->activeBegin(); it != d->mManager->activeEnd(); ++it ) {
     (*it)->clear();
+  }
 }
 
 Ticket *AddressBook::requestSaveTicket( Resource *resource )
 {
-  kDebug(5700) << "AddressBook::requestSaveTicket()" << endl;
+  kDebug(5700) << "AddressBook::requestSaveTicket()";
 
-  if ( !resource )
+  if ( !resource ) {
     resource = standardResource();
+  }
 
   KRES::Manager<Resource>::ActiveIterator it;
   for ( it = d->mManager->activeBegin(); it != d->mManager->activeEnd(); ++it ) {
     if ( (*it) == resource ) {
-      if ( (*it)->readOnly() || !(*it)->isOpen() )
+      if ( (*it)->readOnly() || !(*it)->isOpen() ) {
         return 0;
-      else
+      } else {
         return (*it)->requestSaveTicket();
+      }
     }
   }
 
@@ -502,8 +527,9 @@ Ticket *AddressBook::requestSaveTicket( Resource *resource )
 
 void AddressBook::releaseSaveTicket( Ticket *ticket )
 {
-  if ( !ticket )
+  if ( !ticket ) {
     return;
+  }
 
   if ( ticket->resource() ) {
     ticket->resource()->releaseSaveTicket( ticket );
@@ -513,17 +539,18 @@ void AddressBook::releaseSaveTicket( Ticket *ticket )
 void AddressBook::insertAddressee( const Addressee &a )
 {
   Resource *resource = a.resource();
-  if ( resource == 0 )
+  if ( resource == 0 ) {
     resource = standardResource();
+  }
 
   Resource::Iterator it;
   Addressee fAddr = resource->findByUid( a.uid() );
 
   Addressee addr( a );
   if ( !fAddr.isEmpty() ) {
-    if ( fAddr != a )
+    if ( fAddr != a ) {
       addr.setRevision( QDateTime::currentDateTime() );
-    else {
+    } else {
       if ( fAddr.resource() == 0 ) {
         fAddr.setResource( resource );
         //NOTE: Should we have setChanged( true ) here?
@@ -540,22 +567,25 @@ void AddressBook::insertAddressee( const Addressee &a )
 
 void AddressBook::removeAddressee( const Addressee &a )
 {
-  if ( a.resource() )
+  if ( a.resource() ) {
     a.resource()->removeAddressee( a );
+  }
 }
 
 void AddressBook::removeAddressee( const Iterator &it )
 {
-  if ( (*it).resource() )
+  if ( (*it).resource() ) {
     (*it).resource()->removeAddressee( *it );
+  }
 }
 
 AddressBook::Iterator AddressBook::find( const Addressee &a )
 {
   Iterator it;
   for ( it = begin(); it != end(); ++it ) {
-    if ( a.uid() == (*it).uid() )
+    if ( a.uid() == (*it).uid() ) {
       return it;
+    }
   }
 
   return end();
@@ -566,8 +596,9 @@ Addressee AddressBook::findByUid( const QString &uid ) const
   KRES::Manager<Resource>::ActiveIterator it;
   for ( it = d->mManager->activeBegin(); it != d->mManager->activeEnd(); ++it ) {
     Addressee addr = (*it)->findByUid( uid );
-    if ( !addr.isEmpty() )
+    if ( !addr.isEmpty() ) {
       return addr;
+    }
   }
 
   return Addressee();
@@ -578,8 +609,9 @@ Addressee::List AddressBook::allAddressees() const
   Addressee::List list;
 
   ConstIterator it;
-  for ( it = begin(); it != end(); ++it )
+  for ( it = begin(); it != end(); ++it ) {
     list.append( *it );
+  }
 
   return list;
 }
@@ -589,8 +621,9 @@ Addressee::List AddressBook::findByName( const QString &name ) const
   Addressee::List results;
 
   KRES::Manager<Resource>::ActiveIterator it;
-  for ( it = d->mManager->activeBegin(); it != d->mManager->activeEnd(); ++it )
+  for ( it = d->mManager->activeBegin(); it != d->mManager->activeEnd(); ++it ) {
     results += (*it)->findByName( name );
+  }
 
   return results;
 }
@@ -600,8 +633,9 @@ Addressee::List AddressBook::findByEmail( const QString &email ) const
   Addressee::List results;
 
   KRES::Manager<Resource>::ActiveIterator it;
-  for ( it = d->mManager->activeBegin(); it != d->mManager->activeEnd(); ++it )
+  for ( it = d->mManager->activeBegin(); it != d->mManager->activeEnd(); ++it ) {
     results += (*it)->findByEmail( email );
+  }
 
   return results;
 }
@@ -611,33 +645,34 @@ Addressee::List AddressBook::findByCategory( const QString &category ) const
   Addressee::List results;
 
   KRES::Manager<Resource>::ActiveIterator it;
-  for ( it = d->mManager->activeBegin(); it != d->mManager->activeEnd(); ++it )
+  for ( it = d->mManager->activeBegin(); it != d->mManager->activeEnd(); ++it ) {
     results += (*it)->findByCategory( category );
+  }
 
   return results;
 }
 
 void AddressBook::dump() const
 {
-  kDebug(5700) << "AddressBook::dump() --- begin ---" << endl;
+  kDebug(5700) << "AddressBook::dump() --- begin ---";
 
   ConstIterator it;
   for ( it = begin(); it != end(); ++it ) {
-    (*it).dump();
+    kDebug(5700) << (*it).toString();
   }
 
-  kDebug(5700) << "AddressBook::dump() ---  end  ---" << endl;
+  kDebug(5700) << "AddressBook::dump() ---  end  ---";
 }
 
 QString AddressBook::identifier() const
 {
   QStringList identifier;
 
-
   KRES::Manager<Resource>::ActiveIterator it;
   for ( it = d->mManager->activeBegin(); it != d->mManager->activeEnd(); ++it ) {
-    if ( !(*it)->identifier().isEmpty() )
+    if ( !(*it)->identifier().isEmpty() ) {
       identifier.append( (*it)->identifier() );
+    }
   }
 
   return identifier.join( ":" );
@@ -649,20 +684,25 @@ Field::List AddressBook::fields( int category ) const
     d->mAllFields = Field::allFields();
   }
 
-  if ( category == Field::All ) return d->mAllFields;
+  if ( category == Field::All ) {
+    return d->mAllFields;
+  }
 
   Field::List result;
   Field::List::ConstIterator it;
   for ( it = d->mAllFields.constBegin(); it != d->mAllFields.constEnd(); ++it ) {
-    if ( (*it)->category() & category )
+    if ( (*it)->category() & category ) {
       result.append( *it );
+    }
   }
 
   return result;
 }
 
-bool AddressBook::addCustomField( const QString &label, int category,
-                                  const QString &key, const QString &app )
+bool AddressBook::addCustomField( const QString &label,
+                                  int category,
+                                  const QString &key,
+                                  const QString &app ) const
 {
   if ( d->mAllFields.isEmpty() ) {
     d->mAllFields = Field::allFields();
@@ -673,7 +713,9 @@ bool AddressBook::addCustomField( const QString &label, int category,
 
   Field *field = Field::createCustomField( label, category, k, a );
 
-  if ( !field ) return false;
+  if ( !field ) {
+    return false;
+  }
 
   d->mAllFields.append( field );
 
@@ -682,24 +724,26 @@ bool AddressBook::addCustomField( const QString &label, int category,
 
 QDataStream &KABC::operator<<( QDataStream &s, const AddressBook &ab )
 {
-  if (!ab.d) return s;
+  if ( !ab.d ) {
+    return s;
+  }
 
   return s;// << ab.d->mAddressees;
 }
 
 QDataStream &KABC::operator>>( QDataStream &s, AddressBook &ab )
 {
-  if (!ab.d) return s;
+  if ( !ab.d ) {
+    return s;
+  }
 
-//  s >> ab.d->mAddressees;
-
-  return s;
+  return s;//  s >> ab.d->mAddressees;
 }
 
 bool AddressBook::addResource( Resource *resource )
 {
   if ( !resource->open() ) {
-    kDebug(5700) << "AddressBook::addResource(): can't add resource" << endl;
+    kDebug(5700) << "AddressBook::addResource(): can't add resource";
     return false;
   }
 
@@ -723,8 +767,9 @@ bool AddressBook::removeResource( Resource *resource )
 {
   resource->close();
 
-  if ( resource == standardResource() )
+  if ( resource == standardResource() ) {
     d->mManager->setStandardResource( 0 );
+  }
 
   resource->setAddressBook( 0 );
 
@@ -749,10 +794,11 @@ QList<Resource*> AddressBook::resources() const
 
   KRES::Manager<Resource>::ActiveIterator it;
   for ( it = d->mManager->activeBegin(); it != d->mManager->activeEnd(); ++it ) {
-    if ( d->mManager->standardResource() == (*it) )
+    if ( d->mManager->standardResource() == (*it) ) {
       list.prepend( *it );
-    else
+    } else {
       list.append( *it );
+    }
   }
 
   return list;
@@ -764,20 +810,18 @@ void AddressBook::setErrorHandler( ErrorHandler *handler )
   d->mErrorHandler = handler;
 }
 
-void AddressBook::error( const QString& msg )
+void AddressBook::error( const QString &msg )
 {
-  if ( !d->mErrorHandler ) // create default error handler
-    d->mErrorHandler = new ConsoleErrorHandler;
+  if ( !d->mErrorHandler ) {
+    // create default error handler
+    d->mErrorHandler = new ConsoleErrorHandler();
+  }
 
-  if ( d->mErrorHandler )
+  if ( d->mErrorHandler ) {
     d->mErrorHandler->error( msg );
-  else
-    kError(5700) << "no error handler defined" << endl;
-}
-
-void AddressBook::deleteRemovedAddressees()
-{
-  // no any longer needed
+  } else {
+    kError(5700) << "no error handler defined";
+  }
 }
 
 void AddressBook::setStandardResource( Resource *resource )
@@ -800,34 +844,38 @@ bool AddressBook::loadingHasFinished() const
   return d->mPendingLoadResources.isEmpty();
 }
 
-void AddressBook::resourceLoadingFinished( Resource *res )
+void AddressBook::resourceLoadingFinished( Resource *resource )
 {
-  d->mPendingLoadResources.removeAll( res );
-  emit loadingFinished( res );
+  d->mPendingLoadResources.removeAll( resource );
+  emit loadingFinished( resource );
 
-  if ( d->mPendingLoadResources.count() == 0 )
+  if ( d->mPendingLoadResources.count() == 0 ) {
     emit addressBookChanged( this );
+  }
 }
 
-void AddressBook::resourceSavingFinished( Resource *res )
+void AddressBook::resourceSavingFinished( Resource *resource )
 {
-  d->mPendingLoadResources.removeAll( res );
+  d->mPendingSaveResources.removeAll( resource );
 
-  emit savingFinished( res );
+  emit savingFinished( resource );
 }
 
-void AddressBook::resourceLoadingError( Resource *res, const QString &errMsg )
+void AddressBook::resourceLoadingError( Resource *resource,
+                                        const QString &errMsg )
 {
   error( errMsg );
 
-  d->mPendingLoadResources.removeAll( res );
-  if ( d->mPendingLoadResources.count() == 0 )
+  d->mPendingLoadResources.removeAll( resource );
+  if ( d->mPendingLoadResources.count() == 0 ) {
     emit addressBookChanged( this );
+  }
 }
 
-void AddressBook::resourceSavingError( Resource *res, const QString &errMsg )
+void AddressBook::resourceSavingError( Resource *resource,
+                                       const QString &errMsg )
 {
   error( errMsg );
 
-  d->mPendingSaveResources.removeAll( res );
+  d->mPendingSaveResources.removeAll( resource );
 }
