@@ -21,13 +21,13 @@
 #ifndef KABC_ADDRESSBOOK_H
 #define KABC_ADDRESSBOOK_H
 
-#include <QObject>
-#include <QList>
+#include "addressee.h"
+#include "field.h"
 
 #include "kresources/manager.h"
 
-#include "addressee.h"
-#include "field.h"
+#include <QtCore/QObject>
+#include <QtCore/QList>
 
 namespace KABC {
 
@@ -44,8 +44,10 @@ class KABC_EXPORT AddressBook : public QObject
 {
   Q_OBJECT
 
-  friend KABC_EXPORT QDataStream &operator<<( QDataStream &, const AddressBook & );
-  friend KABC_EXPORT QDataStream &operator>>( QDataStream &, AddressBook & );
+  friend KABC_EXPORT QDataStream &operator<<( QDataStream &lhs,
+                                              const AddressBook &rhs );
+  friend KABC_EXPORT QDataStream &operator>>( QDataStream &lhs,
+                                              AddressBook &rhs );
   friend class StdAddressBook;
 
   public:
@@ -54,92 +56,103 @@ class KABC_EXPORT AddressBook : public QObject
 
       This class provides an iterator for address book entries.
      */
-    class KABC_EXPORT Iterator
+    class KABC_EXPORT Iterator  //krazy:exclude=dpointer
     {
+      friend class AddressBook;
       public:
         /**
-         * Default constructor
-         */
+          Default constructor
+        */
         Iterator();
+
         /**
-         * Copy constructor
-         */
+          Copy constructor
+        */
         Iterator( const Iterator & );
         ~Iterator();
 
         /**
-         * Assignment operator. Assignes the given iterator to
-         * @c *this.
-         *
-         * @return this iterator, @c *this
-         */
+          Assignment operator. Assignes the given iterator to @c *this.
+
+          @return this iterator, @c *this
+        */
         Iterator &operator=( const Iterator & );
+
         /**
-         * Constant Dereference operator.
-         * @note For invalid iterators, the result is undefined.
-         *
-         * @return the @c const Addressee object the iterator points to.
-         */
+          Constant Dereference operator.
+          @note For invalid iterators, the result is undefined.
+
+          @return the @c const Addressee object the iterator points to.
+        */
         const Addressee &operator*() const;
+
         /**
-         * Dereference operator.
-         * @note For invalid iterators, the result is undefined.
-         *
-         * @return the Addressee object the iterator points to.
-         */
+          Dereference operator.
+          @note For invalid iterators, the result is undefined.
+
+          @return the Addressee object the iterator points to.
+        */
         Addressee &operator*();
+
         /**
-         * Arrow Dereference operator, provided for convenience.
-         * @note For invalid iterators, the result is undefined.
-         *
-         * @return the Addressee object the iterator points to.
-         */
-        Addressee* operator->();
+          Arrow Dereference operator, provided for convenience.
+          @note For invalid iterators, the result is undefined.
+
+          @return the Addressee object the iterator points to.
+        */
+        Addressee *operator->();
+
         /**
-         * Preincrement operator. Advances the iterator by one.
-         *
-         * @return this iterator, @c *this
-         */
+          Preincrement operator. Advances the iterator by one.
+
+          @return this iterator, @c *this
+        */
         Iterator &operator++();
+
         /**
-         * Postincrement operator. Advances the iterator by one.
-         * @note This function does not copy the iterator object.
-         *
-         * @return this iterator, @c *this
-         */
+          Postincrement operator. Advances the iterator by one.
+          @note This function does not copy the iterator object.
+
+          @return this iterator, @c *this
+        */
         Iterator &operator++(int);
+
         /**
-         * Predecrement operator. Decreases the iterator by one.
-         *
-         * @return this iterator, @c *this
-         */
+          Predecrement operator. Decreases the iterator by one.
+
+          @return this iterator, @c *this
+        */
         Iterator &operator--();
+
         /**
-         * Postdecrement operator. Decreases the iterator by one.
-         * @note This function does not copy the iterator object.
-         *
-         * @return this iterator, @c *this
-         */
+          Postdecrement operator. Decreases the iterator by one.
+          @note This function does not copy the iterator object.
+
+          @return this iterator, @c *this
+        */
         Iterator &operator--(int);
+
         /**
-         * Equality operator. Compares this iterator to @p it
-         *
-         * @param it the iterator to compare this iterator to
-         * @return @c true if both iterators are equal,
-         *         @c false otherwise
-         */
+          Equality operator. Compares this iterator to @p it
+
+          @param it the iterator to compare this iterator to
+          @return @c true if both iterators are equal,
+                  @c false otherwise
+        */
         bool operator==( const Iterator &it ) const;
+
         /**
-         * Inequality operator. Compares this iterator to @p it
-         *
-         * @param it the iterator to compare this iterator to
-         * @return @c true if the iterators are not equal,
-         *         @c false otherwise
-         */
+          Inequality operator. Compares this iterator to @p it
+
+          @param it the iterator to compare this iterator to
+          @return @c true if the iterators are not equal,
+                  @c false otherwise
+        */
         bool operator!=( const Iterator &it ) const;
 
+      private:
         struct IteratorData;
-        IteratorData *d;
+        IteratorData *const d;
     };
 
     /**
@@ -147,92 +160,103 @@ class KABC_EXPORT AddressBook : public QObject
 
       This class provides a const iterator for address book entries.
      */
-    class KABC_EXPORT ConstIterator
+    class KABC_EXPORT ConstIterator //krazy:exclude=dpointer
     {
+      friend class AddressBook;
       public:
         /**
          * Default constructor
          */
         ConstIterator();
+
         /**
-         * Copy constructor
-         */
+          Copy constructor
+        */
         ConstIterator( const ConstIterator & );
+
         /**
-         * Copy constructor. Constructs a ConstIterator from
-         * an non-@c const Iterator
-         */
+          Copy constructor. Constructs a ConstIterator from
+          an non-@c const Iterator
+        */
         ConstIterator( const Iterator & );
         ~ConstIterator();
 
         /**
-         * Assignment operator. Assignes the given iterator to
-         * @c *this.
-         *
-         * @return this iterator, @c *this
-         */
+          Assignment operator. Assignes the given iterator to @c *this.
+
+          @return this iterator, @c *this
+        */
         ConstIterator &operator=( const ConstIterator & );
+
         /**
-         * Constant Dereference operator.
-         * @note For invalid iterators, the result is undefined.
-         * @note Unlike in Iterator, there is no non-constant
-         *       dereference operator.
-         *
-         * @return the @c const Addressee object the iterator points to.
-         */
+          Constant Dereference operator.
+          @note For invalid iterators, the result is undefined.
+          @note Unlike in Iterator, there is no non-constant
+                dereference operator.
+
+          @return the @c const Addressee object the iterator points to.
+        */
         const Addressee &operator*() const;
+
         /**
-         * Arrow Dereference operator, provided for convenience.
-         * @note For invalid iterators, the result is undefined.
-         *
-         * @return the Addressee object the iterator points to.
-         */
-        const Addressee* operator->() const;
+          Arrow Dereference operator, provided for convenience.
+          @note For invalid iterators, the result is undefined.
+
+          @return the Addressee object the iterator points to.
+        */
+        const Addressee *operator->() const;
+
         /**
-         * Preincrement operator. Advances the iterator by one.
-         *
-         * @return this iterator, @c *this
-         */
+          Preincrement operator. Advances the iterator by one.
+
+          @return this iterator, @c *this
+        */
         ConstIterator &operator++();
+
         /**
-         * Postincrement operator. Advances the iterator by one.
-         * @note This function does not copy the iterator object.
-         *
-         * @return this iterator, @c *this
-         */
+          Postincrement operator. Advances the iterator by one.
+          @note This function does not copy the iterator object.
+
+          @return this iterator, @c *this
+        */
         ConstIterator &operator++(int);
+
         /**
-         * Predecrement operator. Decreases the iterator by one.
-         *
-         * @return this iterator, @c *this
-         */
+          Predecrement operator. Decreases the iterator by one.
+
+          @return this iterator, @c *this
+        */
         ConstIterator &operator--();
+
         /**
-         * Postdecrement operator. Decreases the iterator by one.
-         * @note This function does not copy the iterator object.
-         *
-         * @return this iterator, @c *this
-         */
+          Postdecrement operator. Decreases the iterator by one.
+          @note This function does not copy the iterator object.
+
+          @return this iterator, @c *this
+        */
         ConstIterator &operator--(int);
+
         /**
-         * Equality operator. Compares this iterator to @p it
-         *
-         * @param it the iterator to compare this iterator to
-         * @return @c true if both iterators are equal,
-         *         @c false otherwise
-         */
+          Equality operator. Compares this iterator to @p it
+
+          @param it the iterator to compare this iterator to
+          @return @c true if both iterators are equal,
+                  @c false otherwise
+        */
         bool operator==( const ConstIterator &it ) const;
+
         /**
-         * Inequality operator. Compares this iterator to @p it
-         *
-         * @param it the iterator to compare this iterator to
-         * @return @c true if the iterators are not equal,
-         *         @c false otherwise
-         */
+          Inequality operator. Compares this iterator to @p it
+
+          @param it the iterator to compare this iterator to
+          @return @c true if the iterators are not equal,
+                  @c false otherwise
+        */
         bool operator!=( const ConstIterator &it ) const;
 
+      private:
         struct ConstIteratorData;
-        ConstIteratorData *d;
+        ConstIteratorData *const d;
     };
 
     /**
@@ -270,6 +294,8 @@ class KABC_EXPORT AddressBook : public QObject
     /**
       Releases the ticket requested previously with requestSaveTicket().
       Call this function, if you want to release a ticket without saving.
+
+      @param ticket the save ticket aquired with requestSaveTicket()
      */
     void releaseSaveTicket( Ticket *ticket );
 
@@ -331,7 +357,6 @@ class KABC_EXPORT AddressBook : public QObject
      */
     Iterator end();
 
-
     /**
       Removes all addressees from the address book.
      */
@@ -377,6 +402,7 @@ class KABC_EXPORT AddressBook : public QObject
               empty addressee.
      */
     Addressee findByUid( const QString &uid ) const;
+
     /**
       Returns a list of all addressees in the address book.
      */
@@ -413,8 +439,8 @@ class KABC_EXPORT AddressBook : public QObject
     virtual QString identifier() const;
 
     /**
-      Returns a list of all Fields known to the address book which are associated
-      with the given field category.
+      Returns a list of all Fields known to the address book which are
+      associated with the given field category.
      */
     Field::List fields( int category = Field::All ) const;
 
@@ -429,7 +455,7 @@ class KABC_EXPORT AddressBook : public QObject
      */
     bool addCustomField( const QString &label, int category = Field::All,
                          const QString &key = QString(),
-                         const QString &app = QString() );
+                         const QString &app = QString() ) const;
 
     /**
       Adds a resource to the address book.
@@ -474,10 +500,17 @@ class KABC_EXPORT AddressBook : public QObject
     void dump() const;
 
     /**
-      */
-    void emitAddressBookLocked() { emit addressBookLocked( this ); }
-    void emitAddressBookUnlocked() { emit addressBookUnlocked( this ); }
-    void emitAddressBookChanged() { emit addressBookChanged( this ); }
+      Emits the signal addressBookLocked() using @c this as the parameter
+     */
+    void emitAddressBookLocked() { addressBookLocked( this ); }
+    /**
+      Emits the signal addressBookUnlocked() using @c this as the parameter
+     */
+    void emitAddressBookUnlocked() { addressBookUnlocked( this ); }
+    /**
+      Emits the signal addressBookChanged() using @c this as the parameter
+     */
+    void emitAddressBookChanged() { addressBookChanged( this ); }
 
     /**
       Returns true when the loading of the addressbook has finished,
@@ -530,24 +563,82 @@ class KABC_EXPORT AddressBook : public QObject
     void savingFinished( Resource *resource );
 
   protected Q_SLOTS:
-    void resourceLoadingFinished( Resource* );
-    void resourceSavingFinished( Resource* );
-    void resourceLoadingError( Resource*, const QString& );
-    void resourceSavingError( Resource*, const QString& );
+    /**
+      Handles loading success.
+
+      Resource will be removed from the list of those pending for loading
+      and signal loadingFinished() will be emitted.
+      It this has been the last one in this list, signal addressBookChanged()
+      is emitted as well.
+
+      @param resource The resource which has been saved successfully.
+     */
+    void resourceLoadingFinished( Resource *resource );
+
+    /**
+      Handles saving success.
+
+      Resource will be removed from the list of those pending for saving.
+
+      @param resource The resource which has been saved successfully.
+     */
+    void resourceSavingFinished( Resource *resource );
+
+    /**
+      Handles loading errors.
+
+      Resource will be removed from the list of those pending for loading.
+      If this has been the last one in this list, signal addressBookChanged()
+      is emitted.
+
+      @param resource The resource which could not be loaded.
+      @param errMsg The message describing the error. See error()
+     */
+    void resourceLoadingError( Resource *resource, const QString &errMsg );
+
+    /**
+      Handles saving errors.
+
+      Resource will be removed from the list of those pending for saving.
+
+      @param resource The resource which could not be saved.
+      @param errMsg The message describing the error. See error()
+     */
+    void resourceSavingError( Resource *resource, const QString &errMsg );
 
   protected:
-    void deleteRemovedAddressees();
-    void setStandardResource( Resource* );
+    /**
+      Sets the resource manager's standard resource.
+
+      Convenience method for resourceManager()->setStandardResource()
+
+      @param resource The resource to use as the standard
+
+      @see standardResource()
+     */
+    void setStandardResource( Resource *resource );
+
+    /**
+      Returns the addressbook resource manager's standard resource.
+
+      Convenience method for resourceManager()->standardResource()
+
+      @see setStandardResource()
+     */
     Resource *standardResource();
+
+    /**
+      Returns the addressbook's resource manager.
+     */
     KRES::Manager<Resource> *resourceManager();
 
   private:
-    struct AddressBookData;
-    AddressBookData *d;
+    class Private;
+    Private *const d;
 };
 
-KABC_EXPORT QDataStream &operator<<( QDataStream &, const AddressBook & );
-KABC_EXPORT QDataStream &operator>>( QDataStream &, AddressBook & );
+KABC_EXPORT QDataStream &operator<<( QDataStream &lhs, const AddressBook &rhs );
+KABC_EXPORT QDataStream &operator>>( QDataStream &lhs, AddressBook &rhs );
 
 }
 
