@@ -22,13 +22,15 @@
 #ifndef KABC_ADDRESSEELIST_H
 #define KABC_ADDRESSEELIST_H
 
-#include "addressee.h"
+#include "kabc_export.h"
+#include <QtCore/QSharedDataPointer>
+#include <QtCore/QList>
 
 namespace KABC {
 
 class Field;
-class SortField;
 class SortMode;
+class Addressee;
 
 /**
  * Each trait must implement one static function for equality, one for "less
@@ -45,36 +47,207 @@ namespace SortingTraits
 class KABC_EXPORT Uid
 {
   public:
+    /**
+     * Creates an instance.
+     */
+    Uid();
+
+    /**
+     * Destroys the instance.
+     */
+    ~Uid();
+
+    /**
+     * "Equal" compare method
+     *
+     * @return @c true if the first parameter is equal to the second
+     *         when comparing the uid attribute.
+     *
+     * @see Addressee::uid()
+     * @see QString::compare()
+     */
     static bool eq( const Addressee &, const Addressee & );
+
+    /**
+     * "Less-Than" compare method
+     *
+     * @return @c true if the first parameter is "less-than" the second
+     *         when comparing the uid attribute.
+     *
+     * @see Addressee::uid()
+     * @see QString::compare()
+     */
     static bool lt( const Addressee &, const Addressee & );
+
+  private:
+    class Private;
+    Private *const d;
 };
 
 class KABC_EXPORT Name
 {
   public:
+    /**
+     * Creates an instance.
+     */
+    Name();
+
+    /**
+     * Destroys the instance.
+     */
+    ~Name();
+
+    /**
+     * "Equal" compare method
+     *
+     * @return @c true if the first parameter is equal to the second
+     *         when comparing the name attribute.
+     *
+     * @see Addressee::name()
+     * @see QString::localeAwareCompare()
+     */
     static bool eq( const Addressee &, const Addressee & );
+
+    /**
+     * "Less-Than" compare method
+     *
+     * @return @c true if the first parameter is "less-than" the second
+     *         when comparing the name attribute.
+     *
+     * @see Addressee::name()
+     * @see QString::localeAwareCompare()
+     */
     static bool lt( const Addressee &, const Addressee & );
+
+  private:
+    class Private;
+    Private *const d;
 };
 
 class KABC_EXPORT FormattedName
 {
   public:
+    /**
+     * Creates an instance.
+     */
+    FormattedName();
+
+    /**
+     * Destroys the instance.
+     */
+    ~FormattedName();
+
+    /**
+     * "Equal" compare method
+     *
+     * @return @c true if the first parameter is equal to the second
+     *         when comparing the formatted name attribute.
+     *
+     * @see Addressee::formattedName()
+     * @see QString::localeAwareCompare()
+     */
     static bool eq( const Addressee &, const Addressee & );
+
+    /**
+     * "Less-Than" compare method
+     *
+     * @return @c true if the first parameter is "less-than" the second
+     *         when comparing the formatted name attribute.
+     *
+     * @see Addressee::formattedName()
+     * @see QString::localeAwareCompare()
+     */
     static bool lt( const Addressee &, const Addressee & );
+
+  private:
+    class Private;
+    Private *const d;
 };
 
 class KABC_EXPORT FamilyName // fallback to given name
 {
   public:
+    /**
+     * Creates an instance.
+     */
+    FamilyName();
+
+    /**
+     * Destroys the instance.
+     */
+    ~FamilyName();
+
+    /**
+     * "Equal" compare method
+     *
+     * @return @c true if the first parameter is equal to the second
+     *         when comparing the family name and given name attributes.
+     *
+     * @see Addressee::familyName()
+     * @see Addressee::givenName()
+     * @see QString::localeAwareCompare()
+     */
     static bool eq( const Addressee &, const Addressee & );
+
+    /**
+     * "Less-Than" compare method
+     *
+     * Falls back to comparing given name if equal
+     *
+     * @return @c true if the first parameter is "less-than" the second
+     *         when comparing the family name attribute.
+     *
+     * @see Addressee::familyName()
+     * @see QString::localeAwareCompare()
+     */
     static bool lt( const Addressee &, const Addressee & );
+
+  private:
+    class Private;
+    Private *const d;
 };
 
 class KABC_EXPORT GivenName  // fallback to family name
 {
   public:
+    /**
+     * Creates an instance.
+     */
+    GivenName();
+
+    /**
+     * Destroys the instance.
+     */
+    ~GivenName();
+
+    /**
+     * "Equal" compare method
+     *
+     * @return @c true if the first parameter is equal to the second
+     *         when comparing the given name and family name attributes.
+     *
+     * @see Addressee::givenName()
+     * @see Addressee::familyName()
+     * @see QString::localeAwareCompare()
+     */
     static bool eq( const Addressee &, const Addressee & );
+
+    /**
+     * "Less-Than" compare method
+     *
+     * Falls back to comparing family name if equal
+     *
+     * @return @c true if the first parameter is "less-than" the second
+     *         when comparing the given name attribute.
+     *
+     * @see Addressee::givenName()
+     * @see QString::localeAwareCompare()
+     */
     static bool lt( const Addressee &, const Addressee & );
+
+  private:
+    class Private;
+    Private *const d;
 };
 
 }
@@ -82,7 +255,13 @@ class KABC_EXPORT GivenName  // fallback to family name
 /**
  * Addressee attribute used for sorting.
  */
-typedef enum { Uid, Name, FormattedName, FamilyName, GivenName } SortingCriterion;
+typedef enum {
+  Uid,
+  Name,
+  FormattedName,
+  FamilyName,
+  GivenName
+} SortingCriterion;
 
 /**
  * @short  a QValueList of Addressee, with sorting functionality
@@ -110,28 +289,47 @@ typedef enum { Uid, Name, FormattedName, FamilyName, GivenName } SortingCriterio
 class KABC_EXPORT AddresseeList : public QList<Addressee>
 {
   public:
+    /**
+     * Creates a new addressee list.
+     */
     AddresseeList();
-    ~AddresseeList();
+
+    /**
+     * Creates a new addressee list.
+     */
     AddresseeList( const AddresseeList & );
+
+    /**
+     * Creates a new addressee list.
+     */
     AddresseeList( const QList<Addressee> & );
 
     /**
-     * Debug output.
+     * Destroys the addressee list.
      */
-    void dump() const;
+    ~AddresseeList();
+
+    /**
+     * Assignment operator.
+     *
+     * @param other the list to assign from
+     * @return a reference to @c this
+     */
+    AddresseeList &operator=( const AddresseeList &other );
 
     /**
      * Determines the direction of sorting. On change, the list
      * will <em>not</em> automatically be resorted.
-     * @param r   <tt>true</tt> if sorting should be done reverse, <tt>false</tt> otherwise
+     * @param reverseSorting <tt>true</tt> if sorting should be done reverse,
+     *                       <tt>false</tt> otherwise
      */
-    void setReverseSorting( bool r = true ) { mReverseSorting = r; }
+    void setReverseSorting( bool reverseSorting = true );
 
     /**
      * Returns the direction of sorting.
      * @return    <tt>true</tt> if sorting is done reverse, <tt>false</tt> otherwise
      */
-    bool reverseSorting() const { return mReverseSorting; }
+    bool reverseSorting() const;
 
     /**
      * Sorts this list by a specific criterion.
@@ -196,7 +394,7 @@ class KABC_EXPORT AddresseeList : public QList<Addressee>
      * Returns the active sorting criterion, ie the sorting criterion that
      * will be used by a {@link #sort} call.
      */
-    SortingCriterion sortingCriterion() const { return mActiveSortingCriterion; }
+    SortingCriterion sortingCriterion() const;
 
     /**
      * Returns the active sorting field, ie a pointer to the Field object
@@ -205,20 +403,18 @@ class KABC_EXPORT AddresseeList : public QList<Addressee>
      * the class specific one.
      * You're a lot better off by keeping track of this locally.
      */
-    Field* sortingField() const;
+    Field *sortingField() const;
+
+    /**
+     * Returns a string representation of the addressee list.
+     */
+    QString toString() const;
 
   private:
-    bool mReverseSorting;
-    SortingCriterion mActiveSortingCriterion;
-    //KDE 4.0 - add a d-pointer here!
+    class Private;
+    QSharedDataPointer<Private> d;
 };
 
-// needed for msvc, 
-inline uint qHash(const Addressee &adr)
-{
-    return qHash(adr.uid());
-}
-
 }
 
 #endif
