@@ -21,9 +21,8 @@
 #ifndef KABC_LOCKNULL_H
 #define KABC_LOCKNULL_H
 
-#include <QString>
-
 #include "lock.h"
+#include <QtCore/QString>
 
 namespace KABC {
 
@@ -43,10 +42,8 @@ class KABC_EXPORT LockNull : public Lock
     QString error() const;
 
   private:
-    bool mAllowAccess;
-
     class Private;
-    Private *d;
+    Private *const d;
 };
 
 }
