@@ -18,88 +18,126 @@
     Boston, MA 02110-1301, USA.
 */
 
-#include <QDataStream>
+#include "phonenumber.h"
 
 #include <klocale.h>
 #include <krandom.h>
 
-#include "phonenumber.h"
+#include <QtCore/QDataStream>
+#include <QtCore/QSharedData>
 
 using namespace KABC;
 
-PhoneNumber::PhoneNumber() :
-  mType( Home )
+static QString cleanupNumber( const QString &input )
 {
-  init();
+  return input.simplified();
 }
 
-PhoneNumber::PhoneNumber( const QString &number, int type ) :
-  mType( type )
+class PhoneNumber::Private : public QSharedData
 {
-  init();
+  public:
+    Private( Type type )
+      : mId( KRandom::randomString( 8 ) ), mType( type )
+    {
+    }
 
-  validateNumber( number );
+    Private( const Private &other )
+      : QSharedData( other )
+    {
+      mId = other.mId;
+      mType = other.mType;
+      mNumber = other.mNumber;
+    }
+
+    QString mId;
+    Type mType;
+    QString mNumber;
+};
+
+PhoneNumber::PhoneNumber()
+  : d( new Private( Home ) )
+{
+}
+
+PhoneNumber::PhoneNumber( const QString &number, Type type )
+  : d( new Private( type ) )
+{
+  d->mNumber = cleanupNumber( number );
+}
+
+PhoneNumber::PhoneNumber( const PhoneNumber &other )
+  : d( other.d )
+{
 }
 
 PhoneNumber::~PhoneNumber()
 {
 }
 
-void PhoneNumber::init()
+bool PhoneNumber::operator==( const PhoneNumber &other ) const
 {
-  mId = KRandom::randomString( 8 );
-}
+  if ( d->mId != other.d->mId ) {
+    return false;
+  }
 
-void PhoneNumber::validateNumber( const QString &number )
-{
-  mNumber = number;
+  if ( d->mNumber != other.d->mNumber ) {
+    return false;
+  }
 
-  // remove line breaks
-  mNumber = mNumber.replace( '\n', "" );
-  mNumber = mNumber.replace( '\r', "" );
-}
-
-bool PhoneNumber::operator==( const PhoneNumber &p ) const
-{
-  if ( mNumber != p.mNumber ) return false;
-  if ( mType != p.mType ) return false;
+  if ( d->mType != other.d->mType ) {
+    return false;
+  }
 
   return true;
 }
 
-bool PhoneNumber::operator!=( const PhoneNumber &p ) const
+bool PhoneNumber::operator!=( const PhoneNumber &other ) const
 {
-  return !( p == *this );
+  return !( other == *this );
+}
+
+PhoneNumber &PhoneNumber::operator=( const PhoneNumber &other )
+{
+  if ( this != &other ) {
+    d = other.d;
+  }
+
+  return *this;
+}
+
+bool PhoneNumber::isEmpty() const
+{
+  return d->mNumber.isEmpty();
 }
 
 void PhoneNumber::setId( const QString &id )
 {
-  mId = id;
+  d->mId = id;
 }
 
 QString PhoneNumber::id() const
 {
-  return mId;
+  return d->mId;
 }
 
 void PhoneNumber::setNumber( const QString &number )
 {
-  validateNumber( number );
+  d->mNumber = cleanupNumber( number );
 }
 
 QString PhoneNumber::number() const
 {
-  return mNumber;
+  return d->mNumber;
 }
 
-void PhoneNumber::setType( int type )
+void PhoneNumber::setType( Type type )
 {
-  mType = type;
+  d->mType = type;
 }
 
-int PhoneNumber::type() const
+PhoneNumber::Type PhoneNumber::type() const
 {
-  return mType;
+  return d->mType;
 }
 
 QString PhoneNumber::typeLabel() const
@@ -113,19 +151,15 @@ QString PhoneNumber::typeLabel() const
   for ( it = list.begin(); it != list.end(); ++it ) {
     if ( ( type() & (*it) ) && ( (*it) != Pref ) ) {
       label.append( ( first ? "" : "/" ) + typeLabel( *it ) );
-      if ( first )
+      if ( first ) {
         first = false;
+      }
     }
   }
 
   return label;
 }
 
-QString PhoneNumber::label() const
-{
-  return typeLabel( type() );
-}
-
 PhoneNumber::TypeList PhoneNumber::typeList()
 {
   static TypeList list;
@@ -138,78 +172,89 @@ PhoneNumber::TypeList PhoneNumber::typeList()
   return list;
 }
 
-QString PhoneNumber::label( int type )
+QString PhoneNumber::typeLabel( Type type )
 {
-  return typeLabel( type );
-}
-
-QString PhoneNumber::typeLabel( int type )
-{
-  if ( type & Pref )
+  if ( type & Pref ) {
     return i18nc( "Preferred phone", "Preferred" );
+  }
 
   switch ( type ) {
     case Home:
-      return i18nc("Home phone", "Home");
+      return i18nc( "Home phone", "Home" );
       break;
     case Work:
-      return i18nc("Work phone", "Work");
+      return i18nc( "Work phone", "Work" );
       break;
     case Msg:
-      return i18n("Messenger");
-      break;  
+      return i18n( "Messenger" );
+      break;
     case Pref:
-      return i18n("Preferred Number");
+      return i18n( "Preferred Number" );
       break;
     case Voice:
-      return i18n("Voice");
-      break;  
+      return i18n( "Voice" );
+      break;
     case Fax:
-      return i18n("Fax");
-      break;  
+      return i18n( "Fax" );
+      break;
     case Cell:
-      return i18nc("Mobile Phone", "Mobile" );
-      break;  
+      return i18nc( "Mobile Phone", "Mobile" );
+      break;
     case Video:
-      return i18n("Video");
+      return i18n( "Video" );
       break;
     case Bbs:
-      return i18n("Mailbox");
+      return i18n( "Mailbox" );
       break;
     case Modem:
-      return i18n("Modem");
+      return i18n( "Modem" );
       break;
     case Car:
-      return i18nc("Car Phone", "Car" );
+      return i18nc( "Car Phone", "Car" );
       break;
     case Isdn:
-      return i18n("ISDN");
+      return i18n( "ISDN" );
       break;
     case Pcs:
-      return i18n("PCS");
+      return i18n( "PCS" );
       break;
     case Pager:
-      return i18n("Pager");
+      return i18n( "Pager" );
       break;
-    case Home | Fax:
-      return i18n("Home Fax");
+    case Home + Fax:
+      return i18n( "Home Fax" );
       break;
-    case Work | Fax:
-      return i18n("Work Fax");
+    case Work + Fax:
+      return i18n( "Work Fax" );
       break;
     default:
-      return i18n("Other");
+      return i18n( "Other" );
   }
 }
 
+QString PhoneNumber::toString() const
+{
+  QString str;
+
+  str += QString( "PhoneNumber {\n" );
+  str += QString( "    Id: %1\n" ).arg( d->mId );
+  str += QString( "    Type: %1\n" ).arg( typeLabel( d->mType ) );
+  str += QString( "    Number: %1\n" ).arg( d->mNumber );
+  str += QString( "}\n" );
+
+  return str;
+}
+
 QDataStream &KABC::operator<<( QDataStream &s, const PhoneNumber &phone )
 {
-  return s << phone.mId << phone.mType << phone.mNumber;
+  return s << phone.d->mId << (uint)phone.d->mType << phone.d->mNumber;
 }
 
 QDataStream &KABC::operator>>( QDataStream &s, PhoneNumber &phone )
 {
-  s >> phone.mId >> phone.mType >> phone.mNumber;
+  uint type;
+  s >> phone.d->mId >> type >> phone.d->mNumber;
+  phone.d->mType = PhoneNumber::Type( type );
 
   return s;
 }
