@@ -21,31 +21,31 @@
 #ifndef KABC_PLUGIN_H
 #define KABC_PLUGIN_H
 
-#include <QString>
-
-#include "kabc.h"
+#include "kabc_export.h"
+#include <QtCore/QString>
 
 namespace KABC {
 
 class KABC_EXPORT Plugin
 {
-public:
-  Plugin();
-  virtual ~Plugin();
+  public:
+    Plugin();
+    virtual ~Plugin();
 
-  virtual void setType( const QString& type );
-  virtual QString type() const;
+    virtual void setType( const QString &type );
+    virtual QString type() const;
 
-  virtual void setNameLabel( const QString& label );
-  virtual QString nameLabel() const;
+    virtual void setNameLabel( const QString &label );
+    virtual QString nameLabel() const;
 
-  virtual void setDescriptionLabel( const QString& label );
-  virtual QString descriptionLabel() const;
+    virtual void setDescriptionLabel( const QString &label );
+    virtual QString descriptionLabel() const;
 
-private:
-  QString mType;
-  QString mNameLabel;
-  QString mDescriptionLabel;
+  private:
+    class Private;
+    Private *const d;
+
+    Q_DISABLE_COPY( Plugin )
 };
 
 }
