@@ -19,28 +19,28 @@
     Boston, MA 02110-1301, USA.
 */
 
-#include <signal.h>
-#include <sys/types.h>
-#include <sys/stat.h>
-#include <unistd.h>
-
-#include <QFile>
-#include <QFileInfo>
-
-#include <kconfig.h>
-#include <kdebug.h>
-#include <kio/scheduler.h>
-#include <klocale.h>
-#include <ksavefile.h>
-#include <kstandarddirs.h>
-#include <ktemporaryfile.h>
+#include "resourcefile.h"
+#include "resourcefileconfig.h"
 
 #include "kabc/formatfactory.h"
 #include "kabc/stdaddressbook.h"
 #include "kabc/lock.h"
 
-#include "resourcefileconfig.h"
-#include "resourcefile.h"
+#include <kio/scheduler.h>
+#include <kconfiggroup.h>
+#include <kdebug.h>
+#include <klocale.h>
+#include <ksavefile.h>
+#include <kstandarddirs.h>
+#include <ktemporaryfile.h>
+
+#include <QtCore/QFile>
+#include <QtCore/QFileInfo>
+
+#include <sys/types.h>
+#include <sys/stat.h>
+#include <signal.h>
+#include <unistd.h>
 
 using namespace KABC;
 
@@ -54,26 +54,33 @@ class ResourceFile::ResourceFilePrivate
     bool mIsSaving;
 };
 
-ResourceFile::ResourceFile( const KConfig *config )
-  : Resource( config ), mFormat( 0 ), mTempFile( 0 ),
+ResourceFile::ResourceFile()
+  : Resource(), mFormat( 0 ), mTempFile( 0 ),
     mAsynchronous( false ), d( new ResourceFilePrivate )
 {
   QString fileName, formatName;
 
-  if ( config ) {
-    fileName = config->readPathEntry( "FileName", StdAddressBook::fileName() );
-    formatName = config->readEntry( "FileFormat", "vcard" );
-  } else {
-    fileName = StdAddressBook::fileName();
-    formatName = "vcard";
-  }
+  fileName = StdAddressBook::fileName();
+  formatName = "vcard";
+
+  init( fileName, formatName );
+}
+
+ResourceFile::ResourceFile( const KConfigGroup &group )
+  : Resource( group ), mFormat( 0 ), mTempFile( 0 ),
+    mAsynchronous( false ), d( new ResourceFilePrivate )
+{
+  QString fileName, formatName;
+
+  fileName = group.readPathEntry( "FileName", StdAddressBook::fileName() );
+  formatName = group.readEntry( "FileFormat", "vcard" );
 
   init( fileName, formatName );
 }
 
 ResourceFile::ResourceFile( const QString &fileName,
                             const QString &formatName )
-  : Resource( 0 ), mFormat( 0 ), mTempFile( 0 ),
+  : Resource(), mFormat( 0 ), mTempFile( 0 ),
     mAsynchronous( false ), d( new ResourceFilePrivate )
 {
   init( fileName, formatName );
@@ -107,10 +114,12 @@ void ResourceFile::init( const QString &fileName, const QString &formatName )
 
 ResourceFile::~ResourceFile()
 {
-  if ( d->mIsLoading )
+  if ( d->mIsLoading ) {
     d->mLoadJob->kill();
-  if ( d->mIsSaving )
+  }
+  if ( d->mIsSaving ) {
     d->mSaveJob->kill();
+  }
 
   delete d;
   d = 0;
@@ -120,23 +129,26 @@ ResourceFile::~ResourceFile()
   deleteLocalTempFile();
 }
 
-void ResourceFile::writeConfig( KConfig *config )
+void ResourceFile::writeConfig( KConfigGroup &group )
 {
-  Resource::writeConfig( config );
+  Resource::writeConfig( group );
 
-  if ( mFileName == StdAddressBook::fileName() )
-    config->deleteEntry( "FileName" );
-  else
-    config->writePathEntry( "FileName", mFileName );
+  if ( mFileName == StdAddressBook::fileName() ) {
+    group.deleteEntry( "FileName" );
+  } else {
+    group.writePathEntry( "FileName", mFileName );
+  }
 
-  config->writeEntry( "FileFormat", mFormatName );
+  group.writeEntry( "FileFormat", mFormatName );
 }
 
 Ticket *ResourceFile::requestSaveTicket()
 {
-  kDebug(5700) << "ResourceFile::requestSaveTicket()" << endl;
+  kDebug(5700) << "ResourceFile::requestSaveTicket()";
 
-  if ( !addressBook() ) return 0;
+  if ( !addressBook() ) {
+    return 0;
+  }
 
   delete mLock;
   mLock = new Lock( mFileName );
@@ -146,7 +158,7 @@ Ticket *ResourceFile::requestSaveTicket()
   } else {
     addressBook()->error( mLock->error() );
     kDebug(5700) << "ResourceFile::requestSaveTicket(): Unable to lock file '"
-                  << mFileName << "': " << mLock->error() << endl;
+                  << mFileName << "':" << mLock->error();
     return 0;
   }
 
@@ -170,18 +182,20 @@ bool ResourceFile::doOpen()
   if ( !file.exists() ) {
     // try to create the file
     bool ok = file.open( QIODevice::WriteOnly );
-    if ( ok )
+    if ( ok ) {
       file.close();
-
+    }
     return ok;
   } else {
     QFileInfo fileInfo( mFileName );
     if ( readOnly() || !fileInfo.isWritable() ) {
-      if ( !file.open( QIODevice::ReadOnly ) )
+      if ( !file.open( QIODevice::ReadOnly ) ) {
         return false;
+      }
     } else {
-      if ( !file.open( QIODevice::ReadWrite ) )
+      if ( !file.open( QIODevice::ReadWrite ) ) {
         return false;
+      }
     }
 
     if ( file.size() == 0 ) {
@@ -202,7 +216,7 @@ void ResourceFile::doClose()
 
 bool ResourceFile::load()
 {
-  kDebug(5700) << "ResourceFile::load(): '" << mFileName << "'" << endl;
+  kDebug(5700) << "ResourceFile::load(): '" << mFileName << "'";
 
   if ( d->mIsLoading ) {
     abortAsyncLoading();
@@ -212,12 +226,12 @@ bool ResourceFile::load()
 
   QFile file( mFileName );
   if ( !file.open( QIODevice::ReadOnly ) ) {
-    addressBook()->error( i18n( "Unable to open file '%1'." ,  mFileName ) );
+    addressBook()->error( i18n( "Unable to open file '%1'.", mFileName ) );
     return false;
   }
 
   if ( !clearAndLoad( &file ) ) {
-      addressBook()->error( i18n( "Problems during parsing file '%1'." ,  mFileName ) );
+      addressBook()->error( i18n( "Problems during parsing file '%1'.", mFileName ) );
     return false;
   }
 
@@ -236,8 +250,8 @@ bool ResourceFile::asyncLoad()
     abortAsyncLoading();
   }
 
-  if (d->mIsSaving) {
-    kWarning(5700) << "Aborted asyncSave() because we're still asyncSave()ing!" << endl;
+  if ( d->mIsSaving ) {
+    kWarning(5700) << "Aborted asyncSave() because we're still saving!";
     return false;
   }
 
@@ -246,7 +260,7 @@ bool ResourceFile::asyncLoad()
   bool ok = createLocalTempFile();
 
   if ( !ok ) {
-    emit loadingError( this, i18n( "Unable to open file '%1'." ,  mTempFile->fileName() ) );
+    emit loadingError( this, i18n( "Unable to open file '%1'.", mTempFile->fileName() ) );
     deleteLocalTempFile();
     return false;
   }
@@ -266,7 +280,7 @@ bool ResourceFile::asyncLoad()
 
 void ResourceFile::abortAsyncLoading()
 {
-  kDebug(5700) << "ResourceFile::abortAsyncLoading()" << endl;
+  kDebug(5700) << "ResourceFile::abortAsyncLoading()";
 
   if ( d->mLoadJob ) {
     d->mLoadJob->kill(); // result not emitted
@@ -279,7 +293,7 @@ void ResourceFile::abortAsyncLoading()
 
 void ResourceFile::abortAsyncSaving()
 {
-  kDebug(5700) << "ResourceFile::abortAsyncSaving()" << endl;
+  kDebug(5700) << "ResourceFile::abortAsyncSaving()";
 
   if ( d->mSaveJob ) {
     d->mSaveJob->kill(); // result not emitted
@@ -290,32 +304,31 @@ void ResourceFile::abortAsyncSaving()
   d->mIsSaving = false;
 }
 
-bool ResourceFile::save( Ticket * )
+bool ResourceFile::save( Ticket *ticket )
 {
-  kDebug(5700) << "ResourceFile::save()" << endl;
+  Q_UNUSED( ticket );
+  kDebug(5700) << "ResourceFile::save()";
 
-  if (d->mIsSaving) {
+  if ( d->mIsSaving ) {
     abortAsyncSaving();
   }
 
   // create backup file
   QString extension = '_' + QString::number( QDate::currentDate().dayOfWeek() );
-  (void) KSaveFile::simpleBackupFile( mFileName, QString() /*directory*/,
-                                extension );
+  (void) KSaveFile::simpleBackupFile( mFileName, QString(), extension );
 
   mDirWatch.stopScan();
 
   KSaveFile saveFile( mFileName );
   bool ok = false;
 
-  if ( saveFile.open() )
-  {
+  if ( saveFile.open() ) {
     mFormat->saveAll( addressBook(), this, &saveFile );
     ok = saveFile.finalize();
   }
 
   if ( !ok ) {
-    addressBook()->error( i18n( "Unable to save file '%1'." ,  mFileName ) );
+    addressBook()->error( i18n( "Unable to save file '%1'.", mFileName ) );
   }
 
   mDirWatch.startScan();
@@ -325,14 +338,14 @@ bool ResourceFile::save( Ticket * )
 
 bool ResourceFile::asyncSave( Ticket * )
 {
-  kDebug(5700) << "ResourceFile::asyncSave()" << endl;
+  kDebug(5700) << "ResourceFile::asyncSave()";
 
-  if (d->mIsSaving) {
+  if ( d->mIsSaving ) {
     abortAsyncSaving();
   }
 
-  if (d->mIsLoading) {
-    kWarning(5700) << "Aborted asyncSave() because we're still asyncLoad()ing!" << endl;
+  if ( d->mIsLoading ) {
+    kWarning(5700) << "Aborted asyncSave() because we're still loading!";
     return false;
   }
 
@@ -342,7 +355,7 @@ bool ResourceFile::asyncSave( Ticket * )
   }
 
   if ( !ok ) {
-    emit savingError( this, i18n( "Unable to save file '%1'." ,  mTempFile->fileName() ) );
+    emit savingError( this, i18n( "Unable to save file '%1'.", mTempFile->fileName() ) );
     deleteLocalTempFile();
     return false;
   }
@@ -371,7 +384,7 @@ bool ResourceFile::createLocalTempFile()
 void ResourceFile::deleteStaleTempFile()
 {
   if ( hasTempFile() ) {
-    kDebug(5700) << "stale temp file detected " << mTempFile->fileName() << endl;
+    kDebug(5700) << "stale temp file detected" << mTempFile->fileName();
     deleteLocalTempFile();
   }
 }
@@ -390,8 +403,9 @@ void ResourceFile::saveToFile( QFile *file )
 void ResourceFile::setFileName( const QString &fileName )
 {
   mDirWatch.stopScan();
-  if ( mDirWatch.contains( mFileName ) )
+  if ( mDirWatch.contains( mFileName ) ) {
     mDirWatch.removeFile( mFileName );
+  }
 
   mFileName = fileName;
 
@@ -420,33 +434,40 @@ QString ResourceFile::format() const
 
 void ResourceFile::fileChanged()
 {
-    kDebug(5700) << "ResourceFile::fileChanged(): " << mFileName << endl;
+  kDebug(5700) << "ResourceFile::fileChanged():" << mFileName;
 
-  if ( !addressBook() )
+  if ( !addressBook() ) {
     return;
+  }
 
 //  clear(); // moved to clearAndLoad()
-  if ( mAsynchronous )
+  if ( mAsynchronous ) {
     asyncLoad();
-  else {
+  } else {
     load();
-    kDebug() << "addressBookChanged() " << endl;
+    kDebug(5700) << "addressBookChanged()";
     addressBook()->emitAddressBookChanged();
   }
 }
 
 void ResourceFile::removeAddressee( const Addressee &addr )
 {
-  QFile::remove( QFile::encodeName( KStandardDirs::locateLocal( "data", "kabc/photos/" ) + addr.uid() ) );
-  QFile::remove( QFile::encodeName( KStandardDirs::locateLocal( "data", "kabc/logos/" ) + addr.uid() ) );
-  QFile::remove( QFile::encodeName( KStandardDirs::locateLocal( "data", "kabc/sounds/" ) + addr.uid() ) );
+  QFile::remove(
+    QFile::encodeName( KStandardDirs::locateLocal( "data", "kabc/photos/" ) + addr.uid() ) );
+
+  QFile::remove(
+    QFile::encodeName( KStandardDirs::locateLocal( "data", "kabc/logos/" ) + addr.uid() ) );
+
+  QFile::remove(
+    QFile::encodeName( KStandardDirs::locateLocal( "data", "kabc/sounds/" ) + addr.uid() ) );
 
   mAddrMap.remove( addr.uid() );
 }
 
-void ResourceFile::downloadFinished( KJob* )
+void ResourceFile::downloadFinished( KJob *job )
 {
-  kDebug(5700) << "ResourceFile::downloadFinished()" << endl;
+  Q_UNUSED( job );
+  kDebug(5700) << "ResourceFile::downloadFinished()";
 
   d->mIsLoading = false;
 
@@ -457,13 +478,15 @@ void ResourceFile::downloadFinished( KJob* )
 
   QFile file( mTempFile->fileName() );
   if ( file.open( QIODevice::ReadOnly ) ) {
-    if ( clearAndLoad( &file ) )
+    if ( clearAndLoad( &file ) ) {
       emit loadingFinished( this );
-    else
-      emit loadingError( this, i18n( "Problems during parsing file '%1'." ,  mTempFile->fileName() ) );
-  }
-  else {
-    emit loadingError( this, i18n( "Unable to open file '%1'." ,  mTempFile->fileName() ) );
+    } else {
+      emit loadingError( this, i18n( "Problems during parsing file '%1'.",
+                                     mTempFile->fileName() ) );
+    }
+  } else {
+    emit loadingError( this, i18n( "Unable to open file '%1'.",
+                                   mTempFile->fileName() ) );
   }
 
   deleteLocalTempFile();
@@ -471,14 +494,15 @@ void ResourceFile::downloadFinished( KJob* )
 
 void ResourceFile::uploadFinished( KJob *job )
 {
-  kDebug(5700) << "ResourceFile::uploadFinished()" << endl;
+  kDebug(5700) << "ResourceFile::uploadFinished()";
 
   d->mIsSaving = false;
 
-  if ( job->error() )
+  if ( job->error() ) {
     emit savingError( this, job->errorString() );
-  else
+  } else {
     emit savingFinished( this );
+  }
 
   deleteLocalTempFile();
   mDirWatch.startScan();
