@@ -21,15 +21,15 @@
 #ifndef KABC_RESOURCEFILE_H
 #define KABC_RESOURCEFILE_H
 
-#include <sys/types.h>
+#include "kabc/kabc_export.h"
+#include "kabc/resource.h"
 
 #include <kconfig.h>
 #include <kdirwatch.h>
 
-#include "kabc/resource.h"
+#include <sys/types.h>
 
 class QFile;
-class QTimer;
 class KTemporaryFile;
 
 class KJob;
@@ -37,7 +37,6 @@ class KJob;
 namespace KABC {
 
 class Format;
-class ResourceConfigWidget;
 class Lock;
 
 /**
@@ -48,17 +47,25 @@ class KABC_FILE_CORE_EXPORT ResourceFile : public Resource
   Q_OBJECT
 
   public:
+    /**
+      Default constructor.
+     */
+    ResourceFile();
     /**
       Constructor.
 
-      @param cfg The config object where custom resource settings are stored.
+      @param group The configuration group where custom resource settings are stored.
      */
-    explicit ResourceFile( const KConfig *cfg );
+    explicit ResourceFile( const KConfigGroup &group );
 
     /**
-      Construct file resource on file @arg fileName using format @arg formatName.
+      Constructs a file resource on file @arg fileName using format @arg formatName.
+
+      @param fileName The file to use for this resource
+      @param formatName The format of the data in the given file
      */
-    explicit ResourceFile( const QString &fileName, const QString &formatName = QLatin1String( "vcard" ) );
+    explicit ResourceFile( const QString &fileName,
+                           const QString &formatName = QLatin1String( "vcard" ) );
 
     /**
       Destructor.
@@ -68,7 +75,7 @@ class KABC_FILE_CORE_EXPORT ResourceFile : public Resource
     /**
       Writes the config back.
      */
-    virtual void writeConfig( KConfig *cfg );
+    virtual void writeConfig( KConfigGroup &group );
 
     /**
       Tries to open the file and checks for the proper format.
@@ -86,7 +93,7 @@ class KABC_FILE_CORE_EXPORT ResourceFile : public Resource
      */
     virtual Ticket *requestSaveTicket();
 
-    virtual void releaseSaveTicket( Ticket* );
+    virtual void releaseSaveTicket( Ticket *ticket );
 
     /**
       Loads all addressees from file to the address book.
@@ -129,12 +136,16 @@ class KABC_FILE_CORE_EXPORT ResourceFile : public Resource
     /**
       Remove a addressee from its source.
       This method is mainly called by KABC::AddressBook.
+
+      @param addr The addressee to remove
+
+      @see KABC::AddressBook::removeAddressee()
      */
-    virtual void removeAddressee( const Addressee& addr );
+    virtual void removeAddressee( const Addressee &addr );
 
   private Q_SLOTS:
-    void downloadFinished( KJob* );
-    void uploadFinished( KJob* );
+    void downloadFinished( KJob *job );
+    void uploadFinished( KJob *job );
 
   protected Q_SLOTS:
     void fileChanged();
