@@ -18,31 +18,31 @@
     Boston, MA 02110-1301, USA.
 */
 
-#include <QCheckBox>
-#include <QLabel>
-#include <QLayout>
-#include <QPushButton>
-#include <QSpinBox>
-#include <QRadioButton>
+#include "resourceldapkioconfig.h"
+#include "resourceldapkio.h"
 
+#include <kio/netaccess.h>
 #include <kacceleratormanager.h>
 #include <kcombobox.h>
 #include <kdebug.h>
-#include <kio/netaccess.h>
 #include <klocale.h>
 #include <klineedit.h>
 #include <kmessagebox.h>
 #include <kvbox.h>
 
-#include "resourceldapkio.h"
+#include <QtGui/QCheckBox>
+#include <QtGui/QLabel>
+#include <QtGui/QLayout>
+#include <QtGui/QPushButton>
+#include <QtGui/QSpinBox>
+#include <QtGui/QRadioButton>
 
-#include "resourceldapkioconfig.h"
 #include "resourceldapkioconfig.moc"
 
 using namespace KABC;
 
-ResourceLDAPKIOConfig::ResourceLDAPKIOConfig( QWidget* parent )
-    : KRES::ConfigWidget( parent )
+ResourceLDAPKIOConfig::ResourceLDAPKIOConfig( QWidget *parent )
+  : KRES::ConfigWidget( parent )
 {
   QBoxLayout *mainLayout = new QVBoxLayout( this );
   cfg = new KLDAP::LdapConfigWidget(
@@ -80,7 +80,7 @@ void ResourceLDAPKIOConfig::loadSettings( KRES::Resource *res )
   ResourceLDAPKIO *resource = dynamic_cast<ResourceLDAPKIO*>( res );
 
   if ( !resource ) {
-    kDebug(5700) << "ResourceLDAPKIOConfig::loadSettings(): cast failed" << endl;
+    kDebug(5700) << "ResourceLDAPKIOConfig::loadSettings(): cast failed";
     return;
   }
 
@@ -93,16 +93,23 @@ void ResourceLDAPKIOConfig::loadSettings( KRES::Resource *res )
   cfg->setVersion( resource->ver() );
   cfg->setTimeLimit( resource->timeLimit() );
   cfg->setSizeLimit( resource->sizeLimit() );
-  cfg->setDn( resource->dn() );
+  cfg->setDn( KLDAP::LdapDN( resource->dn() ) );
   cfg->setFilter( resource->filter() );
   cfg->setMech( resource->mech() );
-  if ( resource->isTLS() ) cfg->setSecurity( KLDAP::LdapConfigWidget::TLS );
-  else if ( resource->isSSL() ) cfg->setSecurity( KLDAP::LdapConfigWidget::SSL );
-  else cfg->setSecurity( KLDAP::LdapConfigWidget::None );
-  if ( resource->isAnonymous() ) cfg->setAuth( KLDAP::LdapConfigWidget::Anonymous );
-  else if ( resource->isSASL() ) cfg->setAuth( KLDAP::LdapConfigWidget::SASL );
-  else cfg->setAuth( KLDAP::LdapConfigWidget::Simple );
-
+  if ( resource->isTLS() ) {
+    cfg->setSecurity( KLDAP::LdapConfigWidget::TLS );
+  } else if ( resource->isSSL() ) {
+    cfg->setSecurity( KLDAP::LdapConfigWidget::SSL );
+  } else {
+    cfg->setSecurity( KLDAP::LdapConfigWidget::None );
+  }
+  if ( resource->isAnonymous() ) {
+    cfg->setAuth( KLDAP::LdapConfigWidget::Anonymous );
+  } else if ( resource->isSASL() ) {
+    cfg->setAuth( KLDAP::LdapConfigWidget::SASL );
+  } else {
+    cfg->setAuth( KLDAP::LdapConfigWidget::Simple );
+  }
   mSubTree->setChecked( resource->isSubTree() );
   mAttributes = resource->attributes();
   mRDNPrefix = resource->RDNPrefix();
@@ -116,7 +123,7 @@ void ResourceLDAPKIOConfig::saveSettings( KRES::Resource *res )
   ResourceLDAPKIO *resource = dynamic_cast<ResourceLDAPKIO*>( res );
 
   if ( !resource ) {
-    kDebug(5700) << "ResourceLDAPKIOConfig::saveSettings(): cast failed" << endl;
+    kDebug(5700) << "ResourceLDAPKIOConfig::saveSettings(): cast failed";
     return;
   }
 
@@ -129,10 +136,10 @@ void ResourceLDAPKIOConfig::saveSettings( KRES::Resource *res )
   resource->setVer( cfg->version() );
   resource->setTimeLimit( cfg->timeLimit() );
   resource->setSizeLimit( cfg->sizeLimit() );
-  resource->setDn( cfg->dn() );
+  resource->setDn( cfg->dn().toString() );
   resource->setFilter( cfg->filter() );
   resource->setIsAnonymous( cfg->auth() == KLDAP::LdapConfigWidget::Anonymous );
-  resource->setIsSASL(  cfg->auth() == KLDAP::LdapConfigWidget::SASL );
+  resource->setIsSASL( cfg->auth() == KLDAP::LdapConfigWidget::SASL );
   resource->setMech( cfg->mech() );
   resource->setIsTLS( cfg->security() == KLDAP::LdapConfigWidget::TLS );
   resource->setIsSSL( cfg->security() == KLDAP::LdapConfigWidget::SSL );
@@ -160,12 +167,13 @@ void ResourceLDAPKIOConfig::editCache()
 
   src = cfg->url();
   src.setScope( mSubTree->isChecked() ? KLDAP::LdapUrl::Sub : KLDAP::LdapUrl::One );
-  if (!mAttributes.empty()) {
+  if ( !mAttributes.empty() ) {
     QMap<QString,QString>::Iterator it;
     QStringList attr;
     for ( it = mAttributes.begin(); it != mAttributes.end(); ++it ) {
-      if ( !it.value().isEmpty() && it.key() != "objectClass" )
+      if ( !it.value().isEmpty() && it.key() != "objectClass" ) {
         attr.append( it.value() );
+      }
     }
     src.setAttributes( attr );
   }
@@ -180,18 +188,17 @@ void ResourceLDAPKIOConfig::editCache()
 
 AttributesDialog::AttributesDialog( const QMap<QString, QString> &attributes,
                                     int rdnprefix,
-                                    QWidget *parent, const char *name )
+                                    QWidget *parent )
   : KDialog( parent )
 {
   setCaption( i18n( "Attributes Configuration" ) );
   setButtons( Ok | Cancel );
   setDefaultButton( Ok );
-  setObjectName( name );
   setModal( true );
   showButtonSeparator( true );
 
   mNameDict.insert( "objectClass", i18n( "Object classes" ) );
-  mNameDict.insert( "commonName",  i18n( "Common name" ) );
+  mNameDict.insert( "commonName", i18n( "Common name" ) );
   mNameDict.insert( "formattedName", i18n( "Formatted name" ) );
   mNameDict.insert( "familyName", i18n( "Family name" ) );
   mNameDict.insert( "givenName", i18n( "Given name" ) );
@@ -282,11 +289,11 @@ AttributesDialog::AttributesDialog( const QMap<QString, QString> &attributes,
       i--;
       continue;
     }
-    if ( (i - 2) == ( mNameDict.count()  >> 1 ) ) {
+    if ( ( i - 2 ) == ( mNameDict.count() >> 1 ) ) {
       i = 0;
       j = 2;
     }
-    kDebug(7125) << "itkey: " << it.key() << " i: " << i << endl;
+    kDebug(7125) << "itkey:" << it.key() << "i:" << i;
     label = new QLabel( mNameDict[ it.key() ] + ':', page );
     KLineEdit *lineedit = new KLineEdit( page );
     mLineEditDict.insert( it.key(), lineedit );
@@ -297,14 +304,18 @@ AttributesDialog::AttributesDialog( const QMap<QString, QString> &attributes,
   }
 
   for ( i = 1; i < mMapCombo->count(); i++ ) {
-	QHash<QString,KLineEdit*>::const_iterator it2 = mLineEditDict.constBegin();
-	while (it2 != mLineEditDict.constEnd()){
+    QHash<QString,KLineEdit*>::const_iterator it2 = mLineEditDict.constBegin();
+    while ( it2 != mLineEditDict.constEnd() ) {
       if ( mMapList[ i ].contains( it2.key() ) ) {
-        if ( mMapList[ i ][ it2.key() ] != it2.value()->text() ) break;
+        if ( mMapList[ i ][ it2.key() ] != it2.value()->text() ) {
+          break;
+        }
       } else {
-        if ( mDefaultMap[ it2.key() ] != it2.value()->text() ) break;
+        if ( mDefaultMap[ it2.key() ] != it2.value()->text() ) {
+          break;
+        }
       }
-	  ++it2;
+      ++it2;
     }
     if ( it2 != mLineEditDict.constEnd() ) {
       mMapCombo->setCurrentIndex( i );
@@ -317,7 +328,7 @@ AttributesDialog::AttributesDialog( const QMap<QString, QString> &attributes,
 
 AttributesDialog::~AttributesDialog()
 {
-	mNameDict.clear();
+  mNameDict.clear();
 }
 
 QMap<QString, QString> AttributesDialog::attributes() const
@@ -325,10 +336,9 @@ QMap<QString, QString> AttributesDialog::attributes() const
   QMap<QString, QString> map;
 
   QHash<QString,KLineEdit*>::const_iterator it = mLineEditDict.constBegin();
-  while (it != mLineEditDict.constEnd())
-  {
-	map.insert( it.key(), it.value()->text() );
-	++it;
+  while ( it != mLineEditDict.constEnd() ) {
+    map.insert( it.key(), it.value()->text() );
+    ++it;
   }
   return map;
 }
@@ -343,25 +353,27 @@ void AttributesDialog::mapChanged( int pos )
 
   // apply first the default and than the spezific changes
   QMap<QString, QString>::Iterator it;
-  for ( it = mDefaultMap.begin(); it != mDefaultMap.end(); ++it )
+  for ( it = mDefaultMap.begin(); it != mDefaultMap.end(); ++it ) {
     mLineEditDict[ it.key() ]->setText( it.value() );
+  }
 
   for ( it = mMapList[ pos ].begin(); it != mMapList[ pos ].end(); ++it ) {
     if ( !it.value().isEmpty() ) {
       KLineEdit *le = mLineEditDict[ it.key() ];
-      if ( le ) le->setText( it.value() );
+      if ( le ) {
+        le->setText( it.value() );
+      }
     }
   }
 }
 
 OfflineDialog::OfflineDialog( bool autoCache, int cachePolicy, const KUrl &src,
-  const QString &dst, QWidget *parent, const char *name )
+  const QString &dst, QWidget *parent )
   : KDialog( parent )
 {
   setCaption( i18n( "Offline Configuration" ) );
   setButtons( Ok | Cancel );
   setDefaultButton( Ok );
-  setObjectName( name );
   setModal( true );
   showButtonSeparator( true );
 
@@ -369,36 +381,38 @@ OfflineDialog::OfflineDialog( bool autoCache, int cachePolicy, const KUrl &src,
   setMainWidget( page );
   QVBoxLayout *layout = new QVBoxLayout( page );
 
-  mSrc = src; mDst = dst;
-  mCacheBox = new QGroupBox( i18n("Offline Cache Policy"), page );
+  mSrc = src;
+  mDst = dst;
+  mCacheBox = new QGroupBox( i18n( "Offline Cache Policy" ), page );
   QVBoxLayout *cacheBoxLayout = new QVBoxLayout( mCacheBox );
 
   mCacheGroup = new QButtonGroup( this );
 
   QRadioButton *bt;
-  bt = new QRadioButton( i18n("Do not use offline cache"), mCacheBox );
+  bt = new QRadioButton( i18n( "Do not use offline cache" ), mCacheBox );
   cacheBoxLayout->addWidget( bt );
   mCacheGroup->addButton( bt );
 
-  bt = new QRadioButton( i18n("Use local copy if no connection"), mCacheBox );
+  bt = new QRadioButton( i18n( "Use local copy if no connection" ), mCacheBox );
   cacheBoxLayout->addWidget( bt );
   mCacheGroup->addButton( bt );
 
-  bt = new QRadioButton( i18n("Always use local copy"), mCacheBox );
+  bt = new QRadioButton( i18n( "Always use local copy" ), mCacheBox );
   cacheBoxLayout->addWidget( bt );
   mCacheGroup->addButton( bt );
 
-  if ( mCacheGroup->button( cachePolicy ) )
+  if ( mCacheGroup->button( cachePolicy ) ) {
     mCacheGroup->button( cachePolicy )->setDown( true );
+  }
 
-  mAutoCache = new QCheckBox( i18n("Refresh offline cache automatically"),
+  mAutoCache = new QCheckBox( i18n( "Refresh offline cache automatically" ),
     page );
   mAutoCache->setChecked( autoCache );
   mAutoCache->setEnabled( bt->isChecked() );
 
   connect( bt, SIGNAL(toggled(bool)), mAutoCache, SLOT(setEnabled(bool)) );
 
-  QPushButton *lcache = new QPushButton( i18n("Load into Cache"), page );
+  QPushButton *lcache = new QPushButton( i18n( "Load into Cache" ), page );
   connect( lcache, SIGNAL( clicked() ), SLOT( loadCache() ) );
 
   layout->addWidget( mCacheBox );
@@ -424,9 +438,9 @@ void OfflineDialog::loadCache()
 {
   if ( KIO::NetAccess::download( mSrc, mDst, this ) ) {
     KMessageBox::information( this,
-      i18n("Successfully downloaded directory server contents.") );
+      i18n( "Successfully downloaded directory server contents." ) );
   } else {
     KMessageBox::error( this,
-      i18n("An error occurred downloading directory server contents into file %1.", mDst) );
+      i18n( "An error occurred downloading directory server contents into file %1.", mDst ) );
   }
 }
