@@ -18,22 +18,22 @@
     Boston, MA 02110-1301, USA.
 */
 
-#include <QFile>
-
-#include <kdebug.h>
-#include <kio/netaccess.h>
-#include <kio/scheduler.h>
-#include <klocale.h>
-#include <ksavefile.h>
-#include <ktemporaryfile.h>
-#include <kurlrequester.h>
+#include "resourcenet.h"
+#include "resourcenetconfig.h"
 
 #include "kabc/addressbook.h"
 #include "kabc/formatfactory.h"
 #include "kabc/stdaddressbook.h"
 
-#include "resourcenetconfig.h"
-#include "resourcenet.h"
+#include <kio/netaccess.h>
+#include <kio/scheduler.h>
+#include <kdebug.h>
+#include <klocale.h>
+#include <ksavefile.h>
+#include <ktemporaryfile.h>
+#include <kurlrequester.h>
+
+#include <QtCore/QFile>
 
 using namespace KABC;
 
@@ -47,20 +47,24 @@ class ResourceNet::ResourceNetPrivate
     bool mIsSaving;
 };
 
-ResourceNet::ResourceNet( const KConfig *config )
-  : Resource( config ), mFormat( 0 ),
+ResourceNet::ResourceNet()
+  : Resource(), mFormat( 0 ),
     mTempFile( 0 ),
     d( new ResourceNetPrivate )
 {
-  if ( config ) {
-    init( KUrl( config->readPathEntry( "NetUrl" ) ), config->readEntry( "NetFormat" ) );
-  } else {
-    init( KUrl(), "vcard" );
-  }
+  init( KUrl(), "vcard" );
+}
+
+ResourceNet::ResourceNet( const KConfigGroup &group )
+  : Resource( group ), mFormat( 0 ),
+    mTempFile( 0 ),
+    d( new ResourceNetPrivate )
+{
+  init( KUrl( group.readPathEntry( "NetUrl" ) ), group.readEntry( "NetFormat" ) );
 }
 
 ResourceNet::ResourceNet( const KUrl &url, const QString &format )
-  : Resource( 0 ), mFormat( 0 ),
+  : Resource(), mFormat( 0 ),
     mTempFile( 0 ),
     d( new ResourceNetPrivate )
 {
@@ -88,10 +92,12 @@ void ResourceNet::init( const KUrl &url, const QString &format )
 
 ResourceNet::~ResourceNet()
 {
-  if ( d->mIsLoading )
+  if ( d->mIsLoading ) {
     d->mLoadJob->kill();
-  if ( d->mIsSaving )
+  }
+  if ( d->mIsSaving ) {
     d->mSaveJob->kill();
+  }
 
   delete d;
   d = 0;
@@ -102,17 +108,17 @@ ResourceNet::~ResourceNet()
   deleteLocalTempFile();
 }
 
-void ResourceNet::writeConfig( KConfig *config )
+void ResourceNet::writeConfig( KConfigGroup &group )
 {
-  Resource::writeConfig( config );
+  Resource::writeConfig( group );
 
-  config->writePathEntry( "NetUrl", mUrl.url() );
-  config->writeEntry( "NetFormat", mFormatName );
+  group.writePathEntry( "NetUrl", mUrl.url() );
+  group.writeEntry( "NetFormat", mFormatName );
 }
 
 Ticket *ResourceNet::requestSaveTicket()
 {
-  kDebug(5700) << "ResourceNet::requestSaveTicket()" << endl;
+  kDebug(5700) << "ResourceNet::requestSaveTicket()";
 
   return createTicket( this );
 }
@@ -136,20 +142,21 @@ bool ResourceNet::load()
   QString tempFile;
 
   if ( !KIO::NetAccess::download( mUrl, tempFile, 0 ) ) {
-    addressBook()->error( i18n( "Unable to download file '%1'." ,  mUrl.prettyUrl() ) );
+    addressBook()->error( i18n( "Unable to download file '%1'.", mUrl.prettyUrl() ) );
     return false;
   }
 
   QFile file( tempFile );
   if ( !file.open( QIODevice::ReadOnly ) ) {
-    addressBook()->error( i18n( "Unable to open file '%1'." ,  tempFile ) );
+    addressBook()->error( i18n( "Unable to open file '%1'.", tempFile ) );
     KIO::NetAccess::removeTempFile( tempFile );
     return false;
   }
 
   bool result = clearAndLoad( &file );
-  if ( !result )
-      addressBook()->error( i18n( "Problems during parsing file '%1'." ,  tempFile ) );
+  if ( !result ) {
+    addressBook()->error( i18n( "Problems during parsing file '%1'.", tempFile ) );
+  }
 
   KIO::NetAccess::removeTempFile( tempFile );
 
@@ -168,15 +175,15 @@ bool ResourceNet::asyncLoad()
     abortAsyncLoading();
   }
 
-  if (d->mIsSaving) {
-    kWarning(5700) << "Aborted asyncLoad() because we're still asyncSave()ing!" << endl;
+  if ( d->mIsSaving ) {
+    kWarning(5700) << "Aborted asyncLoad() because we're still saving!";
     return false;
   }
 
   bool ok = createLocalTempFile();
 
   if ( !ok ) {
-    emit loadingError( this, i18n( "Unable to open file '%1'." ,  mTempFile->fileName() ) );
+    emit loadingError( this, i18n( "Unable to open file '%1'.", mTempFile->fileName() ) );
     deleteLocalTempFile();
     return false;
   }
@@ -195,7 +202,7 @@ bool ResourceNet::asyncLoad()
 
 void ResourceNet::abortAsyncLoading()
 {
-  kDebug(5700) << "ResourceNet::abortAsyncLoading()" << endl;
+  kDebug(5700) << "ResourceNet::abortAsyncLoading()";
 
   if ( d->mLoadJob ) {
     d->mLoadJob->kill(); // result not emitted
@@ -208,7 +215,7 @@ void ResourceNet::abortAsyncLoading()
 
 void ResourceNet::abortAsyncSaving()
 {
-  kDebug(5700) << "ResourceNet::abortAsyncSaving()" << endl;
+  kDebug(5700) << "ResourceNet::abortAsyncSaving()";
 
   if ( d->mSaveJob ) {
     d->mSaveJob->kill(); // result not emitted
@@ -219,11 +226,12 @@ void ResourceNet::abortAsyncSaving()
   d->mIsSaving = false;
 }
 
-bool ResourceNet::save( Ticket* )
+bool ResourceNet::save( Ticket *ticket )
 {
-  kDebug(5700) << "ResourceNet::save()" << endl;
+  Q_UNUSED( ticket );
+  kDebug(5700) << "ResourceNet::save()";
 
-  if (d->mIsSaving) {
+  if ( d->mIsSaving ) {
     abortAsyncSaving();
   }
 
@@ -235,27 +243,29 @@ bool ResourceNet::save( Ticket* )
   }
 
   if ( !ok ) {
-    addressBook()->error( i18n( "Unable to save file '%1'." ,  tempFile.fileName() ) );
+    addressBook()->error( i18n( "Unable to save file '%1'.", tempFile.fileName() ) );
     return false;
   }
 
   ok = KIO::NetAccess::upload( tempFile.fileName(), mUrl, 0 );
-  if ( !ok )
-    addressBook()->error( i18n( "Unable to upload to '%1'." ,  mUrl.prettyUrl() ) );
+  if ( !ok ) {
+    addressBook()->error( i18n( "Unable to upload to '%1'.", mUrl.prettyUrl() ) );
+  }
 
   return ok;
 }
 
-bool ResourceNet::asyncSave( Ticket* )
+bool ResourceNet::asyncSave( Ticket *ticket )
 {
-  kDebug(5700) << "ResourceNet::asyncSave()" << endl;
+  Q_UNUSED( ticket );
+  kDebug(5700) << "ResourceNet::asyncSave()";
 
-  if (d->mIsSaving) {
+  if ( d->mIsSaving ) {
     abortAsyncSaving();
   }
 
-  if (d->mIsLoading) {
-    kWarning(5700) << "Aborted asyncSave() because we're still asyncLoad()ing!" << endl;
+  if ( d->mIsLoading ) {
+    kWarning(5700) << "Aborted asyncSave() because we're still loading!";
     return false;
   }
 
@@ -265,7 +275,7 @@ bool ResourceNet::asyncSave( Ticket* )
   }
 
   if ( !ok ) {
-    emit savingError( this, i18n( "Unable to save file '%1'." ,  mTempFile->fileName() ) );
+    emit savingError( this, i18n( "Unable to save file '%1'.", mTempFile->fileName() ) );
     deleteLocalTempFile();
     return false;
   }
@@ -292,7 +302,7 @@ bool ResourceNet::createLocalTempFile()
 void ResourceNet::deleteStaleTempFile()
 {
   if ( hasTempFile() ) {
-    kDebug(5700) << "stale temp file detected " << mTempFile->fileName() << endl;
+    kDebug(5700) << "stale temp file detected" << mTempFile->fileName();
     deleteLocalTempFile();
   }
 }
@@ -321,8 +331,9 @@ KUrl ResourceNet::url() const
 void ResourceNet::setFormat( const QString &name )
 {
   mFormatName = name;
-  if ( mFormat )
+  if ( mFormat ) {
     delete mFormat;
+  }
 
   FormatFactory *factory = FormatFactory::self();
   mFormat = factory->format( mFormatName );
@@ -333,9 +344,10 @@ QString ResourceNet::format() const
   return mFormatName;
 }
 
-void ResourceNet::downloadFinished( KJob* )
+void ResourceNet::downloadFinished( KJob *job )
 {
-  kDebug(5700) << "ResourceNet::downloadFinished()" << endl;
+  Q_UNUSED( job );
+  kDebug(5700) << "ResourceNet::downloadFinished()";
 
   d->mIsLoading = false;
 
@@ -346,13 +358,15 @@ void ResourceNet::downloadFinished( KJob* )
 
   QFile file( mTempFile->fileName() );
   if ( file.open( QIODevice::ReadOnly ) ) {
-    if ( clearAndLoad( &file ) )
+    if ( clearAndLoad( &file ) ) {
       emit loadingFinished( this );
-    else
-      emit loadingError( this, i18n( "Problems during parsing file '%1'." ,  mTempFile->fileName() ) );
-  }
-  else {
-    emit loadingError( this, i18n( "Unable to open file '%1'." ,  mTempFile->fileName() ) );
+    } else {
+      emit loadingError( this, i18n( "Problems during parsing file '%1'.",
+                                     mTempFile->fileName() ) );
+    }
+  } else {
+    emit loadingError( this, i18n( "Unable to open file '%1'.",
+                                   mTempFile->fileName() ) );
   }
 
   deleteLocalTempFile();
@@ -360,14 +374,15 @@ void ResourceNet::downloadFinished( KJob* )
 
 void ResourceNet::uploadFinished( KJob *job )
 {
-  kDebug(5700) << "ResourceFile::uploadFinished()" << endl;
+  kDebug(5700) << "ResourceFile::uploadFinished()";
 
   d->mIsSaving = false;
 
-  if ( job->error() )
+  if ( job->error() ) {
     emit savingError( this, job->errorString() );
-  else
+  } else {
     emit savingFinished( this );
+  }
 
   deleteLocalTempFile();
 }
