@@ -1,37 +1,40 @@
 /*
-    This file is part of the kcal library.
+  This file is part of the kcal library.
 
-    Copyright (c) 2001 Cornelius Schumacher <schumacher@kde.org>
+  Copyright (c) 2001 Cornelius Schumacher <schumacher@kde.org>
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Library General Public
-    License as published by the Free Software Foundation; either
-    version 2 of the License, or (at your option) any later version.
+  This library is free software; you can redistribute it and/or
+  modify it under the terms of the GNU Library General Public
+  License as published by the Free Software Foundation; either
+  version 2 of the License, or (at your option) any later version.
 
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Library General Public License for more details.
+  This library is distributed in the hope that it will be useful,
+  but WITHOUT ANY WARRANTY; without even the implied warranty of
+  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+  Library General Public License for more details.
 
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-    Boston, MA 02110-1301, USA.
+  You should have received a copy of the GNU Library General Public License
+  along with this library; see the file COPYING.LIB.  If not, write to
+  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+  Boston, MA 02110-1301, USA.
 */
 /**
   @file
   This file is part of the API for handling calendar data and
   defines the Attendee class.
 
-  @author Cornelius Schumacher
+  @brief
+  Represents information related to an attendee of an Calendar Incidence.
+
+  @author Cornelius Schumacher \<schumacher@kde.org\>
 */
 
-#include <QStringList>
+#include "attendee.h"
 
 #include <kdebug.h>
 #include <klocale.h>
 
-#include "attendee.h"
+#include <QtCore/QStringList>
 
 using namespace KCal;
 
@@ -47,6 +50,8 @@ class KCal::Attendee::Private
     Role mRole;
     PartStat mStatus;
     QString mUid;
+    QString mDelegate;
+    QString mDelegator;
 };
 //@endcond
 
@@ -69,13 +74,14 @@ Attendee::~Attendee()
 
 bool KCal::Attendee::operator==( const Attendee &attendee )
 {
-  return (
-    (Person &)*this == (const Person &)attendee &&
+  return
+    ( Person & )*this == ( const Person & )attendee &&
     d->mRSVP == attendee.d->mRSVP &&
     d->mRole == attendee.d->mRole &&
     d->mStatus == attendee.d->mStatus &&
-    d->mUid == attendee.d->mUid
-    );
+    d->mUid == attendee.d->mUid &&
+    d->mDelegate == attendee.d->mDelegate &&
+    d->mDelegator == attendee.d->mDelegator;
 }
 
 void Attendee::setRSVP( bool r )
@@ -199,3 +205,23 @@ QStringList Attendee::roleList()
 
   return list;
 }
+
+void Attendee::setDelegate( const QString &delegate )
+{
+  d->mDelegate = delegate;
+}
+
+QString Attendee::delegate() const
+{
+  return d->mDelegate;
+}
+
+void Attendee::setDelegator( const QString &delegator )
+{
+  d->mDelegator = delegator;
+}
+
+QString Attendee::delegator() const
+{
+  return d->mDelegator;
+}
