@@ -1,41 +1,44 @@
 /*
-    This file is part of the kcal library.
+  This file is part of the kcal library.
 
-    Copyright (c) 1998 Preston Brown <pbrown@kde.org>
-    Copyright (c) 2001,2003,2004 Cornelius Schumacher <schumacher@kde.org>
-    Copyright (C) 2003-2004 Reinhold Kainhofer <reinhold@kainhofer.com>
+  Copyright (c) 1998 Preston Brown <pbrown@kde.org>
+  Copyright (c) 2001,2003,2004 Cornelius Schumacher <schumacher@kde.org>
+  Copyright (C) 2003-2004 Reinhold Kainhofer <reinhold@kainhofer.com>
+  Copyright (c) 2006 David Jarvie <software@astrojar.org.uk>
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Library General Public
-    License as published by the Free Software Foundation; either
-    version 2 of the License, or (at your option) any later version.
+  This library is free software; you can redistribute it and/or
+  modify it under the terms of the GNU Library General Public
+  License as published by the Free Software Foundation; either
+  version 2 of the License, or (at your option) any later version.
 
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Library General Public License for more details.
+  This library is distributed in the hope that it will be useful,
+  but WITHOUT ANY WARRANTY; without even the implied warranty of
+  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+  Library General Public License for more details.
 
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-    Boston, MA 02110-1301, USA.
+  You should have received a copy of the GNU Library General Public License
+  along with this library; see the file COPYING.LIB.  If not, write to
+  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+  Boston, MA 02110-1301, USA.
 */
 /**
   @file
   This file is part of the API for handling calendar data and
   defines the Calendar class.
 
-  @author Preston Brown
-  @author Cornelius Schumacher
-  @author Reinhold Kainhofer
+  @author Preston Brown \<pbrown@kde.org\>
+  @author Cornelius Schumacher \<schumacher@kde.org\>
+  @author Reinhold Kainhofer \<reinhold@kainhofer.com\>
+  @author David Jarvie \<software@astrojar.org.uk\>
  */
+
 #ifndef KCAL_CALENDAR_H
 #define KCAL_CALENDAR_H
 
-#include <QObject>
-#include <QString>
-#include <QList>
-#include <QMultiHash>
+#include <QtCore/QObject>
+#include <QtCore/QString>
+#include <QtCore/QList>
+#include <QtCore/QMultiHash>
 
 #include <kdatetime.h>
 
@@ -44,13 +47,13 @@
 #include "todo.h"
 #include "journal.h"
 #include "kcalversion.h"
-#include "person.h"
 
 namespace KCal {
 
 class ICalTimeZone;
 class ICalTimeZones;
 class CalFilter;
+class Person;
 
 /**
   Calendar Incidence sort directions.
@@ -152,22 +155,18 @@ class KCAL_EXPORT Calendar : public QObject, public CustomProperties,
     */
     virtual ~Calendar();
 
-  // DONE ABOVE
-
     /**
-      Sets the calendar Product ID to @p productId.
+      Sets the calendar Product ID to @p id.
 
-      @param productId is a string containing the Product ID.
+      @param id is a string containing the Product ID.
 
       @see productId() const
     */
-    void setProductId( const QString &productId );
+    void setProductId( const QString &id );
 
     /**
       Returns the calendar's Product ID.
 
-      @return the string containing the Product ID.
-
       @see setProductId()
     */
     QString productId() const;
@@ -188,7 +187,7 @@ class KCAL_EXPORT Calendar : public QObject, public CustomProperties,
 
       @see setOwner()
     */
-    const Person &owner() const;
+    Person owner() const;
 
     /**
       Sets the default time specification (time zone, etc.) used for creating
@@ -233,25 +232,55 @@ class KCAL_EXPORT Calendar : public QObject, public CustomProperties,
     QString timeZoneId() const;
 
     /**
-      Notes the time zone which the client application intends to use for viewing
-      the incidences in this calendar. This is simply a convenience method which
-      makes a note of the new time zone so that it can be read back by
-      viewTimeSpec(). The client application must convert date/time values to
-      the desired time zone itself.
+      Notes the time specification which the client application intends to
+      use for viewing the incidences in this calendar. This is simply a
+      convenience method which makes a note of the new time zone so that
+      it can be read back by viewTimeSpec(). The client application must
+      convert date/time values to the desired time zone itself.
 
-      The time zone is not used in any way by the Calendar or its incidences. It
-      is solely for use by the client application.
-      @ref viewTimeSpec()
+      The time specification is not used in any way by the Calendar or its
+      incidences; it is solely for use by the client application.
+
+      @param timeSpec time specification
+
+      @see viewTimeSpec()
+    */
+    void setViewTimeSpec( const KDateTime::Spec &timeSpec ) const;
+
+    /**
+      Notes the time zone Id which the client application intends to use for
+      viewing the incidences in this calendar. This is simply a convenience
+      method which makes a note of the new time zone so that it can be read
+      back by viewTimeId(). The client application must convert date/time
+      values to the desired time zone itself.
+
+      The Id is not used in any way by the Calendar or its incidences.
+      It is solely for use by the client application.
+
+      @param timeZoneId is a string containing a time zone ID, which is
+      assumed to be valid. The time zone ID is used to set the time zone
+      for viewing Incidence date/times. If no time zone is found, the
+      viewing time specification is set to local clock time.
+      @e Example: "Europe/Berlin"
+
+      @see viewTimeZoneId()
     */
-    void setViewTimeSpec( const KDateTime::Spec &spec ) const;
     void setViewTimeZoneId( const QString &timeZoneId ) const;
 
     /**
-      Returns the time specification (time zone, etc.) used for viewing the
-      incidences in this calendar. This simply returns the time specification
-      last set by setViewTimeSpec().
+      Returns the time specification used for viewing the incidences in
+      this calendar. This simply returns the time specification last
+      set by setViewTimeSpec().
+      @see setViewTimeSpec().
     */
     KDateTime::Spec viewTimeSpec() const;
+
+    /**
+      Returns the time zone Id used for viewing the incidences in this
+      calendar. This simply returns the time specification last set by
+      setViewTimeSpec().
+      @see setViewTimeZoneId().
+    */
     QString viewTimeZoneId() const;
 
     /**
@@ -270,7 +299,7 @@ class KCAL_EXPORT Calendar : public QObject, public CustomProperties,
 
       @see isLocalTime()
     */
-    void shiftTimes(const KDateTime::Spec &oldSpec, const KDateTime::Spec &newSpec);
+    void shiftTimes( const KDateTime::Spec &oldSpec, const KDateTime::Spec &newSpec );
 
     /**
       Returns the time zone collection used by the calendar.
@@ -315,8 +344,10 @@ class KCAL_EXPORT Calendar : public QObject, public CustomProperties,
 
     /**
       Syncs changes in memory to persistent storage.
+
+      @return true if the save was successful; false otherwise.
     */
-    virtual void save() = 0;
+    virtual bool save() = 0;
 
     /**
       Loads the calendar contents from storage. This requires that the
@@ -325,17 +356,13 @@ class KCAL_EXPORT Calendar : public QObject, public CustomProperties,
       @return true if the reload was successful; otherwise false.
     */
     virtual bool reload() = 0;
-    /** Use reload() plus setTimeZoneId() instead. */
-
-    virtual KDE_DEPRECATED
-    bool reload( const QString &tz ) = 0;
 
     /**
       Determine if the calendar is currently being saved.
 
       @return true if the calendar is currently being saved; false otherwise.
     */
-    virtual bool isSaving() { return false; }
+    virtual bool isSaving();
 
     /**
       Returns a list of all categories used by Incidences in this Calendar.
@@ -411,6 +438,14 @@ class KCAL_EXPORT Calendar : public QObject, public CustomProperties,
     */
     Incidence *incidenceFromSchedulingID( const QString &sid );
 
+    /**
+      Searches all events and todos for an incidence with this
+      scheduling identifiere. Returns a list of matching results.
+
+      @param sid is a unique scheduling identifier string.
+     */
+    Incidence::List incidencesFromSchedulingID( const QString &sid );
+
     /**
       Create a merged list of Events, Todos, and Journals.
 
@@ -438,9 +473,6 @@ class KCAL_EXPORT Calendar : public QObject, public CustomProperties,
     */
     virtual bool endChange( Incidence *incidence );
 
-// Dissociate a single occurrence or all future occurrences from a recurring
-// sequence. The new incidence is returned, but not automatically inserted
-// into the calendar, which is left to the calling application.
     /**
       Dissociate an Incidence from a recurring Incidence.
       By default, only one single Incidence for the specified @a date
@@ -452,12 +484,14 @@ class KCAL_EXPORT Calendar : public QObject, public CustomProperties,
       @param incidence is a pointer to a recurring Incidence.
       @param date is the QDate within the recurring Incidence on which
       the dissociation will be performed.
+      @param spec is the spec in which the @a date is formulated.
       @param single is a flag meaning that a new Incidence should be created
       from the recurring Incidences after @a date.
 
       @return a pointer to a new recurring Incidence if @a single is false.
     */
     Incidence *dissociateOccurrence( Incidence *incidence, const QDate &date,
+                                     const KDateTime::Spec &spec,
                                      bool single = true );
 
   // Event Specific Methods //
@@ -480,10 +514,16 @@ class KCAL_EXPORT Calendar : public QObject, public CustomProperties,
 
       @return true if the Event was successfully remove; false otherwise.
 
-      @see addEvent()
+      @see addEvent(), deleteAllEvents()
     */
     virtual bool deleteEvent( Event *event ) = 0;
 
+    /**
+      Removes all Events from the calendar.
+      @see deleteEvent()
+    */
+    virtual void deleteAllEvents() = 0;
+
     /**
       Sort a list of Events.
 
@@ -516,13 +556,14 @@ class KCAL_EXPORT Calendar : public QObject, public CustomProperties,
       @return the list of filtered Events occurring on the specified timestamp.
     */
     Event::List events( const KDateTime &dt );
-    KDE_DEPRECATED Event::List events( const QDateTime &qdt );
 
     /**
       Returns a filtered list of all Events occurring within a date range.
 
       @param start is the starting date.
       @param end is the ending date.
+      @param timespec time zone etc. to interpret @p start and @p end,
+                      or the calendar's default time spec if none is specified
       @param inclusive if true only Events which are completely included
       within the date range are returned.
 
@@ -530,6 +571,7 @@ class KCAL_EXPORT Calendar : public QObject, public CustomProperties,
       date range.
     */
     Event::List events( const QDate &start, const QDate &end,
+                        const KDateTime::Spec &timespec = KDateTime::Spec(),
                         bool inclusive = false );
 
     /**
@@ -538,6 +580,8 @@ class KCAL_EXPORT Calendar : public QObject, public CustomProperties,
       @a sortDirection.
 
       @param date request filtered Event list for this QDate only.
+      @param timespec time zone etc. to interpret @p start and @p end,
+                      or the calendar's default time spec if none is specified
       @param sortField specifies the EventSortField.
       @param sortDirection specifies the SortDirection.
 
@@ -545,6 +589,7 @@ class KCAL_EXPORT Calendar : public QObject, public CustomProperties,
     */
     Event::List events(
       const QDate &date,
+      const KDateTime::Spec &timespec = KDateTime::Spec(),
       EventSortField sortField = EventSortUnsorted,
       SortDirection sortDirection = SortDirectionAscending );
 
@@ -570,13 +615,14 @@ class KCAL_EXPORT Calendar : public QObject, public CustomProperties,
       timestamp.
     */
     virtual Event::List rawEventsForDate( const KDateTime &dt ) = 0;
-    KDE_DEPRECATED Event::List rawEventsForDate( const QDateTime &qdt );
 
     /**
       Returns an unfiltered list of all Events occurring within a date range.
 
-      @param start is the starting date.
-      @param end is the ending date.
+      @param start is the starting date
+      @param end is the ending date
+      @param timespec time zone etc. to interpret @p start and @p end,
+                      or the calendar's default time spec if none is specified
       @param inclusive if true only Events which are completely included
       within the date range are returned.
 
@@ -584,6 +630,7 @@ class KCAL_EXPORT Calendar : public QObject, public CustomProperties,
       date range.
     */
     virtual Event::List rawEvents( const QDate &start, const QDate &end,
+                                   const KDateTime::Spec &timespec = KDateTime::Spec(),
                                    bool inclusive = false ) = 0;
 
     /**
@@ -591,14 +638,16 @@ class KCAL_EXPORT Calendar : public QObject, public CustomProperties,
       date.  The Events are sorted according to @a sortField and
       @a sortDirection.
 
-      @param date request unfiltered Event list for this QDate only.
-      @param sortField specifies the EventSortField.
-      @param sortDirection specifies the SortDirection.
+      @param date request unfiltered Event list for this QDate only
+      @param timespec time zone etc. to interpret @p date,
+                      or the calendar's default time spec if none is specified
+      @param sortField specifies the EventSortField
+      @param sortDirection specifies the SortDirection
 
-      @return the list of sorted, unfiltered Events occurring on @a date.
+      @return the list of sorted, unfiltered Events occurring on @p date
     */
     virtual Event::List rawEventsForDate(
-      const QDate &date,
+      const QDate &date, const KDateTime::Spec &timespec = KDateTime::Spec(),
       EventSortField sortField = EventSortUnsorted,
       SortDirection sortDirection = SortDirectionAscending ) = 0;
 
@@ -632,10 +681,16 @@ class KCAL_EXPORT Calendar : public QObject, public CustomProperties,
 
       @return true if the Todo was successfully removed; false otherwise.
 
-      @see addTodo()
+      @see addTodo(), deleteAllTodos()
     */
     virtual bool deleteTodo( Todo *todo ) = 0;
 
+    /**
+      Removes all To-dos from the calendar.
+      @see deleteTodo()
+    */
+    virtual void deleteAllTodos() = 0;
+
     /**
       Sort a list of Todos.
 
@@ -721,10 +776,16 @@ class KCAL_EXPORT Calendar : public QObject, public CustomProperties,
 
       @return true if the Journal was successfully removed; false otherwise.
 
-      @see addJournal()
+      @see addJournal(), deleteAllJournals()
     */
     virtual bool deleteJournal( Journal *journal ) = 0;
 
+    /**
+      Removes all Journals from the calendar.
+      @see deleteJournal()
+    */
+    virtual void deleteAllJournals() = 0;
+
     /**
       Sort a list of Journals.
 
@@ -849,7 +910,7 @@ class KCAL_EXPORT Calendar : public QObject, public CustomProperties,
 
       The CalendarObserver class.
     */
-    class CalendarObserver
+    class KCAL_EXPORT CalendarObserver //krazy:exclude=dpointer
     {
       public:
         /**
@@ -864,32 +925,28 @@ class KCAL_EXPORT Calendar : public QObject, public CustomProperties,
           @param calendar is a pointer to the Calendar object that
           is being observed.
         */
-        virtual void calendarModified( bool modified, Calendar *calendar )
-          { Q_UNUSED( modified ); Q_UNUSED( calendar ); }
+        virtual void calendarModified( bool modified, Calendar *calendar );
 
         /**
           Notify the Observer that an Incidence has been inserted.
 
           @param incidence is a pointer to the Incidence that was inserted.
         */
-        virtual void calendarIncidenceAdded( Incidence *incidence )
-          { Q_UNUSED( incidence );}
+        virtual void calendarIncidenceAdded( Incidence *incidence );
 
         /**
           Notify the Observer that an Incidence has been modified.
 
           @param incidence is a pointer to the Incidence that was modified.
         */
-        virtual void calendarIncidenceChanged( Incidence *incidence )
-          { Q_UNUSED( incidence ); }
+        virtual void calendarIncidenceChanged( Incidence *incidence );
 
         /**
           Notify the Observer that an Incidence has been removed.
 
           @param incidence is a pointer to the Incidence that was removed.
         */
-        virtual void calendarIncidenceDeleted( Incidence *incidence )
-          { Q_UNUSED( incidence ); }
+        virtual void calendarIncidenceDeleted( Incidence *incidence );
     };
 
     /**
@@ -942,8 +999,7 @@ class KCAL_EXPORT Calendar : public QObject, public CustomProperties,
       @param timeSpec is the time specification (time zone, etc.) for
                       viewing Incidence dates.\n
     */
-    virtual void doSetTimeSpec( const KDateTime::Spec &timeSpec )
-      { Q_UNUSED( timeSpec ); }
+    virtual void doSetTimeSpec( const KDateTime::Spec &timeSpec );
 
     /**
       Let Calendar subclasses notify that they inserted an Incidence.
@@ -980,11 +1036,27 @@ class KCAL_EXPORT Calendar : public QObject, public CustomProperties,
     */
     void setObserversEnabled( bool enabled );
 
-    /** Appends alarms of incidence in interval to list of alarms. */
+    /**
+      Appends alarms of incidence in interval to list of alarms.
+
+      @param alarms is a List of Alarms to be appended onto.
+      @param incidence is a pointer to an Incidence containing the Alarm
+      to be appended.
+      @param from is the lower range of the next Alarm repitition.
+      @param to is the upper range of the next Alarm repitition.
+    */
     void appendAlarms( Alarm::List &alarms, Incidence *incidence,
                        const KDateTime &from, const KDateTime &to );
 
-    /** Appends alarms of recurring events in interval to list of alarms. */
+    /**
+      Appends alarms of recurring events in interval to list of alarms.
+
+      @param alarms is a List of Alarms to be appended onto.
+      @param incidence is a pointer to an Incidence containing the Alarm
+      to be appended.
+      @param from is the lower range of the next Alarm repitition.
+      @param to is the upper range of the next Alarm repitition.
+    */
     void appendRecurringAlarms( Alarm::List &alarms, Incidence *incidence,
                                 const KDateTime &from, const KDateTime &to );
 
