@@ -1,48 +1,51 @@
 /*
-    This file is part of the kcal library.
+  This file is part of the kcal library.
 
-    Copyright (c) 1998 Preston Brown <pbrown@kde.org>
-    Copyright (c) 2001,2003,2004 Cornelius Schumacher <schumacher@kde.org>
-    Copyright (C) 2003-2004 Reinhold Kainhofer <reinhold@kainhofer.com>
+  Copyright (c) 1998 Preston Brown <pbrown@kde.org>
+  Copyright (c) 2001,2003,2004 Cornelius Schumacher <schumacher@kde.org>
+  Copyright (C) 2003-2004 Reinhold Kainhofer <reinhold@kainhofer.com>
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Library General Public
-    License as published by the Free Software Foundation; either
-    version 2 of the License, or (at your option) any later version.
+  This library is free software; you can redistribute it and/or
+  modify it under the terms of the GNU Library General Public
+  License as published by the Free Software Foundation; either
+  version 2 of the License, or (at your option) any later version.
 
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Library General Public License for more details.
+  This library is distributed in the hope that it will be useful,
+  but WITHOUT ANY WARRANTY; without even the implied warranty of
+  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+  Library General Public License for more details.
 
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-    Boston, MA 02110-1301, USA.
+  You should have received a copy of the GNU Library General Public License
+  along with this library; see the file COPYING.LIB.  If not, write to
+  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+  Boston, MA 02110-1301, USA.
 */
 /**
   @file
   This file is part of the API for handling calendar data and
   defines the CalendarLocal class.
 
-  @author Preston Brown
-  @author Cornelius Schumacher
- */
-#include <QHash>
-#include <QString>
+  @brief
+  This class provides a calendar stored as a local file.
 
-#include <kdebug.h>
-#include <kdatetime.h>
-#include <klocale.h>
-#include <kmessagebox.h>
+  @author Preston Brown \<pbrown@kde.org\>
+  @author Cornelius Schumacher \<schumacher@kde.org\>
+ */
+
+#include "calendarlocal.h"
 
 #include "incidence.h"
 #include "event.h"
 #include "todo.h"
 #include "journal.h"
 #include "filestorage.h"
+#include <QtCore/QHash>
+#include <QtCore/QString>
 
-#include "calendarlocal.h"
+#include <kdebug.h>
+#include <kdatetime.h>
+#include <klocale.h>
+#include <kmessagebox.h>
 
 using namespace KCal;
 
@@ -56,17 +59,22 @@ class KCal::CalendarLocal::Private
   public:
     Private()
     {
-        mDeletedIncidences.setAutoDelete( true );
+      mDeletedIncidences.setAutoDelete( true );
     }
-    QString mFileName;                  // filename where the calendar is stored
+    QString mFileName;                 // filename where the calendar is stored
+    CalFormat *mFormat;                // calendar format
+
     QHash<QString, Event *> mEvents;    // hash on uids of all calendar events
     QHash<QString, Todo *> mTodos;      // hash on uids of all calendar to-dos
     QHash<QString, Journal *> mJournals;// hash on uids of all calendar journals
     Incidence::List mDeletedIncidences; // list of all deleted incidences
+
+    void insertEvent( Event *event );
+    void insertTodo( Todo *todo );
+    void insertJournal( Journal *journal );
 };
 //@endcond
 
-
 CalendarLocal::CalendarLocal( const KDateTime::Spec &timeSpec )
   : Calendar( timeSpec ),
     d( new KCal::CalendarLocal::Private )
@@ -102,6 +110,20 @@ bool CalendarLocal::reload()
   return storage.load();
 }
 
+bool CalendarLocal::save()
+{
+  if ( d->mFileName.isEmpty() ) {
+    return false;
+  }
+
+  if ( isModified() ) {
+    FileStorage storage( this, d->mFileName, d->mFormat );
+    return storage.save();
+  } else {
+    return true;
+  }
+}
+
 bool CalendarLocal::save( const QString &fileName, CalFormat *format )
 {
   // Save only if the calendar is either modified, or saved to a
@@ -131,7 +153,7 @@ void CalendarLocal::close()
 
 bool CalendarLocal::addEvent( Event *event )
 {
-  insertEvent( event );
+  d->insertEvent( event );
 
   event->registerObserver( this );
 
@@ -150,7 +172,7 @@ bool CalendarLocal::deleteEvent( Event *event )
     d->mDeletedIncidences.append( event );
     return true;
   } else {
-    kWarning() << "CalendarLocal::deleteEvent(): Event not found." << endl;
+    kWarning() << "CalendarLocal::deleteEvent(): Event not found.";
     return false;
   }
 }
@@ -171,7 +193,7 @@ Event *CalendarLocal::event( const QString &uid )
 
 bool CalendarLocal::addTodo( Todo *todo )
 {
-  insertTodo( todo );
+  d->insertTodo( todo );
 
   todo->registerObserver( this );
 
@@ -185,20 +207,21 @@ bool CalendarLocal::addTodo( Todo *todo )
   return true;
 }
 
-void CalendarLocal::insertTodo( Todo *todo )
+//@cond PRIVATE
+void CalendarLocal::Private::insertTodo( Todo *todo )
 {
   QString uid = todo->uid();
-  if ( d->mTodos.value( uid ) == 0 ) {
-    d->mTodos.insert( uid, todo );
-  }
+  if ( mTodos.value( uid ) == 0 ) {
+    mTodos.insert( uid, todo );
+  } else {
 #ifndef NDEBUG
-  else {
     // if we already have an to-do with this UID, it must be the same to-do,
     // otherwise something's really broken
-    Q_ASSERT( d->mTodos.value( uid ) == todo );
-  }
+    Q_ASSERT( mTodos.value( uid ) == todo );
 #endif
+  }
 }
+//@endcond
 
 bool CalendarLocal::deleteTodo( Todo *todo )
 {
@@ -211,7 +234,7 @@ bool CalendarLocal::deleteTodo( Todo *todo )
     d->mDeletedIncidences.append( todo );
     return true;
   } else {
-    kWarning() << "CalendarLocal::deleteTodo(): Todo not found." << endl;
+    kWarning() << "CalendarLocal::deleteTodo(): Todo not found.";
     return false;
   }
 }
@@ -260,7 +283,7 @@ Alarm::List CalendarLocal::alarms( const KDateTime &from, const KDateTime &to )
 {
   Alarm::List alarms;
   foreach ( Event *e, d->mEvents ) {
-    if ( e->doesRecur() ) {
+    if ( e->recurs() ) {
       appendRecurringAlarms( alarms, e, from, to );
     } else {
       appendAlarms( alarms, e, from, to );
@@ -276,48 +299,73 @@ Alarm::List CalendarLocal::alarms( const KDateTime &from, const KDateTime &to )
   return alarms;
 }
 
-void CalendarLocal::insertEvent( Event *event )
+//@cond PRIVATE
+void CalendarLocal::Private::insertEvent( Event *event )
 {
   QString uid = event->uid();
-  if ( d->mEvents.value( uid ) == 0 ) {
-    d->mEvents.insert( uid, event );
-  }
-#ifndef NDEBUG
-  else {
+  if ( mEvents.value( uid ) == 0 ) {
+    mEvents.insert( uid, event );
+  } else {
+#ifdef NDEBUG
     // if we already have an event with this UID, it must be the same event,
     // otherwise something's really broken
-    Q_ASSERT( d->mEvents.value( uid ) == event );
-  }
+    Q_ASSERT( mEvents.value( uid ) == event );
 #endif
+  }
+}
+//@endcond
+
+void CalendarLocal::incidenceUpdated( IncidenceBase *incidence )
+{
+  KDateTime nowUTC = KDateTime::currentUtcDateTime();
+  incidence->setLastModified( nowUTC );
+  // we should probably update the revision number here,
+  // or internally in the Event itself when certain things change.
+  // need to verify with ical documentation.
+
+  // The static_cast is ok as the CalendarLocal only observes Incidence objects
+  notifyIncidenceChanged( static_cast<Incidence *>( incidence ) );
+
+  setModified( true );
 }
 
 Event::List CalendarLocal::rawEventsForDate( const QDate &qd,
+                                             const KDateTime::Spec &timespec,
                                              EventSortField sortField,
                                              SortDirection sortDirection )
 {
-//TODO: add KDateTime::Spec parameter?
   Event::List eventList;
+  KDateTime::Spec ts = timespec.isValid() ? timespec : timeSpec();
 
   foreach ( Event *event, d->mEvents ) {
 
-    if ( event->doesRecur() ) {
+    if ( event->recurs() ) {
       if ( event->isMultiDay() ) {
         int extraDays = event->dtStart().date().daysTo( event->dtEnd().date() );
         int i;
         for ( i = 0; i <= extraDays; i++ ) {
-          if ( event->recursOn( qd.addDays( -i ), timeSpec() ) ) {
+          if ( event->recursOn( qd.addDays( -i ), ts ) ) {
             eventList.append( event );
             break;
           }
         }
       } else {
-        if ( event->recursOn( qd, timeSpec() ) ) {
+        if ( event->recursOn( qd, ts ) ) {
           eventList.append( event );
         }
       }
     } else {
-      if ( event->dtStart().date() <= qd && event->dateEnd() >= qd ) {
-        eventList.append( event );
+      KDateTime kdt( qd, ts );
+      if ( event->dtStart() <= kdt ) {
+        KDateTime end( event->dtEnd().toTimeSpec( event->dtStart() ) );
+        if ( event->floats() ) {
+          end.setDateOnly( true );
+        } else {
+          end = end.addSecs(-1);
+        }
+        if ( end >= kdt ) {
+          eventList.append( event );
+        }
       }
     }
   }
@@ -326,23 +374,25 @@ Event::List CalendarLocal::rawEventsForDate( const QDate &qd,
 }
 
 Event::List CalendarLocal::rawEvents( const QDate &start, const QDate &end,
-                                          bool inclusive )
+                                      const KDateTime::Spec &timespec, bool inclusive )
 {
-//TODO: add KDateTime::Spec parameter?
   Event::List eventList;
+  KDateTime::Spec ts = timespec.isValid() ? timespec : timeSpec();
+  KDateTime st( start, ts );
+  KDateTime nd( end, ts );
 
   // Get non-recurring events
   foreach ( Event *event, d->mEvents ) {
-    if ( event->doesRecur() ) {
-      QDate rStart = event->dtStart().date();
+    if ( event->recurs() ) {
+      KDateTime rStart = event->dtStart();
       bool found = false;
       if ( inclusive ) {
-        if ( rStart >= start && rStart <= end ) {
+        if ( rStart >= st && rStart <= nd ) {
           // Start date of event is in range. Now check for end date.
           // if duration is negative, event recurs forever, so do not include it.
           if ( event->recurrence()->duration() == 0 ) {  // End date set
-            QDate rEnd = event->recurrence()->endDate();
-            if ( rEnd >= start && rEnd <= end ) {  // End date within range
+            KDateTime rEnd = event->recurrence()->endDateTime();
+            if ( rEnd >= st && rEnd <= nd ) {  // End date within range
               found = true;
             }
           } else if ( event->recurrence()->duration() > 0 ) {  // Duration set
@@ -351,14 +401,14 @@ Event::List CalendarLocal::rawEvents( const QDate &start, const QDate &end,
           }
         }
       } else {
-        if ( rStart <= end ) {  // Start date not after range
-          if ( rStart >= start ) {  // Start date within range
+        if ( rStart <= nd ) {  // Start date not after range
+          if ( rStart >= st ) {  // Start date within range
             found = true;
           } else if ( event->recurrence()->duration() == -1 ) {// Recurs forever
             found = true;
           } else if ( event->recurrence()->duration() == 0 ) { // End date set
-            QDate rEnd = event->recurrence()->endDate();
-            if ( rEnd >= start && rEnd <= end ) {  // End date within range
+            KDateTime rEnd = event->recurrence()->endDateTime();
+            if ( rEnd >= st && rEnd <= nd ) {  // End date within range
               found = true;
             }
           } else {  // Duration set
@@ -374,15 +424,15 @@ Event::List CalendarLocal::rawEvents( const QDate &start, const QDate &end,
       }
 
     } else {
-      QDate s = event->dtStart().date();
-      QDate e = event->dtEnd().date();
+      KDateTime s = event->dtStart();
+      KDateTime e = event->dtEnd();
 
       if ( inclusive ) {
-        if ( s >= start && e <= end ) {
+        if ( s >= st && e <= nd ) {
           eventList.append( event );
         }
       } else {
-        if ( s <= end && e >= start ) {
+        if ( s <= nd && e >= st ) {
           eventList.append( event );
         }
       }
@@ -392,9 +442,9 @@ Event::List CalendarLocal::rawEvents( const QDate &start, const QDate &end,
   return eventList;
 }
 
-Event::List CalendarLocal::rawEventsForDate( const KDateTime &qdt )
+Event::List CalendarLocal::rawEventsForDate( const KDateTime &kdt )
 {
-  return rawEventsForDate( qdt.date() );
+  return rawEventsForDate( kdt.date(), kdt.timeSpec() );
 }
 
 Event::List CalendarLocal::rawEvents( EventSortField sortField,
@@ -409,7 +459,7 @@ Event::List CalendarLocal::rawEvents( EventSortField sortField,
 
 bool CalendarLocal::addJournal( Journal *journal )
 {
-  insertJournal( journal );
+  d->insertJournal( journal );
 
   journal->registerObserver( this );
 
@@ -420,20 +470,21 @@ bool CalendarLocal::addJournal( Journal *journal )
   return true;
 }
 
-void CalendarLocal::insertJournal( Journal *journal )
+//@cond PRIVATE
+void CalendarLocal::Private::insertJournal( Journal *journal )
 {
   QString uid = journal->uid();
-  if ( d->mJournals.value( uid ) == 0 ) {
-    d->mJournals.insert( uid, journal );
-  }
+  if ( mJournals.value( uid ) == 0 ) {
+    mJournals.insert( uid, journal );
+  } else {
 #ifndef NDEBUG
-  else {
     // if we already have an journal with this UID, it must be the same journal,
     // otherwise something's really broken
-    Q_ASSERT( d->mJournals.value( uid ) == journal );
-  }
+    Q_ASSERT( mJournals.value( uid ) == journal );
 #endif
+  }
 }
+//@endcond
 
 bool CalendarLocal::deleteJournal( Journal *journal )
 {
@@ -443,7 +494,7 @@ bool CalendarLocal::deleteJournal( Journal *journal )
     d->mDeletedIncidences.append( journal );
     return true;
   } else {
-    kWarning() << "CalendarLocal::deleteJournal(): Journal not found." << endl;
+    kWarning() << "CalendarLocal::deleteJournal(): Journal not found.";
     return false;
   }
 }
@@ -482,19 +533,3 @@ Journal::List CalendarLocal::rawJournalsForDate( const QDate &date )
   }
   return journalList;
 }
-
-// DEPRECATED methods
-#include "icaltimezones.h"
-Alarm::List CalendarLocal::alarmsTo( const QDateTime &to )
-{ return alarmsTo(KDateTime(to, timeSpec())); }
-
-bool CalendarLocal::reload( const QString &tz )
-{
-  const QString filename = d->mFileName;
-  save();
-  close();
-  d->mFileName = filename;
-  setTimeZoneId( tz );
-  FileStorage storage( this, d->mFileName );
-  return storage.load();
-}
