@@ -1,48 +1,80 @@
 /*
-    This file is part of the kcal library.
+  This file is part of the kcal library.
 
-    Copyright (c) 1998 Preston Brown <pbrown@kde.org>
-    Copyright (c) 2001,2002 Cornelius Schumacher <schumacher@kde.org>
-    Copyright (C) 2003-2004 Reinhold Kainhofer <reinhold@kainhofer.com>
-    Copyright (c) 2005 Rafal Rzepecki <divide@users.sourceforge.net>
+  Copyright (c) 1998 Preston Brown <pbrown@kde.org>
+  Copyright (c) 2001,2002 Cornelius Schumacher <schumacher@kde.org>
+  Copyright (C) 2003-2004 Reinhold Kainhofer <reinhold@kainhofer.com>
+  Copyright (c) 2005 Rafal Rzepecki <divide@users.sourceforge.net>
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Library General Public
-    License as published by the Free Software Foundation; either
-    version 2 of the License, or (at your option) any later version.
+  This library is free software; you can redistribute it and/or
+  modify it under the terms of the GNU Library General Public
+  License as published by the Free Software Foundation; either
+  version 2 of the License, or (at your option) any later version.
 
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Library General Public License for more details.
+  This library is distributed in the hope that it will be useful,
+  but WITHOUT ANY WARRANTY; without even the implied warranty of
+  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+  Library General Public License for more details.
 
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-    Boston, MA 02110-1301, USA.
+  You should have received a copy of the GNU Library General Public License
+  along with this library; see the file COPYING.LIB.  If not, write to
+  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+  Boston, MA 02110-1301, USA.
+*/
+/**
+  @file
+  This file is part of the API for handling calendar data and
+  defines the DndFactory class.
+
+  @brief
+  vCalendar/iCalendar Drag-and-Drop object factory.
+
+  @author Preston Brown \<pbrown@kde.org\>
+  @author Cornelius Schumacher \<schumacher@kde.org\>
+  @author Reinhold Kainhofer \<reinhold@kainhofer.com\>
 */
 
-#include <QApplication>
-#include <QClipboard>
-#include <QDropEvent>
-#include <QPixmap>
+#include "dndfactory.h"
+#include "vcaldrag.h"
+#include "icaldrag.h"
+#include "calendar.h"
+#include "calendarlocal.h"
 
 #include <kiconloader.h>
 #include <kdebug.h>
 #include <klocale.h>
 #include <kurl.h>
 
-#include "vcaldrag.h"
-#include "icaldrag.h"
-#include "calendar.h"
-#include "calendarlocal.h"
-#include "dndfactory.h"
+#include <QtGui/QApplication>
+#include <QtGui/QClipboard>
+#include <QtGui/QDropEvent>
+#include <QtGui/QPixmap>
 
 using namespace KCal;
 
-DndFactory::DndFactory( Calendar *cal ) :
-  mCalendar( cal ), d( 0 )
+/**
+  Private class that helps to provide binary compatibility between releases.
+  @internal
+*/
+//@cond PRIVATE
+class KCal::DndFactory::Private
 {
+  public:
+    Private( Calendar *cal )
+      : mCalendar ( cal )
+    {}
+    Calendar *mCalendar;
+};
+//@endcond
+
+DndFactory::DndFactory( Calendar *cal )
+  : d( new KCal::DndFactory::Private ( cal ) )
+{
+}
+
+DndFactory::~DndFactory()
+{
+  delete d;
 }
 
 QDrag *DndFactory::createDrag( QWidget *owner )
@@ -51,15 +83,15 @@ QDrag *DndFactory::createDrag( QWidget *owner )
   QMimeData *mimeData = new QMimeData;
   drag->setMimeData( mimeData );
 
-  ICalDrag::populateMimeData( mimeData, mCalendar );
-  VCalDrag::populateMimeData( mimeData, mCalendar );
+  ICalDrag::populateMimeData( mimeData, d->mCalendar );
+  VCalDrag::populateMimeData( mimeData, d->mCalendar );
 
   return drag;
 }
 
 QDrag *DndFactory::createDrag( Incidence *incidence, QWidget *owner )
 {
-  CalendarLocal cal( mCalendar->timeSpec() );
+  CalendarLocal cal( d->mCalendar->timeSpec() );
   Incidence *i = incidence->clone();
   cal.addIncidence( i );
 
@@ -72,22 +104,23 @@ QDrag *DndFactory::createDrag( Incidence *incidence, QWidget *owner )
 
   KUrl uri = i->uri();
   if ( uri.isValid() ) {
-  QMap<QString, QString> metadata;
+    QMap<QString, QString> metadata;
     metadata["labels"] = KUrl::toPercentEncoding( i->summary() );
     uri.populateMimeData( mimeData, metadata );
   }
 
-  if ( i->type() == "Event" )
+  if ( i->type() == "Event" ) {
     drag->setPixmap( BarIcon( "appointment" ) );
-  else if ( i->type() == "Todo" )
+  } else if ( i->type() == "Todo" ) {
     drag->setPixmap( BarIcon( "todo" ) );
+  }
 
   return drag;
 }
 
 Calendar *DndFactory::createDropCalendar( const QMimeData *md )
 {
-  Calendar *cal = new CalendarLocal( mCalendar->timeSpec() );
+  Calendar *cal = new CalendarLocal( d->mCalendar->timeSpec() );
 
   if ( ICalDrag::fromMimeData( md, cal ) ||
        VCalDrag::fromMimeData( md, cal ) ){
@@ -106,9 +139,9 @@ Calendar *DndFactory::createDropCalendar( QDropEvent *de )
   return 0;
 }
 
-Event *DndFactory::createDropEvent(QDropEvent *de)
+Event *DndFactory::createDropEvent( QDropEvent *de )
 {
-  kDebug(5800) << "DndFactory::createDrop()" << endl;
+  kDebug(5800) << "DndFactory::createDrop()";
   Event *ev = 0;
   Calendar *cal = createDropCalendar( de );
 
@@ -122,9 +155,9 @@ Event *DndFactory::createDropEvent(QDropEvent *de)
   return ev;
 }
 
-Todo *DndFactory::createDropTodo(QDropEvent *de)
+Todo *DndFactory::createDropTodo( QDropEvent *de )
 {
-  kDebug(5800) << "DndFactory::createDropTodo()" << endl;
+  kDebug(5800) << "DndFactory::createDropTodo()";
   Todo *todo = 0;
   Calendar *cal = createDropCalendar( de );
 
@@ -139,21 +172,22 @@ Todo *DndFactory::createDropTodo(QDropEvent *de)
   return todo;
 }
 
-
 void DndFactory::cutIncidence( Incidence *selectedInc )
 {
   if ( copyIncidence( selectedInc ) ) {
-    mCalendar->deleteIncidence( selectedInc );
+    d->mCalendar->deleteIncidence( selectedInc );
   }
 }
 
 bool DndFactory::copyIncidence( Incidence *selectedInc )
 {
-  if ( !selectedInc )
+  if ( !selectedInc ) {
     return false;
+  }
+
   QClipboard *cb = QApplication::clipboard();
 
-  CalendarLocal cal( mCalendar->timeSpec() );
+  CalendarLocal cal( d->mCalendar->timeSpec() );
   Incidence *inc = selectedInc->clone();
   cal.addIncidence( inc );
 
@@ -166,15 +200,13 @@ bool DndFactory::copyIncidence( Incidence *selectedInc )
   return true;
 }
 
-Incidence *DndFactory::pasteIncidence(const QDate &newDate, const QTime *newTime)
+Incidence *DndFactory::pasteIncidence( const QDate &newDate, const QTime *newTime )
 {
-//  kDebug(5800) << "DnDFactory::pasteEvent()" << endl;
   QClipboard *cb = QApplication::clipboard();
-
   Calendar *cal = createDropCalendar( cb->mimeData() );
 
   if ( !cal ) {
-    kDebug(5800) << "Can't parse clipboard" << endl;
+    kDebug(5800) << "Can't parse clipboard";
     return 0;
   }
   Incidence *ret = 0;
@@ -201,7 +233,7 @@ Incidence *DndFactory::pasteIncidence(const QDate &newDate, const QTime *newTime
       startDate.setDate( newDate );
       if ( newTime ) {
         // additional offset for new time of day
-        int addSecsOffset( anEvent->dtStart().time().secsTo( *newTime ));
+        int addSecsOffset( anEvent->dtStart().time().secsTo( *newTime ) );
         endDate=endDate.addSecs( addSecsOffset );
         startDate.setTime( *newTime );
       }
@@ -223,11 +255,11 @@ Incidence *DndFactory::pasteIncidence(const QDate &newDate, const QTime *newTime
       if ( newTime ) {
         startDate.setTime( *newTime );
       } else {
-        startDate.setTime( QTime(0,0,0) );
+        startDate.setTime( QTime( 0, 0, 0 ) );
       }
       anJournal->setDtStart( startDate );
     } else {
-      kDebug(5850) << "Trying to paste unknown incidence of type " << inc->type() << endl;
+      kDebug(5800) << "Trying to paste unknown incidence of type" << inc->type();
     }
 
     ret = inc;
