@@ -21,11 +21,12 @@
 #ifndef KCAL_FREEBUSYCACHE_H
 #define KCAL_FREEBUSYCACHE_H
 
-#include <QString>
+#include <QtCore/QString>
 
 namespace KCal {
 
 class FreeBusy;
+class Person;
 
 class FreeBusyCache
 {
