@@ -21,50 +21,72 @@
 
 #include "freebusyurlstore.h"
 
-#include <kstaticdeleter.h>
+#include <QtCore/QCoreApplication>
+
 #include <kconfig.h>
 #include <kstandarddirs.h>
 
 using namespace KCal;
 
-static KStaticDeleter<FreeBusyUrlStore> selfDeleter;
-
-FreeBusyUrlStore *FreeBusyUrlStore::mSelf = 0;
+class FreeBusyUrlStore::Private
+{
+public:
+    Private()
+     : mConfig(0)
+    {}
+    ~Private()
+    {
+      qRemovePostRoutine(cleanupFreeBusyUrlStore);
+      cleanupFreeBusyUrlStore();
+    }
+    KConfig *mConfig;
+    
+    static FreeBusyUrlStore *sSelf;
+    static void cleanupFreeBusyUrlStore()
+    {
+      delete sSelf;
+      sSelf = 0;
+    }
+};
+FreeBusyUrlStore *FreeBusyUrlStore::Private::sSelf = 0;
 
 FreeBusyUrlStore *FreeBusyUrlStore::self()
 {
-  if ( !mSelf ) {
-    selfDeleter.setObject( mSelf, new FreeBusyUrlStore() );
+  static Private p;
+  if(!p.sSelf) {
+    p.sSelf = new FreeBusyUrlStore();
+    qAddPostRoutine(Private::cleanupFreeBusyUrlStore);
   }
-  return mSelf;
+  return p.sSelf;
 }
 
-FreeBusyUrlStore::FreeBusyUrlStore() : d( 0 )
+FreeBusyUrlStore::FreeBusyUrlStore() : d( new Private() )
 {
   QString configFile = KStandardDirs::locateLocal( "data", "korganizer/freebusyurls" );
-  mConfig = new KConfig( configFile );
+  d->mConfig = new KConfig( configFile );
 }
 
 FreeBusyUrlStore::~FreeBusyUrlStore()
 {
-  delete mConfig;
+  delete d->mConfig;
+  delete d;
 }
 
 void FreeBusyUrlStore::writeUrl( const QString &email, const QString &url )
 {
-  mConfig->setGroup( email );
+  KConfigGroup group = d->mConfig->group(email);
 
-  mConfig->writeEntry( "url", url );
+  group.writeEntry( "url", url );
 }
 
 QString FreeBusyUrlStore::readUrl( const QString &email )
 {
-  mConfig->setGroup( email );
 
-  return mConfig->readEntry( "url" );
+  KConfigGroup group = d->mConfig->group(email);
+  return group.readEntry( "url" );
 }
 
 void FreeBusyUrlStore::sync()
 {
-  mConfig->sync();
+  d->mConfig->sync();
 }
