@@ -21,11 +21,10 @@
 #ifndef KCAL_FREEBUSYURLSTORE_H
 #define KCAL_FREEBUSYURLSTORE_H
 
-#include <QString>
+#include <QtCore/QString>
 
-#include "kcal.h"
+#include "kcal_export.h"
 
-class KConfig;
 
 namespace KCal {
 
@@ -43,8 +42,6 @@ class KCAL_EXPORT FreeBusyUrlStore
 
   private:
     FreeBusyUrlStore();
-    static FreeBusyUrlStore *mSelf;
-    KConfig *mConfig;
 
     class Private;
     Private *const d;
