@@ -23,8 +23,8 @@
 #ifndef KCAL_ICALDRAG_H
 #define KCAL_ICALDRAG_H
 
-#include "kcal.h"
-#include <QString>
+#include "kcal_export.h"
+#include <QtCore/QString>
 
 class QMimeData;
 
