@@ -1,7 +1,7 @@
 /*
     This file is part of the kcal library.
 
-    Copyright (c) 2005,2006 David Jarvie <software@astrojar.org.uk>
+    Copyright (c) 2005-2007 David Jarvie <software@astrojar.org.uk>
 
     This library is free software; you can redistribute it and/or
     modify it under the terms of the GNU Library General Public
@@ -19,13 +19,18 @@
     Boston, MA 02110-1301, USA.
 */
 
-#include <QDateTime>
-#include <QString>
-#include <QList>
-#include <QVector>
-#include <QSet>
-#include <QFile>
-#include <QTextStream>
+#include "icaltimezones.h"
+
+#include "icalformat.h"
+#include "icalformat_p.h"
+
+#include <QtCore/QDateTime>
+#include <QtCore/QString>
+#include <QtCore/QList>
+#include <QtCore/QVector>
+#include <QtCore/QSet>
+#include <QtCore/QFile>
+#include <QtCore/QTextStream>
 
 #include <ksystemtimezone.h>
 #include <kdatetime.h>
@@ -36,11 +41,6 @@ extern "C" {
   #include <icaltimezone.h>
 }
 
-#include "icalformat.h"
-#include "icalformatimpl.h"
-#include "icaltimezones.h"
-
-
 using namespace KCal;
 
 
@@ -92,36 +92,11 @@ namespace KCal {
 class ICalTimeZonesPrivate
 {
 public:
-  ICalTimeZonesPrivate() : zones(new ICalTimeZones::ZoneMap())  {}
-  ~ICalTimeZonesPrivate()  { clear();  delete zones; }
-  void clear();
-  static ICalTimeZone *utc();
+  ICalTimeZonesPrivate() {}
 
-  ICalTimeZones::ZoneMap *zones;
-  QSet<ICalTimeZone*> nonconstZones;   // member zones owned by ICalTimeZones
+  ICalTimeZones::ZoneMap zones;
 };
 
-void ICalTimeZonesPrivate::clear()
-{
-  // Delete all zones actually owned by this collection.
-  for (ICalTimeZones::ZoneMap::ConstIterator it = zones->begin(), end = zones->end();  it != end;  ++it) {
-    if (nonconstZones.contains(const_cast<ICalTimeZone*>(it.value())))   // only delete zones actually owned
-      delete it.value();
-  }
-  zones->clear();
-  nonconstZones.clear();
-}
-
-ICalTimeZone *ICalTimeZonesPrivate::utc()
-{
-  static ICalTimeZone *utcZone = 0;
-  if ( !utcZone ) {
-    ICalTimeZoneSource tzs;
-    utcZone = tzs.parse( icaltimezone_get_utc_timezone() );
-  }
-  return utcZone;
-}
-
 
 ICalTimeZones::ICalTimeZones()
   : d(new ICalTimeZonesPrivate)
@@ -135,89 +110,110 @@ ICalTimeZones::~ICalTimeZones()
 
 const ICalTimeZones::ZoneMap ICalTimeZones::zones() const
 {
-  return *d->zones;
+  return d->zones;
 }
 
-bool ICalTimeZones::add(ICalTimeZone *zone)
+bool ICalTimeZones::add(const ICalTimeZone &zone)
 {
-  if (!zone)
+  if (!zone.isValid())
     return false;
-  if (d->zones->find(zone->name()) != d->zones->end())
+  if (d->zones.find(zone.name()) != d->zones.end())
     return false;    // name already exists
-  d->zones->insert(zone->name(), zone);
-  d->nonconstZones.insert(zone);
+  d->zones.insert(zone.name(), zone);
   return true;
 }
 
-bool ICalTimeZones::addConst(const ICalTimeZone *zone)
+ICalTimeZone ICalTimeZones::remove(const ICalTimeZone &zone)
 {
-  if (!zone)
-    return false;
-  if (d->zones->find(zone->name()) != d->zones->end())
-    return false;    // name already exists
-  d->zones->insert(zone->name(), zone);
-  return true;
-}
-
-const ICalTimeZone *ICalTimeZones::detach(const ICalTimeZone *zone)
-{
-  if (zone) {
-    for (ZoneMap::Iterator it = d->zones->begin(), end = d->zones->end();  it != end;  ++it) {
+  if (zone.isValid()) {
+    for (ZoneMap::Iterator it = d->zones.begin(), end = d->zones.end();  it != end;  ++it) {
       if (it.value() == zone) {
-        d->zones->erase(it);
-        d->nonconstZones.remove(const_cast<ICalTimeZone*>(zone));
-        return (zone == utc()) ? 0 : zone;
+        d->zones.erase(it);
+        return (zone == ICalTimeZone::utc()) ? ICalTimeZone() : zone;
       }
     }
   }
-  return 0;
+  return ICalTimeZone();
 }
 
-const ICalTimeZone *ICalTimeZones::detach(const QString &name)
+ICalTimeZone ICalTimeZones::remove(const QString &name)
 {
   if (!name.isEmpty()) {
-    ZoneMap::Iterator it = d->zones->find(name);
-    if (it != d->zones->end()) {
-      const ICalTimeZone *zone = it.value();
-      d->zones->erase(it);
-      d->nonconstZones.remove(const_cast<ICalTimeZone*>(zone));
-      return (zone == utc()) ? 0 : zone;
+    ZoneMap::Iterator it = d->zones.find(name);
+    if (it != d->zones.end()) {
+      ICalTimeZone zone = it.value();
+      d->zones.erase(it);
+      return (zone == ICalTimeZone::utc()) ? ICalTimeZone() : zone;
     }
   }
-  return 0;
+  return ICalTimeZone();
 }
 
 void ICalTimeZones::clear()
 {
-  d->clear();
+  d->zones.clear();
 }
 
-const ICalTimeZone *ICalTimeZones::zone(const QString &name) const
+ICalTimeZone ICalTimeZones::zone(const QString &name) const
 {
   if (!name.isEmpty()) {
-    ZoneMap::ConstIterator it = d->zones->find(name);
-    if (it != d->zones->end())
+    ZoneMap::ConstIterator it = d->zones.find(name);
+    if (it != d->zones.end())
       return it.value();
   }
-  return 0;    // error
-}
-
-const ICalTimeZone *ICalTimeZones::utc()
-{
-  return ICalTimeZonesPrivate::utc();
+  return ICalTimeZone();   // error
 }
 
 
 /******************************************************************************/
 
+ICalTimeZoneBackend::ICalTimeZoneBackend()
+  : KTimeZoneBackend()
+{}
+
+ICalTimeZoneBackend::ICalTimeZoneBackend(ICalTimeZoneSource *source, const QString &name,
+       const QString &countryCode, float latitude, float longitude, const QString &comment)
+  : KTimeZoneBackend(source, name, countryCode, latitude, longitude, comment)
+{}
+
+ICalTimeZoneBackend::ICalTimeZoneBackend(const KTimeZone &tz, const QDate &earliest)
+  : KTimeZoneBackend(0, tz.name(), tz.countryCode(), tz.latitude(), tz.longitude(), tz.comment())
+{}
+
+ICalTimeZoneBackend::~ICalTimeZoneBackend()
+{}
+
+KTimeZoneBackend *ICalTimeZoneBackend::clone() const
+{
+    return new ICalTimeZoneBackend(*this);
+}
+
+QByteArray ICalTimeZoneBackend::type() const
+{
+    return "ICalTimeZone";
+}
+
+bool ICalTimeZoneBackend::hasTransitions(const KTimeZone *caller) const
+{
+    Q_UNUSED(caller)
+    return true;
+}
+
+
+/******************************************************************************/
+
+ICalTimeZone::ICalTimeZone()
+  : KTimeZone(new ICalTimeZoneBackend())
+{}
+
 ICalTimeZone::ICalTimeZone(ICalTimeZoneSource *source, const QString &name, ICalTimeZoneData *data)
-  : KTimeZone(source, name), d( 0 )
+  : KTimeZone(new ICalTimeZoneBackend(source, name))
 {
   setData(data);
 }
 
 ICalTimeZone::ICalTimeZone(const KTimeZone &tz, const QDate &earliest)
-  : KTimeZone(0, tz.name(), tz.countryCode(), tz.latitude(), tz.longitude(), tz.comment()), d( 0 )
+  : KTimeZone(new ICalTimeZoneBackend(0, tz.name(), tz.countryCode(), tz.latitude(), tz.longitude(), tz.comment()))
 {
   const KTimeZoneData *data = tz.data(true);
   if (data) {
@@ -229,20 +225,8 @@ ICalTimeZone::ICalTimeZone(const KTimeZone &tz, const QDate &earliest)
   }
 }
 
-ICalTimeZone::ICalTimeZone(const ICalTimeZone &tz)
-  : KTimeZone(tz), d( 0 )
-{
-}
-
 ICalTimeZone::~ICalTimeZone()
-{
-}
-
-ICalTimeZone &ICalTimeZone::operator=(const ICalTimeZone &tz)
-{
-  KTimeZone::operator=(tz);
-  return *this;
-}
+{}
 
 QString ICalTimeZone::city() const
 {
@@ -274,9 +258,22 @@ icaltimezone *ICalTimeZone::icalTimezone() const
   return dat ? dat->icalTimezone() : 0;
 }
 
-bool ICalTimeZone::hasTransitions() const
+bool ICalTimeZone::update(const ICalTimeZone &other)
 {
-    return true;
+  if (!updateBase(other))
+    return false;
+  setData(other.data()->clone(), other.source());
+  return true;
+}
+
+ICalTimeZone ICalTimeZone::utc()
+{
+  static ICalTimeZone utcZone;
+  if ( !utcZone.isValid() ) {
+    ICalTimeZoneSource tzs;
+    utcZone = tzs.parse( icaltimezone_get_utc_timezone() );
+  }
+  return utcZone;
 }
 
 
@@ -332,20 +329,19 @@ ICalTimeZoneData::ICalTimeZoneData(const KTimeZoneData &rhs, const KTimeZone &tz
     LAST_WEEKDAY_OF_MONTH = 0x04
   };
 
-  if (dynamic_cast<const KSystemTimeZone*>(&tz)) {
+  if (tz.type() == "KSystemTimeZone") {
     // Try to fetch a system time zone in preference, on the grounds
     // that system time zones are more likely to be up to date than
     // built-in libical ones.
     icalcomponent *c = 0;
-    KTimeZone *ktz = KSystemTimeZones::readZone( tz.name() );
-    if ( ktz ) {
-      if ( ktz->data(true) ) {
-        ICalTimeZone icaltz( *ktz, earliest );
+    KTimeZone ktz = KSystemTimeZones::readZone( tz.name() );
+    if ( ktz.isValid() ) {
+      if ( ktz.data(true) ) {
+        ICalTimeZone icaltz( ktz, earliest );
         icaltimezone *itz = icaltz.icalTimezone();
         c = icalcomponent_new_clone( icaltimezone_get_component( itz ) );
         icaltimezone_free( itz, 1 );
       }
-      delete ktz;
     }
     if ( !c ) {
       // Try to fetch a built-in libical time zone.
@@ -586,7 +582,7 @@ ICalTimeZoneData &ICalTimeZoneData::operator=(const ICalTimeZoneData &rhs)
   return *this;
 }
 
-KTimeZoneData *ICalTimeZoneData::clone()
+KTimeZoneData *ICalTimeZoneData::clone() const
 {
   return new ICalTimeZoneData(*this);
 }
@@ -675,18 +671,22 @@ bool ICalTimeZoneSource::parse(icalcomponent *calendar, ICalTimeZones &zones)
   for (icalcomponent *c = icalcomponent_get_first_component(calendar, ICAL_VTIMEZONE_COMPONENT);
        c;  c = icalcomponent_get_next_component(calendar, ICAL_VTIMEZONE_COMPONENT))
   {
-    ICalTimeZone *zone = parse(c);
-    if (!zone)
+    ICalTimeZone zone = parse(c);
+    if (!zone.isValid())
       return false;
-    if (!zones.add(zone)) {
-      delete zone;
+    ICalTimeZone oldzone = zones.zone(zone.name());
+    if (oldzone.isValid()) {
+      // The zone already exists in the collection, so update the definition
+      // of the zone rather than using a newly created one.
+      oldzone.update(zone);
+    } else if (!zones.add(zone)) {
       return false;
     }
   }
   return true;
 }
 
-ICalTimeZone *ICalTimeZoneSource::parse(icalcomponent *vtimezone)
+ICalTimeZone ICalTimeZoneSource::parse(icalcomponent *vtimezone)
 {
   QString name;
   QString xlocation;
@@ -722,7 +722,7 @@ ICalTimeZone *ICalTimeZoneSource::parse(icalcomponent *vtimezone)
         if (t.is_utc) {
           data->d->lastModified = toQDateTime(t);
         } else {
-          kDebug(5800) << "ICalTimeZoneSource::parse(): LAST-MODIFIED not UTC" << endl;
+          kDebug(5800) << "ICalTimeZoneSource::parse(): LAST-MODIFIED not UTC";
         }
         break;
       }
@@ -733,9 +733,9 @@ ICalTimeZone *ICalTimeZoneSource::parse(icalcomponent *vtimezone)
   }
 
   if (name.isEmpty()) {
-    kDebug(5800) << "ICalTimeZoneSource::parse(): TZID missing" << endl;
+    kDebug(5800) << "ICalTimeZoneSource::parse(): TZID missing";
     delete data;
-    return 0;
+    return ICalTimeZone();
   }
   if (data->d->location.isEmpty()  &&  !xlocation.isEmpty())
     data->d->location = xlocation;
@@ -746,7 +746,7 @@ ICalTimeZone *ICalTimeZoneSource::parse(icalcomponent *vtimezone)
     if (i > 0)
       name = name.mid(i + 1);
   }
-  //kDebug(5800) << "---zoneId: \"" << name << '"' << endl;
+  //kDebug(5800) << "---zoneId: \"" << name << '"';
 
   /*
    * Iterate through all time zone rules for this VTIMEZONE,
@@ -766,17 +766,17 @@ ICalTimeZone *ICalTimeZoneSource::parse(icalcomponent *vtimezone)
     switch (kind) {
 
       case ICAL_XSTANDARD_COMPONENT:
-        //kDebug(5800) << "---standard phase: found" << endl;
+        //kDebug(5800) << "---standard phase: found";
         times = ICalTimeZoneSourcePrivate::parsePhase(c, false, prevoff, phase);
         break;
 
       case ICAL_XDAYLIGHT_COMPONENT:
-        //kDebug(5800) << "---daylight phase: found" << endl;
+        //kDebug(5800) << "---daylight phase: found";
         times = ICalTimeZoneSourcePrivate::parsePhase(c, true, prevoff, phase);
         break;
 
       default:
-        kDebug(5800) << "ICalTimeZoneSource::parse(): Unknown component: " << kind << endl;
+        kDebug(5800) << "ICalTimeZoneSource::parse(): Unknown component:" << kind;
         break;
     }
     int tcount = times.count();
@@ -805,11 +805,11 @@ ICalTimeZone *ICalTimeZoneSource::parse(icalcomponent *vtimezone)
   data->setTransitions(transitions);
 
   data->d->setComponent( icalcomponent_new_clone(vtimezone) );
-  kDebug(5800) << "ICalTimeZoneSource::parse(): VTIMEZONE " << name << endl;
-  return new ICalTimeZone(this, name, data);
+  kDebug(5800) << "ICalTimeZoneSource::parse(): VTIMEZONE" << name;
+  return ICalTimeZone(this, name, data);
 }
 
-ICalTimeZone *ICalTimeZoneSource::parse(icaltimezone *tz)
+ICalTimeZone ICalTimeZoneSource::parse(icaltimezone *tz)
 {
   /* Parse the VTIMEZONE component stored in the icaltimezone structure.
    * This is both easier and provides more complete information than
@@ -882,7 +882,7 @@ QList<QDateTime> ICalTimeZoneSourcePrivate::parsePhase(icalcomponent *c, bool da
         break;
 
       default:
-        kDebug(5800) << "ICalTimeZoneSource::readPhase(): Unknown property: " << kind << endl;
+        kDebug(5800) << "ICalTimeZoneSource::readPhase(): Unknown property:" << kind;
         break;
     }
     p = icalcomponent_get_next_property(c, ICAL_ANY_PROPERTY);
@@ -890,7 +890,7 @@ QList<QDateTime> ICalTimeZoneSourcePrivate::parsePhase(icalcomponent *c, bool da
 
   // Validate the phase data
   if (!found_dtstart || !found_tzoffsetfrom || !found_tzoffsetto) {
-    kDebug(5800) << "ICalTimeZoneSource::readPhase(): DTSTART/TZOFFSETFROM/TZOFFSETTO missing" << endl;
+    kDebug(5800) << "ICalTimeZoneSource::readPhase(): DTSTART/TZOFFSETFROM/TZOFFSETTO missing";
     return transitions;
   }
 
@@ -907,8 +907,8 @@ QList<QDateTime> ICalTimeZoneSourcePrivate::parsePhase(icalcomponent *c, bool da
      * Note that we had to get DTSTART, TZOFFSETFROM, TZOFFSETTO before reading
      * recurrences.
      */
-    KDateTime klocalStart(localStart, KDateTime::Spec::ClockTime);
-    KDateTime maxTime(MAX_DATE(), KDateTime::Spec::ClockTime);
+    KDateTime klocalStart(localStart, KDateTime::Spec::ClockTime());
+    KDateTime maxTime(MAX_DATE(), KDateTime::Spec::ClockTime());
     Recurrence recur;
     icalproperty *p = icalcomponent_get_first_property(c, ICAL_ANY_PROPERTY);
     while (p) {
@@ -947,8 +947,8 @@ QList<QDateTime> ICalTimeZoneSourcePrivate::parsePhase(icalcomponent *c, bool da
           // Convert to local time to avoid timesInInterval() getting things wrong.
           if (r.duration() == 0) {
             KDateTime end(r.endDt());
-            if (end.timeSpec() == KDateTime::Spec::UTC) {
-              end.setTimeSpec(KDateTime::Spec::ClockTime);
+            if (end.timeSpec() == KDateTime::Spec::UTC()) {
+              end.setTimeSpec(KDateTime::Spec::ClockTime());
               r.setEndDt( end.addSecs(prevOffset) );
             }
           }
@@ -972,7 +972,7 @@ QList<QDateTime> ICalTimeZoneSourcePrivate::parsePhase(icalcomponent *c, bool da
   return transitions;
 }
 
-ICalTimeZone *ICalTimeZoneSource::standardZone(const QString &zone, bool icalBuiltIn)
+ICalTimeZone ICalTimeZoneSource::standardZone(const QString &zone, bool icalBuiltIn)
 {
   if ( !icalBuiltIn ) {
     // Try to fetch a system time zone in preference, on the grounds
@@ -985,15 +985,13 @@ ICalTimeZone *ICalTimeZoneSource::standardZone(const QString &zone, bool icalBui
       if ( i > 0 )
         tzid = zone.mid( i + 1 );   // strip off the libical prefix
     }
-    KTimeZone *ktz = KSystemTimeZones::readZone( tzid );
-    if ( ktz ) {
-      if ( ktz->data(true) ) {
-        ICalTimeZone *icaltz = new ICalTimeZone( *ktz );
-        delete ktz;
-        kDebug(5800) << "ICalTimeZoneSource::standardZone(" << zone << "): read from system database" << endl;
+    KTimeZone ktz = KSystemTimeZones::readZone( tzid );
+    if ( ktz.isValid() ) {
+      if ( ktz.data(true) ) {
+        ICalTimeZone icaltz( ktz );
+        kDebug(5800) << "ICalTimeZoneSource::standardZone(" << zone << "): read from system database";
         return icaltz;
       }
-      delete ktz;
     }
   }
   // Try to fetch a built-in libical time zone.
@@ -1004,7 +1002,7 @@ ICalTimeZone *ICalTimeZoneSource::standardZone(const QString &zone, bool icalBui
     // This will find it if it includes the libical prefix
     icaltz = icaltimezone_get_builtin_timezone_from_tzid( zoneName );
     if ( !icaltz )
-      return 0;
+      return ICalTimeZone();
   }
   return parse( icaltz );
 }
@@ -1021,7 +1019,7 @@ QByteArray ICalTimeZoneSource::icalTzidPrefix()
         return ICalTimeZoneSourcePrivate::icalTzidPrefix;
       }
     }
-    kError(5800) << "ICalTimeZoneSource: failed to get libical TZID prefix" << endl;
+    kError(5800) << "ICalTimeZoneSource: failed to get libical TZID prefix";
   }
   return ICalTimeZoneSourcePrivate::icalTzidPrefix;
 }
