@@ -1,7 +1,7 @@
 /*
     This file is part of the kcal library.
 
-    Copyright (c) 2005,2006 David Jarvie <software@astrojar.org.uk>
+    Copyright (c) 2005-2007 David Jarvie <software@astrojar.org.uk>
 
     This library is free software; you can redistribute it and/or
     modify it under the terms of the GNU Library General Public
@@ -22,9 +22,9 @@
 #ifndef KCAL_ICALTIMEZONES_H
 #define KCAL_ICALTIMEZONES_H
 
-#include <ktimezones.h>
+#include <ktimezone.h>
 
-#include "kcal.h"
+#include "kcal_export.h"
 
 #ifndef ICALCOMPONENT_H
 typedef struct icalcomponent_impl icalcomponent;
@@ -43,7 +43,6 @@ class ICalTimeZonesPrivate;
 class ICalTimeZonePrivate;
 class ICalTimeZoneSourcePrivate;
 class ICalTimeZoneDataPrivate;
-class Recurrence;
 
 
 /**
@@ -52,8 +51,6 @@ class Recurrence;
  *
  * Each individual time zone is defined in a ICalTimeZone instance. The time zones in the
  * collection are indexed by name, which must be unique within the collection.
- * ICalTimeZone instances in the collection are owned by the ICalTimeZones instance,
- * and are deleted when the ICalTimeZones instance is destructed.
  *
  * Different calendars could define the same time zone differently. As a result,
  * to avoid conflicting definitions, each calendar should normally have its own
@@ -74,14 +71,14 @@ public:
     /**
      * Returns the time zone with the given name.
      * Note that the ICalTimeZone returned remains a member of the ICalTimeZones
-     * collection, and should not be deleted without calling detach() first.
+     * collection, and should not be deleted without calling remove() first.
      *
      * @param name name of time zone
-     * @return time zone, or 0 if not found
+     * @return time zone, or invalid if not found
      */
-    const ICalTimeZone *zone(const QString &name) const;
+    ICalTimeZone zone(const QString &name) const;
 
-    typedef QMap<QString, const ICalTimeZone*> ZoneMap;
+    typedef QMap<QString, ICalTimeZone> ZoneMap;
 
     /**
      * Returns all the time zones defined in this collection.
@@ -92,64 +89,34 @@ public:
 
     /**
      * Adds a time zone to the collection.
-     * ICalTimeZones takes ownership of the ICalTimeZone instance, which will be deleted
-     * when the ICalTimeZones instance is destructed.
      * The time zone's name must be unique within the collection.
      *
      * @param zone time zone to add
      * @return @c true if successful, @c false if zone's name duplicates one already in the collection
      */
-    bool add(ICalTimeZone *zone);
-
-    /**
-     * Adds a time zone to the collection.
-     * ICalTimeZones does not take ownership of the ICalTimeZone instance.
-     * The time zone's name must be unique within the collection.
-     *
-     * @param zone time zone to add
-     * @return @c true if successful, @c false if zone's name duplicates one already in the collection
-     */
-    bool addConst(const ICalTimeZone *zone);
+    bool add(const ICalTimeZone &zone);
 
     /**
      * Removes a time zone from the collection.
-     * The caller assumes responsibility for deleting the removed ICalTimeZone. If
-     * the removed ICalTimeZone was created by the caller, the constness of the return
-     * value may safely be cast away.
      *
      * @param zone time zone to remove
-     * @return the time zone which was removed, or 0 if not found or not a deletable object
+     * @return the time zone which was removed, or invalid if not found
      */
-    const ICalTimeZone *detach(const ICalTimeZone *zone);
+    ICalTimeZone remove(const ICalTimeZone &zone);
 
     /**
      * Removes a time zone from the collection.
-     * The caller assumes responsibility for deleting the removed ICalTimeZone.
      *
      * @param name name of time zone to remove
-     * @return the time zone which was removed, or 0 if not found or not a deletable object
+     * @return the time zone which was removed, or invalid if not found
      */
-    const ICalTimeZone *detach(const QString &name);
+    ICalTimeZone remove(const QString &name);
 
     /**
      * Clears the collection.
-     * All time zone instances owned by the collection are deleted.
      */
     void clear();
 
-    /**
-     * Returns a standard UTC time zone, with name "UTC".
-     *
-     * @note The ICalTimeZone returned by this method does not belong to any
-     * ICalTimeZones collection, and is statically allocated and therefore cannot
-     * be deleted and cannot be added to a ICalTimeZones collection. Any ICalTimeZones
-     * instance may contain its own UTC ICalTimeZone, but that will be a different
-     * instance than this ICalTimeZone.
-     *
-     * @return UTC time zone
-     */
-    static const ICalTimeZone *utc();
-
 private:
     ICalTimeZones(const ICalTimeZones &);              // prohibit copying
     ICalTimeZones &operator=(const ICalTimeZones &);   // prohibit copying
@@ -167,9 +134,16 @@ private:
  * @see ICalTimeZoneSource, ICalTimeZoneData
  * @author David Jarvie <software@astrojar.org.uk>.
  */
-class KCAL_EXPORT ICalTimeZone : public KTimeZone
+class KCAL_EXPORT ICalTimeZone : public KTimeZone  //krazy:exclude=dpointer (no d-pointer for KTimeZone derived classes)
 {
   public:
+    /**
+     * Constructs a null time zone. A null time zone is invalid.
+     *
+     * @see isValid()
+     */
+    ICalTimeZone();
+
     /**
      * Creates a time zone. This constructor is normally called from ICalTimeZoneSource::parse().
      *
@@ -187,14 +161,8 @@ class KCAL_EXPORT ICalTimeZone : public KTimeZone
      */
     explicit ICalTimeZone(const KTimeZone &tz, const QDate &earliest = QDate());
 
-    /**
-     * Copy constructor.
-     */
-    ICalTimeZone(const ICalTimeZone &);
     virtual ~ICalTimeZone();
 
-    ICalTimeZone &operator=(const ICalTimeZone &);
-
     /**
      * Returns the name of the city for this time zone, if any. There is no fixed
      * format for the name.
@@ -234,14 +202,90 @@ class KCAL_EXPORT ICalTimeZone : public KTimeZone
     icaltimezone *icalTimezone() const;
 
     /**
+     * Update the definition of the time zone to be identical to another
+     * ICalTimeZone instance. A prerequisite is that the two instances must
+     * have the same name.
+     *
+     * The purpose of this method is to enable updates of ICalTimeZone
+     * definitions when a calendar is reloaded, without invalidating pointers
+     * to the instance (particularly pointers held by KDateTime objects).
+     *
+     * @param other time zone whose definition is to be used
+     * @return true if definition was updated (i.e. names are the same)
+     */
+    bool update(const ICalTimeZone &other);
+
+    /**
+     * Returns a standard UTC time zone, with name "UTC".
+     *
+     * @note The ICalTimeZone returned by this method does not belong to any
+     * ICalTimeZones collection. Any ICalTimeZones instance may contain its own
+     * UTC ICalTimeZone defined by its time zone source data, but that will be
+     * a different instance than this ICalTimeZone.
+     *
+     * @return UTC time zone
+     */
+    static ICalTimeZone utc();
+
+private:
+    // d-pointer is in ICalTimeZoneBackend.
+    // This is a requirement for classes inherited from KTimeZone.
+};
+
+
+/**
+ * Backend class for KICalTimeZone class.
+ *
+ * This class implements KICalTimeZone's constructors and virtual methods. A
+ * backend class is required for all classes inherited from KTimeZone to
+ * allow KTimeZone virtual methods to work together with reference counting of
+ * private data.
+ *
+ * @short Backend class for KICalTimeZone class
+ * @see KTimeZoneBackend, KICalTimeZone, KTimeZone
+ * @ingroup timezones
+ * @author David Jarvie <software@astrojar.org.uk>.
+ */
+class KCAL_EXPORT ICalTimeZoneBackend : public KTimeZoneBackend  //krazy:exclude=dpointer (non-const d-pointer for KTimeZoneBackend-derived classes)
+{
+public:
+    /** Implements ICalTimeZone::ICalTimeZone(). */
+    ICalTimeZoneBackend();
+    /** Implements ICalTimeZone::ICalTimeZone(). */
+    ICalTimeZoneBackend(ICalTimeZoneSource *source, const QString &name, const QString &countryCode = QString(),
+                        float latitude = KTimeZone::UNKNOWN, float longitude = KTimeZone::UNKNOWN,
+                        const QString &comment = QString());
+    /** Implements ICalTimeZone::ICalTimeZone(). */
+    ICalTimeZoneBackend(const KTimeZone &tz, const QDate &earliest);
+
+    virtual ~ICalTimeZoneBackend();
+
+    /**
+     * Creates a copy of this instance.
+     *
+     * @return new copy
+     */
+    virtual KTimeZoneBackend *clone() const;
+
+    /**
+     * Returns the class name of the data represented by this instance.
+     *
+     * @return "ICalTimeZone"
+     */
+    virtual QByteArray type() const;
+
+    /**
+     * Implements ICalTimeZone::hasTransitions().
+     *
      * Return whether daylight saving transitions are available for the time zone.
      *
+     * @param caller calling ICalTimeZone object
      * @return @c true
      */
-    virtual bool hasTransitions() const;
+    virtual bool hasTransitions(const KTimeZone* caller) const;
 
-  private:
-    ICalTimeZonePrivate *const d;
+private:
+    ICalTimeZonePrivate *d;   // non-const
 };
 
 
@@ -270,11 +314,9 @@ class KCAL_EXPORT ICalTimeZoneSource : public KTimeZoneSource
      * from a VTIMEZONE component.
      *
      * @param vtimezone the VTIMEZONE component from which data is to be extracted
-     * @return a ICalTimeZone instance containing the parsed data.
-     *         The caller is responsible for deleting the ICalTimeZone instance.
-     *         Null is returned on error.
+     * @return an ICalTimeZone instance containing the parsed data, or invalid on error
      */
-    ICalTimeZone *parse(icalcomponent *vtimezone);
+    ICalTimeZone parse(icalcomponent *vtimezone);
 
     /**
      * Creates an ICalTimeZone instance for each VTIMEZONE component within a
@@ -317,11 +359,9 @@ class KCAL_EXPORT ICalTimeZoneSource : public KTimeZoneSource
      * VTIMEZONE component.
      *
      * @param tz the icaltimezone structure from which data is to be extracted
-     * @return a ICalTimeZone instance containing the time zone data.
-     *         The caller is responsible for deleting the ICalTimeZone instance.
-     *         Null is returned on error.
+     * @return an ICalTimeZone instance containing the time zone data, or invalid on error
      */
-    ICalTimeZone *parse(icaltimezone *tz);
+    ICalTimeZone parse(icaltimezone *tz);
 
     /**
      * Creates an ICalTimeZone instance for a standard time zone. The system
@@ -332,11 +372,9 @@ class KCAL_EXPORT ICalTimeZoneSource : public KTimeZoneSource
      *             prefix string
      * @param icalBuiltIn @p true to fetch only the libical built-in time zone,
      *                    and ignore system time zone definitions
-     * @return a ICalTimeZone instance containing the time zone data.
-     *         The caller is responsible for deleting the ICalTimeZone instance.
-     *         Null is returned on error.
+     * @return an ICalTimeZone instance containing the time zone data, or invalid on error
      */
-    ICalTimeZone *standardZone(const QString &zone, bool icalBuiltIn = false);
+    ICalTimeZone standardZone(const QString &zone, bool icalBuiltIn = false);
 
     /**
      * Returns the prefix string used in the TZID field in built-in libical
@@ -391,7 +429,7 @@ class KCAL_EXPORT ICalTimeZoneData : public KTimeZoneData
      *
      * @return copy of this instance
      */
-    virtual KTimeZoneData *clone();
+    virtual KTimeZoneData *clone() const;
 
     /**
      * Returns the name of the city for this time zone, if any. There is no fixed
