@@ -21,8 +21,8 @@
 #ifndef KCAL_IMIPSCHEDULER_H
 #define KCAL_IMIPSCHEDULER_H
 
-#include <QList>
-#include "kcal.h"
+#include <QtCore/QList>
+#include "kcal_export.h"
 
 #include "scheduler.h"
 
