@@ -24,17 +24,23 @@
   This file is part of the API for handling calendar data and
   defines the IncidenceBase class.
 
-  @author Cornelius Schumacher
-  @author Reinhold Kainhofer
+  @brief
+  An abstract base class that provides a common base for all calendar incidence
+  classes.
+
+  @author Cornelius Schumacher \<schumacher@kde.org\>
+  @author Reinhold Kainhofer \<reinhold@kainhofer.com\>
 */
 
+#include "incidencebase.h"
+
+#include "calformat.h"
+
 #include <kglobal.h>
 #include <klocale.h>
 #include <kdebug.h>
 #include <kurl.h>
-
-#include "calformat.h"
-#include "incidencebase.h"
+#include <ksystemtimezone.h>
 
 using namespace KCal;
 
@@ -46,21 +52,33 @@ using namespace KCal;
 class KCal::IncidenceBase::Private
 {
   public:
+    Private() : mFloats( true ), mHasDuration( false )
+    { mAttendees.setAutoDelete( true ); }
+
+    Private( const Private &other )
+      : mLastModified( other.mLastModified ),
+        mDtStart( other.mDtStart ),
+        mOrganizer( other.mOrganizer ),
+        mUid( other.mUid ),
+        mDuration( other.mDuration ),
+        mFloats( other.mFloats ),
+        mHasDuration( other.mHasDuration )
+        //????? mComments
+        // mObservers: the copied object is a new one, so it isn't observed
+        // by the observer of the original object.
+      { mAttendees.setAutoDelete( true ); }
+
     KDateTime mLastModified;     // incidence last modified date
     KDateTime mDtStart;          // incidence start time
     Person mOrganizer;           // incidence person (owner)
     QString mUid;                // incidence unique id
+    Duration mDuration;          // incidence duration
     bool mFloats;                // true if the incidence floats
     bool mHasDuration;           // true if the incidence has a duration
-    int mDuration;               // incidence duration, in seconds
 
     Attendee::List mAttendees;   // list of incidence attendees
     QStringList mComments;       // list of incidence comments
     QList<IncidenceObserver*> mObservers; // list of incidence observers
-
-    // PILOT SYNCHRONIZATION STUFF
-    unsigned long mPilotId;  // unique id for pilot sync
-    int mSyncStatus;         // status (for sync)
 };
 //@endcond
 
@@ -68,46 +86,19 @@ IncidenceBase::IncidenceBase() : d( new KCal::IncidenceBase::Private )
 {
   mReadOnly = false;
 
-  d->mFloats = true;
-  d->mHasDuration = false;
-  d->mDuration = 0;
-
-  d->mPilotId = 0;
-  d->mSyncStatus = SYNCMOD;
-
   setUid( CalFormat::createUniqueId() );
-
-  d->mAttendees.setAutoDelete( true );
 }
 
 IncidenceBase::IncidenceBase( const IncidenceBase &i ) :
-  CustomProperties( i ), d( new KCal::IncidenceBase::Private )
+  CustomProperties( i ), d( new KCal::IncidenceBase::Private( *i.d ) )
 {
   mReadOnly = i.mReadOnly;
 
-  d->mFloats = i.d->mFloats;
-  d->mHasDuration = i.d->mHasDuration;
-  d->mDuration = i.d->mDuration;
-
-  d->mPilotId = i.d->mPilotId;
-  d->mSyncStatus = i.d->mSyncStatus;
-
-  d->mUid = i.d->mUid;
-
-  d->mDtStart = i.d->mDtStart;
-  d->mOrganizer = i.d->mOrganizer;
   Attendee::List attendees = i.attendees();
   Attendee::List::ConstIterator it;
   for ( it = attendees.begin(); it != attendees.end(); ++it ) {
     d->mAttendees.append( new Attendee( *(*it) ) );
   }
-  d->mLastModified = i.d->mLastModified;
-
-  // The copied object is a new one, so it isn't observed by the observer
-  // of the original object.
-  d->mObservers.clear();
-
-  d->mAttendees.setAutoDelete( true );
 }
 
 IncidenceBase::~IncidenceBase()
@@ -137,16 +128,15 @@ bool IncidenceBase::operator==( const IncidenceBase &i2 ) const
     return false;
   }
 
-  return ( dtStart() == i2.dtStart() &&
-           organizer() == i2.organizer() &&
-           uid() == i2.uid() &&
-           // Don't compare lastModified, otherwise the operator is not
-           // of much use. We are not comparing for identity, after all.
-           floats() == i2.floats() &&
-           duration() == i2.duration() &&
-           hasDuration() == i2.hasDuration() &&
-           pilotId() == i2.pilotId() &&
-           syncStatus() == i2.syncStatus() );
+  return
+    dtStart() == i2.dtStart() &&
+    organizer() == i2.organizer() &&
+    uid() == i2.uid() &&
+    // Don't compare lastModified, otherwise the operator is not
+    // of much use. We are not comparing for identity, after all.
+    floats() == i2.floats() &&
+    duration() == i2.duration() &&
+    hasDuration() == i2.hasDuration();
   // no need to compare mObserver
 }
 
@@ -225,19 +215,57 @@ KDateTime IncidenceBase::dtStart() const
   return d->mDtStart;
 }
 
-QString IncidenceBase::dtStartTimeStr( bool shortfmt ) const
+QString IncidenceBase::dtStartTimeStr( bool shortfmt, const KDateTime::Spec &spec ) const
 {
-  return KGlobal::locale()->formatTime( dtStart().time(), shortfmt );
+  if ( spec.isValid() ) {
+
+    QString timeZone;
+    if ( spec.timeZone() != KSystemTimeZones::local() ) {
+      timeZone = ' ' + spec.timeZone().name();
+    }
+
+    return KGlobal::locale()->formatTime( dtStart().toTimeSpec( spec ).time(), shortfmt )
+      + timeZone;
+  } else {
+    return KGlobal::locale()->formatTime( dtStart().time(), shortfmt );
+  }
 }
 
-QString IncidenceBase::dtStartDateStr( bool shortfmt ) const
+QString IncidenceBase::dtStartDateStr( bool shortfmt, const KDateTime::Spec &spec ) const
 {
-  return KGlobal::locale()->formatDate( dtStart().date(), shortfmt );
+  if ( spec.isValid() ) {
+
+    QString timeZone;
+    if ( spec.timeZone() != KSystemTimeZones::local() ) {
+      timeZone = ' ' + spec.timeZone().name();
+    }
+
+    return KGlobal::locale()->formatDate(
+      dtStart().toTimeSpec( spec ).date(), ( shortfmt ? KLocale::ShortDate : KLocale::LongDate ) )
+      + timeZone;
+  } else {
+    return KGlobal::locale()->formatDate(
+      dtStart().date(), ( shortfmt ? KLocale::ShortDate : KLocale::LongDate ) );
+  }
 }
 
-QString IncidenceBase::dtStartStr( bool shortfmt ) const
+QString IncidenceBase::dtStartStr( bool shortfmt, const KDateTime::Spec &spec ) const
 {
-  return KGlobal::locale()->formatDateTime( dtStart().dateTime(), shortfmt );
+  if ( spec.isValid() ) {
+
+    QString timeZone;
+    if ( spec.timeZone() != KSystemTimeZones::local() ) {
+      timeZone = ' ' + spec.timeZone().name();
+    }
+
+    return KGlobal::locale()->formatDateTime(
+      dtStart().toTimeSpec( spec ).dateTime(),
+      ( shortfmt ? KLocale::ShortDate : KLocale::LongDate ) ) + timeZone;
+  } else {
+    return KGlobal::locale()->formatDateTime(
+      dtStart().dateTime(),
+      ( shortfmt ? KLocale::ShortDate : KLocale::LongDate ) );
+  }
 }
 
 bool IncidenceBase::floats() const
@@ -247,7 +275,9 @@ bool IncidenceBase::floats() const
 
 void IncidenceBase::setFloats( bool f )
 {
-  if ( mReadOnly || f == d->mFloats ) return;
+  if ( mReadOnly || f == d->mFloats ) {
+    return;
+  }
   d->mFloats = f;
   updated();
 }
@@ -292,7 +322,10 @@ QStringList IncidenceBase::comments() const
 
 void IncidenceBase::addAttendee( Attendee *a, bool doupdate )
 {
-  if ( mReadOnly ) return;
+  if ( mReadOnly ) {
+    return;
+  }
+
   if ( a->name().left(7).toUpper() == "MAILTO:" ) {
     a->setName( a->name().remove( 0, 7 ) );
   }
@@ -315,7 +348,9 @@ int IncidenceBase::attendeeCount() const
 
 void IncidenceBase::clearAttendees()
 {
-  if ( mReadOnly ) return;
+  if ( mReadOnly ) {
+    return;
+  }
   d->mAttendees.clear();
 }
 
@@ -363,14 +398,14 @@ Attendee *IncidenceBase::attendeeByUid( const QString &uid ) const
   return 0;
 }
 
-void IncidenceBase::setDuration( int seconds )
+void IncidenceBase::setDuration( const Duration &duration )
 {
-  d->mDuration = seconds;
+  d->mDuration = duration;
   setHasDuration( true );
   updated();
 }
 
-int IncidenceBase::duration() const
+Duration IncidenceBase::duration() const
 {
   return d->mDuration;
 }
@@ -385,29 +420,6 @@ bool IncidenceBase::hasDuration() const
   return d->mHasDuration;
 }
 
-void IncidenceBase::setSyncStatus( int stat )
-{
-  if ( mReadOnly ) return;
-  d->mSyncStatus = stat;
-}
-
-int IncidenceBase::syncStatus() const
-{
-  return d->mSyncStatus;
-}
-
-void IncidenceBase::setPilotId( unsigned long id )
-{
-  if ( mReadOnly ) return;
-  d->mPilotId = id;
-  updated();
-}
-
-unsigned long IncidenceBase::pilotId() const
-{
-  return d->mPilotId;
-}
-
 void IncidenceBase::registerObserver( IncidenceBase::IncidenceObserver *observer )
 {
   if ( !d->mObservers.contains( observer ) ) {
@@ -436,3 +448,27 @@ KUrl IncidenceBase::uri() const
 {
   return KUrl( QString( "urn:x-ical:" ) + uid() );
 }
+
+bool IncidenceBase::Visitor::visit( Event *event )
+{
+  Q_UNUSED( event );
+  return false;
+}
+
+bool IncidenceBase::Visitor::visit( Todo *todo )
+{
+  Q_UNUSED( todo );
+  return false;
+}
+
+bool IncidenceBase::Visitor::visit( Journal *journal )
+{
+  Q_UNUSED( journal );
+  return false;
+}
+
+bool IncidenceBase::Visitor::visit( FreeBusy *freebusy )
+{
+  Q_UNUSED( freebusy );
+  return false;
+}
