@@ -25,10 +25,9 @@
   This file is part of the API for handling calendar data and
   defines the IncidenceBase class.
 
-  @authors
-  Cornelius Schumacher \<schumacher@kde.org\>,
-  Reinhold Kainhofer \<reinhold@kainhofer.com\>,
-  Rafal Rzepecki \<divide@users.sourceforge.net\>
+  @author Cornelius Schumacher \<schumacher@kde.org\>
+  @author Reinhold Kainhofer \<reinhold@kainhofer.com\>
+  @author Rafal Rzepecki \<divide@users.sourceforge.net\>
 
   @glossary @anchor incidence @b incidence:
   General term for a calendar component.
@@ -55,14 +54,15 @@
 #ifndef KCAL_INCIDENCEBASE_H
 #define KCAL_INCIDENCEBASE_H
 
-#include <QStringList>
-#include <QByteArray>
-#include <QList>
+#include <QtCore/QStringList>
+#include <QtCore/QByteArray>
+#include <QtCore/QList>
 
 #include <kdatetime.h>
 
 #include "attendee.h"
 #include "customproperties.h"
+#include "duration.h"
 #include "sortablelist.h"
 
 class KUrl;
@@ -80,7 +80,7 @@ class FreeBusy;
 
 /**
   @brief
-  An abstract class that provides a common base for all calendar @ref incidence
+  An abstract class that provides a common base for all calendar incidence
   classes.
 
   define: floats
@@ -111,7 +111,7 @@ class KCAL_EXPORT IncidenceBase : public CustomProperties
       on the concrete types of calendar components, without changing the
       calendar component classes.
     */
-    class Visitor
+    class KCAL_EXPORT Visitor //krazy:exclude=dpointer
     {
       public:
         /** Destruct Incidence::Visitor */
@@ -120,30 +120,30 @@ class KCAL_EXPORT IncidenceBase : public CustomProperties
         /**
           Reimplement this function in your concrete subclass of
           IncidenceBase::Visitor to perform actions on an Event object.
+          @param event is a pointer to a valid Event object.
         */
-        virtual bool visit( Event *event )
-        { Q_UNUSED( event ); return false; }
+        virtual bool visit( Event *event );
 
         /**
           Reimplement this function in your concrete subclass of
           IncidenceBase::Visitor to perform actions on a Todo object.
+          @param todo is a pointer to a valid Todo object.
         */
-        virtual bool visit( Todo *todo )
-        { Q_UNUSED ( todo ); return false; }
+        virtual bool visit( Todo *todo );
 
         /**
           Reimplement this function in your concrete subclass of
           IncidenceBase::Visitor to perform actions on an Journal object.
+          @param journal is a pointer to a valid Journal object.
         */
-        virtual bool visit( Journal *journal )
-        { Q_UNUSED( journal ); return false; }
+        virtual bool visit( Journal *journal );
 
         /**
           Reimplement this function in your concrete subclass of
           IncidenceBase::Visitor to perform actions on a FreeBusy object.
+          @param freebusy is a pointer to a valid FreeBusy object.
         */
-        virtual bool visit( FreeBusy *freebusy )
-        { Q_UNUSED( freebusy ); return false; }
+        virtual bool visit( FreeBusy *freebusy );
 
       protected:
         /**
@@ -193,7 +193,7 @@ class KCAL_EXPORT IncidenceBase : public CustomProperties
     /**
       Compares this with IncidenceBase @p ib for equality.
 
-      @p ib is the IncidenceBase to compare.
+      @param ib is the IncidenceBase to compare.
     */
     bool operator==( const IncidenceBase &ib ) const;
 
@@ -203,10 +203,18 @@ class KCAL_EXPORT IncidenceBase : public CustomProperties
       <pre>
         bool accept(Visitor &v) { return v.visit(this); }
       </pre>
+
+      @param v is a reference to a Visitor object.
     */
     virtual bool accept( Visitor &v )
-    { Q_UNUSED( v ); return false; }
+    {
+      Q_UNUSED( v );
+      return false;
+    }
 
+    /**
+      Prints the type of Incidence as a string.
+    */
     virtual QByteArray type() const = 0;
 
     /**
@@ -226,7 +234,7 @@ class KCAL_EXPORT IncidenceBase : public CustomProperties
     QString uid() const;
 
     /**
-      >Returns the uri for the incidence, of form urn:x-ical:\<uid\>
+      Returns the uri for the incidence, of form urn:x-ical:\<uid\>
     */
     KUrl uri() const;
 
@@ -251,7 +259,6 @@ class KCAL_EXPORT IncidenceBase : public CustomProperties
       Sets the organizer for the incidence.
 
       @param organizer is a Person to use as the incidence @ref organizer.
-
       @see organizer(), setOrganizer(const QString &)
     */
     void setOrganizer( const Person &organizer );
@@ -260,7 +267,6 @@ class KCAL_EXPORT IncidenceBase : public CustomProperties
       Sets the incidence organizer to any string @p organizer.
 
       @param organizer is a string to use as the incidence @ref organizer.
-
       @see organizer(), setOrganizer(const Person &)
     */
     void setOrganizer( const QString &organizer );
@@ -274,11 +280,16 @@ class KCAL_EXPORT IncidenceBase : public CustomProperties
 
     /**
       Sets readonly status.
+
+      @param readOnly if set, the incidence is read-only; else the incidence
+      can be modified.
+      @see isReadOnly().
     */
     virtual void setReadOnly( bool readOnly );
 
     /**
-      Returns if the object is read-only.
+      Returns true the object is read-only; false otherwise.
+      @see setReadOnly()
     */
     bool isReadOnly() const { return mReadOnly; }
 
@@ -286,55 +297,69 @@ class KCAL_EXPORT IncidenceBase : public CustomProperties
       Sets the incidence's starting date/time with a KDateTime.
       The incidence's floating status is set according to whether @p dtStart
       is a date/time (not floating) or date-only (floating).
+
+      @param dtStart is the incidence start date/time.
+      @see dtStart().
     */
     virtual void setDtStart( const KDateTime &dtStart );
-    virtual KDE_DEPRECATED void setDtStart( const QDateTime &dtStart )
-      { setDtStart( KDateTime( dtStart ) ); }  // use local time zone
 
     /**
       Returns an incidence's starting date/time as a KDateTime.
+      @see setDtStart().
     */
     virtual KDateTime dtStart() const;
 
     /**
       Returns an incidence's starting time as a string formatted according
       to the user's locale settings.
+
       @param shortfmt If set to true, use short date format, if set to false use
-                      long format.
+      long format.
+      @param spec If set, return the time in the given spec, else use the
+      incidence's current spec.
     */
-    virtual QString dtStartTimeStr( bool shortfmt = true ) const;
+    virtual QString dtStartTimeStr( bool shortfmt = true,
+                                    const KDateTime::Spec &spec = KDateTime::Spec() ) const;
 
     /**
       Returns an incidence's starting date as a string formatted according
       to the user's locale settings.
+
       @param shortfmt If set to true, use short date format, if set to false use
-                      long format.
+      long format.
+      @param spec If set, return the date in the given spec, else use the
+      incidence's current spec.
     */
-    virtual QString dtStartDateStr( bool shortfmt = true ) const;
+    virtual QString dtStartDateStr( bool shortfmt = true,
+                                    const KDateTime::Spec &spec = KDateTime::Spec() ) const;
 
     /**
       Returns an incidence's starting date and time as a string formatted
       according to the user's locale settings.
+
       @param shortfmt If set to true, use short date format, if set to false use
-                      long format.
+      long format.
+      @param spec If set, return the date and time in the given spec, else use
+      the incidence's current spec.
     */
-    virtual QString dtStartStr( bool shortfmt = true ) const;
+    virtual QString dtStartStr( bool shortfmt = true,
+                                const KDateTime::Spec &spec = KDateTime::Spec() ) const;
 
     /**
-      Sets the incidence duration to @p seconds seconds.
+      Sets the incidence duration.
 
-      @param seconds is the length of the incidence duration in seconds.
+      @param duration the incidence duration
 
       @see duration()
     */
-    virtual void setDuration( int seconds );
+    virtual void setDuration( const Duration &duration );
 
     /**
-      Returns the length of the incidence duration in seconds.
+      Returns the length of the incidence duration.
 
       @see setDuration()
     */
-    int duration() const;
+    Duration duration() const;
 
     /**
       Sets if the incidence has a duration.
@@ -388,31 +413,31 @@ class KCAL_EXPORT IncidenceBase : public CustomProperties
                              const KDateTime::Spec &newSpec );
 
     /**
-      Add a comment to this incidence.
+      Adds a comment to thieincidence. Does not add a linefeed character; simply
+      appends the text as specified.
 
-      Does not add a linefeed character.  Just appends the text as passed in.
-
-      @param comment  The comment to add.
+      @param comment is the QString containing the comment to add.
+      @see removeComment().
     */
     void addComment( const QString &comment );
 
     /**
-      Remove a comment from the incidence.
-
-      Removes first comment whose string is an exact match for the string
-      passed in.
+      Removes a comment from the incidence. Removes the first comment whose
+      string is an exact match for the specified string in @p comment.
 
+      @param comment is the QString containing the comment to remove.
       @return true if match found, false otherwise.
+      @see addComment().
      */
     bool removeComment( const QString &comment );
 
     /**
-      Deletes all comments associated with this incidence.
+      Deletes all incidence comments.
     */
     void clearComments();
 
     /**
-      Returns all comments associated with this incidence.
+      Returns all incidence comments as a list of strings.
     */
     QStringList comments() const;
 
@@ -426,73 +451,66 @@ class KCAL_EXPORT IncidenceBase : public CustomProperties
     void addAttendee( Attendee *attendee, bool doUpdate = true );
 
     /**
-      Remove all Attendees.
+      Removes all attendees from the incidence.
     */
     void clearAttendees();
 
     /**
-      Returns list of attendees.
+      Returns a list of incidence attendees.
     */
     const Attendee::List &attendees() const;
 
     /**
-      Returns number of attendees.
+      Returns the number of incidence attendees.
     */
     int attendeeCount() const;
 
     /**
-      Returns the Attendee with this email address.
+      Returns the attendee with the specified email address.
+
+      @param email is a QString containing an email address of the
+      form "FirstName LastName <emailaddress>".
+      @see attendeeByMails(), attendeesByUid().
     */
     Attendee *attendeeByMail( const QString &email ) const;
 
     /**
-      Returns first Attendee with one of the given email addresses.
+      Returns the first incidence attendee with one of the specified
+      email addresses.
+
+      @param emails is a list of QStrings containing email addresses of the
+      form "FirstName LastName <emailaddress>".
+      @param email is a QString containing a single email address to search
+      in addition to the list specified in @p emails.
+      @see attendeeByMail(), attendeesByUid().
     */
     Attendee *attendeeByMails( const QStringList &emails,
                                const QString &email = QString() ) const;
 
     /**
-      Returns attendee with given uid.
+      Returns the incidence attendee with the specified attendee @acronym UID.
+
+      @param uid is a QString containing an attendee @acronym UID.
+      @see attendeeByMail(), attendeeByMails().
     */
     Attendee *attendeeByUid( const QString &uid ) const;
 
-    /**
-      Pilot synchronization states
-    */
-    enum {
-      SYNCNONE = 0,
-      SYNCMOD = 1,
-      SYNCDEL = 3
-    };
-
-    /**
-      Sets synchronization satus.
-    */
-    void setSyncStatus( int status );
-
-    /**
-      Returns synchronization status.
-    */
-    int syncStatus() const;
-
-    /**
-      Sets Pilot Id.
-    */
-    void setPilotId( unsigned long id );
-
-    /**
-      Returns Pilot Id.
-    */
-    unsigned long pilotId() const;
-
     /**
       Register observer. The observer is notified when the observed object
       changes.
+
+      @param observer is a pointer to an IncidenceObserver object that will be
+      watching this incidence.
+      @see unRegisterObserver()
     */
     void registerObserver( IncidenceObserver *observer );
 
     /**
       Unregister observer. It isn't notified anymore about changes.
+
+      @param observer is a pointer to an IncidenceObserver object that will be
+      watching this incidence.
+      @see registerObserver().
     */
     void unRegisterObserver( IncidenceObserver *observer );
 
@@ -509,6 +527,9 @@ class KCAL_EXPORT IncidenceBase : public CustomProperties
     */
     virtual void customPropertyUpdated();
 
+    /**
+      Identifies a read-only incidence.
+    */
     bool mReadOnly;
 
   private:
