@@ -3,8 +3,6 @@
   FILE: icalparser.c
   CREATOR: eric 04 August 1999
   
-  $Id: icalparser.c 538897 2006-05-09 08:56:31Z coolo $
-  $Locker:  $
     
  The contents of this file are subject to the Mozilla Public License
  Version 1.0 (the "License"); you may not use this file except in
@@ -63,7 +61,7 @@
 #  define iswspace        isspace
 # endif
 #else
-# ifndef HAVE_ISWSPACE
+# if !defined HAVE_ISWSPACE && !defined WIN32
 #  define iswspace        isspace
 # endif
 #endif
