@@ -3,8 +3,6 @@
   FILE: icalrecur.c
   CREATOR: eric 16 May 2000
   
-  $Id: icalrecur.c 564286 2006-07-19 19:25:58Z chehrlic $
-  $Locker:  $
     
 
  (C) COPYRIGHT 2000, Eric Busboom <eric@softwarestudio.org>
@@ -131,9 +129,7 @@
 
  ======================================================================*/
 
-#ifdef HAVE_CONFIG_H
-#include "config.h"
-#endif
+#include <config.h>
 
 #ifdef HAVE_STDINT_H
 #include <stdint.h>
