@@ -3,8 +3,6 @@
  FILE: icaltimezone.c
  CREATOR: Damon Chaplin 15 March 2001
 
- $Id: icaltimezone.c 564286 2006-07-19 19:25:58Z chehrlic $
- $Locker:  $
 
  (C) COPYRIGHT 2001, Damon Chaplin
 
@@ -41,6 +39,7 @@
 
 #ifdef WIN32
 #define snprintf _snprintf
+/*#define PACKAGE_DATA_DIR "/Projects/libical"*/
 #endif
 
 /** This is the toplevel directory where the timezone data is installed in. */
@@ -1245,7 +1244,7 @@ icaltimezone_array_free			(icalarray	*timezones)
 
 	if ( timezones )
 	{
-		for (i = 0; (unsigned int)i < timezones->num_elements; i++) {
+	    for (i = 0; (unsigned int)i < timezones->num_elements; i++) {
 		zone = icalarray_element_at (timezones, i);
 		icaltimezone_free (zone, 0);
 		}
