@@ -24,13 +24,13 @@
 #ifndef KCAL_RECURRENCE_H
 #define KCAL_RECURRENCE_H
 
-#include <QString>
-#include <QBitArray>
-#include <QList>
+#include <QtCore/QString>
+#include <QtCore/QBitArray>
+#include <QtCore/QList>
 
 #include <kdatetime.h>
 
-#include "kcal.h"
+#include "kcal_export.h"
 #include "recurrencerule.h"
 
 namespace KCal {
@@ -115,7 +115,7 @@ class KCAL_EXPORT Recurrence : public RecurrenceRule::RuleObserver
      @return the current start/time of the recurrence. */
     KDateTime startDateTime() const;
     /** Return the start date/time of the recurrence */
-    QDate startDate() const   { return mStartDateTime.date(); }
+    QDate startDate() const;
     /** Set start of recurrence.
        If @p start is date-only, the recurrence is set to floating. Otherwise, the
        start is set to a date and time, and the recurrence is set to non-floating.
@@ -129,38 +129,55 @@ class KCAL_EXPORT Recurrence : public RecurrenceRule::RuleObserver
      * N.B. This property is derived by default from whether setStartDateTime() is
      * called with a date-only or date/time parameter.
      * @return whether the recurrence has a time (false) or it is just a date (true). */
-    bool doesFloat() const { return mFloating; }
+    bool floats() const;
     /** Sets whether the dtstart is a floating time (i.e. has no time attached)
        @param floats If the recurrence is for all-day item (true) or has a time associated (false).
        */
     void setFloats( bool floats );
 
     /** Set if recurrence is read-only or can be changed. */
-    void setRecurReadOnly(bool readOnly) { mRecurReadOnly = readOnly; }
+    void setRecurReadOnly(bool readOnly);
     /** Returns true if the recurrence is read-only, or false if it can be changed. */
-    bool recurReadOnly() const  { return mRecurReadOnly; }
+    bool recurReadOnly() const;
 
     /** Returns whether the event recurs at all. */
-    bool doesRecur() const;
+    bool recurs() const;
     /** Returns the event's recurrence status.  See the enumeration at the top
      * of this file for possible values. */
     ushort recurrenceType() const;
     /** Returns the recurrence status for a recurrence rule.
-     * See the enumeration at the top of this file for possible values. */
-    static ushort recurrenceType( const RecurrenceRule *rrule );
-    /** Returns true if the date specified is one on which the event will recur.
+     * See the enumeration at the top of this file for possible values.
      *
-     * @param date date to check
-     * @param timeSpec time specification for @p date
+     * @param rrule the recurrence rule to get the type for
      */
+    static ushort recurrenceType( const RecurrenceRule *rrule );
+
+    /**
+      Returns true if the date specified is one on which the event will recur.
+
+      @param date date to check.
+      @param timeSpec time specification for @p date.
+    */
     bool recursOn( const QDate &date, const KDateTime::Spec &timeSpec ) const;
-    /** Returns true if the date/time specified is one at which the event will
-     * recur. Times are rounded down to the nearest minute to determine the result. */
-    bool recursAt( const KDateTime & ) const;
-    /** Removes all recurrence rules. Recurrence dates and exceptions are
-        not removed. */
+
+    /**
+      Returns true if the date/time specified is one at which the event will
+      recur. Times are rounded down to the nearest minute to determine the
+      result.
+
+      @param dt is the date/time to check.
+    */
+    bool recursAt( const KDateTime &dt ) const;
+
+    /**
+      Removes all recurrence rules. Recurrence dates and exceptions are
+      not removed.
+    */
     void unsetRecurs();
-    /** Removes all recurrence and exception rules and dates. */
+
+    /**
+      Removes all recurrence and exception rules and dates.
+    */
     void clear();
 
     /** Returns a list of the times on the specified date at which the
@@ -524,21 +541,10 @@ class KCAL_EXPORT Recurrence : public RecurrenceRule::RuleObserver
     RecurrenceRule *setNewRecurrenceType( RecurrenceRule::PeriodType type, int freq );
 
   private:
-    RecurrenceRule::List mExRules;
-    RecurrenceRule::List mRRules;
-    DateTimeList mRDateTimes;
-    DateList     mRDates;
-    DateTimeList mExDateTimes;
-    DateList     mExDates;
-
-    KDateTime mStartDateTime;    // date/time of first recurrence
-    bool mFloating;              // the recurrence has no time, just a date
-    bool mRecurReadOnly;
-
-    // Cache the type of the recurrence with the old system (e.g. MonthlyPos)
-    mutable ushort mCachedType;
-
-    QList<RecurrenceObserver*> mObservers;
+    //@cond PRIVATE
+    class Private;
+    Private *const d;
+    //@endcond
 };
 
 }
