@@ -24,21 +24,19 @@
 
 #include "resourcecalendar.h"
 
-#include "kresources/idmapper.h"
 #include "incidence.h"
-#include "calendarlocal.h"
 
 #include <kdatetime.h>
-#include <kconfig.h>
 
-#include <QString>
-#include <QTimer>
+#include <QtCore/QString>
 
+class KConfigGroup;
+namespace KRES { class IdMapper; }
 
 
 namespace KCal {
 
-class ICalTimeZone;
+class CalendarLocal;
 
 /**
   This class provides a calendar resource using a local CalendarLocal object to
@@ -73,11 +71,12 @@ class KCAL_EXPORT ResourceCached : public ResourceCalendar,
         SyncCache        // update the cache file before loading, or upload cache after saving
     };
 
-    explicit ResourceCached( const KConfig * );
+    ResourceCached();
+    explicit ResourceCached( const KConfigGroup &group );
     virtual ~ResourceCached();
 
-    void readConfig( const KConfig *config );
-    void writeConfig( KConfig *config );
+    void readConfig( const KConfigGroup &group );
+    void writeConfig( KConfigGroup &group );
 
     /**
       Set reload policy. This controls when the cache is refreshed.
@@ -114,12 +113,12 @@ class KCAL_EXPORT ResourceCached : public ResourceCalendar,
       @param inhibit  true to inhibit reloads, false to allow them
     */
     bool inhibitDefaultReload( bool inhibit );
-    bool defaultReloadInhibited() const   { return mInhibitReload; }
+    bool defaultReloadInhibited() const;
 
     /**
       Return whether the resource cache has been reloaded since startup.
      */
-    bool reloaded() const   { return mReloaded; }
+    bool reloaded() const;
 
     /**
       Set save policy. This controls when the cache is refreshed.
@@ -188,39 +187,64 @@ class KCAL_EXPORT ResourceCached : public ResourceCalendar,
       Add event to calendar.
     */
     bool addEvent(Event *anEvent);
+
     /**
       Deletes an event from this calendar.
     */
     bool deleteEvent(Event *);
 
+    /**
+      Removes all Events from this calendar.
+    */
+    void deleteAllEvents();
+
     /**
       Retrieves an event on the basis of the unique string ID.
     */
     Event *event(const QString &UniqueStr);
+
     /**
       Return filtered list of all events in calendar.
     */
     Event::List events();
+
     /**
       Return unfiltered list of all events in calendar.
     */
     Event::List rawEvents( EventSortField sortField = EventSortUnsorted, SortDirection sortDirection = SortDirectionAscending );
+
     /**
       Builds and then returns a list of all events that match for the
       date specified. useful for dayView, etc. etc.
+
+      @param date date for which to get the events
+      @param timespec the time specification of the date
+      @param sortField field used as the sort key for the result list
+      @param sortDirection direction of sorting according to @p sortField
     */
-    Event::List rawEventsForDate( const QDate &date, EventSortField sortField = EventSortUnsorted, SortDirection sortDirection = SortDirectionAscending );
+    Event::List rawEventsForDate( const QDate &date,
+                                  const KDateTime::Spec &timespec = KDateTime::Spec(),
+                                  EventSortField sortField = EventSortUnsorted,
+                                  SortDirection sortDirection = SortDirectionAscending );
 
     /**
       Get unfiltered events for date \a dt.
     */
     Event::List rawEventsForDate( const KDateTime &dt );
+
     /**
       Get unfiltered events in a range of dates. If inclusive is set to true,
       only events are returned, which are completely included in the range.
+
+      @param start date at the begin of the searching range
+      @param end date at the end of the searching range
+      @param timeSpec timeSpec of the searching range
+      @param inclusive if @c true, only match events which are completely within
+             the specified range
     */
     Event::List rawEvents( const QDate &start, const QDate &end,
-                               bool inclusive = false );
+                           const KDateTime::Spec &timespec = KDateTime::Spec(),
+                           bool inclusive = false );
 
     /**
       Add a todo to the todolist.
@@ -230,35 +254,53 @@ class KCAL_EXPORT ResourceCached : public ResourceCalendar,
       Remove a todo from the todolist.
     */
     bool deleteTodo( Todo * );
+
+    /**
+      Removes all todos from this calendar.
+    */
+    void deleteAllTodos();
+
     /**
       Searches todolist for an event with this unique string identifier,
       returns a pointer or null.
     */
     Todo *todo( const QString &uid );
+
     /**
       Return list of all todos.
     */
     Todo::List rawTodos( TodoSortField sortField = TodoSortUnsorted, SortDirection sortDirection = SortDirectionAscending );
+
     /**
       Returns list of todos due on the specified date.
     */
     Todo::List rawTodosForDate( const QDate &date );
+
     /**
       Add a Journal entry to calendar
     */
     virtual bool addJournal( Journal * );
+
     /**
       Remove a Journal from the calendar
     */
     virtual bool deleteJournal( Journal * );
+
+    /**
+      Removes all Journals from this calendar.
+    */
+    virtual void deleteAllJournals();
+
     /**
       Return Journal with given unique id.
     */
     virtual Journal *journal( const QString &uid );
+
     /**
       Return list of all journals.
     */
     Journal::List rawJournals( JournalSortField sortField = JournalSortUnsorted,SortDirection sortDirection = SortDirectionAscending );
+
     /**
       Return list of journals for the given date.
     */
@@ -276,6 +318,9 @@ class KCAL_EXPORT ResourceCached : public ResourceCalendar,
 
     /**
       Set the time specification (time zone, etc.).
+
+      @param timeSpec the time specification to set
+      @see timeSpec()
     */
     void setTimeSpec( const KDateTime::Spec &timeSpec );
 
@@ -288,6 +333,9 @@ class KCAL_EXPORT ResourceCached : public ResourceCalendar,
 
     /**
       Set id of timezone, e.g. "Europe/Berlin"
+
+      @param timeZoneId the identifier for the timezone
+      @see timeZoneId()
     */
     void setTimeZoneId( const QString &timeZoneId );
 
@@ -308,9 +356,11 @@ class KCAL_EXPORT ResourceCached : public ResourceCalendar,
     /**
       Return the owner of the calendar's full name.
     */
-    const Person &owner() const;
+    Person owner() const;
     /**
       Set the owner of the calendar. Should be owner's full name.
+
+      @param owner the person who owns this calendar resource
     */
     void setOwner( const Person &owner );
 
@@ -355,13 +405,13 @@ class KCAL_EXPORT ResourceCached : public ResourceCalendar,
     KRES::IdMapper& idMapper();
 
   protected:
+    CalendarLocal *calendar() const;
+
     // From Calendar::CalendarObserver
     void calendarIncidenceAdded( KCal::Incidence *incidence );
     void calendarIncidenceChanged( KCal::Incidence *incidence );
     void calendarIncidenceDeleted( KCal::Incidence *incidence );
 
-    CalendarLocal mCalendar;
-
     /**
       Virtual method from KRES::Resource, called when the last instace of the
       resource is closed
@@ -380,8 +430,10 @@ class KCAL_EXPORT ResourceCached : public ResourceCalendar,
     /**
       Set the cache-reloaded status.
       Non-local resources must set this true once the cache has been downloaded successfully.
+
+      @param done the new cache-reloaded status
      */
-    void setReloaded( bool done )   { mReloaded = done; }
+    void setReloaded( bool done );
     /**
       Do the actual saving of the resource data. Called by save(CacheAction). Saves
       the resource data to the cache and optionally uploads (if a remote resource).
@@ -392,7 +444,10 @@ class KCAL_EXPORT ResourceCached : public ResourceCalendar,
     virtual bool doSave( bool syncCache ) = 0;
     /**
       Do the actual saving of the resource data. Called by save(CacheAction).
-      Save one Incidence. The default implementation calls doSave(bool) to save everything
+      Save one Incidence. The default implementation calls doSave(bool) to save everything.
+
+      @param syncCache if @c true, the cache will be uploaded to the remote
+             resource. If @c false, only the cache will be updated
     */
     virtual bool doSave( bool syncCache, Incidence * );
 
@@ -434,32 +489,14 @@ class KCAL_EXPORT ResourceCached : public ResourceCalendar,
     void setIdMapperIdentifier();
 
   private:
-    // Virtual methods which should not be used by derived classes.
-    virtual bool doLoad()   { return doLoad( true ); }
-    virtual bool doSave()   { return doSave( true ); }
-
-    int mReloadPolicy;
-    int mReloadInterval;
-    QTimer mReloadTimer;
-    bool mInhibitReload;   // true to prevent downloads by load(DefaultCache)
-    bool mReloaded;        // true once it has been downloaded
-    bool mSavePending;     // true if a save of changes has been scheduled on the timer
-
-    int mSavePolicy;
-    int mSaveInterval;
-    QTimer mSaveTimer;
-
-    KDateTime mLastLoad;
-    KDateTime mLastSave;
-
-    QMap<KCal::Incidence *,bool> mAddedIncidences;
-    QMap<KCal::Incidence *,bool> mChangedIncidences;
-    QMap<KCal::Incidence *,bool> mDeletedIncidences;
-
-    KRES::IdMapper mIdMapper;
+    // Inherited virtual methods which should not be used by derived classes.
+    virtual bool doLoad();
+    virtual bool doSave();
 
+    //@cond PRIVATE
     class Private;
     Private *const d;
+    //@endcond
 };
 
 }
