@@ -21,10 +21,10 @@
 #ifndef KCAL_RESOURCECACHEDCONFIG_H
 #define KCAL_RESOURCECACHEDCONFIG_H
 
-#include <QWidget>
-#include "kcal.h"
+#include <QtGui/QWidget>
+#include "kcal_export.h"
 
-class Q3ButtonGroup;
+class QButtonGroup;
 class QSpinBox;
 
 namespace KCal {
@@ -47,14 +47,13 @@ class KCAL_EXPORT ResourceCachedReloadConfig : public QWidget
     void saveSettings( ResourceCached *resource );
 
   protected Q_SLOTS:
-    void slotIntervalStateChanged( int );
+    void slotIntervalToggled( bool );
 
   private:
-    Q3ButtonGroup *mGroup;
-    QSpinBox *mIntervalSpin;
-
+    //@cond PRIVATE
     class Private;
     Private *const d;
+    //@endcond
 };
 
 /**
@@ -73,14 +72,13 @@ class KCAL_EXPORT ResourceCachedSaveConfig : public QWidget
     void saveSettings( ResourceCached *resource );
 
   protected Q_SLOTS:
-    void slotIntervalStateChanged( int );
+    void slotIntervalToggled( bool );
 
   private:
-    Q3ButtonGroup *mGroup;
-    QSpinBox *mIntervalSpin;
-
+    //@cond PRIVATE
     class Private;
     Private *const d;
+    //@endcond
 };
 
 }
