@@ -1,35 +1,30 @@
 /*
-    This file is part of the kcal library.
+  This file is part of the kcal library.
 
-    Copyright (c) 1998 Preston Brown <pbrown@kde.org>
-    Copyright (c) 2001,2003 Cornelius Schumacher <schumacher@kde.org>
-    Copyright (c) 2002 Jan-Pascal van Best <janpascal@vanbest.org>
-    Copyright (C) 2003-2004 Reinhold Kainhofer <reinhold@kainhofer.com>
+  Copyright (c) 1998 Preston Brown <pbrown@kde.org>
+  Copyright (c) 2001,2003 Cornelius Schumacher <schumacher@kde.org>
+  Copyright (c) 2002 Jan-Pascal van Best <janpascal@vanbest.org>
+  Copyright (C) 2003-2004 Reinhold Kainhofer <reinhold@kainhofer.com>
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Library General Public
-    License as published by the Free Software Foundation; either
-    version 2 of the License, or (at your option) any later version.
+  This library is free software; you can redistribute it and/or
+  modify it under the terms of the GNU Library General Public
+  License as published by the Free Software Foundation; either
+  version 2 of the License, or (at your option) any later version.
 
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Library General Public License for more details.
+  This library is distributed in the hope that it will be useful,
+  but WITHOUT ANY WARRANTY; without even the implied warranty of
+  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+  Library General Public License for more details.
 
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-    Boston, MA 02110-1301, USA.
+  You should have received a copy of the GNU Library General Public License
+  along with this library; see the file COPYING.LIB.  If not, write to
+  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+  Boston, MA 02110-1301, USA.
 */
 
 #ifndef KCAL_RESOURCECALENDAR_H
 #define KCAL_RESOURCECALENDAR_H
 
-#include <QString>
-
-#include <kdatetime.h>
-#include <kconfig.h>
-
 #include "alarm.h"
 #include "todo.h"
 #include "event.h"
@@ -40,11 +35,13 @@
 #include "kresources/manager.h"
 #include "kabc/lock.h"
 
+#include <kdatetime.h>
+#include <kconfig.h>
+
+#include <QtCore/QString>
 
 namespace KCal {
 
-class CalFormat;
-
 /**
   This class provides the interfaces for a calendar resource. It makes use of
   the kresources framework.
@@ -56,12 +53,14 @@ class KCAL_EXPORT ResourceCalendar : public KRES::Resource
 {
     Q_OBJECT
   public:
-    explicit ResourceCalendar( const KConfig * );
+    ResourceCalendar();
+    explicit ResourceCalendar( const KConfigGroup &group );
     virtual ~ResourceCalendar();
 
-    void setResolveConflict( bool b);
+    bool isResolveConflictSet() const;
+    void setResolveConflict( bool b );
 
-    virtual void writeConfig( KConfig* config );
+    virtual void writeConfig( KConfigGroup &group );
 
     /**
       Return rich text with info about the resource. Adds standard info and
@@ -113,7 +112,10 @@ class KCAL_EXPORT ResourceCalendar : public KRES::Resource
       Return true if a save operation is still in progress, otherwise return
       false.
     */
-    virtual bool isSaving() { return false; }
+    virtual bool isSaving()
+    {
+      return false;
+    }
 
     /**
       Inhibit or allow saves, overriding the save policy set by setSavePolicy().
@@ -123,6 +125,7 @@ class KCAL_EXPORT ResourceCalendar : public KRES::Resource
       @param inhibit true to inhibit saves, false to allow them
     */
     void setInhibitSave( bool inhibit );
+
     /**
       Return whether saves have been inhibited by setInhibitSave().
      */
@@ -146,6 +149,8 @@ class KCAL_EXPORT ResourceCalendar : public KRES::Resource
     /**
       Return incidence with given unique id. If there is no incidence with that
       uid, return 0.
+
+      @param uid the identifier of the Incidence to look for
     */
     Incidence *incidence( const QString &uid );
 
@@ -159,6 +164,11 @@ class KCAL_EXPORT ResourceCalendar : public KRES::Resource
     */
     virtual bool deleteEvent( Event * ) = 0;
 
+    /**
+      Removes all Events from the calendar.
+    */
+    virtual void deleteAllEvents() = 0;
+
     /**
       Retrieves an event on the basis of the unique string ID.
     */
@@ -167,27 +177,48 @@ class KCAL_EXPORT ResourceCalendar : public KRES::Resource
     /**
       Return unfiltered list of all events in calendar. Use with care,
       this can be a bad idea for server-based calendars.
+
+      @param sortField field used as the sort key for the result list
+      @param sortDirection direction of sorting according to @p sortField
     */
-    virtual Event::List rawEvents( EventSortField sortField = EventSortUnsorted, SortDirection sortDirection = SortDirectionAscending ) = 0;
+    virtual Event::List rawEvents(
+      EventSortField sortField = EventSortUnsorted,
+      SortDirection sortDirection = SortDirectionAscending ) = 0;
 
     /**
       Builds and then returns a list of all events that match the
       date specified. Useful for dayView, etc. etc.
+
+      @param date date for which to get the events
+      @param timespec the time specification of the date
+      @param sortField field used as the sort key for the result list
+      @param sortDirection direction of sorting according to @p sortField
     */
-    virtual Event::List rawEventsForDate( const QDate &date, EventSortField sortField = EventSortUnsorted, SortDirection sortDirection = SortDirectionAscending ) = 0;
+    virtual Event::List rawEventsForDate(
+      const QDate &date,
+      const KDateTime::Spec &timespec = KDateTime::Spec(),
+      EventSortField sortField = EventSortUnsorted,
+      SortDirection sortDirection = SortDirectionAscending ) = 0;
 
     /**
       Get unfiltered events for date \a dt.
     */
     virtual Event::List rawEventsForDate( const KDateTime &dt ) = 0;
-    KDE_DEPRECATED Event::List rawEventsForDate( const QDateTime &qdt );
 
     /**
       Get unfiltered events in a range of dates. If inclusive is set to true,
       only events which are completely included in the range are returned.
+
+      @param start date at the begin of the searching range
+      @param end date at the end of the searching range
+      @param timeSpec timeSpec of the searching range
+      @param inclusive if @c true, only match events which are completely within
+             the specified range
     */
-    virtual Event::List rawEvents( const QDate &start, const QDate &end,
-                                   bool inclusive = false ) = 0;
+    virtual Event::List rawEvents(
+      const QDate &start, const QDate &end,
+      const KDateTime::Spec &timespec = KDateTime::Spec(),
+      bool inclusive = false ) = 0;
 
     /**
       Sets a particular value of the resource's configuration. The possible
@@ -207,6 +238,9 @@ class KCAL_EXPORT ResourceCalendar : public KRES::Resource
           res->setValue( "DownloadURL", yourURL );
           manager->add( res );
         }
+
+      @param key the key of the resource configuration option
+      @param value the value to set for the given option
     */
     virtual bool setValue( const QString &key, const QString &value );
 
@@ -224,6 +258,7 @@ class KCAL_EXPORT ResourceCalendar : public KRES::Resource
       finished.
     */
     void resourceLoaded( ResourceCalendar * );
+
     /**
       This signal is emitted when saving the data of the resource has been
       finished.
@@ -234,6 +269,7 @@ class KCAL_EXPORT ResourceCalendar : public KRES::Resource
       This signal is emitted when an error occurs during loading.
     */
     void resourceLoadError( ResourceCalendar *, const QString &error );
+
     /**
       This signal is emitted when an error occurs during saving.
     */
@@ -242,8 +278,8 @@ class KCAL_EXPORT ResourceCalendar : public KRES::Resource
     /**
      This signal is emitted when a subresource is added.
     */
-    void signalSubresourceAdded( ResourceCalendar *, const QString& type,
-                                 const QString& subresource, const QString& label );
+    void signalSubresourceAdded( ResourceCalendar *, const QString &type,
+                                 const QString &subresource, const QString &label );
 
     /**
      This signal is emitted when a subresource is removed.
@@ -256,26 +292,38 @@ class KCAL_EXPORT ResourceCalendar : public KRES::Resource
       Add a todo to the todolist.
     */
     virtual bool addTodo( Todo *todo ) = 0;
+
     /**
       Remove a todo from the todolist.
     */
     virtual bool deleteTodo( Todo * ) = 0;
+
+    /**
+      Removes all To-dos from the calendar.
+    */
+    virtual void deleteAllTodos() = 0;
+
     /**
       Searches todolist for an event with this unique id.
 
+      @param uid the identifier of the todo to look for
+
       @return pointer to todo or 0 if todo wasn't found
     */
     virtual Todo *todo( const QString &uid ) = 0;
+
     /**
       Return list of all todos.
     */
-    virtual Todo::List rawTodos( TodoSortField sortField = TodoSortUnsorted, SortDirection sortDirection = SortDirectionAscending ) = 0;
+    virtual Todo::List rawTodos(
+      TodoSortField sortField = TodoSortUnsorted,
+      SortDirection sortDirection = SortDirectionAscending ) = 0;
+
     /**
       Returns list of todos due on the specified date.
     */
     virtual Todo::List rawTodosForDate( const QDate &date ) = 0;
 
-
     /**
       Add a Journal entry to the resource.
     */
@@ -286,14 +334,23 @@ class KCAL_EXPORT ResourceCalendar : public KRES::Resource
     */
     virtual bool deleteJournal( Journal * ) = 0;
 
+    /**
+      Removes all Journals from the calendar.
+    */
+    virtual void deleteAllJournals() = 0;
+
     /**
       Return Journal with given unique id.
     */
     virtual Journal *journal( const QString &uid ) = 0;
+
     /**
       Return list of all journals.
     */
-    virtual Journal::List rawJournals( JournalSortField sortField = JournalSortUnsorted, SortDirection sortDirection = SortDirectionAscending ) = 0;
+    virtual Journal::List rawJournals(
+      JournalSortField sortField = JournalSortUnsorted,
+      SortDirection sortDirection = SortDirectionAscending ) = 0;
+
     /**
       Returns list of journals for the given date.
     */
@@ -309,8 +366,6 @@ class KCAL_EXPORT ResourceCalendar : public KRES::Resource
       Return all alarms which occur before given date.
     */
     virtual Alarm::List alarmsTo( const KDateTime &to ) = 0;
-    KDE_DEPRECATED Alarm::List alarmsTo( const QDateTime &to );
-
 
     /** Returns a list of all incideces */
     Incidence::List rawIncidences();
@@ -364,54 +419,88 @@ class KCAL_EXPORT ResourceCalendar : public KRES::Resource
       @param oldSpec the time specification which provides the clock times
       @param newSpec the new time specification
     */
-    virtual void shiftTimes(const KDateTime::Spec &oldSpec, const KDateTime::Spec &newSpec) = 0;
+    virtual void shiftTimes( const KDateTime::Spec &oldSpec,
+                             const KDateTime::Spec &newSpec ) = 0;
 
     /**
       If this resource has subresources, return a QStringList of them.
       In most cases, resources do not have subresources, so this is
       by default just empty.
     */
-    virtual QStringList subresources() const { return QStringList(); }
+    virtual QStringList subresources() const
+    {
+      return QStringList();
+    }
+
+    /**
+     * Is this resource capable of having subresources or not?
+     */
+    virtual bool canHaveSubresources() const
+    {
+      return false;
+    }
 
     /**
       Is this subresource active or not?
     */
-    virtual bool subresourceActive( const QString& ) const { return true; }
+    virtual bool subresourceActive( const QString &resource ) const
+    {
+      Q_UNUSED( resource );
+      return true;
+    }
 
     /**
       What is the label for this subresource?
      */
-    virtual const QString labelForSubresource( const QString& resource ) const
+    virtual const QString labelForSubresource( const QString &resource ) const
     {
        // the resource identifier is a sane fallback
        return resource;
-    };
+    }
 
     /**
       Get the identifier of the subresource associated with a specified
       incidence.
 
+      @param incidence the incidence to get the identifier for
+
       @return the identifier of the subresource or an empty string.
     */
     virtual QString subresourceIdentifier( Incidence *incidence )
-    { Q_UNUSED( incidence ); return QString(); }
+    {
+      Q_UNUSED( incidence );
+      return QString();
+    }
 
   public Q_SLOTS:
     /**
       (De-)activate a subresource.
     */
-    virtual void setSubresourceActive( const QString &, bool active );
+    virtual void setSubresourceActive( const QString &resource, bool active );
+
+    /**
+     * Remove a subresource with the id @param resource
+     */
+    virtual bool removeSubresource( const QString &resource );
+
+    /**
+      Add a subresource with the id @param resource and the parent id
+      @param parent
+    */
+    virtual bool addSubresource( const QString &resource, const QString &parent );
+
+    /**
+      Returns the type of the subresource: "event", "todo", or "journal",
+      QString if unknown/mixed.
+    */
+    virtual QString subresourceType( const QString &resource );
 
   protected:
-
-    bool mResolveConflict;
-    bool mReceivedLoadError;
-    bool mReceivedSaveError;
-
     /**
       Do the actual loading of the resource data. Called by load().
     */
     virtual bool doLoad() = 0;
+
     /**
       Do the actual saving of the resource data. Called by save().
     */
@@ -419,7 +508,8 @@ class KCAL_EXPORT ResourceCalendar : public KRES::Resource
 
     /**
       Do the actual saving of the resource data. Called by save().
-      Save one Incidence. The default implementation calls doSave() to save everything
+      Save one Incidence. The default implementation calls doSave()
+      to save everything.
     */
     virtual bool doSave( Incidence * );
 
@@ -432,10 +522,17 @@ class KCAL_EXPORT ResourceCalendar : public KRES::Resource
       A resource should call this function if a load error happens.
     */
     void loadError( const QString &errorMessage = QString() );
+
     /**
       A resource should call this function if a save error happens.
     */
     void saveError( const QString &errorMessage = QString() );
+
+    bool receivedLoadError() const;
+    void setReceivedLoadError( bool b );
+    bool receivedSaveError() const;
+    void setReceivedSaveError( bool b );
+
     /**
       Specify whether individual incidences should be set read-only when a
       read-only resource is loaded.
@@ -443,6 +540,7 @@ class KCAL_EXPORT ResourceCalendar : public KRES::Resource
                         false to allow incidences to be set read-only
     */
     void setNoReadOnlyOnLoad( bool noReadOnly );
+
     /**
       Return whether individual incidences are inhibited from being set
       read-only when a read-only resources is loaded.
@@ -450,11 +548,10 @@ class KCAL_EXPORT ResourceCalendar : public KRES::Resource
     bool noReadOnlyOnLoad() const;
 
   private:
-    bool mNoReadOnlyOnLoad;
-    bool mInhibitSave;     // true to prevent saves
-
+    //@cond PRIVATE
     class Private;
     Private *const d;
+    //@endcond
 };
 
 /** Type representing the manager of a ResourceCalendar. */
