@@ -28,16 +28,9 @@
   @author Cornelius Schumacher <schumacher@kde.org>
 */
 
-#include <typeinfo>
-#include <stdlib.h>
-
-#include <QString>
-
-#include <kdebug.h>
-#include <klocale.h>
-#include <kurl.h>
-#include <kstandarddirs.h>
+#include "resourcelocal.moc"
 
+#include "resourcelocalconfig.h"
 #include "vcalformat.h"
 #include "icalformat.h"
 #include "exceptions.h"
@@ -48,56 +41,66 @@
 
 #include "kresources/configwidget.h"
 
-#include "resourcelocalconfig.h"
+#include <typeinfo>
+#include <stdlib.h>
 
-#include "resourcelocal.h"
+#include <QtCore/QString>
+
+#include <kdebug.h>
+#include <klocale.h>
+#include <kurl.h>
+#include <kstandarddirs.h>
 
 using namespace KCal;
 
-ResourceLocal::ResourceLocal( const KConfig *config )
-  : ResourceCached( config ), d( new ResourceLocal::Private() )
+ResourceLocal::ResourceLocal()
+  : ResourceCached(), d( new ResourceLocal::Private() )
 {
   d->mLock = 0;
-  if ( config ) {
-    QString url = config->readPathEntry( "CalendarURL" );
-    d->mURL = KUrl( url );
+  d->mURL = KUrl();
+  d->mFormat = new ICalFormat();
+  init();
+}
 
-    QString format = config->readEntry( "Format" );
-    if ( format == "ical" ) {
-      d->mFormat = new ICalFormat();
-    } else if ( format == "vcal" ) {
-      d->mFormat = new VCalFormat();
-    } else {
-      d->mFormat = new ICalFormat();
-    }
+ResourceLocal::ResourceLocal( const KConfigGroup &group )
+  : ResourceCached( group ), d( new ResourceLocal::Private() )
+{
+  d->mLock = 0;
+  QString url = group.readPathEntry( "CalendarURL" );
+  d->mURL = KUrl( url );
+
+  QString format = group.readEntry( "Format" );
+  if ( format == "ical" ) {
+    d->mFormat = new ICalFormat();
+  } else if ( format == "vcal" ) {
+    d->mFormat = new VCalFormat();
   } else {
-    d->mURL = KUrl();
     d->mFormat = new ICalFormat();
   }
   init();
 }
 
 ResourceLocal::ResourceLocal( const QString &fileName )
-  : ResourceCached( 0 ), d( new ResourceLocal::Private )
+  : ResourceCached(), d( new ResourceLocal::Private )
 {
   d->mURL = KUrl::fromPath( fileName );
   d->mFormat = new ICalFormat();
   init();
 }
 
-void ResourceLocal::writeConfig( KConfig *config )
+void ResourceLocal::writeConfig( KConfigGroup &group )
 {
-  kDebug(5800) << "ResourceLocal::writeConfig()" << endl;
+  kDebug(5800) << "ResourceLocal::writeConfig()";
 
-  ResourceCalendar::writeConfig( config );
-  config->writePathEntry( "CalendarURL", d->mURL.prettyUrl() );
+  ResourceCalendar::writeConfig( group );
+  group.writePathEntry( "CalendarURL", d->mURL.prettyUrl() );
 
   if ( typeid( *d->mFormat ) == typeid( ICalFormat ) ) {
-    config->writeEntry( "Format", "ical" );
+    group.writeEntry( "Format", "ical" );
   } else if ( typeid( *d->mFormat ) == typeid( VCalFormat ) ) {
-    config->writeEntry( "Format", "vcal" );
+    group.writeEntry( "Format", "vcal" );
   } else {
-    kDebug(5800) << "ERROR: Unknown format type" << endl;
+    kDebug(5800) << "ERROR: Unknown format type";
   }
 }
 
@@ -106,6 +109,8 @@ void ResourceLocal::init()
 
   setType( "file" );
 
+  setSavePolicy( SaveDelayed );
+
   connect( &d->mDirWatch, SIGNAL( dirty( const QString & ) ),
            SLOT( reload() ) );
   connect( &d->mDirWatch, SIGNAL( created( const QString & ) ),
@@ -141,11 +146,11 @@ bool ResourceLocal::doLoad( bool )
   bool success;
 
   if ( !KStandardDirs::exists( d->mURL.path() ) ) {
-    kDebug(5800) << "ResourceLocal::load(): File doesn't exist yet." << endl;
+    kDebug(5800) << "ResourceLocal::load(): File doesn't exist yet.";
     // Save the empty calendar, so the calendar file will be created.
     success = doSave( true );
   } else {
-    success = mCalendar.load( d->mURL.path() );
+    success = calendar()->load( d->mURL.path() );
     if ( success ) d->mLastModified = readLastModified();
   }
 
@@ -154,7 +159,7 @@ bool ResourceLocal::doLoad( bool )
 
 bool ResourceLocal::doSave( bool )
 {
-  bool success = mCalendar.save( d->mURL.path() );
+  bool success = calendar()->save( d->mURL.path() );
   d->mLastModified = readLastModified();
 
   return success;
@@ -167,18 +172,17 @@ KABC::Lock *ResourceLocal::lock()
 
 bool ResourceLocal::doReload()
 {
-  kDebug(5800) << "ResourceLocal::doReload()" << endl;
+  kDebug(5800) << "ResourceLocal::doReload()";
 
   if ( !isOpen() ) return false;
 
   if ( d->mLastModified == readLastModified() ) {
-    kDebug(5800) << "ResourceLocal::reload(): file not modified since last read."
-              << endl;
+    kDebug(5800) << "ResourceLocal::reload(): file not modified since last read.";
     return false;
   }
 
-  mCalendar.close();
-  mCalendar.load( d->mURL.path() );
+  calendar()->close();
+  calendar()->load( d->mURL.path() );
   return true;
 }
 
@@ -191,7 +195,7 @@ void ResourceLocal::reload()
 void ResourceLocal::dump() const
 {
   ResourceCalendar::dump();
-  kDebug(5800) << "  Url: " << d->mURL.url() << endl;
+  kDebug(5800) << "  Url:" << d->mURL.url();
 }
 
 QString ResourceLocal::fileName() const
@@ -234,5 +238,3 @@ ResourceLocal &ResourceLocal::operator=( const ResourceLocal &other )
   d->mLastModified = other.d->mLastModified;
   return *this;
 }
-
-#include "resourcelocal.moc"
