@@ -31,16 +31,14 @@
 #ifndef KCAL_RESOURCELOCAL_H
 #define KCAL_RESOURCELOCAL_H
 
-#include <QString>
+#include <QtCore/QString>
 
 #include <kdatetime.h>
 #include <kurl.h>
 #include <kdirwatch.h>
 
-class KConfig;
-
 #include "calendarlocal.h"
-#include "kcal.h"
+#include "kcal_export.h"
 #include "resourcecached.h"
 
 namespace KCal {
@@ -58,13 +56,18 @@ class KCAL_EXPORT ResourceLocal : public ResourceCached
 
   public:
 
+    /**
+      Constructs a resource using default  configuration information.
+    */
+    ResourceLocal();
+
     /**
       Constructs a resource from configuration information
       stored in a KConfig object.
 
-      @param config the KConfig object to store as a resource.
+      @param group the configuration group to read the resource configuration from
     */
-    explicit ResourceLocal( const KConfig *config );
+    explicit ResourceLocal( const KConfigGroup &group );
 
     /**
       Constructs a resource for file named @p fileName.
@@ -81,7 +84,7 @@ class KCAL_EXPORT ResourceLocal : public ResourceCached
     /**
       Writes KConfig @p config to a local file.
     **/
-    virtual void writeConfig( KConfig *config );
+    virtual void writeConfig( KConfigGroup &group );
 
     /**
       Returns the lock.
@@ -99,6 +102,8 @@ class KCAL_EXPORT ResourceLocal : public ResourceCached
       Sets the fileName for this resource. This will be the local
       file where the resource data will be stored.
 
+      @param fileName the file to use for this resource
+
       @see fileName()
     **/
     bool setFileName( const QString &fileName );
@@ -154,6 +159,8 @@ class KCAL_EXPORT ResourceLocal : public ResourceCached
     /**
       Compares this ResourceLocal and @p other for equality.
       Returns true if they are equal.
+
+      @param other the instance to compare with
     **/
     bool operator==( const ResourceLocal &other );
 
