@@ -20,28 +20,28 @@
     Boston, MA 02110-1301, USA.
 */
 
+#include "resourcelocalconfig.moc"
+
+#include "vcalformat.h"
+#include "icalformat.h"
+#include "resourcelocal.h"
+
 #include <typeinfo>
 
-#include <QLabel>
-#include <QLayout>
-#include <QGridLayout>
+#include <QtGui/QLabel>
+#include <QtGui/QGridLayout>
+#include <QtGui/QGroupBox>
 
 #include <klocale.h>
 #include <kmessagebox.h>
 #include <kdebug.h>
 #include <kstandarddirs.h>
 
-#include "vcalformat.h"
-#include "icalformat.h"
-#include "resourcelocal.h"
-#include "resourcelocalconfig.h"
-
 using namespace KCal;
 
-ResourceLocalConfig::ResourceLocalConfig( QWidget* parent,  const char* name )
+ResourceLocalConfig::ResourceLocalConfig( QWidget* parent )
     : KRES::ConfigWidget( parent ), d( 0 )
 {
-  setObjectName(name);
   resize( 245, 115 );
   QGridLayout *mainLayout = new QGridLayout( this );
 
@@ -50,12 +50,16 @@ ResourceLocalConfig::ResourceLocalConfig( QWidget* parent,  const char* name )
   mainLayout->addWidget( label, 1, 0 );
   mainLayout->addWidget( mURL, 1, 1 );
 
-  formatGroup = new Q3ButtonGroup( 1, Qt::Horizontal, i18n( "Calendar Format" ), this );
-//  formatGroup->setExclusive( true );
+    formatGroup = new QGroupBox( i18n( "Calendar Format" ), this );
 
-//  formatGroup->setFrameStyle(QFrame::NoFrame);
-  icalButton = new QRadioButton( i18n("iCalendar"), formatGroup );
-  vcalButton = new QRadioButton( i18n("vCalendar"), formatGroup );
+    icalButton = new QRadioButton( i18n("iCalendar"), formatGroup );
+    vcalButton = new QRadioButton( i18n("vCalendar"), formatGroup );
+
+    QVBoxLayout *vbox = new QVBoxLayout;
+    vbox->addWidget(icalButton);
+    vbox->addWidget(vcalButton);
+    vbox->addStretch(1);
+    formatGroup->setLayout(vbox);
 
   mainLayout->addWidget( formatGroup, 2, 1 );
 }
@@ -65,15 +69,15 @@ void ResourceLocalConfig::loadSettings( KRES::Resource *resource )
   ResourceLocal* res = static_cast<ResourceLocal*>( resource );
   if ( res ) {
     mURL->setUrl( res->d->mURL.prettyUrl() );
-    kDebug(5800) << "Format typeid().name(): " << typeid( res->d->mFormat ).name() << endl;
+    kDebug(5800) << "Format typeid().name():" << typeid( res->d->mFormat ).name();
     if ( typeid( *(res->d->mFormat) ) == typeid( ICalFormat ) )
-      formatGroup->setButton( 0 );
+      icalButton->setChecked(true);
     else if ( typeid( *(res->d->mFormat) ) == typeid( VCalFormat ) )
-      formatGroup->setButton( 1 );
+      vcalButton->setChecked(true);
     else
-      kDebug(5800) << "ERROR: ResourceLocalConfig::loadSettings(): Unknown format type" << endl;
+      kDebug(5800) << "ERROR: ResourceLocalConfig::loadSettings(): Unknown format type";
   } else
-    kDebug(5700) << "ERROR: ResourceLocalConfig::loadSettings(): no ResourceLocal, cast failed" << endl;
+    kDebug(5800) << "ERROR: ResourceLocalConfig::loadSettings(): no ResourceLocal, cast failed";
 }
 
 void ResourceLocalConfig::saveSettings( KRES::Resource *resource )
@@ -105,7 +109,5 @@ void ResourceLocalConfig::saveSettings( KRES::Resource *resource )
       res->d->mFormat = new VCalFormat();
     }
   } else
-    kDebug(5700) << "ERROR: ResourceLocalConfig::saveSettings(): no ResourceLocal, cast failed" << endl;
+    kDebug(5800) << "ERROR: ResourceLocalConfig::saveSettings(): no ResourceLocal, cast failed";
 }
-
-#include "resourcelocalconfig.moc"
