@@ -22,16 +22,16 @@
 #ifndef KCAL_RESOURCELOCALCONFIG_H
 #define KCAL_RESOURCELOCALCONFIG_H
 
-#include <QRadioButton>
-#include <q3buttongroup.h>
+#include <QtGui/QRadioButton>
+
 #include <kurlrequester.h>
 
 #include "kresources/resource.h"
 #include "kresources/configwidget.h"
 
+#include "kcal_export.h"
 
-#include "kcal.h"
-
+class QGroupBox;
 namespace KCal {
 
 /**
@@ -43,7 +43,7 @@ class KCAL_EXPORT ResourceLocalConfig : public KRES::ConfigWidget
 {
     Q_OBJECT
   public:
-    explicit ResourceLocalConfig( QWidget* parent = 0, const char* name = 0 );
+    explicit ResourceLocalConfig( QWidget* parent = 0 );
 
   public Q_SLOTS:
     virtual void loadSettings( KRES::Resource *resource);
@@ -51,7 +51,7 @@ class KCAL_EXPORT ResourceLocalConfig : public KRES::ConfigWidget
 
   private:
     KUrlRequester *mURL;
-    Q3ButtonGroup *formatGroup;
+    QGroupBox *formatGroup;
     QRadioButton *icalButton;
     QRadioButton *vcalButton;
 
