@@ -19,17 +19,9 @@
     Boston, MA 02110-1301, USA.
 */
 
-#include <typeinfo>
-#include <stdlib.h>
-
-#include <QString>
-
-#include <kdebug.h>
-#include <klocale.h>
-#include <kurl.h>
-#include <kconfig.h>
-#include <kstandarddirs.h>
+#include "resourcelocaldir.moc"
 
+#include "resourcelocaldirconfig.h"
 #include "calendarlocal.h"
 #include "incidence.h"
 #include "event.h"
@@ -38,24 +30,34 @@
 
 #include "kresources/configwidget.h"
 
-#include "resourcelocaldirconfig.h"
+#include <typeinfo>
+#include <stdlib.h>
 
-#include "resourcelocaldir.h"
+#include <QtCore/QString>
+
+#include <kdebug.h>
+#include <klocale.h>
+#include <kurl.h>
+#include <kconfig.h>
+#include <kstandarddirs.h>
 
 using namespace KCal;
 
-ResourceLocalDir::ResourceLocalDir( const KConfig *config )
-  : ResourceCached( config ), mLock( 0 ), d( 0 )
+ResourceLocalDir::ResourceLocalDir()
+  : ResourceCached(), mLock( 0 ), d( 0 )
 {
-  if ( config ) {
-    readConfig( config );
-  }
+  init();
+}
 
+ResourceLocalDir::ResourceLocalDir( const KConfigGroup &group )
+  : ResourceCached( group ), mLock( 0 ), d( 0 )
+{
+  readConfig( group );
   init();
 }
 
 ResourceLocalDir::ResourceLocalDir( const QString &dirName )
-  : ResourceCached( 0 ), d( 0 )
+  : ResourceCached(), d( 0 )
 {
   mURL = KUrl( dirName );
 
@@ -63,25 +65,27 @@ ResourceLocalDir::ResourceLocalDir( const QString &dirName )
 }
 
 
-void ResourceLocalDir::readConfig( const KConfig *config )
+void ResourceLocalDir::readConfig( const KConfigGroup &group )
 {
-  QString url = config->readPathEntry( "CalendarURL" );
+  QString url = group.readPathEntry( "CalendarURL" );
   mURL = KUrl( url );
 }
 
-void ResourceLocalDir::writeConfig( KConfig *config )
+void ResourceLocalDir::writeConfig( KConfigGroup &group )
 {
-  kDebug(5800) << "ResourceLocalDir::writeConfig()" << endl;
+  kDebug(5800) << "ResourceLocalDir::writeConfig()";
 
-  ResourceCalendar::writeConfig( config );
+  ResourceCalendar::writeConfig( group );
 
-  config->writePathEntry( "CalendarURL", mURL.prettyUrl() );
+  group.writePathEntry( "CalendarURL", mURL.prettyUrl() );
 }
 
 void ResourceLocalDir::init()
 {
   setType( "dir" );
 
+  setSavePolicy( SaveDelayed );
+
   connect( &mDirWatch, SIGNAL( dirty( const QString & ) ),
            SLOT( reload( const QString & ) ) );
   connect( &mDirWatch, SIGNAL( created( const QString & ) ),
@@ -91,7 +95,7 @@ void ResourceLocalDir::init()
 
   mLock = new KABC::Lock( mURL.path() );
 
-  mDirWatch.addDir( mURL.path(), true );
+  mDirWatch.addDir( mURL.path(), KDirWatch::WatchFiles );
   mDirWatch.startScan();
 }
 
@@ -105,14 +109,14 @@ ResourceLocalDir::~ResourceLocalDir()
 
 bool ResourceLocalDir::doLoad( bool )
 {
-  kDebug(5800) << "ResourceLocalDir::load()" << endl;
+  kDebug(5800) << "ResourceLocalDir::load()";
 
-  mCalendar.close();
+  calendar()->close();
   QString dirName = mURL.path();
   bool success = true;
 
   if ( !( KStandardDirs::exists( dirName ) || KStandardDirs::exists( dirName + '/') ) ) {
-    kDebug(5800) << "ResourceLocalDir::load(): Directory '" << dirName << "' doesn't exist yet. Creating it..." << endl;
+    kDebug(5800) << "ResourceLocalDir::load(): Directory '" << dirName << "' doesn't exist yet. Creating it...";
 
     // Create the directory. Use 0775 to allow group-writable if the umask
     // allows it (permissions will be 0775 & ~umask). This is desired e.g. for
@@ -120,19 +124,19 @@ bool ResourceLocalDir::doLoad( bool )
     success = KStandardDirs::makeDir( dirName, 0775 );
   } else {
 
-    kDebug(5800) << "ResourceLocalDir::load(): '" << dirName << "'" << endl;
+    kDebug(5800) << "ResourceLocalDir::load(): '" << dirName << "'";
     QDir dir( dirName );
 
     QStringList entries = dir.entryList( QDir::Files | QDir::Readable );
 
     QStringList::ConstIterator it;
     for( it = entries.begin(); it != entries.end(); ++it ) {
-      if ( (*it).endsWith( "~" ) ) // is backup file, ignore it
+      if ( (*it).endsWith( '~' ) ) // is backup file, ignore it
         continue;
 
       QString fileName = dirName + '/' + *it;
-      kDebug(5800) << " read '" << fileName << "'" << endl;
-      CalendarLocal cal( mCalendar.timeSpec() );
+      kDebug(5800) << " read '" << fileName << "'";
+      CalendarLocal cal( calendar()->timeSpec() );
       if ( !doFileLoad( cal, fileName ) ) {
         success = false;
       }
@@ -150,7 +154,7 @@ bool ResourceLocalDir::doFileLoad( CalendarLocal &cal, const QString &fileName )
   Incidence::List::ConstIterator it;
   for ( it = incidences.constBegin(); it != incidences.constEnd(); ++it ) {
     Incidence *i = *it;
-    if ( i ) mCalendar.addIncidence( i->clone() );
+    if ( i ) calendar()->addIncidence( i->clone() );
   }
   return true;
 }
@@ -172,9 +176,9 @@ bool ResourceLocalDir::doSave( bool, Incidence *incidence )
   mDirWatch.stopScan();  // do prohibit the dirty() signal and a following reload()
 
   QString fileName = mURL.path() + '/' + incidence->uid();
-  kDebug(5800) << "writing '" << fileName << "'" << endl;
+  kDebug(5800) << "writing '" << fileName << "'";
 
-  CalendarLocal cal( mCalendar.timeSpec() );
+  CalendarLocal cal( calendar()->timeSpec() );
   cal.addIncidence( incidence->clone() );
   cal.save( fileName );
 
@@ -190,51 +194,62 @@ KABC::Lock *ResourceLocalDir::lock()
 
 void ResourceLocalDir::reload( const QString &file )
 {
-  kDebug(5800) << "ResourceLocalDir::reload()" << endl;
+  kDebug(5800) << "ResourceLocalDir::reload()";
 
   if ( !isOpen() ) return;
 
-  kDebug(5800) << "  File: '" << file << "'" << endl;
+  kDebug(5800) << "  File: '" << file << "'";
 
-  mCalendar.close();
+  calendar()->close();
   load();
 
   emit resourceChanged( this );
 }
 
-
 bool ResourceLocalDir::deleteEvent(Event *event)
 {
-  kDebug(5800) << "ResourceLocalDir::deleteEvent" << endl;
+  kDebug(5800) << "ResourceLocalDir::deleteEvent";
   if ( deleteIncidenceFile(event) )
-    return( mCalendar.deleteEvent( event ) );
+    return( calendar()->deleteEvent( event ) );
   else
     return( false );
 }
 
+void ResourceLocalDir::deleteAllEvents()
+{
+  calendar()->deleteAllEvents();
+}
 
 bool ResourceLocalDir::deleteTodo(Todo *todo)
 {
   if ( deleteIncidenceFile(todo) )
-    return( mCalendar.deleteTodo( todo ) );
+    return( calendar()->deleteTodo( todo ) );
   else
     return( false );
 }
 
+void ResourceLocalDir::deleteAllTodos()
+{
+  calendar()->deleteAllTodos();
+}
 
 bool ResourceLocalDir::deleteJournal( Journal *journal )
 {
   if ( deleteIncidenceFile( journal ) )
-    return( mCalendar.deleteJournal( journal ) );
+    return( calendar()->deleteJournal( journal ) );
   else
     return( false );
 }
 
+void ResourceLocalDir::deleteAllJournals()
+{
+  calendar()->deleteAllJournals();
+}
 
 void ResourceLocalDir::dump() const
 {
   ResourceCalendar::dump();
-  kDebug(5800) << "  Url: " << mURL.url() << endl;
+  kDebug(5800) << "  Url:" << mURL.url();
 }
 
 bool ResourceLocalDir::deleteIncidenceFile(Incidence *incidence)
@@ -248,5 +263,3 @@ bool ResourceLocalDir::deleteIncidenceFile(Incidence *incidence)
   mDirWatch.startScan();
   return removed;
 }
-
-#include "resourcelocaldir.moc"
