@@ -27,7 +27,7 @@
 
 #include "resourcecached.h"
 
-#include "kcal.h"
+#include "kcal_export.h"
 
 class QString;
 class KConfig;
@@ -49,28 +49,42 @@ class KCAL_EXPORT ResourceLocalDir : public ResourceCached
     friend class ResourceLocalDirConfig;
 
   public:
-    explicit ResourceLocalDir( const KConfig * );
+    ResourceLocalDir();
+    explicit ResourceLocalDir( const KConfigGroup &group );
     explicit ResourceLocalDir( const QString& fileName );
     virtual ~ResourceLocalDir();
 
-    void readConfig( const KConfig *config );
-    void writeConfig( KConfig* config );
+    void readConfig( const KConfigGroup &group );
+    void writeConfig( KConfigGroup &group );
 
     KABC::Lock *lock();
 
     /** deletes an event from this calendar. */
     bool deleteEvent(Event *);
 
+    /** Removes all Events from this calendar. */
+    void deleteAllEvents();
+
     /**
       Remove a todo from the todolist.
     */
     bool deleteTodo( Todo * );
 
+    /**
+      Removes all todos from this calendar.
+    */
+    void deleteAllTodos();
+
     /**
       Remove a journal from the journallist.
     */
     bool deleteJournal( Journal * );
 
+    /**
+      Removes all journals from this calendar.
+    */
+    void deleteAllJournals();
+
     void dump() const;
 
   protected Q_SLOTS:
