@@ -19,26 +19,25 @@
     Boston, MA 02110-1301, USA.
 */
 
+#include "resourcelocaldirconfig.moc"
+
+#include "resourcelocaldir.h"
+
 #include <typeinfo>
 
-#include <QLabel>
-#include <QLayout>
-#include <QGridLayout>
+#include <QtGui/QLabel>
+#include <QtGui/QLayout>
+#include <QtGui/QGridLayout>
 
 #include <klocale.h>
 #include <kdebug.h>
 #include <kstandarddirs.h>
 
-#include "resourcelocaldir.h"
-#include "resourcelocaldirconfig.h"
-
 using namespace KCal;
 
-ResourceLocalDirConfig::ResourceLocalDirConfig( QWidget *parent,
-                                                const char *name )
+ResourceLocalDirConfig::ResourceLocalDirConfig( QWidget *parent )
     : KRES::ConfigWidget( parent ), d( 0 )
 {
-  setObjectName(name);
   resize( 245, 115 );
   QGridLayout *mainLayout = new QGridLayout( this );
 
@@ -55,7 +54,7 @@ void ResourceLocalDirConfig::loadSettings( KRES::Resource *resource )
   if ( res ) {
     mURL->setUrl( res->mURL.prettyUrl() );
   } else
-    kDebug(5700) << "ERROR: ResourceLocalDirConfig::loadSettings(): no ResourceLocalDir, cast failed" << endl;
+    kDebug(5800) << "ERROR: ResourceLocalDirConfig::loadSettings(): no ResourceLocalDir, cast failed";
 }
 
 void ResourceLocalDirConfig::saveSettings( KRES::Resource *resource )
@@ -64,7 +63,5 @@ void ResourceLocalDirConfig::saveSettings( KRES::Resource *resource )
   if (res) {
     res->mURL = mURL->url();
   } else
-    kDebug(5700) << "ERROR: ResourceLocalDirConfig::saveSettings(): no ResourceLocalDir, cast failed" << endl;
+    kDebug(5800) << "ERROR: ResourceLocalDirConfig::saveSettings(): no ResourceLocalDir, cast failed";
 }
-
-#include "resourcelocaldirconfig.moc"
