@@ -23,14 +23,13 @@
 #ifndef KCAL_RESOURCELOCALDIRCONFIG_H
 #define KCAL_RESOURCELOCALDIRCONFIG_H
 
-#include <QRadioButton>
-#include <q3buttongroup.h>
+#include <QtGui/QRadioButton>
 #include <kurlrequester.h>
 
 #include "kresources/resource.h"
 #include "kresources/configwidget.h"
 
-#include "kcal.h"
+#include "kcal_export.h"
 
 namespace KCal {
 
@@ -45,7 +44,7 @@ class KCAL_EXPORT ResourceLocalDirConfig : public KRES::ConfigWidget
 {
     Q_OBJECT
   public:
-    explicit ResourceLocalDirConfig( QWidget *parent = 0, const char *name = 0 );
+    explicit ResourceLocalDirConfig( QWidget *parent = 0 );
 
   public Q_SLOTS:
     virtual void loadSettings( KRES::Resource *resource);
@@ -53,7 +52,6 @@ class KCAL_EXPORT ResourceLocalDirConfig : public KRES::ConfigWidget
 
   private:
     KUrlRequester *mURL;
-    Q3ButtonGroup *formatGroup;
     QRadioButton *icalButton;
     QRadioButton *vcalButton;
 
