@@ -20,9 +20,7 @@
     Boston, MA 02110-1301, USA.
 */
 
-#include <klocale.h>
-#include <kdebug.h>
-#include <kstandarddirs.h>
+#include "scheduler.h"
 
 #include "event.h"
 #include "todo.h"
@@ -31,7 +29,10 @@
 #include "calendar.h"
 #include "freebusycache.h"
 
-#include "scheduler.h"
+#include <klocale.h>
+#include <kdebug.h>
+#include <kmessagebox.h>
+#include <kstandarddirs.h>
 
 using namespace KCal;
 
@@ -92,7 +93,7 @@ FreeBusyCache *Scheduler::freeBusyCache() const
 bool Scheduler::acceptTransaction(IncidenceBase *incidence,Method method,ScheduleMessage::Status status)
 {
   kDebug(5800) << "Scheduler::acceptTransaction, method="
-                << methodName( method ) << endl;
+                << methodName( method );
 
   switch (method) {
     case Publish:
@@ -180,7 +181,7 @@ bool Scheduler::acceptPublish( IncidenceBase *newIncBase,
 
   bool res = false;
   kDebug(5800) << "Scheduler::acceptPublish, status="
-            << ScheduleMessage::statusName( status ) << endl;
+            << ScheduleMessage::statusName( status );
   Incidence *newInc = static_cast<Incidence *>( newIncBase );
   Incidence *calInc = mCalendar->incidence( newIncBase->uid() );
   switch ( status ) {
@@ -288,27 +289,92 @@ bool Scheduler::acceptReply(IncidenceBase *incidence,ScheduleMessage::Status /*
   bool ret = false;
   Event *ev = mCalendar->event(incidence->uid());
   Todo *to = mCalendar->todo(incidence->uid());
+
+  // try harder to find the correct incidence
+  if ( !ev && !to ) {
+    Incidence::List list = mCalendar->incidences();
+    for ( Incidence::List::ConstIterator it = list.constBegin(); it != list.constEnd(); ++it ) {
+      if ( (*it)->schedulingID() == incidence->uid() ) {
+        ev = dynamic_cast<Event*>( *it );
+        to = dynamic_cast<Todo*>( *it );
+        break;
+      }
+    }
+  }
+
   if (ev || to) {
     //get matching attendee in calendar
-    kDebug(5800) << "Scheduler::acceptTransaction match found!" << endl;
+    kDebug(5800) << "Scheduler::acceptTransaction match found!";
     Attendee::List attendeesIn = incidence->attendees();
     Attendee::List attendeesEv;
+    Attendee::List attendeesNew;
     if (ev) attendeesEv = ev->attendees();
     if (to) attendeesEv = to->attendees();
     Attendee::List::ConstIterator inIt;
     Attendee::List::ConstIterator evIt;
     for ( inIt = attendeesIn.begin(); inIt != attendeesIn.end(); ++inIt ) {
       Attendee *attIn = *inIt;
+      bool found = false;
       for ( evIt = attendeesEv.begin(); evIt != attendeesEv.end(); ++evIt ) {
         Attendee *attEv = *evIt;
         if (attIn->email().toLower()==attEv->email().toLower()) {
           //update attendee-info
-          kDebug(5800) << "Scheduler::acceptTransaction update attendee" << endl;
+          kDebug(5800) << "Scheduler::acceptTransaction update attendee";
           attEv->setStatus(attIn->status());
+          attEv->setDelegate(attIn->delegate());
+          attEv->setDelegator(attIn->delegator());
           ret = true;
+          found = true;
         }
       }
+      if ( !found && attIn->status() != Attendee::Declined )
+        attendeesNew.append( attIn );
     }
+
+    bool attendeeAdded = false;
+    for ( Attendee::List::ConstIterator it = attendeesNew.constBegin(); it != attendeesNew.constEnd(); ++it ) {
+      Attendee* attNew = *it;
+      QString msg = i18n("%1 wants to attend %2 but was not invited.", attNew->fullName(),
+          ( ev ? ev->summary() : to->summary() ) );
+      if ( !attNew->delegator().isEmpty() )
+        msg = i18n("%1 wants to attend %2 on behalf of %3.", attNew->fullName(),
+            ( ev ? ev->summary() : to->summary() ), attNew->delegator() );
+      if ( KMessageBox::questionYesNo( 0, msg, i18n("Uninvited attendee"),
+           KGuiItem(i18n("Accept Attendance")), KGuiItem(i18n("Reject Attendance")) )
+           != KMessageBox::Yes )
+      {
+        KCal::Incidence *cancel = dynamic_cast<Incidence*>( incidence );
+        if ( cancel )
+          cancel->addComment( i18n( "The organizer rejected your attendance at this meeting." ) );
+        performTransaction( cancel ? cancel : incidence, Scheduler::Cancel, attNew->fullName() );
+        delete cancel;
+        continue;
+      }
+
+      Attendee *a = new Attendee( attNew->name(), attNew->email(), attNew->RSVP(),
+                                  attNew->status(), attNew->role(), attNew->uid() );
+      a->setDelegate( attNew->delegate() );
+      a->setDelegator( attNew->delegator() );
+      if ( ev )
+        ev->addAttendee( a );
+      else if ( to )
+        to->addAttendee( a );
+      ret = true;
+      attendeeAdded = true;
+    }
+
+    // send update about new participants
+    if ( attendeeAdded ) {
+      if ( ev ) {
+        ev->setRevision( ev->revision() + 1 );
+        performTransaction( ev, Scheduler::Request );
+      }
+      if ( to ) {
+        to->setRevision( ev->revision() + 1 );
+        performTransaction( to, Scheduler::Request );
+      }
+    }
+
     if ( ret ) {
       // We set at least one of the attendees, so the incidence changed
       // Note: This should not result in a sequence number bump
@@ -349,13 +415,13 @@ bool Scheduler::acceptCounter(IncidenceBase *incidence,ScheduleMessage::Status /
 bool Scheduler::acceptFreeBusy(IncidenceBase *incidence, Method method)
 {
   if ( !d->mFreeBusyCache ) {
-    kError() << "KCal::Scheduler: no FreeBusyCache." << endl;
+    kError() << "KCal::Scheduler: no FreeBusyCache.";
     return false;
   }
 
   FreeBusy *freebusy = static_cast<FreeBusy *>(incidence);
 
-  kDebug(5800) << "acceptFreeBusy:: freeBusyDirName: " << freeBusyDir() << endl;
+  kDebug(5800) << "acceptFreeBusy:: freeBusyDirName:" << freeBusyDir();
 
   Person from;
   if(method == Scheduler::Publish) {
