@@ -21,15 +21,14 @@
 #ifndef KCAL_SCHEDULER_H
 #define KCAL_SCHEDULER_H
 
-#include <QString>
-#include <QList>
+#include <QtCore/QString>
+#include <QtCore/QList>
 
-#include "kcal.h"
+#include "kcal_export.h"
 
 namespace KCal {
 
 class IncidenceBase;
-class Event;
 class Calendar;
 class ICalFormat;
 class FreeBusyCache;
@@ -117,6 +116,9 @@ class KCAL_EXPORT Scheduler
     /**
       Perform iTIP transaction on incidence. The method is specified as the
       method argument and can be any valid iTIP method.
+
+      @param incidence the incidence for the transaction
+      @param method the iTIP transaction method to use
     */
     virtual bool performTransaction( IncidenceBase *incidence,
                                      Method method ) = 0;
@@ -124,6 +126,10 @@ class KCAL_EXPORT Scheduler
       Perform iTIP transaction on incidence to specified recipient(s). The
       method is specified as the method argumanet and can be any valid iTIP
       method.
+
+      @param incidence the incidence for the transaction
+      @param method the iTIP transaction method to use
+      @param recipients the receipients of the transaction
     */
     virtual bool performTransaction( IncidenceBase *incidence, Method method,
                                      const QString &recipients ) = 0;
@@ -137,6 +143,9 @@ class KCAL_EXPORT Scheduler
       on which the transaction acts. The status is the result of processing a
       iTIP message with the current calendar and specifies the action to be
       taken for this incidence.
+
+      @param method iTIP transaction method to check
+      @param status scheduling status
     */
     bool acceptTransaction( IncidenceBase *, Method method,
                             ScheduleMessage::Status status );
