@@ -16,18 +16,14 @@
    Boston, MA 02110-1301, USA.
 */
 
-#ifdef HAVE_CONFIG_H
-#include "config.h"
-#endif
-
 #include <stdio.h>
 #include <stdlib.h>
 #include <unistd.h>
 #include <assert.h>
 
-#include <QDir>
-#include <QFileInfo>
-#include <QStringList>
+#include <QtCore/QDir>
+#include <QtCore/QFileInfo>
+#include <QtCore/QStringList>
 
 #include <kurl.h>
 #include <kcomponentdata.h>
@@ -49,13 +45,6 @@
 #include "testresource.h"
 #include "testincidencegenerator.h"
 
-static const KCmdLineOptions options[] =
-{
-  { "resource <type>", "The resource to test", 0 },
-  { "configfile <file>", "Location of a config file for the resource", 0 },
-  KCmdLineLastOption // End of options
-};
-
 int main(int argc, char *argv[])
 {
   // Use another directory than the real one, just to keep things clean
@@ -63,32 +52,37 @@ int main(int argc, char *argv[])
   setenv( "KDEHOME", QFile::encodeName( QDir::homePath() + "/.kde-testresource" ), true );
   setenv( "KDE_FORK_SLAVES", "yes", true ); // simpler, for the final cleanup
 
-  KAboutData aboutData("testresource", "Part of LibKCal's test suite.", "0.1");
+  KAboutData aboutData("testresource", 0, ki18n("Part of LibKCal's test suite."), "0.1");
   KCmdLineArgs::init(argc, argv, &aboutData);
+
+  KCmdLineOptions options;
+  options.add("resource <type>", ki18n("The resource to test"));
+  options.add("configfile <file>", ki18n("Location of a config file for the resource"));
   KCmdLineArgs::addCmdLineOptions( options );
 
   KComponentData componentData( &aboutData );
-  //QCoreApplication app( *KCmdLineArgs::qt_argc(), *KCmdLineArgs::qt_argv() );
+  //QCoreApplication app( KCmdLineArgs::qtArgc(), KCmdLineArgs::qtArgv() );
 
   KCmdLineArgs *args = KCmdLineArgs::parsedArgs();
   QString type = QString();
   if ( !args->getOption( "resource" ).isEmpty() )
-    type = QString::fromLocal8Bit( args->getOption( "resource" ) );
-  KConfig *config = 0;
-  if ( !args->getOption( "configfile" ).isEmpty() )
-    config = new KConfig( KUrl( args->getOption( "configfile" ) ).url() );
-  kDebug() << KUrl( args->getOption( "configfile" ) ).url() << endl;
+    type = args->getOption( "resource" );
+  KConfigGroup *config = 0;
+  if ( !args->getOption( "configfile" ).isEmpty() ) {
+    KConfig _config( KUrl( args->getOption( "configfile" ) ).url() );
+    config = new KConfigGroup( &_config, "FRED" ); //TODO: replace FRED with a real group name
+  }
   KCal::TestResource test( type, config );
   test.setup();
   test.runAll();
   test.cleanup();
-  kDebug() << "All tests OK." << endl;
+  kDebug() << "All tests OK.";
   return 0;
 }
 
 namespace KCal {
 
-TestResource::TestResource( const QString &type, KConfig *config )
+TestResource::TestResource( const QString &type, KConfigGroup *config )
  :m_resource_type( type ), m_config( config ), m_res( 0 )
 {}
 
@@ -107,18 +101,18 @@ void TestResource::setup()
         "Select the resource you wish to test. Test data will be used.",
         descs );
 
-    kDebug() << "Selected Resource: " << desc << endl;
+    kDebug() << "Selected Resource:" << desc;
     if ( !desc.isNull() )
       m_resource_type = types[ descs.indexOf( desc ) ];
   }
   assert( !m_resource_type.isNull() );
   /* Either read one from the config file, or create a default one. */
   if ( m_config ) {
-    kDebug() << "Reading config from file" << endl;
+    kDebug() << "Reading config from file";
     KRES::Factory *factory = KRES::Factory::self( "calendar" );
-    m_res = dynamic_cast<ResourceCalendar*>( factory->resource( m_resource_type, m_config ) );
+    m_res = dynamic_cast<ResourceCalendar*>( factory->resource( m_resource_type, *m_config ) );
   } else {
-    kDebug() << "Creating blank resource" << endl;
+    kDebug() << "Creating blank resource";
     m_res = manager->createResource( m_resource_type );
   }
   assert( m_res );
@@ -146,15 +140,15 @@ bool TestResource::check(const QString& txt, const QString &a, const QString &b)
     tb.clear();
   if (ta == tb) {
     kDebug() << txt
-             << " : checking '" << ta
+             << ": checking '" << ta
              << "' against expected value '" << tb
-             << "'... " << "ok" << endl;
+             << "'..." << "ok";
   }
   else {
     kDebug() << txt
-             << " : checking '" << ta
+             << ": checking '" << ta
              << "' against expected value '" << tb
-             << "'... " << "KO !" << endl;
+             << "'..." << "KO !";
     cleanup();
     exit(1);
   }
@@ -163,7 +157,7 @@ bool TestResource::check(const QString& txt, const QString &a, const QString &b)
 
 void TestResource::testOpenAndClose()
 {
-  kDebug() << k_funcinfo << endl;
+  kDebug() ;
   assert( m_res->open() );
   assert( m_res->isOpen() );
   m_res->close();
@@ -172,7 +166,7 @@ void TestResource::testOpenAndClose()
 
 void TestResource::testResourceAttributes()
 {
-  kDebug() << k_funcinfo << endl;
+  kDebug() ;
 
   check( "type", m_res->type(), m_resource_type );
 
@@ -193,14 +187,14 @@ void TestResource::testResourceAttributes()
 
 void TestResource::testResourceCalendarAttributes()
 {
-  kDebug() << k_funcinfo << endl;
+  kDebug() ;
 }
 
 
 void TestResource::testEventAddRemove()
 {
   ICalFormat f;
-  kDebug() << k_funcinfo << endl;
+  kDebug() ;
 
   int oldcount = m_res->rawIncidences().count();
   Event *event = makeTestEvent();
@@ -220,7 +214,7 @@ void TestResource::testEventAddRemove()
 void TestResource::testTodoAddRemove()
 {
   ICalFormat f;
-  kDebug() << k_funcinfo << endl;
+  kDebug() ;
 
   int oldcount = m_res->rawIncidences().count();
   Todo *todo = makeTestTodo();
@@ -240,7 +234,7 @@ void TestResource::testTodoAddRemove()
 void TestResource::testJournalAddRemove()
 {
   ICalFormat f;
-  kDebug() << k_funcinfo << endl;
+  kDebug() ;
 
   int oldcount = m_res->rawIncidences().count();
   Journal *journal = makeTestJournal();
@@ -259,7 +253,7 @@ void TestResource::testJournalAddRemove()
 
 void TestResource::cleanup()
 {
-  kDebug() << k_funcinfo << endl;
+  kDebug() ;
 }
 
 }
