@@ -1,47 +1,49 @@
 /*
-    This file is part of the kcal library.
+  This file is part of the kcal library.
 
-    Copyright (c) 2001-2003 Cornelius Schumacher <schumacher@kde.org>
+  Copyright (c) 2001-2003 Cornelius Schumacher <schumacher@kde.org>
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Library General Public
-    License as published by the Free Software Foundation; either
-    version 2 of the License, or (at your option) any later version.
+  This library is free software; you can redistribute it and/or
+  modify it under the terms of the GNU Library General Public
+  License as published by the Free Software Foundation; either
+  version 2 of the License, or (at your option) any later version.
 
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Library General Public License for more details.
+  This library is distributed in the hope that it will be useful,
+  but WITHOUT ANY WARRANTY; without even the implied warranty of
+  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+  Library General Public License for more details.
 
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-    Boston, MA 02110-1301, USA.
+  You should have received a copy of the GNU Library General Public License
+  along with this library; see the file COPYING.LIB.  If not, write to
+  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+  Boston, MA 02110-1301, USA.
 */
 /**
   @file
   This file is part of the API for handling calendar data and
   defines the Todo class.
 
-  @authors Cornelius Schumacher \<schumacher@kde.org\>
+  @author Cornelius Schumacher \<schumacher@kde.org\>
 */
 
 #ifndef KCAL_TODO_H
 #define KCAL_TODO_H
 
-#include <QByteArray>
-
 #include "incidence.h"
+#include <QtCore/QByteArray>
 
 namespace KCal {
 
 /**
   @brief
-  Provides a @ref to-do in the sense of RFC2445.
+  Provides a To-do in the sense of RFC2445.
 */
 class KCAL_EXPORT Todo : public Incidence
 {
   public:
+    /**
+      List of to-dos.
+    */
     typedef ListBase<Todo> List;
 
     /**
@@ -50,18 +52,21 @@ class KCAL_EXPORT Todo : public Incidence
     Todo();
 
     /**
-      Constructs a to-do as a copy of another to-do object.
-
-      @param todo is the to-do to copy.
+      Copy constructor.
+      @param other is the to-do to copy.
     */
-    Todo( const Todo &todo );
+    Todo( const Todo &other );
 
     /**
       Destroys a to-do.
     */
     ~Todo();
 
-    QByteArray type() const { return "Todo"; }
+    /**
+      @copydoc
+      IncidenceBase::type()
+    */
+    QByteArray type() const;
 
     /**
       Returns an exact copy of this todo. The returned object is owned by the
@@ -73,43 +78,55 @@ class KCAL_EXPORT Todo : public Incidence
       Sets due date and time.
 
       @param dtDue The due date/time.
-      @param first Sets the date of the first occurrence (if the todo is recurrent).
+      @param first If true and the todo recurs, the due date of the first
+      occurrence will be returned. If false and recurrent, the date of the
+      current occurrence will be returned. If non-recurrent, the normal due
+      date will be returned.
     */
     void setDtDue( const KDateTime &dtDue, bool first = false );
-    KDE_DEPRECATED void setDtDue( const QDateTime &dtDue, bool first = false );
 
     /**
       Returns due date and time.
 
       @param first If true and the todo recurs, the due date of the first
       occurrence will be returned. If false and recurrent, the date of the
-      current occurrence will be returned. If non-recurrent, the normal due date
-      will be returned.
+      current occurrence will be returned. If non-recurrent, the normal due
+      date will be returned.
     */
     KDateTime dtDue( bool first = false ) const;
 
     /**
       Returns due time as string formatted according to the user's locale
       settings.
+
+      @param shortfmt If set, use short date format; else use long format.
+      @param spec If set, return the time in the given spec, else use the
+      todo's current spec.
     */
-    QString dtDueTimeStr( bool shortfmt = true ) const;
+    QString dtDueTimeStr( bool shortfmt = true,
+                          const KDateTime::Spec &spec = KDateTime::Spec() ) const;
 
     /**
       Returns due date as string formatted according to the user's locale
       settings.
 
-      @param shortfmt If set to true, use short date format, if set to false use
-                      long format.
+      @param shortfmt If set, use short date format; else use long format.
+      @param spec If set, return the date in the given spec, else use the
+      todo's current spec.
     */
-    QString dtDueDateStr( bool shortfmt = true ) const;
+    QString dtDueDateStr( bool shortfmt = true,
+                          const KDateTime::Spec &spec = KDateTime::Spec() ) const;
 
     /**
       Returns due date and time as string formatted according to the user's
       locale settings.
-      @param shortfmt If set to true, use short date format, if set to false use
-                      long format.
+
+      @param shortfmt If set, use short date format; else use long format.
+      @param spec If set, return the date/time in the given spec, else use
+      the todo's current spec.
     */
-    QString dtDueStr( bool shortfmt = true ) const;
+    QString dtDueStr( bool shortfmt = true,
+                      const KDateTime::Spec &spec = KDateTime::Spec() ) const;
 
     /**
       Returns true if the todo has a due date, otherwise return false.
@@ -150,47 +167,51 @@ class KCAL_EXPORT Todo : public Incidence
       @param dtStart is the to-do start date.
     */
     void setDtStart( const KDateTime &dtStart );
-    KDE_DEPRECATED void setDtStart( const QDateTime &dtStart )
-      { setDtStart( KDateTime ( dtStart ) ); }  // use local time zone
 
     /**
       Returns a todo's starting time as a string formatted according to the
       user's locale settings.
 
-      @param shortfmt If set to true, use short date format, if set to false use
-                      long format.
+      @param shortfmt If set, use short date format; else use long format.
       @param first If true, the start date of the todo will be returned. If the
       todo recurs, the start date of the first occurrence will be returned.
       If false and the todo recurs, the relative start date will be returned,
       based on the date returned by dtRecurrence().
+      @param spec If set, returns the time in the given spec, else use the
+      todo's current spec.
     */
-    QString dtStartTimeStr( bool shortfmt = true, bool first = false ) const;
+    QString dtStartTimeStr( bool shortfmt = true, bool first = false,
+                            const KDateTime::Spec &spec = KDateTime::Spec() ) const;
 
     /**
       Returns a todo's starting date as a string formatted according to the
       user's locale settings.
 
-      @param shortfmt If true, use short date format, if set to false use
-      long format.
+      @param shortfmt If set, use short date format; else use long format.
       @param first If true, the start date of the todo will be returned. If the
       todo recurs, the start date of the first occurrence will be returned.
       If false and the todo recurs, the relative start date will be returned,
       based on the date returned by dtRecurrence().
+      @param spec If set, returns the date in the given spec, else use the
+      todo's current spec.
     */
-    QString dtStartDateStr( bool shortfmt = true, bool first = false ) const;
+    QString dtStartDateStr( bool shortfmt = true, bool first = false,
+                            const KDateTime::Spec &spec = KDateTime::Spec() ) const;
 
     /**
       Returns a todo's starting date and time as a string formatted according
       to the user's locale settings.
 
-      @param shortfmt If set to true, use short date format, if set to false use
-                      long format.
+      @param shortfmt If set, use short date format; else use long format.
       @param first If true, the start date of the todo will be returned. If the
       todo recurs, the start date of the first occurrence will be returned.
       If false and the todo recurs, the relative start date will be returned,
       based on the date returned by dtRecurrence().
+      @param spec If set, returns the date and time in the given spec, else
+      use the todo's current spec.
     */
-    QString dtStartStr( bool shortfmt = true, bool first = false ) const;
+    QString dtStartStr( bool shortfmt = true, bool first = false,
+                        const KDateTime::Spec &spec = KDateTime::Spec() ) const;
 
     /**
       Returns true if the todo is 100% completed, otherwise return false.
@@ -234,8 +255,8 @@ class KCAL_EXPORT Todo : public Incidence
     /**
       Returns string contaiting date and time when the todo was completed
       formatted according to the user's locale settings.
-      @param shortfmt If set to true, use short date format, if set to false use
-                      long format.
+
+      @param shortfmt If set, use short date format; else use long format.
     */
     QString completedStr( bool shortfmt = false ) const;
 
@@ -245,7 +266,6 @@ class KCAL_EXPORT Todo : public Incidence
       @param completeDate is the to-do completion date.
     */
     void setCompleted( const KDateTime &completeDate );
-    KDE_DEPRECATED void setCompleted( const QDateTime &completeDate );
 
     /**
       Returns true, if todo has a date associated with completion, otherwise
@@ -291,7 +311,7 @@ class KCAL_EXPORT Todo : public Incidence
     bool isOverdue() const;
 
     /**
-      Compare this with @p to-do for equality.
+      Compare this with @p todo for equality.
 
       @param todo is the to-do to compare.
     */
@@ -301,15 +321,14 @@ class KCAL_EXPORT Todo : public Incidence
     /**
       Returns the end date/time of the base incidence.
     */
-    virtual KDateTime endDateRecurrenceBase() const { return dtDue(); }
+    virtual KDateTime endDateRecurrenceBase() const;
 
   private:
-    bool accept( Visitor &v ) { return v.visit( this ); }
-
     /**
-      Returns true if the todo got a new date, else false will be returned.
+      @copydoc
+      IncidenceBase::accept()
     */
-    bool recurTodo();
+    bool accept( Visitor &v ) { return v.visit( this ); }
 
     //@cond PRIVATE
     class Private;
