@@ -19,21 +19,25 @@
 */
 
 #include "ldapconnection.h"
+#include "kldap_config.h" // SASL2_FOUND, LDAP_FOUND
 
 #include <stdlib.h>
 #include <klocale.h>
 #include <kdebug.h>
 
-#include <kldap_config.h> // SASL2_FOUND, LDAP_FOUND
-
 #ifdef SASL2_FOUND
 #include <sasl/sasl.h>
 #endif
 
 #ifdef LDAP_FOUND
 #define LDAP_DEPRECATED 1 //for ldap_simple_bind_s
-#include <ldap.h>
 #include <lber.h>
+#include <ldap.h>
+
+#ifndef LDAP_OPT_SUCCESS
+#define LDAP_OPT_SUCCESS 0
+#endif
+
 #endif
 
 using namespace KLDAP;
@@ -89,7 +93,7 @@ void LdapConnection::setServer( const LdapServer &server )
 
 void *LdapConnection::handle() const
 {
-  return (void*) d->mLDAP;
+  return (void *)d->mLDAP;
 }
 
 QString LdapConnection::errorString( int code )
@@ -146,7 +150,7 @@ QString LdapConnection::ldapErrorString() const
 bool LdapConnection::setSizeLimit( int sizelimit )
 {
   Q_ASSERT( d->mLDAP );
-  kDebug() << "sizelimit: " << sizelimit << endl;
+  kDebug(5322) << "sizelimit:" << sizelimit;
   if ( setOption( LDAP_OPT_SIZELIMIT, &sizelimit ) != LDAP_OPT_SUCCESS ) {
     return false;
   }
@@ -166,7 +170,7 @@ int LdapConnection::sizeLimit() const
 bool LdapConnection::setTimeLimit( int timelimit )
 {
   Q_ASSERT( d->mLDAP );
-  kDebug() << "timelimit: " << timelimit << endl;
+  kDebug(5322) << "timelimit:" << timelimit;
   if ( setOption( LDAP_OPT_TIMELIMIT, &timelimit ) != LDAP_OPT_SUCCESS ) {
     return false;
   }
@@ -186,7 +190,7 @@ int LdapConnection::timeLimit() const
 static int kldap_sasl_interact( LDAP *, unsigned, void *defaults, void *in )
 {
 #ifdef SASL2_FOUND
-  LdapConnection::SASL_Data *data = (LdapConnection::SASL_Data*) defaults;
+  LdapConnection::SASL_Data *data = (LdapConnection::SASL_Data *) defaults;
   sasl_interact_t *interact = ( sasl_interact_t * ) in;
 
   if ( data->proc ) {
@@ -219,19 +223,19 @@ static int kldap_sasl_interact( LDAP *, unsigned, void *defaults, void *in )
     switch( interact->id ) {
       case SASL_CB_GETREALM:
         value = data->creds.realm;
-        kDebug() << "SASL_REALM=" << value << endl;
+        kDebug(5322) << "SASL_REALM=" << value;
         break;
       case SASL_CB_AUTHNAME:
         value = data->creds.authname;
-        kDebug() << "SASL_AUTHNAME=" << value << endl;
+        kDebug(5322) << "SASL_AUTHNAME=" << value;
         break;
       case SASL_CB_PASS:
         value = data->creds.password;
-        kDebug() << "SASL_PASSWD=[hidden]" << endl;
+        kDebug(5322) << "SASL_PASSWD=[hidden]";
         break;
       case SASL_CB_USER:
         value = data->creds.authzid;
-        kDebug() << "SASL_AUTHZID=" << value << endl;
+        kDebug(5322) << "SASL_AUTHZID=" << value;
         break;
     }
   }
@@ -262,33 +266,46 @@ int LdapConnection::connect()
   url += d->mServer.host();
   url += ':';
   url += QString::number( d->mServer.port() );
-  kDebug() << "ldap url: " << url << endl;
+  kDebug(5322) << "ldap url:" << url;
+#ifdef HAVE_LDAP_INITIALIZE
   ret = ldap_initialize( &d->mLDAP, url.toLatin1() );
+#else
+  d->mLDAP = ldap_init( d->mServer.host().toLatin1().data(), d->mServer.port() );
+  if ( d->mLDAP == 0 ) {
+    ret = -1;
+  }
+#endif
   if ( ret != LDAP_SUCCESS ) {
     d->mConnectionError = i18n("An error occurred during the connection initialization phase.");
     return ret;
   }
 
-  kDebug() << "setting version to: " << version << endl;
+  kDebug(5322) << "setting version to:" << version;
   if ( setOption( LDAP_OPT_PROTOCOL_VERSION, &version ) != LDAP_OPT_SUCCESS ) {
     ret = ldapErrorCode();
-      d->mConnectionError = i18n("Cannot set protocol version to %1.", version );
+    d->mConnectionError = i18n("Cannot set protocol version to %1.", version );
     close();
     return ret;
   }
 
   //FIXME: accessing to certificate handling would be good
-  kDebug() << "setting security to: " << d->mServer.security() << endl;
+  kDebug(5322) << "setting security to:" << d->mServer.security();
   if ( d->mServer.security() == LdapServer::TLS ) {
-    kDebug() << "start TLS" << endl;
+    kDebug(5322) << "start TLS";
+#ifdef HAVE_LDAP_START_TLS_S
     if ( ( ret = ldap_start_tls_s( d->mLDAP, NULL, NULL ) ) != LDAP_SUCCESS ) {
       close();
       d->mConnectionError = i18n("Cannot start TLS.");
       return ret;
     }
+#else
+    close();
+    d->mConnectionError = i18n("TLS support not available in the LDAP client libraries.");
+    return -1;
+#endif
   }
 
-  kDebug() << "setting sizelimit to: " << d->mServer.sizeLimit() << endl;
+  kDebug(5322) << "setting sizelimit to:" << d->mServer.sizeLimit();
   if ( d->mServer.sizeLimit() ) {
     if ( !setSizeLimit( d->mServer.sizeLimit() ) ) {
       ret = ldapErrorCode();
@@ -298,7 +315,7 @@ int LdapConnection::connect()
     }
   }
 
-  kDebug() << "setting timelimit to: " << d->mServer.timeLimit() << endl;
+  kDebug(5322) << "setting timelimit to:" << d->mServer.timeLimit();
   if ( d->mServer.timeLimit() ) {
     if ( !setTimeLimit( d->mServer.timeLimit() ) ) {
       ret = ldapErrorCode();
@@ -341,8 +358,8 @@ int LdapConnection::bind( SASL_Callback_Proc *saslproc, void *data )
       bindname = d->mServer.bindDn();
       pass = d->mServer.password();
     }
-    kDebug() << "binding to server, bindname: " << bindname << " password: *****" << endl;
-    ret = ldap_simple_bind_s( d->mLDAP, bindname.toUtf8(), pass.toUtf8() );
+    kDebug(5322) << "binding to server, bindname:" << bindname << "password: *****";
+    ret = ldap_simple_bind_s( d->mLDAP, bindname.toUtf8().data(), pass.toUtf8().data() );
   }
   return ret;
 }
@@ -350,77 +367,84 @@ int LdapConnection::bind( SASL_Callback_Proc *saslproc, void *data )
 void LdapConnection::close()
 {
   if ( d->mLDAP ) {
-    ldap_unbind_ext_s( d->mLDAP, 0, 0 );
+#ifdef HAVE_LDAP_UNBIND_EXT
+    ldap_unbind_ext( d->mLDAP, 0, 0 );
+#else
+    ldap_unbind( d->mLDAP );
+#endif
   }
   d->mLDAP = 0;
-  kDebug() << "connection closed!" << endl;
+  kDebug(5322) << "connection closed!";
 }
 #else //LDAP_FOUND
 
 int LdapConnection::getOption( int option, void *value ) const
 {
-  kError() << "No LDAP support..." << endl;
+  kError() << "No LDAP support...";
   return -1;
 }
 
 int LdapConnection::setOption( int option, void *value )
 {
-  kError() << "No LDAP support..." << endl;
+  kError() << "No LDAP support...";
   return -1;
 }
 
 int LdapConnection::ldapErrorCode() const
 {
-  kError() << "No LDAP support..." << endl;
+  kError() << "No LDAP support...";
   return -1;
 }
 
 QString LdapConnection::ldapErrorString() const
 {
-  kError() << "No LDAP support..." << endl;
+  kError() << "No LDAP support...";
   return QString();
 }
 
 bool LdapConnection::setSizeLimit( int sizelimit )
 {
-  kError() << "No LDAP support..." << endl;
+  kError() << "No LDAP support...";
   return false;
 }
 
 int LdapConnection::sizeLimit() const
 {
-  kError() << "No LDAP support..." << endl;
+  kError() << "No LDAP support...";
   return -1;
 }
 
 bool LdapConnection::setTimeLimit( int timelimit )
 {
-  kError() << "No LDAP support..." << endl;
+  kError() << "No LDAP support...";
   return false;
 }
 
 int LdapConnection::timeLimit() const
 {
-  kError() << "No LDAP support..." << endl;
+  kError() << "No LDAP support...";
   return -1;
 }
 
 int LdapConnection::connect( )
 {
-  d->mConnectionError = i18n("LDAP support not compiled in. Please recompile libkldap with the OpenLDAP (or compatible) client libraries, or complain to your distribution packagers.");
-  kError() << "No LDAP support..." << endl;
+  d->mConnectionError =
+    i18n("LDAP support not compiled in. Please recompile libkldap with the "
+         "OpenLDAP (or compatible) client libraries, or complain to your "
+         "distribution packagers.");
+  kError() << "No LDAP support...";
   return -1;
 }
 
 int LdapConnection::bind( SASL_Callback_Proc *saslproc, void *data )
 {
-  kError() << "No LDAP support..." << endl;
+  kError() << "No LDAP support...";
   return -1;
 }
 
 void LdapConnection::close()
 {
-  kError() << "No LDAP support..." << endl;
+  kError() << "No LDAP support...";
 }
 
 #endif
