@@ -19,22 +19,48 @@
 */
 
 #include "ldapoperation.h"
-
-#include <stdlib.h>
+#include "kldap_config.h"
 
 #include <kdebug.h>
 
-#include <kldap_config.h>
+#include <QtCore/QTime>
+
+#include <stdlib.h>
+#ifdef HAVE_SYS_TIME_H
+#include <sys/time.h>
+#endif
 
 #ifdef LDAP_FOUND
-#include <ldap.h>
 #include <lber.h>
+#include <ldap.h>
 #endif
 
 using namespace KLDAP;
 
+#ifdef LDAP_FOUND
+static void extractControls( LdapControls &ctrls, LDAPControl **pctrls );
+#endif // LDAP_FOUND
+
+/*
+   Returns the difference between msecs and elapsed. If msecs is -1,
+   however, -1 is returned.
+*/
+static int kldap_timeout_value( int msecs, int elapsed )
+{
+  if ( msecs == -1 ) {
+    return -1;
+  }
+
+  int timeout = msecs - elapsed;
+  return timeout < 0 ? 0 : timeout;
+}
+
 class LdapOperation::LdapOperationPrivate {
-  public:
+public:
+#ifdef LDAP_FOUND
+  int processResult( int rescode, LDAPMessage *msg );
+#endif
+
   LdapControls mClientCtrls, mServerCtrls, mControls;
   LdapObject mObject;
   QByteArray mExtOid, mExtData;
@@ -81,22 +107,22 @@ void LdapOperation::setServerControls( const LdapControls &ctrls )
   d->mServerCtrls = ctrls;
 }
 
-const LdapControls &LdapOperation::clientControls() const
+LdapControls LdapOperation::clientControls() const
 {
   return d->mClientCtrls;
 }
 
-const LdapControls &LdapOperation::serverControls() const
+LdapControls LdapOperation::serverControls() const
 {
   return d->mServerCtrls;
 }
 
-const LdapObject &LdapOperation::object() const
+LdapObject LdapOperation::object() const
 {
   return d->mObject;
 }
 
-const LdapControls &LdapOperation::controls() const
+LdapControls LdapOperation::controls() const
 {
   return d->mControls;
 }
@@ -123,12 +149,117 @@ QList<QByteArray> LdapOperation::referrals() const
 
 #ifdef LDAP_FOUND
 
-static void addModOp( LDAPMod ***pmods, int mod_type, const QString &attr,
-                      const QByteArray &value )
+int LdapOperation::LdapOperationPrivate::processResult( int rescode, LDAPMessage *msg )
 {
-  //  kDebug() << "type: " << mod_type << " attr: " << attr <<
-  //    " value: " << QString::fromUtf8(value,value.size()) <<
-  //    " size: " << value.size() << endl;
+  //kDebug(5322) << "LdapOperation::LdapOperationPrivate::processResult()";
+  int retval;
+  LDAP *ld = (LDAP*) mConnection->handle();
+
+  switch ( rescode ) {
+    case RES_SEARCH_ENTRY:
+    {
+      //kDebug(5322) << "LdapOperation::LdapOperationPrivate::processResult():"
+      //             << "Found search entry";
+      mObject.clear();
+      LdapAttrMap attrs;
+      char *name;
+      struct berval **bvals;
+      BerElement     *entry;
+
+      char *dn = ldap_get_dn( ld, msg );
+      mObject.setDn( QString::fromUtf8( dn ) );
+      ldap_memfree( dn );
+
+      // iterate over the attributes
+      name = ldap_first_attribute( ld, msg, &entry );
+      while ( name != 0 ) {
+        // print the values
+        bvals = ldap_get_values_len( ld, msg, name );
+        LdapAttrValue values;
+        if ( bvals ) {
+          for ( int i = 0; bvals[i] != 0; i++ ) {
+            char *val = bvals[i]->bv_val;
+            unsigned long len = bvals[i]->bv_len;
+            values.append( QByteArray( val, len ) );
+          }
+          ldap_value_free_len( bvals );
+        }
+        attrs[ QString::fromLatin1( name ) ] = values;
+        // next attribute
+        name = ldap_next_attribute( ld, msg, entry );
+      }
+      ber_free( entry , 0 );
+      mObject.setAttributes( attrs );
+      break;
+    }
+    case RES_EXTENDED:
+    {
+      char *retoid;
+      struct berval *retdata;
+      retval = ldap_parse_extended_result( ld, msg, &retoid, &retdata, 0 );
+      if ( retval != LDAP_SUCCESS ) {
+        ldap_msgfree( msg );
+        return -1;
+      }
+      mExtOid = retoid ? QByteArray( retoid ) : QByteArray();
+      mExtData = retdata ? QByteArray( retdata->bv_val, retdata->bv_len ) : QByteArray();
+      ldap_memfree( retoid );
+      ber_bvfree( retdata );
+      break;
+    }
+    default:
+    {
+      LDAPControl **serverctrls = 0;
+      char *matcheddn = 0, *errmsg = 0;
+      char **referralsp;
+      int errcodep;
+      retval =
+          ldap_parse_result( ld, msg, &errcodep, &matcheddn, &errmsg, &referralsp,
+                             &serverctrls, 0 );
+      kDebug(5322) << "rescode" << rescode << "retval:" << retval
+                   << "matcheddn:" << matcheddn << "errcode:"
+                   << errcodep << "errmsg:" << errmsg;
+      if ( retval != LDAP_SUCCESS ) {
+        ldap_msgfree( msg );
+        return -1;
+      }
+      mControls.clear();
+      if ( serverctrls ) {
+        extractControls( mControls, serverctrls );
+        ldap_controls_free( serverctrls );
+      }
+      mReferrals.clear();
+      if ( referralsp ) {
+        char **tmp = referralsp;
+        while ( *tmp ) {
+          mReferrals.append( QByteArray( *tmp ) );
+          ldap_memfree( *tmp );
+          tmp++;
+        }
+        ldap_memfree( (char *) referralsp );
+      }
+      mMatchedDn = QString();
+      if ( matcheddn ) {
+        mMatchedDn = QString::fromUtf8( matcheddn );
+        ldap_memfree( matcheddn );
+      }
+      if ( errmsg ) {
+        ldap_memfree( errmsg );
+      }
+    }
+  }
+
+  ldap_msgfree( msg );
+
+  return rescode;
+}
+
+static void addModOp( LDAPMod ***pmods, int mod_type, const QString &attr,
+                      const QByteArray *value = 0 )
+{
+  //  kDebug(5322) << "type:" << mod_type << "attr:" << attr <<
+  //    "value:" << QString::fromUtf8(value,value.size()) <<
+  //    "size:" << value.size();
   LDAPMod **mods;
 
   mods = *pmods;
@@ -148,7 +279,7 @@ static void addModOp( LDAPMod ***pmods, int mod_type, const QString &attr,
     if ( mods[ i ] == 0 ) {
       mods = (LDAPMod **)realloc( mods, ( i + 2 ) * sizeof( LDAPMod * ) );
       if ( mods == 0 ) {
-        kError() << "addModOp: realloc" << endl;
+        kError() << "addModOp: realloc";
         return;
       }
       mods[ i + 1 ] = 0;
@@ -164,22 +295,26 @@ static void addModOp( LDAPMod ***pmods, int mod_type, const QString &attr,
 
   *pmods = mods;
 
-  int vallen = value.size();
-  if ( vallen == 0 ) {
+  if ( value == 0 ) 
     return;
-  }
+    
+  int vallen = value->size();
   BerValue *berval;
-  berval = (BerValue*) malloc( sizeof( BerValue ) );
-  berval -> bv_val = (char*) malloc( vallen );
+  berval = (BerValue *) malloc( sizeof( BerValue ) );
   berval -> bv_len = vallen;
-  memcpy( berval -> bv_val, value.data(), vallen );
+  if ( vallen > 0 ) {
+    berval -> bv_val = (char *) malloc( vallen );
+    memcpy( berval -> bv_val, value->data(), vallen );
+  } else {
+    berval -> bv_val = 0;
+  }
 
   if ( mods[ i ] -> mod_vals.modv_bvals == 0 ) {
     mods[ i ]->mod_vals.modv_bvals =
-      (BerValue**) malloc( sizeof( BerValue * ) * 2 );
+      (BerValue **) malloc( sizeof( BerValue * ) * 2 );
     mods[ i ]->mod_vals.modv_bvals[ 0 ] = berval;
     mods[ i ]->mod_vals.modv_bvals[ 1 ] = 0;
-    kDebug() << "addModOp: new bervalue struct " << endl;
+//    kDebug(5322) << "addModOp: new bervalue struct" << attr << value;
   } else {
     uint j = 0;
     while ( mods[ i ]->mod_vals.modv_bvals[ j ] != 0 ) {
@@ -189,13 +324,13 @@ static void addModOp( LDAPMod ***pmods, int mod_type, const QString &attr,
       (BerValue **) realloc( mods[ i ]->mod_vals.modv_bvals,
                              ( j + 2 ) * sizeof( BerValue * ) );
     if ( mods[ i ]->mod_vals.modv_bvals == 0 ) {
-      kError() << "addModOp: realloc" << endl;
+      kError() << "addModOp: realloc";
       free( berval );
       return;
     }
     mods[ i ]->mod_vals.modv_bvals[ j ] = berval;
     mods[ i ]->mod_vals.modv_bvals[ j+1 ] = 0;
-    kDebug() << j << ". new bervalue " << endl;
+    kDebug(5322) << j << ". new bervalue";
   }
 }
 
@@ -207,11 +342,11 @@ static void addControlOp( LDAPControl ***pctrls, const QString &oid,
 
   ctrls = *pctrls;
 
-  kDebug() << "addControlOp: oid:'" << oid << "' val: '" << value << "'" << endl;
+  kDebug(5322) << "addControlOp: oid:'" << oid << "' val: '" << value << "'";
   int vallen = value.size();
   ctrl->ldctl_value.bv_len = vallen;
   if ( vallen ) {
-    ctrl->ldctl_value.bv_val = (char*) malloc( vallen );
+    ctrl->ldctl_value.bv_val = (char *) malloc( vallen );
     memcpy( ctrl->ldctl_value.bv_val, value.data(), vallen );
   } else {
     ctrl->ldctl_value.bv_val = 0;
@@ -261,7 +396,7 @@ static void extractControls( LdapControls &ctrls, LDAPControl **pctrls )
   }
 }
 
-int LdapOperation::search( const QString &base, LdapUrl::Scope scope,
+int LdapOperation::search( const LdapDN &base, LdapUrl::Scope scope,
                            const QString &filter, const QStringList &attributes )
 {
   Q_ASSERT( d->mConnection );
@@ -296,11 +431,11 @@ int LdapOperation::search( const QString &base, LdapUrl::Scope scope,
     break;
   }
 
-  kDebug() << "asyncSearch() base=\"" << base << "\" scope=" << scope <<
-    " filter=\"" << filter << "\" attrs=" << attributes << endl;
+  kDebug(5322) << "asyncSearch() base=\"" << base.toString() << "\" scope=" << scope <<
+    "filter=\"" << filter << "\" attrs=" << attributes;
   int retval =
-    ldap_search_ext( ld, base.toUtf8(), lscope,
-                     filter.isEmpty() ? QByteArray("objectClass=*") : filter.toUtf8(),
+    ldap_search_ext( ld, base.toString().toUtf8().data(), lscope,
+                     filter.isEmpty() ? QByteArray("objectClass=*").data() : filter.toUtf8().data(),
                      attrs, 0, serverctrls, clientctrls, 0,
                      d->mConnection->sizeLimit(), &msgid );
 
@@ -337,12 +472,12 @@ int LdapOperation::add( const LdapObject &object )
         it != object.attributes().end(); ++it ) {
     QString attr = it.key();
     for ( LdapAttrValue::ConstIterator it2 = (*it).begin(); it2 != (*it).end(); ++it2 ) {
-      addModOp( &lmod, 0, attr, *it2 );
+      addModOp( &lmod, 0, attr, &(*it2) );
     }
   }
 
   int retval =
-    ldap_add_ext( ld, object.dn().toString().toUtf8(), lmod, serverctrls,
+    ldap_add_ext( ld, object.dn().toString().toUtf8().data(), lmod, serverctrls,
                   clientctrls, &msgid );
 
   ldap_controls_free( serverctrls );
@@ -369,12 +504,12 @@ int LdapOperation::add_s( const LdapObject &object )
         it != object.attributes().end(); ++it ) {
     QString attr = it.key();
     for ( LdapAttrValue::ConstIterator it2 = (*it).begin(); it2 != (*it).end(); ++it2 ) {
-      addModOp( &lmod, 0, attr, *it2 );
+      addModOp( &lmod, 0, attr, &(*it2) );
     }
   }
 
   int retval =
-    ldap_add_ext_s( ld, object.dn().toString().toUtf8(), lmod, serverctrls,
+    ldap_add_ext_s( ld, object.dn().toString().toUtf8().data(), lmod, serverctrls,
                     clientctrls );
 
   ldap_controls_free( serverctrls );
@@ -383,7 +518,65 @@ int LdapOperation::add_s( const LdapObject &object )
   return retval;
 }
 
-int LdapOperation::rename( const QString &dn, const QString &newRdn,
+int LdapOperation::add( const LdapDN &dn, const ModOps &ops )
+{
+  Q_ASSERT( d->mConnection );
+  LDAP *ld = (LDAP*) d->mConnection->handle();
+
+  int msgid;
+  LDAPMod **lmod = 0;
+
+  LDAPControl **serverctrls = 0, **clientctrls = 0;
+  createControls( &serverctrls, d->mServerCtrls );
+  createControls( &serverctrls, d->mClientCtrls );
+
+  for ( int i = 0; i < ops.count(); ++i ) {
+    for ( int j = 0; j < ops[i].values.count(); ++j ) {
+      addModOp( &lmod, 0, ops[i].attr, &ops[i].values[j] );
+    }
+  }
+
+  int retval =
+    ldap_add_ext( ld, dn.toString().toUtf8().data(), lmod, serverctrls,
+                  clientctrls, &msgid );
+
+  ldap_controls_free( serverctrls );
+  ldap_controls_free( clientctrls );
+  ldap_mods_free( lmod, 1 );
+  if ( retval == 0 ) {
+    retval = msgid;
+  }
+  return retval;
+}
+
+int LdapOperation::add_s( const LdapDN &dn, const ModOps &ops )
+{
+  Q_ASSERT( d->mConnection );
+  LDAP *ld = (LDAP*) d->mConnection->handle();
+
+  LDAPMod **lmod = 0;
+
+  LDAPControl **serverctrls = 0, **clientctrls = 0;
+  createControls( &serverctrls, d->mServerCtrls );
+  createControls( &serverctrls, d->mClientCtrls );
+
+  for ( int i = 0; i < ops.count(); ++i ) {
+    for ( int j = 0; j < ops[i].values.count(); ++j ) {
+      addModOp( &lmod, 0, ops[i].attr, &ops[i].values[j] );
+    }
+  }
+  kDebug(5322) << "LdapOperation::add_s dn=" << dn.toString();
+  int retval =
+    ldap_add_ext_s( ld, dn.toString().toUtf8().data(), lmod, serverctrls,
+                    clientctrls );
+
+  ldap_controls_free( serverctrls );
+  ldap_controls_free( clientctrls );
+  ldap_mods_free( lmod, 1 );
+  return retval;
+}
+
+int LdapOperation::rename( const LdapDN &dn, const QString &newRdn,
                            const QString &newSuperior, bool deleteold )
 {
   Q_ASSERT( d->mConnection );
@@ -395,7 +588,7 @@ int LdapOperation::rename( const QString &dn, const QString &newRdn,
   createControls( &serverctrls, d->mServerCtrls );
   createControls( &serverctrls, d->mClientCtrls );
 
-  int retval = ldap_rename( ld, dn.toUtf8(), newRdn.toUtf8(),
+  int retval = ldap_rename( ld, dn.toString().toUtf8().data(), newRdn.toUtf8().data(),
                             newSuperior.isEmpty() ? (char *) 0 : newSuperior.toUtf8().data(),
                             deleteold, serverctrls, clientctrls, &msgid );
 
@@ -408,7 +601,7 @@ int LdapOperation::rename( const QString &dn, const QString &newRdn,
   return retval;
 }
 
-int LdapOperation::rename_s( const QString &dn, const QString &newRdn,
+int LdapOperation::rename_s( const LdapDN &dn, const QString &newRdn,
                              const QString &newSuperior, bool deleteold )
 {
   Q_ASSERT( d->mConnection );
@@ -418,7 +611,7 @@ int LdapOperation::rename_s( const QString &dn, const QString &newRdn,
   createControls( &serverctrls, d->mServerCtrls );
   createControls( &serverctrls, d->mClientCtrls );
 
-  int retval = ldap_rename_s( ld, dn.toUtf8(), newRdn.toUtf8(),
+  int retval = ldap_rename_s( ld, dn.toString().toUtf8().data(), newRdn.toUtf8().data(),
                               newSuperior.isEmpty() ? (char *) 0 : newSuperior.toUtf8().data(),
                               deleteold, serverctrls, clientctrls );
 
@@ -428,7 +621,7 @@ int LdapOperation::rename_s( const QString &dn, const QString &newRdn,
   return retval;
 }
 
-int LdapOperation::del( const QString &dn )
+int LdapOperation::del( const LdapDN &dn )
 {
   Q_ASSERT( d->mConnection );
   LDAP *ld = (LDAP*) d->mConnection->handle();
@@ -439,7 +632,8 @@ int LdapOperation::del( const QString &dn )
   createControls( &serverctrls, d->mServerCtrls );
   createControls( &serverctrls, d->mClientCtrls );
 
-  int retval = ldap_delete_ext( ld, dn.toUtf8(), serverctrls, clientctrls, &msgid );
+  int retval =
+    ldap_delete_ext( ld, dn.toString().toUtf8().data(), serverctrls, clientctrls, &msgid );
 
   ldap_controls_free( serverctrls );
   ldap_controls_free( clientctrls );
@@ -450,7 +644,7 @@ int LdapOperation::del( const QString &dn )
   return retval;
 }
 
-int LdapOperation::del_s( const QString &dn )
+int LdapOperation::del_s( const LdapDN &dn )
 {
   Q_ASSERT( d->mConnection );
   LDAP *ld = (LDAP*) d->mConnection->handle();
@@ -459,7 +653,7 @@ int LdapOperation::del_s( const QString &dn )
   createControls( &serverctrls, d->mServerCtrls );
   createControls( &serverctrls, d->mClientCtrls );
 
-  int retval = ldap_delete_ext_s( ld, dn.toUtf8(), serverctrls, clientctrls );
+  int retval = ldap_delete_ext_s( ld, dn.toString().toUtf8().data(), serverctrls, clientctrls );
 
   ldap_controls_free( serverctrls );
   ldap_controls_free( clientctrls );
@@ -467,7 +661,7 @@ int LdapOperation::del_s( const QString &dn )
   return retval;
 }
 
-int LdapOperation::modify( const QString &dn, const ModOps &ops )
+int LdapOperation::modify( const LdapDN &dn, const ModOps &ops )
 {
   Q_ASSERT( d->mConnection );
   LDAP *ld = (LDAP*) d->mConnection->handle();
@@ -495,12 +689,14 @@ int LdapOperation::modify( const QString &dn, const ModOps &ops )
       mtype = LDAP_MOD_DELETE;
       break;
     }
+    addModOp( &lmod, mtype, ops[i].attr, 0 );
     for ( int j = 0; j < ops[i].values.count(); ++j ) {
-      addModOp( &lmod, mtype, ops[i].attr, ops[i].values[j] );
+      addModOp( &lmod, mtype, ops[i].attr, &ops[i].values[j] );
     }
   }
 
-  int retval = ldap_modify_ext( ld, dn.toUtf8(), lmod, serverctrls, clientctrls, &msgid );
+  int retval =
+    ldap_modify_ext( ld, dn.toString().toUtf8().data(), lmod, serverctrls, clientctrls, &msgid );
 
   ldap_controls_free( serverctrls );
   ldap_controls_free( clientctrls );
@@ -511,7 +707,7 @@ int LdapOperation::modify( const QString &dn, const ModOps &ops )
   return retval;
 }
 
-int LdapOperation::modify_s( const QString &dn, const ModOps &ops )
+int LdapOperation::modify_s( const LdapDN &dn, const ModOps &ops )
 {
   Q_ASSERT( d->mConnection );
   LDAP *ld = (LDAP*) d->mConnection->handle();
@@ -538,12 +734,14 @@ int LdapOperation::modify_s( const QString &dn, const ModOps &ops )
       mtype = LDAP_MOD_DELETE;
       break;
     }
+    addModOp( &lmod, mtype, ops[i].attr, 0 );
     for ( int j = 0; j < ops[i].values.count(); ++j ) {
-      addModOp( &lmod, mtype, ops[i].attr, ops[i].values[j] );
+      addModOp( &lmod, mtype, ops[i].attr, &ops[i].values[j] );
     }
   }
 
-  int retval = ldap_modify_ext_s( ld, dn.toUtf8(), lmod, serverctrls, clientctrls );
+  int retval =
+    ldap_modify_ext_s( ld, dn.toString().toUtf8().data(), lmod, serverctrls, clientctrls );
 
   ldap_controls_free( serverctrls );
   ldap_controls_free( clientctrls );
@@ -551,7 +749,7 @@ int LdapOperation::modify_s( const QString &dn, const ModOps &ops )
   return retval;
 }
 
-int LdapOperation::compare( const QString &dn, const QString &attr, const QByteArray &value )
+int LdapOperation::compare( const LdapDN &dn, const QString &attr, const QByteArray &value )
 {
   Q_ASSERT( d->mConnection );
   LDAP *ld = (LDAP*) d->mConnection->handle();
@@ -563,12 +761,12 @@ int LdapOperation::compare( const QString &dn, const QString &attr, const QByteA
 
   int vallen = value.size();
   BerValue *berval;
-  berval = (BerValue*) malloc( sizeof( BerValue ) );
-  berval -> bv_val = (char*) malloc( vallen );
+  berval = (BerValue *) malloc( sizeof( BerValue ) );
+  berval -> bv_val = (char *) malloc( vallen );
   berval -> bv_len = vallen;
   memcpy( berval -> bv_val, value.data(), vallen );
 
-  int retval = ldap_compare_ext( ld, dn.toUtf8(), attr.toUtf8(), berval,
+  int retval = ldap_compare_ext( ld, dn.toString().toUtf8().data(), attr.toUtf8().data(), berval,
                                  serverctrls, clientctrls, &msgid );
 
   ber_bvfree( berval );
@@ -581,7 +779,7 @@ int LdapOperation::compare( const QString &dn, const QString &attr, const QByteA
   return retval;
 }
 
-int LdapOperation::compare_s( const QString &dn, const QString &attr, const QByteArray &value )
+int LdapOperation::compare_s( const LdapDN &dn, const QString &attr, const QByteArray &value )
 {
   Q_ASSERT( d->mConnection );
   LDAP *ld = (LDAP*) d->mConnection->handle();
@@ -592,12 +790,12 @@ int LdapOperation::compare_s( const QString &dn, const QString &attr, const QByt
 
   int vallen = value.size();
   BerValue *berval;
-  berval = (BerValue*) malloc( sizeof( BerValue ) );
-  berval -> bv_val = (char*) malloc( vallen );
+  berval = (BerValue *) malloc( sizeof( BerValue ) );
+  berval -> bv_val = (char *) malloc( vallen );
   berval -> bv_len = vallen;
   memcpy( berval -> bv_val, value.data(), vallen );
 
-  int retval = ldap_compare_ext_s( ld, dn.toUtf8(), attr.toUtf8(), berval,
+  int retval = ldap_compare_ext_s( ld, dn.toString().toUtf8().data(), attr.toUtf8().data(), berval,
                                    serverctrls, clientctrls );
 
   ber_bvfree( berval );
@@ -610,6 +808,7 @@ int LdapOperation::compare_s( const QString &dn, const QString &attr, const QByt
 int LdapOperation::exop( const QString &oid, const QByteArray &data )
 {
   Q_ASSERT( d->mConnection );
+#if defined(HAVE_LDAP_EXTENDED_OPERATION) && defined(HAVE_LDAP_EXTENDED_OPERATION_PROTOTYPE)
   LDAP *ld = (LDAP*) d->mConnection->handle();
   int msgid;
 
@@ -619,12 +818,12 @@ int LdapOperation::exop( const QString &oid, const QByteArray &data )
 
   int vallen = data.size();
   BerValue *berval;
-  berval = (BerValue*) malloc( sizeof( BerValue ) );
-  berval -> bv_val = (char*) malloc( vallen );
+  berval = (BerValue *) malloc( sizeof( BerValue ) );
+  berval -> bv_val = (char *) malloc( vallen );
   berval -> bv_len = vallen;
   memcpy( berval -> bv_val, data.data(), vallen );
 
-  int retval = ldap_extended_operation( ld, oid.toUtf8(), berval,
+  int retval = ldap_extended_operation( ld, oid.toUtf8().data(), berval,
                                         serverctrls, clientctrls, &msgid );
 
   ber_bvfree( berval );
@@ -635,10 +834,15 @@ int LdapOperation::exop( const QString &oid, const QByteArray &data )
     retval = msgid;
   }
   return retval;
+#else
+  kError() << "Your LDAP client libraries don't support extended operations.";
+  return -1;
+#endif
 }
 
 int LdapOperation::exop_s( const QString &oid, const QByteArray &data )
 {
+#if defined(HAVE_LDAP_EXTENDED_OPERATION) && defined(HAVE_LDAP_EXTENDED_OPERATION_PROTOTYPE)
   Q_ASSERT( d->mConnection );
   LDAP *ld = (LDAP*) d->mConnection->handle();
   BerValue *retdata;
@@ -650,12 +854,12 @@ int LdapOperation::exop_s( const QString &oid, const QByteArray &data )
 
   int vallen = data.size();
   BerValue *berval;
-  berval = (BerValue*) malloc( sizeof( BerValue ) );
-  berval -> bv_val = (char*) malloc( vallen );
+  berval = (BerValue *) malloc( sizeof( BerValue ) );
+  berval -> bv_val = (char *) malloc( vallen );
   berval -> bv_len = vallen;
   memcpy( berval -> bv_val, data.data(), vallen );
 
-  int retval = ldap_extended_operation_s( ld, oid.toUtf8(), berval,
+  int retval = ldap_extended_operation_s( ld, oid.toUtf8().data(), berval,
                                           serverctrls, clientctrls, &retoid, &retdata );
 
   ber_bvfree( berval );
@@ -665,6 +869,10 @@ int LdapOperation::exop_s( const QString &oid, const QByteArray &data )
   ldap_controls_free( clientctrls );
 
   return retval;
+#else
+  kError() << "Your LDAP client libraries don't support extended operations.";
+  return -1;
+#endif
 }
 
 int LdapOperation::abandon( int id )
@@ -684,206 +892,149 @@ int LdapOperation::abandon( int id )
   return retval;
 }
 
-int LdapOperation::result( int id )
+int LdapOperation::waitForResult( int id, int msecs )
 {
   Q_ASSERT( d->mConnection );
   LDAP *ld = (LDAP*) d->mConnection->handle();
 
   LDAPMessage *msg;
-  int rescode, retval;
+  int rescode;
 
-  rescode = ldap_result( ld, id, 0, NULL, &msg );
-  if ( rescode == -1 ) {
-    return -1;
-  }
+  QTime stopWatch;
+  stopWatch.start();
+  int attempt( 1 );
+  int timeout( 0 );
 
-  switch ( rescode ) {
-  case RES_SEARCH_ENTRY:
-  {
-    d->mObject.clear();
-    LdapAttrMap attrs;
-    char *name;
-    struct berval **bvals;
-    BerElement     *entry;
+  do {
+    // Calculate the timeout value to use and assign it to a timeval structure
+    // see man select (2) for details
+    timeout = kldap_timeout_value( msecs, stopWatch.elapsed() );
+    kDebug(5322) << "LdapOperation::waitForResult(" << id << "," << msecs
+             << "): Waiting" << timeout / 1000.0
+             << "secs for result. Attempt #" << attempt++;
+    struct timeval tv;
+    tv.tv_sec = timeout / 1000;
+    tv.tv_usec = ( timeout % 1000 ) * 1000;
 
-    char *dn = ldap_get_dn( ld, msg );
-    d->mObject.setDn( QString::fromUtf8( dn ) );
-    ldap_memfree( dn );
-
-    // iterate over the attributes
-    name = ldap_first_attribute( ld, msg, &entry );
-    while ( name != 0 ) {
-      // print the values
-      bvals = ldap_get_values_len( ld, msg, name );
-      LdapAttrValue values;
-      if ( bvals ) {
-        for ( int i = 0; bvals[i] != 0; i++ ) {
-          char *val = bvals[i]->bv_val;
-          unsigned long len = bvals[i]->bv_len;
-          values.append( QByteArray( val, len ) );
-        }
-        ldap_value_free_len( bvals );
-      }
-      attrs[ QString::fromLatin1( name ) ] = values;
-      // next attribute
-      name = ldap_next_attribute( ld, msg, entry );
-    }
-    ber_free( entry , 0 );
-    d->mObject.setAttributes( attrs );
-    break;
-  }
-  case RES_EXTENDED:
-  {
-    char *retoid;
-    struct berval *retdata;
-    retval = ldap_parse_extended_result( ld, msg, &retoid, &retdata, 0 );
-    if ( retval != LDAP_SUCCESS ) {
-      ldap_msgfree( msg );
+    // Wait for a result
+    rescode = ldap_result( ld, id, 0, timeout < 0 ? 0 : &tv, &msg );
+    if ( rescode == -1 ) {
       return -1;
     }
-    d->mExtOid = retoid ? QByteArray( retoid ) : QByteArray();
-    d->mExtData = retdata ? QByteArray( retdata->bv_val, retdata->bv_len ) : QByteArray();
-    ldap_memfree( retoid );
-    ber_bvfree( retdata );
-    break;
-  }
-  default:
-  {
-    LDAPControl **serverctrls = 0;
-    char *matcheddn = 0, *errmsg = 0;
-    char **referralsp;
-    int errcodep;
-    retval =
-      ldap_parse_result( ld, msg, &errcodep, &matcheddn, &errmsg, &referralsp,
-                         &serverctrls, 0 );
-    kDebug() << "rescode " << rescode << " retval: " << retval
-             << " matcheddn: " << matcheddn << " errcode: "
-             << errcodep << " errmsg: " << errmsg << endl;
-    if ( retval != LDAP_SUCCESS ) {
-      ldap_msgfree( msg );
-      return -1;
+    // Act on the return code
+    if ( rescode != 0 ) {
+      // Some kind of result is available for processing
+      return d->processResult( rescode, msg );
     }
-    d->mControls.clear();
-    if ( serverctrls ) {
-      extractControls( d->mControls, serverctrls );
-      ldap_controls_free( serverctrls );
-    }
-    d->mReferrals.clear();
-    if ( referralsp ) {
-      char **tmp = referralsp;
-      while ( *tmp ) {
-        d->mReferrals.append( QByteArray( *tmp ) );
-        tmp++;
-      }
-      ber_memvfree( (void **) referralsp );
-    }
-    d->mMatchedDn = QString();
-    if ( matcheddn ) {
-      d->mMatchedDn = QString::fromUtf8( matcheddn );
-      ldap_memfree( matcheddn );
-    }
-    if ( errmsg ) {
-      ldap_memfree( errmsg );
-    }
-  }
-  }
+  } while ( msecs == -1 || stopWatch.elapsed() < msecs );
 
-  ldap_msgfree( msg );
-
-  return rescode;
+  return 0; //timeout
 }
 
 #else
-int LdapOperation::search( const QString &base, LdapUrl::Scope scope,
+
+int LdapOperation::search( const LdapDN &base, LdapUrl::Scope scope,
                            const QString &filter, const QStringList &attributes )
 {
-  kError() << "LDAP support not compiled" << endl;
+  kError() << "LDAP support not compiled";
   return -1;
 }
 
 int LdapOperation::add( const LdapObject &object )
 {
-  kError() << "LDAP support not compiled" << endl;
+  kError() << "LDAP support not compiled";
   return -1;
 }
 
 int LdapOperation::add_s( const LdapObject &object )
 {
-  kError() << "LDAP support not compiled" << endl;
+  kError() << "LDAP support not compiled";
   return -1;
 }
 
-int LdapOperation::rename( const QString &dn, const QString &newRdn,
+int LdapOperation::add( const LdapDN &dn, const ModOps &ops )
+{
+  kError() << "LDAP support not compiled";
+  return -1;
+}
+
+int LdapOperation::add_s( const LdapDN &dn, const ModOps &ops )
+{
+  kError() << "LDAP support not compiled";
+  return -1;
+}
+                                
+int LdapOperation::rename( const LdapDN &dn, const QString &newRdn,
                            const QString &newSuperior, bool deleteold )
 {
-  kError() << "LDAP support not compiled" << endl;
+  kError() << "LDAP support not compiled";
   return -1;
 }
 
-int LdapOperation::rename_s( const QString &dn, const QString &newRdn,
+int LdapOperation::rename_s( const LdapDN &dn, const QString &newRdn,
                              const QString &newSuperior, bool deleteold )
 {
-  kError() << "LDAP support not compiled" << endl;
+  kError() << "LDAP support not compiled";
   return -1;
 }
 
-int LdapOperation::del( const QString &dn )
+int LdapOperation::del( const LdapDN &dn )
 {
-  kError() << "LDAP support not compiled" << endl;
+  kError() << "LDAP support not compiled";
   return -1;
 }
 
-int LdapOperation::del_s( const QString &dn )
+int LdapOperation::del_s( const LdapDN &dn )
 {
-  kError() << "LDAP support not compiled" << endl;
+  kError() << "LDAP support not compiled";
   return -1;
 }
 
-int LdapOperation::modify( const QString &dn, const ModOps &ops )
+int LdapOperation::modify( const LdapDN &dn, const ModOps &ops )
 {
-  kError() << "LDAP support not compiled" << endl;
+  kError() << "LDAP support not compiled";
   return -1;
 }
 
-int LdapOperation::modify_s( const QString &dn, const ModOps &ops )
+int LdapOperation::modify_s( const LdapDN &dn, const ModOps &ops )
 {
-  kError() << "LDAP support not compiled" << endl;
+  kError() << "LDAP support not compiled";
   return -1;
 }
 
-int LdapOperation::compare( const QString &dn, const QString &attr, const QByteArray &value )
+int LdapOperation::compare( const LdapDN &dn, const QString &attr, const QByteArray &value )
 {
-  kError() << "LDAP support not compiled" << endl;
+  kError() << "LDAP support not compiled";
   return -1;
 }
 
 int LdapOperation::exop( const QString &oid, const QByteArray &data )
 {
-  kError() << "LDAP support not compiled" << endl;
+  kError() << "LDAP support not compiled";
   return -1;
 }
 
-int LdapOperation::compare_s( const QString &dn, const QString &attr, const QByteArray &value )
+int LdapOperation::compare_s( const LdapDN &dn, const QString &attr, const QByteArray &value )
 {
-  kError() << "LDAP support not compiled" << endl;
+  kError() << "LDAP support not compiled";
   return -1;
 }
 
 int LdapOperation::exop_s( const QString &oid, const QByteArray &data )
 {
-  kError() << "LDAP support not compiled" << endl;
+  kError() << "LDAP support not compiled";
   return -1;
 }
 
-int LdapOperation::result( int id )
+int LdapOperation::waitForResult( int id, int msecs )
 {
-  kError() << "LDAP support not compiled" << endl;
+  kError() << "LDAP support not compiled";
   return -1;
 }
 
 int LdapOperation::abandon( int id )
 {
-  kError() << "LDAP support not compiled" << endl;
+  kError() << "LDAP support not compiled";
   return -1;
 }
 
