@@ -21,16 +21,17 @@
 #ifndef KLDAP_LDAPOPERATION_H
 #define KLDAP_LDAPOPERATION_H
 
-#include <QString>
-#include <QList>
-#include <QByteArray>
-
-#include "ldapurl.h"
-#include "ldapobject.h"
-#include "ldapcontrol.h"
-#include "ldapserver.h"
+#include "kldap_export.h"
 #include "ldapconnection.h"
-#include "kldap.h"
+#include "ldapcontrol.h"
+#include "ldapobject.h"
+#include "ldapdn.h"
+#include "ldapserver.h"
+#include "ldapurl.h"
+
+#include <QtCore/QByteArray>
+#include <QtCore/QList>
+#include <QtCore/QString>
 
 namespace KLDAP {
 
@@ -92,17 +93,17 @@ class KLDAP_EXPORT LdapOperation
     /**
      * Returns the client controls (which set by setClientControls()).
      */
-    const LdapControls &clientControls() const;
+    LdapControls clientControls() const;
     /**
      * Returns the server controls (which set by setServerControls()).
      */
-    const LdapControls &serverControls() const;
+    LdapControls serverControls() const;
 
     /**
      * Starts a search operation with the given base DN, scope, filter and
      * result attributes. Returns a message id if successful, -1 if not.
      */
-    int search( const QString &base, LdapUrl::Scope scope,
+    int search( const LdapDN &base, LdapUrl::Scope scope,
                 const QString &filter, const QStringList &attrs );
     /**
      * Starts an addition operation.
@@ -114,13 +115,24 @@ class KLDAP_EXPORT LdapOperation
      * Returns KLDAP_SUCCESS id if successful, else an LDAP error code.
      */
     int add_s( const LdapObject &object );
+    /**
+     * Starts an addition operation. This version accepts ModOps not LdapObject.
+     * Returns a message id if successful, -1 if not.
+     */
+    int add( const LdapDN &dn, const ModOps &ops );
+    /**
+     * Adds the specified object to the LDAP database. This version accepts ModOps not LdapObject.
+     * This is the synchronous version.
+     * Returns KLDAP_SUCCESS id if successful, else an LDAP error code.
+     */
+    int add_s( const LdapDN &dn, const ModOps &ops );
     /**
      * Starts a modrdn operation on given DN, changing its RDN to newRdn,
      * changing its parent to newSuperior (if it's not empty), and deletes
      * the old dn if deleteold is true.
      * Returns a message id if successful, -1 if not.
      */
-    int rename( const QString &dn, const QString &newRdn,
+    int rename( const LdapDN &dn, const QString &newRdn,
                 const QString &newSuperior, bool deleteold = true );
     /**
      * Performs a modrdn operation on given DN, changing its RDN to newRdn,
@@ -128,35 +140,35 @@ class KLDAP_EXPORT LdapOperation
      * the old dn if deleteold is true. This is the synchronous version.
      * Returns KLDAP_SUCCESS id if successful, else an LDAP error code.
      */
-    int rename_s( const QString &dn, const QString &newRdn,
+    int rename_s( const LdapDN &dn, const QString &newRdn,
                   const QString &newSuperior, bool deleteold = true );
     /**
      * Starts a delete operation on the given DN.
      * Returns a message id if successful, -1 if not.
      */
-    int del( const QString &dn );
+    int del( const LdapDN &dn );
     /**
      * Deletes the given DN. This is the synchronous version.
      * Returns KLDAP_SUCCESS id if successful, else an LDAP error code.
      */
-    int del_s( const QString &dn );
+    int del_s( const LdapDN &dn );
     /**
      * Starts a modify operation on the given DN.
      * Returns a message id if successful, -1 if not.
      */
-    int modify( const QString &dn, const ModOps &ops );
+    int modify( const LdapDN &dn, const ModOps &ops );
     /**
      * Performs a modify operation on the given DN.
      * This is the synchronous version.
      * Returns KLDAP_SUCCESS id if successful, else an LDAP error code.
      */
-    int modify_s( const QString &dn, const ModOps &ops );
+    int modify_s( const LdapDN &dn, const ModOps &ops );
     /**
      * Starts a compare operation on the given DN, compares the specified
      * attribute with the given value.
      * Returns a message id if successful, -1 if not.
      */
-    int compare( const QString &dn, const QString &attr, const QByteArray &value );
+    int compare( const LdapDN &dn, const QString &attr, const QByteArray &value );
     /**
      * Performs a compare operation on the given DN, compares the specified
      * attribute with the given value. This is the synchronous version.
@@ -164,7 +176,7 @@ class KLDAP_EXPORT LdapOperation
      * and KLDAP_COMPARE_FALSE if it does not. Otherwise, some error code
      * is returned.
      */
-    int compare_s( const QString &dn, const QString &attr, const QByteArray &value );
+    int compare_s( const LdapDN &dn, const QString &attr, const QByteArray &value );
     /**
      * Starts an extended operation specified with oid and data.
      * Returns a message id if successful, -1 if not.
@@ -180,23 +192,28 @@ class KLDAP_EXPORT LdapOperation
      * Abandons a long-running operation. Requires the message id.
      */
     int abandon( int id );
-
     /**
+     * Waits for up to \p msecs milliseconds for a result message from the LDAP
+     * server. If \p msecs is -1, then this function will block indefinitely.
+     * If \p msecs is 0, then this function will return immediately, that is it
+     * will perform a poll for a result message.
+     *
      * Returns the type of the result LDAP message (RES_XXX constants).
-     * -1 if error occurred. Note! Return code -1 means that fetching the
-     * message resulted in error, not the LDAP operation error. Call
-     * connection().ldapErrorCode() to determine if the operation succeeded.
+     * -1 if error occurred, 0 if the timeout value elapsed. Note!
+     * Return code -1 means that fetching the message resulted in error,
+     * not the LDAP operation error. Call connection().ldapErrorCode() to
+     * determine if the operation succeeded.
      */
-    int result( int id );
+    int waitForResult( int id, int msecs = -1 );
     /**
      * Returns the result object if result() returned RES_SEARCH_ENTRY.
      */
-    const LdapObject &object() const;
+    LdapObject object() const;
     /**
      * Returns the server controls from the returned ldap message (grabbed
      * by result()).
      */
-    const LdapControls &controls() const;
+    LdapControls controls() const;
     /**
      * Returns the OID of the extended operation response (result
      * returned RES_EXTENDED).
