@@ -29,7 +29,7 @@ class LdapServer::LdapServerPrivate
   public:
     QString mHost;
     int mPort;
-    QString mBaseDn;
+    LdapDN mBaseDn;
     QString mUser;
     QString mBindDn;
     QString mRealm;
@@ -98,7 +98,7 @@ int LdapServer::port() const
   return d->mPort;
 }
 
-QString LdapServer::baseDn() const
+LdapDN LdapServer::baseDn() const
 {
   return d->mBaseDn;
 }
@@ -178,7 +178,7 @@ void LdapServer::setPort( int port )
   d->mPort = port;
 }
 
-void LdapServer::setBaseDn( const QString &baseDn )
+void LdapServer::setBaseDn( const LdapDN &baseDn )
 {
   d->mBaseDn = baseDn;
 }
@@ -270,7 +270,7 @@ void LdapServer::setUrl( const LdapUrl &url )
   } else if ( url.hasExtension("x-tls") ) {
     d->mSecurity = TLS;
   }
-  kDebug() << "security: " << d->mSecurity << endl;
+  kDebug(5322) << "security:" << d->mSecurity;
 
   d->mMech = d->mUser = d->mBindDn = QString();
   if ( url.hasExtension("x-sasl") ) {
