@@ -18,12 +18,12 @@
   Boston, MA 02110-1301, USA.
 */
 
-#include <QDir>
-#include <QStringList>
+#include "ldapurl.h"
 
 #include <kdebug.h>
 
-#include "ldapurl.h"
+#include <QtCore/QDir>
+#include <QtCore/QStringList>
 
 using namespace KLDAP;
 
@@ -50,12 +50,10 @@ LdapUrl::LdapUrl( const KUrl &_url )
   : KUrl( _url ), d( new LdapUrlPrivate )
 {
   QString tmp = path();
-  if ( !QDir::isRelativePath( tmp ) )
-#ifdef Q_WS_WIN
-    tmp.remove( 0, 3 ); // e.g. "c:/"
-#else
-    tmp.remove( 0, 1 );
-#endif
+  if ( !QDir::isRelativePath( tmp ) ) {
+    tmp.remove( 0, QDir::rootPath().length() );
+  }
+  setPath( tmp );
   parseQuery();
 }
 
@@ -82,28 +80,23 @@ LdapUrl::~LdapUrl()
   delete d;
 }
 
-void LdapUrl::setDn( const QString &dn )
+void LdapUrl::setDn( const LdapDN &dn )
 {
-  QString tmp = dn;
-  if ( !QDir::isRelativePath( tmp ) )
-#ifdef Q_WS_WIN
-    tmp.remove( 0, 3 ); // e.g. "c:/"
-#else
-    tmp.remove( 0, 1 );
-#endif
+  QString tmp = dn.toString();
+  if ( !QDir::isRelativePath( tmp ) ) {
+    tmp.remove( 0, QDir::rootPath().length() );
+  }
   setPath( tmp );
 }
 
-QString LdapUrl::dn() const
+LdapDN LdapUrl::dn() const
 {
   QString tmp = path();
-  if ( !QDir::isRelativePath( tmp ) )
-#ifdef Q_WS_WIN
-    tmp.remove( 0, 3 ); // e.g. "c:/"
-#else
-    tmp.remove( 0, 1 );
-#endif
-  return tmp;
+  if ( !QDir::isRelativePath( tmp ) ) {
+    tmp.remove( 0, QDir::rootPath().length() );
+  }
+  LdapDN tmpDN( tmp );
+  return tmpDN;
 }
 
 QStringList LdapUrl::attributes() const
@@ -224,7 +217,7 @@ void LdapUrl::updateQuery()
   // set the filter
   q += '?';
   if ( d->m_filter != "(objectClass=*)" && !d->m_filter.isEmpty() ) {
-    q += d->m_filter;
+    q += toPercentEncoding( d->m_filter );
   }
 
   // set the extensions
@@ -235,16 +228,16 @@ void LdapUrl::updateQuery()
     }
     q += it.key();
     if ( !it.value().value.isEmpty() ) {
-      q += '=' + it.value().value;
+      q += '=' + toPercentEncoding(it.value().value);
     }
     q += ',';
   }
-  while  ( q.endsWith("?") || q.endsWith(",") ) {
+  while  ( q.endsWith( '?' ) || q.endsWith( ',' ) ) {
     q.remove( q.length() - 1, 1 );
   }
 
   setQuery( q );
-  kDebug(5700) << "LDAP URL updateQuery(): " << prettyUrl() << endl;
+  kDebug(5322) << "LDAP URL updateQuery():" << prettyUrl();
 }
 
 void LdapUrl::parseQuery()
@@ -253,7 +246,7 @@ void LdapUrl::parseQuery()
   QStringList extensions;
   QString q = query();
   // remove first ?
-  if ( q.startsWith( "?" ) ) {
+  if ( q.startsWith( '?' ) ) {
     q.remove( 0, 1 );
   }
 
@@ -292,11 +285,11 @@ void LdapUrl::parseQuery()
     ext.critical = false;
     name = fromPercentEncoding( (*it).section( '=', 0, 0 ).toLatin1() ).toLower();
     value = fromPercentEncoding( (*it).section( '=', 1 ).toLatin1() );
-    if ( name.startsWith("!") ) {
+    if ( name.startsWith( '!' ) ) {
       ext.critical = true;
       name.remove( 0, 1 );
     }
-    kDebug(5700) << "LdapUrl extensions name= " << name << " value: " << value << endl;
+    kDebug(5322) << "LdapUrl extensions name=" << name << "value:" << value;
     ext.value = value.replace( "%2", "," );
     setExtension( name, ext );
   }
