@@ -4,7 +4,7 @@
     KMime, the KDE internet mail/usenet news message library.
     Copyright (c) 2001 the KMime authors.
     See file AUTHORS for details
-    Copyright (c) 2006 Volker Krause <volker.krause@rwth-aachen.de>
+    Copyright (c) 2006 Volker Krause <vkrause@kde.org>
 
     This library is free software; you can redistribute it and/or
     modify it under the terms of the GNU Library General Public
@@ -30,11 +30,13 @@
   Defines the Content class.
 
   @authors the KMime authors (see AUTHORS file),
-  Volker Krause \<volker.krause@rwth-aachen.de\>
+  Volker Krause \<vkrause@kde.org\>
 */
 
 #include "kmime_content.h"
+#include "kmime_content_p.h"
 #include "kmime_parsers.h"
+#include "kmime_util_p.h"
 
 #include <kcharsets.h>
 #include <kcodecs.h>
@@ -42,63 +44,53 @@
 #include <klocale.h>
 #include <kdebug.h>
 
-#include <QTextCodec>
-#include <QTextStream>
-#include <QByteArray>
+#include <QtCore/QTextCodec>
+#include <QtCore/QTextStream>
+#include <QtCore/QByteArray>
 
 using namespace KMime;
 
 namespace KMime {
 
-class ContentPrivate
-{
-  public:
-  QByteArray head;
-  QByteArray body;
-  Content::List contents;
-  QByteArray defaultCS;
-  bool forceDefaultCS;
-};
-
 Content::Content()
-  : d( new ContentPrivate )
+  : d_ptr( new ContentPrivate( this ) )
 {
-  d->forceDefaultCS = false;
-  d->defaultCS = cachedCharset( "ISO-8859-1" );
 }
 
 Content::Content( const QByteArray &h, const QByteArray &b )
-  : d( new ContentPrivate )
+  : d_ptr( new ContentPrivate( this ) )
+{
+  d_ptr->head = h;
+  d_ptr->body = b;
+}
+
+Content::Content( ContentPrivate *d ) :
+    d_ptr( d )
 {
-  d->forceDefaultCS = false;
-  d->defaultCS = cachedCharset( "ISO-8859-1" );
-  d->head = h;
-  d->body = b;
 }
 
 Content::~Content()
 {
-  qDeleteAll( d->contents );
-  d->contents.clear();
   qDeleteAll( h_eaders );
   h_eaders.clear();
-  delete d;
+  delete d_ptr;
 }
 
 bool Content::hasContent() const
 {
-  return !d->head.isEmpty() || !d->body.isEmpty() || !d->contents.isEmpty();
+  return !d_ptr->head.isEmpty() || !d_ptr->body.isEmpty() || !d_ptr->contents.isEmpty();
 }
 
 void Content::setContent( const QList<QByteArray> &l )
 {
+  Q_D(Content);
   //qDebug("Content::setContent( const QList<QByteArray> &l ) : start");
   d->head.clear();
   d->body.clear();
 
   //usage of textstreams is much faster than simply appending the strings
-  QTextStream hts( &(d->head), QIODevice::WriteOnly ),
-    bts( &(d->body), QIODevice::WriteOnly );
+  QTextStream hts( &( d->head ), QIODevice::WriteOnly );
+  QTextStream bts( &( d->body ), QIODevice::WriteOnly );
   hts.setCodec( "ISO 8859-1" );
   bts.setCodec( "ISO 8859-1" );
 
@@ -120,6 +112,7 @@ void Content::setContent( const QList<QByteArray> &l )
 
 void Content::setContent( const QByteArray &s )
 {
+  Q_D(Content);
   d->head.clear();
   d->body.clear();
 
@@ -140,27 +133,28 @@ void Content::setContent( const QByteArray &s )
 
 QByteArray Content::head() const
 {
-  return d->head;
+  return d_ptr->head;
 }
 
 void Content::setHead( const QByteArray &head )
 {
-  d->head = head;
+  d_ptr->head = head;
 }
 
 QByteArray Content::body() const
 {
-  return d->body;
+  return d_ptr->body;
 }
 
 void Content::setBody( const QByteArray &body )
 {
-  d->body = body;
+  d_ptr->body = body;
 }
 
 //parse the message, split multiple parts
 void Content::parse()
 {
+  Q_D(Content);
   //qDebug("void Content::parse() : start");
   qDeleteAll( h_eaders );
   h_eaders.clear();
@@ -190,9 +184,14 @@ void Content::parse()
     ct->setMimeType( "invalid/invalid" );
   }
 
-  if ( ct->isText() || ct->isEmpty() ) { // default is text/plain
+  if ( ct->isText() ) {
     return; //nothing to do
   }
+  if ( ct->isEmpty() ) {
+    // default is text/plain
+    ct->setMimeType( "text/plain" );
+    return;
+  }
 
   if ( ct->isMultipart() ) {   //this is a multipart message
     tmp = ct->boundary(); //get boundary-parameter
@@ -209,7 +208,8 @@ void Content::parse()
 
         QList<QByteArray> parts = mpp.parts();
         QList<QByteArray>::Iterator it;
-        for ( it=parts.begin(); it!=parts.end(); ++it ) { //create a new Content for every part
+        for ( it=parts.begin(); it != parts.end(); ++it ) {
+          //create a new Content for every part
           c = new Content();
           c->setContent( *it );
           c->parse();
@@ -262,7 +262,9 @@ void Content::parse()
 
         if ( !d->contents.isEmpty() && d->contents.first() ) {
           //readd the plain text before the uuencoded part
-          d->contents.first()->setContent( "Content-Type: text/plain\nContent-Transfer-Encoding: 7Bit\n\n" + uup.textPart() );
+          d->contents.first()->setContent(
+            "Content-Type: text/plain\nContent-Transfer-Encoding: 7Bit\n\n" +
+            uup.textPart() );
           d->contents.first()->contentType()->setMimeType( "text/plain" );
         }
       }
@@ -303,7 +305,9 @@ void Content::parse()
 
           if ( !d->contents.isEmpty() && d->contents.first() ) {
             //readd the plain text before the uuencoded part
-            d->contents.first()->setContent( "Content-Type: text/plain\nContent-Transfer-Encoding: 7Bit\n\n" + yenc.textPart() );
+            d->contents.first()->setContent(
+              "Content-Type: text/plain\nContent-Transfer-Encoding: 7Bit\n\n" +
+              yenc.textPart() );
             d->contents.first()->contentType()->setMimeType( "text/plain" );
           }
         }
@@ -318,35 +322,53 @@ void Content::parse()
 
 void Content::assemble()
 {
-  d->head = assembleHeaders();
-  foreach ( Content *c, contents() )
+  Q_D(Content);
+  QByteArray newHead = assembleHeaders();
+  foreach ( Headers::Base *h, h_eaders ) {
+    if ( h->isXHeader() ) {
+      newHead += h->as7BitString() + '\n';
+      KMime::removeHeader( d->head, h->type() );
+    }
+  }
+  newHead += d->head; // keep unparsed headers
+  d->head = newHead;
+
+  foreach ( Content *c, contents() ) {
     c->assemble();
+  }
 }
 
 QByteArray Content::assembleHeaders()
 {
-  QByteArray newHead = "";
+  Q_D(Content);
+  QByteArray newHead;
 
   //Content-Type
   Headers::Base *h = contentType( false );
-  if ( h && !h->isEmpty() )
+  if ( h && !h->isEmpty() ) {
     newHead += contentType()->as7BitString() + '\n';
+    KMime::removeHeader( d->head, h->type() );
+  }
 
   //Content-Transfer-Encoding
   h = contentTransferEncoding( false );
-  if ( h && !h->isEmpty() )
+  if ( h && !h->isEmpty() ) {
     newHead += contentTransferEncoding()->as7BitString() + '\n';
+    KMime::removeHeader( d->head, h->type() );
+  }
 
   //Content-Description
   h = contentDescription( false );
   if ( h ) {
     newHead += h->as7BitString() + '\n';
+    KMime::removeHeader( d->head, h->type() );
   }
 
   //Content-Disposition
   h = contentDisposition( false );
   if ( h ) {
     newHead += h->as7BitString() + '\n';
+    KMime::removeHeader( d->head, h->type() );
   }
 
   return newHead;
@@ -354,6 +376,7 @@ QByteArray Content::assembleHeaders()
 
 void Content::clear()
 {
+  Q_D(Content);
   qDeleteAll( h_eaders );
   h_eaders.clear();
   qDeleteAll( d->contents );
@@ -364,6 +387,7 @@ void Content::clear()
 
 QByteArray Content::encodedContent( bool useCrLf )
 {
+  Q_D(Content);
   QByteArray e;
 
   // hack to convert articles with uuencoded or yencoded binaries into
@@ -459,14 +483,14 @@ QByteArray Content::decodedContent()
   QByteArray temp, ret;
   Headers::ContentTransferEncoding *ec=contentTransferEncoding();
   bool removeTrailingNewline=false;
-  int size = d->body.length();
+  int size = d_ptr->body.length();
 
   if ( size == 0 ) {
     return ret;
   }
 
   temp.resize( size );
-  memcpy( temp.data(), d->body.data(), size );
+  memcpy( temp.data(), d_ptr->body.data(), size );
 
   if ( ec->decoded() ) {
     ret = temp;
@@ -477,7 +501,7 @@ QByteArray Content::decodedContent()
       KCodecs::base64Decode( temp, ret );
       break;
     case Headers::CEquPr :
-      ret = KCodecs::quotedPrintableDecode( d->body );
+      ret = KCodecs::quotedPrintableDecode( d_ptr->body );
       ret.resize( ret.size() - 1 );  // remove null-char
       removeTrailingNewline = true;
       break;
@@ -494,9 +518,9 @@ QByteArray Content::decodedContent()
     }
   }
 
-  if ( removeTrailingNewline && (ret.size() > 0 ) &&
-       ( ret[ret.size()-1] == '\n') )
+  if ( removeTrailingNewline && (ret.size() > 0 ) && ( ret[ret.size()-1] == '\n') ) {
     ret.resize( ret.size() - 1 );
+  }
 
   return ret;
 }
@@ -511,7 +535,7 @@ QString Content::decodedText( bool trimText, bool removeTrailingNewlines )
   QTextCodec *codec =
     KGlobal::charsets()->codecForName( contentType()->charset(), ok );
 
-  QString s = codec->toUnicode( d->body.data(), d->body.length() );
+  QString s = codec->toUnicode( d_ptr->body.data(), d_ptr->body.length() );
 
   if ( trimText && removeTrailingNewlines ) {
     int i;
@@ -542,7 +566,7 @@ void Content::fromUnicodeString( const QString &s )
     contentType()->setCharset( chset );
   }
 
-  d->body = codec->fromUnicode( s );
+  d_ptr->body = codec->fromUnicode( s );
   contentTransferEncoding()->setDecoded( true ); //text is always decoded
 }
 
@@ -554,7 +578,7 @@ Content *Content::textContent()
   if ( contentType()->isText() ) {
     ret = this;
   } else {
-    foreach ( Content *c, d->contents ) {
+    foreach ( Content *c, d_ptr->contents ) {
       if ( ( ret = c->textContent() ) != 0 ) {
         break;
       }
@@ -566,10 +590,10 @@ Content *Content::textContent()
 Content::List Content::attachments( bool incAlternatives )
 {
   List attachments;
-  if ( d->contents.isEmpty() ) {
+  if ( d_ptr->contents.isEmpty() ) {
     attachments.append( this );
   } else {
-    foreach ( Content *c, d->contents ) {
+    foreach ( Content *c, d_ptr->contents ) {
       if ( !incAlternatives &&
            c->contentType()->category() == Headers::CCalternativePart ) {
         continue;
@@ -590,12 +614,14 @@ Content::List Content::attachments( bool incAlternatives )
 
 Content::List Content::contents() const
 {
-  return d->contents;
+  return d_ptr->contents;
 }
 
 void Content::addContent( Content *c, bool prepend )
 {
-  if ( d->contents.isEmpty() ) { // this message is not multipart yet
+  Q_D(Content);
+  if ( d->contents.isEmpty() && !contentType()->isMultipart() ) {
+    // this message is not multipart yet
 
     // first we convert the body to a content
     Content *main = new Content();
@@ -642,6 +668,7 @@ void Content::addContent( Content *c, bool prepend )
 
 void Content::removeContent( Content *c, bool del )
 {
+  Q_D(Content);
   if ( d->contents.isEmpty() ) { // what the ..
     return;
   }
@@ -659,8 +686,8 @@ void Content::removeContent( Content *c, bool del )
     for ( Headers::Base::List::iterator it = main->h_eaders.begin();
           it != main->h_eaders.end(); ) {
       if ( (*it)->isMimeHeader() ) {
-        kDebug(5003) << "Content::removeContent(Content *c, bool del) : mime-header moved: "
-                     << (*it)->as7BitString() << endl;
+        kDebug(5320) << "Content::removeContent(Content *c, bool del) : mime-header moved:"
+                     << (*it)->as7BitString();
         // first remove the old header
         removeHeader( (*it)->type() );
         // then append to new content
@@ -689,17 +716,20 @@ void Content::changeEncoding( Headers::contentEncoding e )
   }
 
   if ( decodeText() ) {
-    enc->setEncoding( e ); // text is not encoded until it's sent or saved so we just set the new encoding
-  } else { // this content contains non textual data, that has to be re-encoded
-
+    enc->setEncoding( e ); // text is not encoded until it's sent or saved
+                           // so we just set the new encoding
+  } else {
+    // this content contains non textual data, that has to be re-encoded
     if ( e != Headers::CEbase64 ) {
-      //kWarning(5003) << "Content::changeEncoding() : non textual data and encoding != base64 - this should not happen\n => forcing base64" << endl;
+      //kWarning(5003) << "Content::changeEncoding() : non textual data"
+      //               << "and encoding != base64 - this should not happen =>"
+      //               << "forcing base64";
       e = Headers::CEbase64;
     }
 
     if ( enc->encoding() != e ) { // ok, we reencode the content using base64
-      d->body = KCodecs::base64Encode( decodedContent(), true );
-      d->body.append( "\n" );
+      d_ptr->body = KCodecs::base64Encode( decodedContent(), true );
+      d_ptr->body.append( "\n" );
       enc->setEncoding( e ); //set encoding
       enc->setDecoded( false );
     }
@@ -816,6 +846,8 @@ Headers::Base *Content::getHeaderByType( const char *type )
       h = new Headers::ContentDisposition( this, raw );
     } else if ( strcasecmp( "Content-Description", type ) == 0 ) {
       h = new Headers::ContentDescription( this, raw );
+    } else if ( strcasecmp( "Sender", type ) == 0 ) {
+      h = new Headers::Sender( this, raw );
     } else {
       h = new Headers::Generic( type, this, raw );
     }
@@ -848,12 +880,41 @@ bool Content::removeHeader( const char *type )
   return false;
 }
 
+bool Content::hasHeader( const char *type )
+{
+  return getHeaderByType( type ) != 0;
+}
+
+Headers::ContentType *Content::contentType( bool create )
+{
+  Headers::ContentType *p=0;
+  return getHeaderInstance( p, create );
+}
+
+Headers::ContentTransferEncoding *Content::contentTransferEncoding( bool create )
+{
+  Headers::ContentTransferEncoding *p=0;
+  return getHeaderInstance( p, create );
+}
+
+Headers::ContentDisposition *Content::contentDisposition( bool create )
+{
+  Headers::ContentDisposition *p=0;
+  return getHeaderInstance( p, create );
+}
+
+Headers::ContentDescription *Content::contentDescription( bool create )
+{
+  Headers::ContentDescription *p=0;
+  return getHeaderInstance( p, create );
+}
+
 int Content::size()
 {
-  int ret = d->body.length();
+  int ret = d_ptr->body.length();
 
   if ( contentTransferEncoding()->encoding() == Headers::CEbase64 ) {
-    return ( ret * 3 / 4 ); //base64 => 6 bit per byte
+    return ret * 3 / 4; //base64 => 6 bit per byte
   }
 
   return ret;
@@ -861,6 +922,7 @@ int Content::size()
 
 int Content::storageSize() const
 {
+  const Q_D(Content);
   int s = d->head.size();
 
   if ( d->contents.isEmpty() ) {
@@ -876,6 +938,7 @@ int Content::storageSize() const
 
 int Content::lineCount() const
 {
+  const Q_D(Content);
   int ret = 0;
   if ( !isTopLevel() ) {
     ret += d->head.count( '\n' );
@@ -889,13 +952,14 @@ int Content::lineCount() const
   return ret;
 }
 
-QByteArray Content::rawHeader( const char *name )
+QByteArray Content::rawHeader( const char *name ) const
 {
-  return KMime::extractHeader( d->head, name );
+  return KMime::extractHeader( d_ptr->head, name );
 }
 
 bool Content::decodeText()
 {
+  Q_D(Content);
   Headers::ContentTransferEncoding *enc = contentTransferEncoding();
 
   if ( !contentType()->isText() ) {
@@ -931,14 +995,14 @@ bool Content::decodeText()
 
 QByteArray Content::defaultCharset() const
 {
-  return d->defaultCS;
+  return d_ptr->defaultCS;
 }
 
 void Content::setDefaultCharset( const QByteArray &cs )
 {
-  d->defaultCS = KMime::cachedCharset( cs );
+  d_ptr->defaultCS = KMime::cachedCharset( cs );
 
-  foreach ( Content *c, d->contents ) {
+  foreach ( Content *c, d_ptr->contents ) {
     c->setDefaultCharset( cs );
   }
 
@@ -949,14 +1013,14 @@ void Content::setDefaultCharset( const QByteArray &cs )
 
 bool Content::forceDefaultCharset() const
 {
-  return d->forceDefaultCS;
+  return d_ptr->forceDefaultCS;
 }
 
 void Content::setForceDefaultCharset( bool b )
 {
-  d->forceDefaultCS = b;
+  d_ptr->forceDefaultCS = b;
 
-  foreach ( Content *c, d->contents ) {
+  foreach ( Content *c, d_ptr->contents ) {
     c->setForceDefaultCharset( b );
   }
 
@@ -972,8 +1036,8 @@ Content * KMime::Content::content( const ContentIndex &index ) const
   }
   ContentIndex idx = index;
   unsigned int i = idx.pop() - 1; // one-based -> zero-based index
-  if ( i < (unsigned int)d->contents.size() ) {
-    return d->contents[i]->content( idx );
+  if ( i < (unsigned int)d_ptr->contents.size() ) {
+    return d_ptr->contents[i]->content( idx );
   } else {
     return 0;
   }
@@ -981,15 +1045,15 @@ Content * KMime::Content::content( const ContentIndex &index ) const
 
 ContentIndex KMime::Content::indexForContent( Content * content ) const
 {
-  int i = d->contents.indexOf( content );
+  int i = d_ptr->contents.indexOf( content );
   if ( i > 0 ) {
     ContentIndex ci;
     ci.push( i + 1 ); // zero-based -> one-based index
     return ci;
   }
   // not found, we need to search recursively
-  for ( int i = 0; i < d->contents.size(); ++i ) {
-    ContentIndex ci = d->contents[i]->indexForContent( content );
+  for ( int i = 0; i < d_ptr->contents.size(); ++i ) {
+    ContentIndex ci = d_ptr->contents[i]->indexForContent( content );
     if ( ci.isValid() ) {
       // found it
       ci.push( i + 1 ); // zero-based -> one-based index
