@@ -30,9 +30,9 @@
 #include <kglobal.h>
 #include <kcharsets.h>
 
-#include <QTextCodec>
-#include <QMap>
-#include <QStringList>
+#include <QtCore/QTextCodec>
+#include <QtCore/QMap>
+#include <QtCore/QStringList>
 
 #include <ctype.h> // for isdigit
 #include <cassert>
@@ -67,6 +67,11 @@ QString AddrSpec::asString() const
   }
 }
 
+bool AddrSpec::isEmpty() const
+{
+  return localPart.isEmpty() && domain.isEmpty();
+}
+
 QByteArray Mailbox::address() const
 {
   return mAddrSpec.asString().toLatin1();
@@ -94,7 +99,7 @@ void Mailbox::setAddress( const QByteArray &addr )
                                        cursor + addr.length(), mAddrSpec ) ) {
     if ( !HeaderParsing::parseAddrSpec( cursor, cursor + addr.length(),
                                         mAddrSpec ) ) {
-      kWarning() << k_funcinfo << "Invalid address" << endl;
+      kWarning() << "Invalid address";
       return;
     }
   }
@@ -114,7 +119,7 @@ void Mailbox::setNameFrom7Bit( const QByteArray &name,
 
 bool Mailbox::hasAddress() const
 {
-  return !mAddrSpec.asString().isEmpty();
+  return !mAddrSpec.isEmpty();
 }
 
 bool Mailbox::hasName() const
@@ -185,7 +190,7 @@ bool parseEncodedWord( const char* &scursor, const char * const send,
   char ch = *scursor++;
 
   if ( ch != '?' ) {
-    kDebug() << "first" << endl;
+    kDebug(5320) << "first";
     KMIME_WARN_PREMATURE_END_OF( EncodedWord );
     return false;
   }
@@ -207,7 +212,7 @@ bool parseEncodedWord( const char* &scursor, const char * const send,
 
   // not found? can't be an encoded-word!
   if ( scursor == send || *scursor != '?' ) {
-    kDebug() << "second" << endl;
+    kDebug(5320) << "second";
     KMIME_WARN_PREMATURE_END_OF( EncodedWord );
     return false;
   }
@@ -238,7 +243,7 @@ bool parseEncodedWord( const char* &scursor, const char * const send,
 
   // not found? Can't be an encoded-word!
   if ( scursor == send || *scursor != '?' ) {
-    kDebug() << "third" << endl;
+    kDebug(5320) << "third";
     KMIME_WARN_PREMATURE_END_OF( EncodedWord );
     return false;
   }
@@ -246,9 +251,9 @@ bool parseEncodedWord( const char* &scursor, const char * const send,
   // extract the encoding information:
   QByteArray maybeEncoding( encodingStart, scursor - encodingStart );
 
-  kDebug() << "parseEncodedWord: found charset == \"" << maybeCharset
+  kDebug(5320) << "parseEncodedWord: found charset == \"" << maybeCharset
            << "\"; language == \"" << maybeLanguage
-           << "\"; encoding == \"" << maybeEncoding << "\"" << endl;
+           << "\"; encoding == \"" << maybeEncoding << "\"";
 
   //
   // STEP 3:
@@ -269,14 +274,14 @@ bool parseEncodedWord( const char* &scursor, const char * const send,
   // not found? Can't be an encoded-word!
   // ### maybe evaluate it nonetheless if the rest is OK?
   if ( scursor == send || *scursor != '?' ) {
-    kDebug() << "fourth" << endl;
+    kDebug(5320) << "fourth";
     KMIME_WARN_PREMATURE_END_OF( EncodedWord );
     return false;
   }
   scursor++;
   // check for trailing '=':
   if ( scursor == send || *scursor != '=' ) {
-    kDebug() << "fifth" << endl;
+    kDebug(5320) << "fifth";
     KMIME_WARN_PREMATURE_END_OF( EncodedWord );
     return false;
   }
@@ -323,7 +328,7 @@ bool parseEncodedWord( const char* &scursor, const char * const send,
     return false;
   };
 
-  kDebug() << "mimeName(): \"" << textCodec->name() << "\"" << endl;
+  kDebug(5320) << "mimeName(): \"" << textCodec->name() << "\"";
 
   // allocate a temporary buffer to store the 8bit text:
   int encodedTextLength = encodedTextEnd - encodedTextStart;
@@ -338,13 +343,13 @@ bool parseEncodedWord( const char* &scursor, const char * const send,
   //
 
   if ( !dec->decode( encodedTextStart, encodedTextEnd, bit, bend ) ) {
-    KMIME_WARN << codec->name() << " codec lies about it's maxDecodedSizeFor( "
-               << encodedTextLength << " )\nresult may be truncated" << endl;
+    KMIME_WARN << codec->name() << "codec lies about it's maxDecodedSizeFor("
+               << encodedTextLength << ")\nresult may be truncated";
   }
 
   result = textCodec->toUnicode( buffer.begin(), bit - buffer.begin() );
 
-  kDebug() << "result now: \"" << result << "\"" << endl;
+  kDebug(5320) << "result now: \"" << result << "\"";
   // cleanup:
   delete dec;
   language = maybeLanguage;
@@ -1036,7 +1041,7 @@ bool parseAngleAddr( const char* &scursor, const char * const send,
 
   if ( *scursor == '@' || *scursor == ',' ) {
     // obs-route: parse, but ignore:
-    KMIME_WARN << "obsolete source route found! ignoring." << endl;
+    KMIME_WARN << "obsolete source route found! ignoring.";
     QStringList dummy;
     if ( !parseObsRoute( scursor, send, dummy,
                          isCRLF, false /* don't save */ ) ) {
@@ -1311,8 +1316,8 @@ bool parseParameter( const char* &scursor, const char * const send,
   if ( scursor == send ) {
     // don't choke on attribute=, meaning the value was omitted:
     if ( maybeAttribute.endsWith( asterisk ) ) {
-      KMIME_WARN << "attribute ends with \"*\", but value is empty! "
-        "Chopping away \"*\"." << endl;
+      KMIME_WARN << "attribute ends with \"*\", but value is empty!"
+        "Chopping away \"*\".";
       maybeAttribute.truncate( maybeAttribute.length() - 1 );
     }
     result = qMakePair( maybeAttribute.toLower(), QStringOrQPair() );
@@ -1332,8 +1337,8 @@ bool parseParameter( const char* &scursor, const char * const send,
       // attributes ending with "*" designate extended-parameters,
       // which cannot have quoted-strings as values. So we remove the
       // trailing "*" to not confuse upper layers.
-      KMIME_WARN << "attribute ends with \"*\", but value is a quoted-string! "
-        "Chopping away \"*\"." << endl;
+      KMIME_WARN << "attribute ends with \"*\", but value is a quoted-string!"
+        "Chopping away \"*\".";
       maybeAttribute.truncate( maybeAttribute.length() - 1 );
     }
 
@@ -1446,8 +1451,8 @@ static void decodeRFC2231Value( Codec* &rfc2231Codec,
     if ( decCursor == decEnd ) {
       // there wasn't a single single quote at all!
       // take the whole value to be in latin-1:
-      KMIME_WARN << "No charset in extended-initial-value. "
-        "Assuming \"iso-8859-1\"." << endl;
+      KMIME_WARN << "No charset in extended-initial-value."
+        "Assuming \"iso-8859-1\".";
       value += QString::fromLatin1( decBegin, source.second );
       return;
     }
@@ -1464,8 +1469,8 @@ static void decodeRFC2231Value( Codec* &rfc2231Codec,
       }
     }
     if ( decCursor == decEnd ) {
-      KMIME_WARN << "No language in extended-initial-value. "
-        "Trying to recover." << endl;
+      KMIME_WARN << "No language in extended-initial-value."
+        "Trying to recover.";
       decCursor = oldDecCursor;
     } else {
       decCursor++;
@@ -1510,13 +1515,13 @@ static void decodeRFC2231Value( Codec* &rfc2231Codec,
 
   if ( !dec->decode( decCursor, decEnd, bit, bend ) ) {
     KMIME_WARN << rfc2231Codec->name()
-               << " codec lies about it's maxDecodedSizeFor()\n"
-               << "result may be truncated" << endl;
+               << "codec lies about it's maxDecodedSizeFor()" << endl
+               << "result may be truncated";
   }
 
   value += textcodec->toUnicode( buffer.begin(), bit - buffer.begin() );
 
-  kDebug() << "value now: \"" << value << "\"" << endl;
+  kDebug(5320) << "value now: \"" << value << "\"";
   // cleanup:
   delete dec;
 }
@@ -1648,7 +1653,7 @@ static bool parseDayName( const char* &scursor, const char * const send )
   for ( int i = 0 ; i < stdDayNamesLen ; ++i ) {
     if ( qstrnicmp( scursor, stdDayNames[i], 3 ) == 0 ) {
       scursor += 3;
-      kDebug() << "found " << stdDayNames[i] << endl;
+      // kDebug(5320) << "found" << stdDayNames[i];
       return true;
     }
   }
