@@ -18,35 +18,37 @@
     the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
     Boston, MA 02110-1301, USA.
 */
+#include "kcmkresources.h"
 
-#include <QLayout>
+#include <QtGui/QLayout>
 
 #include <kaboutdata.h>
 #include <kgenericfactory.h>
 #include <klocale.h>
 
 #include "configpage.h"
-#include "kcmkresources.h"
 
 typedef KGenericFactory<KCMKResources, QWidget> ResourcesFactory;
 K_EXPORT_COMPONENT_FACTORY( kcm_kresources, ResourcesFactory( "kcmkresources" ) )
 
-KCMKResources::KCMKResources( QWidget *parent, const QStringList& )
+KCMKResources::KCMKResources( QWidget *parent, const QStringList &l )
   : KCModule( ResourcesFactory::componentData(), parent, QStringList() )
 {
+  Q_UNUSED( l );
+
   QVBoxLayout *layout = new QVBoxLayout( this );
   mConfigPage = new KRES::ConfigPage( this );
   layout->addWidget( mConfigPage );
   connect( mConfigPage, SIGNAL( changed( bool ) ), SIGNAL( changed( bool ) ) );
   setButtons( Help | Apply );
   KAboutData *about =
-   new KAboutData( I18N_NOOP( "kcmkresources" ),
-                   I18N_NOOP( "KDE Resources configuration module" ),
-                   0, 0, KAboutData::License_GPL,
-                   I18N_NOOP( "(c) 2003 Tobias Koenig" ) );
+   new KAboutData( I18N_NOOP( "kcmkresources" ), 0,
+                   ki18n( "KDE Resources configuration module" ),
+                   0, KLocalizedString(), KAboutData::License_GPL,
+                   ki18n( "(c) 2003 Tobias Koenig" ) );
 
-  about->addAuthor( "Tobias Koenig", 0, "tokoe@kde.org" );
-  setAboutData(about);
+  about->addAuthor( ki18n( "Tobias Koenig" ), KLocalizedString(), "tokoe@kde.org" );
+  setAboutData( about );
 }
 
 void KCMKResources::load()
