@@ -22,14 +22,18 @@
 #ifndef KRESOURCES_KCMKRESOURCES_H
 #define KRESOURCES_KCMKRESOURCES_H
 
+#include <kresources_export.h>
+#define KDE3_SUPPORT
 #include <kcmodule.h>
+#undef KDE3_SUPPORT
+namespace KRES { class ConfigPage; }
 
 class KCM_KRESOURCES_EXPORT KCMKResources : public KCModule
 {
   Q_OBJECT
 
   public:
-    KCMKResources( QWidget *parent, const QStringList& );
+    KCMKResources( QWidget *parent, const QStringList &l );
 
     void load();
     void save();
