@@ -21,12 +21,11 @@
     Boston, MA 02110-1301, USA.
 */
 
+#include "resource.h"
 #include <kdebug.h>
-#include <kapplication.h>
 #include <krandom.h>
 #include <kconfig.h>
 #include <klocale.h>
-#include "resource.h"
 
 using namespace KRES;
 
@@ -45,6 +44,7 @@ class Resource::ResourcePrivate
     bool mIsOpen;
 };
 
+/*
 Resource::Resource( const KConfig* config )
   : QObject( 0 ), d( new ResourcePrivate )
 {
@@ -65,21 +65,48 @@ Resource::Resource( const KConfig* config )
     d->mIdentifier = KRandom::randomString( 10 );
   }
 }
+*/
+
+Resource::Resource()
+  : QObject( 0 ), d( new ResourcePrivate )
+{
+  d->mOpenCount = 0;
+  d->mIsOpen = false;
+
+  d->mType = "type";
+  d->mName = i18n( "resource" );
+  d->mReadOnly = false;
+  d->mActive = true;
+  d->mIdentifier = KRandom::randomString( 10 );
+}
+
+Resource::Resource( const KConfigGroup &group )
+  : QObject( 0 ), d( new ResourcePrivate )
+{
+  d->mOpenCount = 0;
+  d->mIsOpen = false;
+
+  d->mType = group.readEntry( "ResourceType" );
+  d->mName = group.readEntry( "ResourceName" );
+  d->mReadOnly = group.readEntry( "ResourceIsReadOnly", false );
+  d->mActive = group.readEntry( "ResourceIsActive", true );
+  d->mIdentifier = group.readEntry( "ResourceIdentifier" );
+}
 
 Resource::~Resource()
 {
   delete d;
 }
 
-void Resource::writeConfig( KConfig* config )
+void Resource::writeConfig( KConfigGroup &group )
 {
-  kDebug(5650) << "Resource::writeConfig()" << endl;
+  kDebug(5650) << "Resource::writeConfig()";
 
-  config->writeEntry( "ResourceType", d->mType );
-  config->writeEntry( "ResourceName", d->mName );
-  config->writeEntry( "ResourceIsReadOnly", d->mReadOnly );
-  config->writeEntry( "ResourceIsActive", d->mActive );
-  config->writeEntry( "ResourceIdentifier", d->mIdentifier );
+  group.writeEntry( "ResourceType", d->mType );
+  group.writeEntry( "ResourceName", d->mName );
+  group.writeEntry( "ResourceIsReadOnly", d->mReadOnly );
+  group.writeEntry( "ResourceIsActive", d->mActive );
+  group.writeEntry( "ResourceIdentifier", d->mIdentifier );
 }
 
 bool Resource::open()
@@ -89,7 +116,7 @@ bool Resource::open()
   QMutexLocker guard( &(d->mMutex) );
 #endif
   if ( !d->mOpenCount ) {
-    kDebug(5650) << "Opening resource " << resourceName() << endl;
+    kDebug(5650) << "Opening resource" << resourceName();
     d->mIsOpen = doOpen();
   }
   d->mOpenCount++;
@@ -102,16 +129,18 @@ void Resource::close()
   QMutexLocker guard( &(d->mMutex) );
 #endif
   if ( !d->mOpenCount ) {
-    kDebug(5650) << "ERROR: Resource " << resourceName() << " closed more times than previously opened" << endl;
+    kDebug(5650) << "ERROR: Resource" << resourceName()
+                 << "closed more times than previously opened";
     return;
   }
   d->mOpenCount--;
   if ( !d->mOpenCount ) {
-    kDebug(5650) << "Closing resource " << resourceName() << endl;
+    kDebug(5650) << "Closing resource" << resourceName();
     doClose();
     d->mIsOpen = false;
   } else {
-    kDebug(5650) << "Not yet closing resource " << resourceName() << ", open count = " << d->mOpenCount << endl;
+    kDebug(5650) << "Not yet closing resource" << resourceName()
+                 << ", open count =" << d->mOpenCount;
   }
 }
 
@@ -172,14 +201,33 @@ bool Resource::isActive() const
 
 void Resource::dump() const
 {
-  kDebug(5650) << "Resource:" << endl;
-  kDebug(5650) << "  Name: " << d->mName << endl;
-  kDebug(5650) << "  Identifier: " << d->mIdentifier << endl;
-  kDebug(5650) << "  Type: " << d->mType << endl;
-  kDebug(5650) << "  OpenCount: " << d->mOpenCount << endl;
-  kDebug(5650) << "  ReadOnly: " << ( d->mReadOnly ? "yes" : "no" ) << endl;
-  kDebug(5650) << "  Active: " << ( d->mActive ? "yes" : "no" ) << endl;
-  kDebug(5650) << "  IsOpen: " << ( d->mIsOpen ? "yes" : "no" ) << endl;
+  kDebug(5650) << "Resource:";
+  kDebug(5650) << "  Name:" << d->mName;
+  kDebug(5650) << "  Identifier:" << d->mIdentifier;
+  kDebug(5650) << "  Type:" << d->mType;
+  kDebug(5650) << "  OpenCount:" << d->mOpenCount;
+  kDebug(5650) << "  ReadOnly:" << ( d->mReadOnly ? "yes" : "no" );
+  kDebug(5650) << "  Active:" << ( d->mActive ? "yes" : "no" );
+  kDebug(5650) << "  IsOpen:" << ( d->mIsOpen ? "yes" : "no" );
+}
+
+bool Resource::doOpen()
+{
+  return true;
+}
+
+void Resource::doClose()
+{
+}
+
+QObject *PluginFactoryBase::createObject( QObject *parent,
+                                          const char *className,
+                                          const QStringList &args )
+{
+  Q_UNUSED( parent );
+  Q_UNUSED( className );
+  Q_UNUSED( args );
+  return 0;
 }
 
 #include "resource.moc"
