@@ -21,33 +21,37 @@
     Boston, MA 02110-1301, USA.
 */
 
-#include <kbuttonbox.h>
+#include "selectdialog.h"
+
 #include <klocale.h>
 #include <kmessagebox.h>
 
-#include <QGroupBox>
-#include <QLayout>
-#include <QListWidget>
+#include <QtGui/QGroupBox>
+#include <QtGui/QLayout>
+#include <QtGui/QListWidget>
 
 #include "resource.h"
 
-#include "selectdialog.h"
-
 using namespace KRES;
 
-SelectDialog::SelectDialog( QList<Resource *> list, QWidget *parent,
-                            const char *name )
-  : KDialog( parent )
+class SelectDialog::SelectDialogPrivate
+{
+  public:
+    QListWidget *mResourceId;
+    QMap<int, Resource*> mResourceMap;
+};
+
+SelectDialog::SelectDialog( QList<Resource *> list, QWidget *parent )
+  : KDialog( parent ), d( new SelectDialogPrivate )
 {
   setModal(true);
-  setObjectName(name);
   setCaption( i18n( "Resource Selection" ) );
   resize( 300, 200 );
-  setButtons(Ok|Cancel);
-  setDefaultButton(Ok);
+  setButtons( Ok|Cancel );
+  setDefaultButton( Ok );
 
-  QWidget *widget = new QWidget(this);
-  setMainWidget(widget);
+  QWidget *widget = new QWidget( this );
+  setMainWidget( widget );
 
   QVBoxLayout *mainLayout = new QVBoxLayout( widget );
   mainLayout->setMargin( marginHint() );
@@ -57,8 +61,8 @@ SelectDialog::SelectDialog( QList<Resource *> list, QWidget *parent,
   groupBox->setLayout( grid );
   groupBox->setTitle( i18n( "Resources" ) );
 
-  mResourceId = new QListWidget( groupBox );
-  grid->addWidget( mResourceId, 0, 0 );
+  d->mResourceId = new QListWidget( groupBox );
+  grid->addWidget( d->mResourceId, 0, 0 );
 
   mainLayout->addWidget( groupBox );
 
@@ -69,23 +73,29 @@ SelectDialog::SelectDialog( QList<Resource *> list, QWidget *parent,
   for ( int i = 0; i < list.count(); ++i ) {
     Resource *resource = list.at( i );
     if ( resource && !resource->readOnly() ) {
-      mResourceMap.insert( counter, resource );
-      mResourceId->addItem( resource->resourceName() );
+      d->mResourceMap.insert( counter, resource );
+      d->mResourceId->addItem( resource->resourceName() );
       counter++;
     }
   }
 
-  mResourceId->setCurrentRow( 0 );
-  connect( mResourceId, SIGNAL( itemActivated(QListWidgetItem*)),
+  d->mResourceId->setCurrentRow( 0 );
+  connect( d->mResourceId, SIGNAL( itemActivated(QListWidgetItem*)),
            SLOT(accept()) );
 }
 
+SelectDialog::~SelectDialog()
+{
+  delete d;
+}
+
 Resource *SelectDialog::resource()
 {
-  if ( mResourceId->currentRow() != -1 )
-    return mResourceMap[ mResourceId->currentRow() ];
-  else
+  if ( d->mResourceId->currentRow() != -1 ) {
+    return d->mResourceMap[ d->mResourceId->currentRow() ];
+  } else {
     return 0;
+  }
 }
 
 Resource *SelectDialog::getResource( QList<Resource *> list, QWidget *parent )
@@ -95,27 +105,33 @@ Resource *SelectDialog::getResource( QList<Resource *> list, QWidget *parent )
     return 0;
   }
 
-  if ( list.count() == 1 ) return list.first();
+  if ( list.count() == 1 ) {
+    return list.first();
+  }
 
-  // the following lines will return a writeable resource if only _one_ writeable
-  // resource exists
+  // the following lines will return a writeable resource if only _one_
+  // writeable resource exists
   Resource *found = 0;
 
-  for(int i=0; i< list.size(); ++i) {
-    if (!list.at(i)->readOnly()) {
-      if (found) {
+  for ( int i=0; i< list.size(); ++i ) {
+    if ( !list.at(i)->readOnly() ) {
+      if ( found ) {
         found = 0;
         break;
       }
-    }
-    else
+    } else {
       found = list.at(i);
+    }
   }
 
-  if ( found )
+  if ( found ) {
     return found;
+  }
 
   SelectDialog dlg( list, parent );
-  if ( dlg.exec() == KDialog::Accepted ) return dlg.resource();
-  else return 0;
+  if ( dlg.exec() == KDialog::Accepted ) {
+    return dlg.resource();
+  } else {
+    return 0;
+  }
 }
