@@ -24,9 +24,11 @@
 #ifndef KRESOURCES_SELECTDIALOG_H
 #define KRESOURCES_SELECTDIALOG_H
 
-#include <QObject>
-#include <QMap>
-#include <QList>
+#include "kresources_export.h"
+
+#include <QtCore/QObject>
+#include <QtCore/QMap>
+#include <QtCore/QList>
 
 #include <kdialog.h>
 
@@ -60,10 +62,13 @@ class KRESOURCES_EXPORT SelectDialog : KDialog
      * Constructor.
      * @param list   The list of available resources
      * @param parent The parent widget
-     * @param name   The name of the dialog
      */
-    explicit SelectDialog( QList<Resource *> list, QWidget *parent = 0,
-        const char *name = 0);
+    explicit SelectDialog( QList<Resource *> list, QWidget *parent = 0 );
+
+    /**
+     * Destructor.
+     */
+    ~SelectDialog();
 
     /**
      * Returns selected resource.
@@ -71,15 +76,14 @@ class KRESOURCES_EXPORT SelectDialog : KDialog
     Resource *resource();
 
     /**
-     * Opens a dialog showing the available resources and returns the resource the
-     * user has selected. Returns 0, if the dialog was canceled.
+     * Opens a dialog showing the available resources and returns the resource
+     * the user has selected. Returns 0, if the dialog was canceled.
      */
     static Resource *getResource( QList<Resource *> list, QWidget *parent = 0 );
 
   private:
-    QListWidget *mResourceId;
-
-    QMap<int, Resource*> mResourceMap;
+    class SelectDialogPrivate;
+    SelectDialogPrivate *const d;
 };
 
 }
