@@ -20,34 +20,38 @@
 */
 /**
   @file
-  This file is part of the API for handling TNEF data and provides the
-  Formatter helper class.
+  This file is part of the API for handling TNEF data and provides
+  static Formatter helpers.
+
+  @brief
+  Provides helpers too format @acronym TNEF attachments into different
+  formats like eg. a HTML representation.
 
   @author Cornelius Schumacher
   @author Reinhold Kainhofer
   @author Rafal Rzepecki
 */
 
-#include <time.h>
-
-#include <QBuffer>
-#include <klocale.h>
-#include <kdatetime.h>
-
-#include "emailfunctions/email.h"
-#include "kabc/phonenumber.h"
-#include "kabc/vcardconverter.h"
-#include "kabc/stdaddressbook.h"
-
-#include "kcal/incidenceformatter.h"
-#include "kcal/calendar.h"
-#include "kcal/calendarlocal.h"
-#include "kcal/icalformat.h"
-
+#include "formatter.h"
 #include "ktnefparser.h"
 #include "ktnefmessage.h"
 #include "ktnefdefs.h"
-#include "formatter.h"
+
+#include <kpimutils/email.h>
+#include <kabc/phonenumber.h>
+#include <kabc/vcardconverter.h>
+#include <kabc/stdaddressbook.h>
+#include <kcal/incidenceformatter.h>
+#include <kcal/calendar.h>
+#include <kcal/calendarlocal.h>
+#include <kcal/icalformat.h>
+
+#include <klocale.h>
+#include <kdatetime.h>
+
+#include <QtCore/QBuffer>
+
+#include <time.h>
 
 using namespace KCal;
 using namespace KTnef;
@@ -86,7 +90,7 @@ static struct save_tz set_tz( const char *_tc )
   rv.old_tz = 0;
   rv.tz_env_str = 0;
 
-  //kDebug(5006) << "set_tz(), timezone before = " << timezone << endl;
+  //kDebug(5975) << "set_tz(), timezone before =" << timezone;
 
   char *tz_env = 0;
   if ( getenv( "TZ" ) ) {
@@ -103,7 +107,7 @@ static struct save_tz set_tz( const char *_tc )
   /* tmp_env is not free'ed -- it is part of the environment */
 
   tzset();
-  //kDebug(5006) << "set_tz(), timezone after = " << timezone << endl;
+  //kDebug(5975) << "set_tz(), timezone after =" << timezone;
 
   return rv;
 }
@@ -186,7 +190,7 @@ static KDateTime pureISOToLocalQDateTime( const QString &dtStr,
 }
 //@endcond
 
-QString KTnef::Formatter::msTNEFToVPart( const QByteArray &tnef )
+QString KTnef::msTNEFToVPart( const QByteArray &tnef )
 {
   bool bOk = false;
 
@@ -332,11 +336,11 @@ QString KTnef::Formatter::msTNEFToVPart( const QByteArray &tnef )
 
         s = tnefMsg->findProp( 0x8516 ).replace( QChar( '-' ), QString() )
           .replace( QChar( ':' ), QString() );
-        event->setDtStart( QDateTime::fromString( s ) ); // ## Format??
+        event->setDtStart( KDateTime::fromString( s ) ); // ## Format??
 
         s = tnefMsg->findProp( 0x8517 ).replace( QChar( '-' ), QString() )
           .replace( QChar( ':' ), QString() );
-        event->setDtEnd( QDateTime::fromString( s ) );
+        event->setDtEnd( KDateTime::fromString( s ) );
 
         s = tnefMsg->findProp( 0x8208 );
         event->setLocation( s );
@@ -512,9 +516,9 @@ QString KTnef::Formatter::msTNEFToVPart( const QByteArray &tnef )
   return QString::fromUtf8( converter.createVCard( addressee ) );
 }
 
-QString KTnef::Formatter::formatTNEFInvitation( const QByteArray &tnef,
-                                                KCal::Calendar *cal,
-                                                KCal::InvitationFormatterHelper *h )
+QString KTnef::formatTNEFInvitation( const QByteArray &tnef,
+                                     KCal::Calendar *cal,
+                                     KCal::InvitationFormatterHelper *h )
 {
   QString vPart = msTNEFToVPart( tnef );
   QString iCal = IncidenceFormatter::formatICalInvitation( vPart, cal, h );
