@@ -1,13 +1,13 @@
-/**************************************************************************
-*   Copyright (C) 2006 by Narayan Newton <narayannewton@gmail.com>        *
-*   Copyright (C) 2003 - 2004 by Frerich Raabe <raabe@kde.org>            *
-*                                Tobias Koenig <tokoe@kde.org>            *
-*                                                                         *
-*   This program is free software; you can redistribute it and/or modify  *
-*   it under the terms of the GNU General Public License as published by  *
-*   the Free Software Foundation; either version 2 of the License, or     *
-*   (at your option) any later version.                                   *
-***************************************************************************/
+/*****************************************************************************
+ *   Copyright (C) 2003 - 2004 by Frerich Raabe <raabe@kde.org>               *
+ *                                Tobias Koenig <tokoe@kde.org>               *
+ *   Copyright (C) 2006 by Narayan Newton <narayannewton@gmail.com>           *
+ *                                                                            *
+ * This program is distributed in the hope that it will be useful, but        *
+ * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY *
+ * or FITNESS FOR A PARTICULAR PURPOSE. For licensing and distribution        *
+ * details, check the accompanying file 'COPYING.BSD'.                        *
+ *****************************************************************************/
 /**
   @file
   This file is part of the API for accessing XML-RPC Servers
@@ -16,33 +16,38 @@
   @brief
   Defines the Client class.
 
-  @author Narayan Newton <narayannewton@gmail.com>
   @author Frerich Raabe <raabe@kde.org>
   @author Tobias Koenig <tokoe@kde.org>
+  @author Narayan Newton <narayannewton@gmail.com>
 */
 
-#include <kdebug.h>
-#include <kio/job.h>
-#include <klocale.h>
-#include <kurl.h>
-
-#include <QVariant>
-
 #include "client.h"
 #include "query.h"
 
+#include <kio/job.h>
+#include <kdebug.h>
+#include <klocale.h>
+#include <kurl.h>
+
+#include <QtCore/QVariant>
+
 using namespace KXmlRpc;
 
 class Client::Private
 {
   public:
+    Private() : mUserAgent( "KDE XMLRPC resources" ), mDigestAuth( false )
+                                                    , mDateFormatExtended(true)
+						    , mTimeFormatExtended(true){}
+
+    void queryFinished( Query * );
+
     KUrl mUrl;
     QString mUserAgent;
     bool mDigestAuth;
-
+    bool mDateFormatExtended;
+    bool mTimeFormatExtended;
     QList<Query*> mPendingQueries;
-
-    void queryFinished( Query * );
 };
 
 void Client::Private::queryFinished( Query *query )
@@ -54,19 +59,12 @@ void Client::Private::queryFinished( Query *query )
 Client::Client( QObject *parent )
   : QObject( parent ), d( new Private )
 {
-  d->mUserAgent = "KDE XMLRPC resources";
-  d->mDigestAuth = false;
 }
 
 Client::Client( const KUrl &url, QObject *parent )
   : QObject( parent ), d( new Private )
 {
-  if ( url.isValid() ) {
-    d->mUrl = url;
-  }
-
-  d->mUserAgent = "KDE XMLRPC resources";
-  d->mDigestAuth = false;
+  d->mUrl = url;
 }
 
 Client::~Client()
@@ -101,19 +99,34 @@ void Client::setUserAgent( const QString &userAgent )
   d->mUserAgent = userAgent;
 }
 
-bool Client::digestAuth() const
+void Client::setUseExtendedDateFormat( bool extended )
+{
+  d->mDateFormatExtended=extended;
+}
+
+void Client::setUseExtendedTimeFormat( bool extended )
+{
+  d->mDateFormatExtended=extended;
+}
+
+bool Client::useExtendedDateFormat() const
+{
+  return d->mDateFormatExtended;
+}
+
+bool Client::useExtendedTimeFormat() const
+{
+  return d->mTimeFormatExtended;
+}
+
+bool Client::isDigestAuthEnabled() const
 {
   return d->mDigestAuth;
 }
 
-void Client::enableDigestAuth()
+void Client::setDigestAuthEnabled( bool enabled )
 {
-  d->mDigestAuth = true;
-}
-
-void Client::disableDigestAuth()
-{
-  d->mDigestAuth = false;
+  d->mDigestAuth = enabled;
 }
 
 void Client::call( const QString &method, const QList<QVariant> &args,
@@ -124,7 +137,7 @@ void Client::call( const QString &method, const QList<QVariant> &args,
   QMap<QString, QString> metaData;
 
   if ( d->mUrl.isEmpty() ) {
-    kWarning() << "Cannot execute call to " << method << ": empty server URL" << endl;
+    kWarning() << "Cannot execute call to" << method << ": empty server URL";
   }
 
   //Fill metadata, with userAgent and possible digest auth
@@ -144,7 +157,7 @@ void Client::call( const QString &method, const QList<QVariant> &args,
   connect( query, SIGNAL( finished( Query * ) ), this, SLOT( queryFinished( Query * ) ) );
   d->mPendingQueries.append( query );
 
-  query->call( d->mUrl.url(), method, args, metaData );
+  query->call( d->mUrl.url(), method, args, metaData, d->mDateFormatExtended, d->mTimeFormatExtended  );
 }
 
 void Client::call( const QString &method, const QVariant &arg,
