@@ -1,13 +1,13 @@
-/**************************************************************************
-*   Copyright (C) 2006 by Narayan Newton <narayannewton@gmail.com>        *
-*   Copyright (C) 2003 - 2004 by Frerich Raabe <raabe@kde.org>            *
-*                                Tobias Koenig <tokoe@kde.org>            *
-*                                                                         *
-*   This program is free software; you can redistribute it and/or modify  *
-*   it under the terms of the GNU General Public License as published by  *
-*   the Free Software Foundation; either version 2 of the License, or     *
-*   (at your option) any later version.                                   *
-***************************************************************************/
+/******************************************************************************
+ *   Copyright (C) 2003 - 2004 by Frerich Raabe <raabe@kde.org>               *
+ *                                Tobias Koenig <tokoe@kde.org>               *
+ *   Copyright (C) 2006 by Narayan Newton <narayannewton@gmail.com>           *
+ *                                                                            *
+ * This program is distributed in the hope that it will be useful, but        *
+ * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY *
+ * or FITNESS FOR A PARTICULAR PURPOSE. For licensing and distribution        *
+ * details, check the accompanying file 'COPYING.BSD'.                        *
+ *****************************************************************************/
 /**
   @file
   This file is part of the API for accessing XML-RPC Servers
@@ -16,21 +16,22 @@
   @brief
   Defines the Client class.
 
-  @author Narayan Newton <narayannewton@gmail.com>
   @author Frerich Raabe <raabe@kde.org>
   @author Tobias Koenig <tokoe@kde.org>
+  @author Narayan Newton <narayannewton@gmail.com>
 */
 
 #ifndef KXML_RPC_CLIENT_H
 #define KXML_RPC_CLIENT_H
 
+#include "kxmlrpcclient_export.h"
+
+#include <kurl.h>
+
 #include <QtCore/QList>
 #include <QtCore/QObject>
 #include <QtCore/QVariant>
 
-#include <kurl.h>
-#include "kxmlrpcclient.h"
-
 /** Names for XmlRpc related classes */
 namespace KXmlRpc {
 
@@ -55,7 +56,7 @@ class KXMLRPCCLIENT_EXPORT Client : public QObject
 
   public:
     /**
-			Constructs a XML-RPC Client.
+      Constructs a XML-RPC Client.
 
       @param parent the parent of this object, defaults to NULL.
      */
@@ -72,7 +73,7 @@ class KXMLRPCCLIENT_EXPORT Client : public QObject
     /**
       Destroys the XML-RPC Client.
      */
-    virtual ~Client();
+    ~Client();
 
     /**
       Returns the current url the XML-RPC Client will connect to.
@@ -106,27 +107,56 @@ class KXMLRPCCLIENT_EXPORT Client : public QObject
      */
     void setUserAgent( const QString &userAgent );
 
+    /**
+      Sets the Date Format the Client will use.
+       extended format: YYYY-MM-DD
+       basic format: YYYYMMDD
+      @param extended  true extended format will be used.
+
+      @see useExtendedDateFormat()
+     */
+    void setUseExtendedDateFormat( bool extended );
+
+     /**
+      Sets the Time Format the Client will use.
+       extended format: HH:MM:SS
+       basic format: HHMMSS
+      @param extended  true extended format will be used.
+
+      @see useExtendedTimeFormat()
+     */
+    void setUseExtendedTimeFormat( bool extended );
+
+    /**
+      Returns true if the date format is extended
+    
+      @see setUseExtendedDateFormat()
+     */
+    bool useExtendedDateFormat() const;
+    
+    /**
+      Returns true if the time format is extended
+    
+      @see setUseExtendedTimeFormat()
+     */
+    bool useExtendedTimeFormat() const;
+
     /**
       Returns true if HTTP-Digest authentication is enabled, false
       if not.
 
-      @see enableDigestAuth(), disableDigestAuth()
+      @see setDigestAuthEnabled()
      */
-    bool digestAuth() const;
+    bool isDigestAuthEnabled() const;
+
 
     /**
-      Sets HTTP-Digest authentication on.
+      Enables/disables HTTP-Digest authentication
 
-      @see digestAuth(), disableDigestAuth()
+      @see isDigestAuthEnabled()
      */
-    void enableDigestAuth();
 
-    /**
-      Sets HTTP-Digest authentication off.
-
-      @see enableDigestAuth(), digestAuth()
-     */
-    void disableDigestAuth();
+    void setDigestAuthEnabled( bool enabled );
 
   public Q_SLOTS:
     /**
