@@ -1,90 +1,130 @@
-/**************************************************************************
-*   Copyright (C) 2006 by Narayan Newton <narayannewton@gmail.com>        *
-*   Copyright (C) 2003 - 2004 by Frerich Raabe <raabe@kde.org>            *
-*                                Tobias Koenig <tokoe@kde.org>            *
-*                                                                         *
-*   This program is free software; you can redistribute it and/or modify  *
-*   it under the terms of the GNU General Public License as published by  *
-*   the Free Software Foundation; either version 2 of the License, or     *
-*   (at your option) any later version.                                   *
-***************************************************************************/
+/******************************************************************************
+ *   Copyright (C) 2003 - 2004 by Frerich Raabe <raabe@kde.org>               *
+ *                                Tobias Koenig <tokoe@kde.org>               *
+ *   Copyright (C) 2006 by Narayan Newton <narayannewton@gmail.com>           *
+ *                                                                            *
+ * This program is distributed in the hope that it will be useful, but        *
+ * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY *
+ * or FITNESS FOR A PARTICULAR PURPOSE. For licensing and distribution        *
+ * details, check the accompanying file 'COPYING.BSD'.                        *
+ *****************************************************************************/
+/**
+  @file
+
+  This file is part of KXmlRpc and defines our internal classes.
+
+  @author Frerich Raabe <raabe@kde.org>
+  @author Tobias Koenig <tokoe@kde.org>
+  @author Narayan Newton <narayannewton@gmail.com>
+*/
+
+#include "query.h"
 
 #include <kdebug.h>
 #include <klocale.h>
 
-#include <QDateTime>
-#include <QVariant>
-#include <qdom.h>
-
-#include "query.h"
+#include <QtCore/QDateTime>
+#include <QtCore/QVariant>
+#include <QtXml/QDomDocument>
 
 using namespace KXmlRpc;
 
 /**
   @file
 
-  Implementation of Result and Query
+  Implementation of Query
 **/
 
-class Result::Private
+namespace KXmlRpc {
+
+/**
+  @brief
+  Result is an internal class that represents a response
+  from a XML-RPC server.
+
+  This is an internal class and is only used by Query.
+  @internal
+ */
+class Result
 {
+  friend class Query;
+  friend class Query::Private;
+
   public:
+    /**
+      Constructs a result.
+     */
+    Result();
+
+    /**
+      Destroys a result.
+     */
+    ~Result();
+
+    /**
+      Returns true if the method call succeeded, false
+      if there was an XML-RPC fault.
+
+      @see errorCode(), errorString()
+     */
+    bool success() const;
+
+    /**
+      Returns the error code of the fault.
+
+      @see success(), errorString()
+     */
+    int errorCode() const;
+
+    /**
+      Returns the error string that describes the fault.
+
+      @see success, errorCode()
+     */
+    QString errorString() const;
+
+    /**
+      Returns the data sent to us from the server.
+     */
+    QList<QVariant> data() const;
+
+  private:
     bool mSuccess;
     int mErrorCode;
     QString mErrorString;
     QList<QVariant> mData;
 };
 
-Result::Result()
-  : d( new Private )
+} // namespace KXmlRpcClient
+
+KXmlRpc::Result::Result()
 {
 }
 
-Result::Result( const Result &other )
-  : d( new Private )
+KXmlRpc::Result::~Result()
 {
-  *d = *other.d;
 }
 
-Result &Result::operator=( const Result &other )
+bool KXmlRpc::Result::success() const
 {
-  if ( this == &other ) {
-    return *this;
-  }
-
-  *d = *other.d;
-
-  return *this;
+  return mSuccess;
 }
 
-Result::~Result()
+int KXmlRpc::Result::errorCode() const
 {
-  delete d;
+  return mErrorCode;
 }
 
-bool Result::success() const
+QString KXmlRpc::Result::errorString() const
 {
-  return d->mSuccess;
+  return mErrorString;
 }
 
-int Result::errorCode() const
+QList<QVariant> KXmlRpc::Result::data() const
 {
-  return d->mErrorCode;
+  return mData;
 }
 
-QString Result::errorString() const
-{
-  return d->mErrorString;
-}
-
-QList<QVariant> Result::data() const
-{
-  return d->mData;
-}
-
-//small macro taken from HTTP IOSlave
-#define KIO_ARGS QByteArray packedArgs; QDataStream kioArgsStream( &packedArgs, QIODevice::WriteOnly ); kioArgsStream
-
 class Query::Private
 {
   public:
@@ -110,26 +150,30 @@ class Query::Private
     QByteArray mBuffer;
     QVariant mId;
     QList<KJob*> mPendingJobs;
+    bool mDateFormatExtended;
+    bool mTimeFormatExtended;
 };
 
 bool Query::Private::isMessageResponse( const QDomDocument &doc ) const
 {
-  return doc.documentElement().firstChild().toElement().tagName().toLower() == "params";
+  return doc.documentElement().firstChild().toElement().tagName().toLower()
+      == "params";
 }
 
 bool Query::Private::isFaultResponse( const QDomDocument &doc ) const
 {
-  return doc.documentElement().firstChild().toElement().tagName().toLower() == "fault";
+  return doc.documentElement().firstChild().toElement().tagName().toLower()
+      == "fault";
 }
 
 Result Query::Private::parseMessageResponse( const QDomDocument &doc ) const
 {
   Result response;
-  response.d->mSuccess = true;
+  response.mSuccess = true;
 
   QDomNode paramNode = doc.documentElement().firstChild().firstChild();
   while ( !paramNode.isNull() ) {
-    response.d->mData << demarshal( paramNode.firstChild().toElement() );
+    response.mData << demarshal( paramNode.firstChild().toElement() );
     paramNode = paramNode.nextSibling();
   }
 
@@ -139,17 +183,18 @@ Result Query::Private::parseMessageResponse( const QDomDocument &doc ) const
 Result Query::Private::parseFaultResponse( const QDomDocument &doc ) const
 {
   Result response;
-  response.d->mSuccess = false;
+  response.mSuccess = false;
 
   QDomNode errorNode = doc.documentElement().firstChild().firstChild();
   const QVariant errorVariant = demarshal( errorNode.toElement() );
-  response.d->mErrorCode = errorVariant.toMap() [ "faultCode" ].toInt();
-  response.d->mErrorString = errorVariant.toMap() [ "faultString" ].toString();
+  response.mErrorCode = errorVariant.toMap() [ "faultCode" ].toInt();
+  response.mErrorString = errorVariant.toMap() [ "faultString" ].toString();
 
   return response;
 }
 
-QString Query::Private::markupCall( const QString &cmd, const QList<QVariant> &args ) const
+QString Query::Private::markupCall( const QString &cmd,
+                                    const QList<QVariant> &args ) const
 {
   QString markup = "<?xml version=\"1.0\" ?>\r\n<methodCall>\r\n";
 
@@ -176,7 +221,19 @@ QString Query::Private::marshal( const QVariant &arg ) const
   switch ( arg.type() ) {
 
     case QVariant::String:
-      return "<value><string>" + arg.toString() + "</string></value>\r\n";
+      return "<value><string><![CDATA[" + arg.toString() + "]]></string></value>\r\n";
+    case QVariant::StringList:
+      {
+        QStringList data = arg.toStringList();
+        QStringListIterator dataIterator(data);
+        QString markup;
+        markup += "<value><array><data>";
+        while ( dataIterator.hasNext() ) {
+          markup += "<string><![CDATA[" + dataIterator.next() + "]]></string>\r\n";
+        }
+        markup += "</data></array></value>";
+        return markup;
+      }
     case QVariant::Int:
       return "<value><int>" + QString::number( arg.toInt() ) + "</int></value>\r\n";
     case QVariant::Double:
@@ -191,7 +248,24 @@ QString Query::Private::marshal( const QVariant &arg ) const
     case QVariant::ByteArray:
       return "<value><base64>" + arg.toByteArray().toBase64() + "</base64></value>\r\n";
     case QVariant::DateTime:
-      return "<value><datetime.iso8601>" + arg.toDateTime().toString( Qt::ISODate ) + "</datetime.iso8601></value>\r\n";
+      {
+        QString date;
+        QString time;
+
+        if ( mTimeFormatExtended ) {
+          time = arg.toDateTime().time().toString( Qt::ISODate );
+        } else {
+          time = arg.toDateTime().time().toString( "hhmmss" );
+        }
+
+        if ( mDateFormatExtended ) {
+          date = arg.toDateTime().date().toString( Qt::ISODate );
+        } else {
+          date = arg.toDateTime().date().toString( "yyyyMMdd" );
+        }
+
+        return "<value><dateTime.iso8601>" + date + 'T' + time + "</dateTime.iso8601></value>\r\n";
+      }
     case QVariant::List:
       {
         QString markup = "<value><array><data>\r\n";
@@ -220,7 +294,7 @@ QString Query::Private::marshal( const QVariant &arg ) const
         return markup;
       }
     default:
-      kWarning() << "Failed to marshal unknown variant type: " << arg.type() << endl;
+      kWarning() << "Failed to marshal unknown variant type:" << arg.type();
   };
 
   return QString();
@@ -249,7 +323,20 @@ QVariant Query::Private::demarshal( const QDomElement &element ) const
   } else if ( typeName == "base64" ) {
     return QVariant( QByteArray::fromBase64( typeElement.text().toLatin1() ) );
   } else if ( typeName == "datetime" || typeName == "datetime.iso8601" ) {
-    return QVariant( QDateTime::fromString( typeElement.text(), Qt::ISODate ) );
+    QDateTime date;
+    QString dateText = typeElement.text();
+    // Test for broken use of Basic ISO8601 date and extended ISO8601 time
+    if ( 17 <= dateText.length() && dateText.length() <= 18 &&
+         dateText.at( 4 ) != '-' && dateText.at( 11 ) == ':' ) {
+        if ( dateText.endsWith( 'Z' ) ) {
+          date = QDateTime::fromString( dateText, "yyyyMMddTHH:mm:ssZ" );
+        } else {
+          date = QDateTime::fromString( dateText, "yyyyMMddTHH:mm:ss" );
+        }
+    } else {
+      date = QDateTime::fromString( dateText, Qt::ISODate );
+    }
+    return QVariant( date );
   } else if ( typeName == "array" ) {
     QList<QVariant> values;
     QDomNode valueNode = typeElement.firstChild().firstChild();
@@ -263,14 +350,16 @@ QVariant Query::Private::demarshal( const QDomElement &element ) const
     QMap<QString, QVariant> map;
     QDomNode memberNode = typeElement.firstChild();
     while ( !memberNode.isNull() ) {
-      const QString key = memberNode.toElement().elementsByTagName( "name" ).item( 0 ).toElement().text();
-      const QVariant data = demarshal( memberNode.toElement().elementsByTagName( "value" ).item( 0 ).toElement() );
+      const QString key = memberNode.toElement().elementsByTagName(
+                              "name" ).item( 0 ).toElement().text();
+      const QVariant data = demarshal( memberNode.toElement().elementsByTagName(
+                                       "value" ).item( 0 ).toElement() );
       map[ key ] = data;
       memberNode = memberNode.nextSibling();
     }
     return QVariant( map );
   } else {
-    kWarning() << "Cannot demarshal unknown type " << typeName << endl;
+    kWarning() << "Cannot demarshal unknown type" << typeName;
   }
   return QVariant();
 }
@@ -309,9 +398,11 @@ void Query::Private::slotResult( KJob *job )
   if ( isMessageResponse( doc ) ) {
     emit mParent->message( parseMessageResponse( doc ).data(), mId );
   } else if ( isFaultResponse( doc ) ) {
-    emit mParent->fault( parseFaultResponse( doc ).errorCode(), parseFaultResponse( doc ).errorString(), mId );
+    emit mParent->fault( parseFaultResponse( doc ).errorCode(),
+                         parseFaultResponse( doc ).errorString(), mId );
   } else {
-    emit mParent->fault( 1, i18n( "Unknown type of XML markup received" ), mId );
+    emit mParent->fault( 1, i18n( "Unknown type of XML markup received" ),
+                         mId );
   }
 
   emit mParent->finished( mParent );
@@ -325,26 +416,30 @@ Query *Query::create( const QVariant &id, QObject *parent )
 void Query::call( const QString &server,
                   const QString &method,
                   const QList<QVariant> &args,
-                  const QMap<QString, QString> &jobMetaData )
+                  const QMap<QString, QString> &jobMetaData,
+                  const bool dateFormatExtended,
+                  const bool timeFormatExtended )
 {
+  d->mDateFormatExtended=dateFormatExtended;
+  d->mTimeFormatExtended=timeFormatExtended;
   const QString xmlMarkup = d->markupCall( method, args );
+
   QMap<QString, QString>::const_iterator mapIter;
   QByteArray postData;
   QDataStream stream( &postData, QIODevice::WriteOnly );
   stream.writeRawData( xmlMarkup.toUtf8(), xmlMarkup.toUtf8().length() );
 
-  KIO_ARGS << (int)1 << KUrl( server );
-  KIO::TransferJob *job = new KIO::TransferJob( KUrl( server ), KIO::CMD_SPECIAL, packedArgs, postData, false );
+  KIO::TransferJob *job = KIO::http_post( KUrl( server ), postData, false );
 
   if ( !job ) {
-    kWarning() << "Unable to create KIO job for " << server << endl;
+    kWarning() << "Unable to create KIO job for" << server;
     return;
   }
 
   job->addMetaData( "content-type", "Content-Type: text/xml; charset=utf-8" );
   job->addMetaData( "ConnectTimeout", "50" );
 
-  for (mapIter = jobMetaData.begin(); mapIter != jobMetaData.end(); mapIter++) {
+  for ( mapIter = jobMetaData.begin(); mapIter != jobMetaData.end(); mapIter++ ) {
     job->addMetaData( mapIter.key(), mapIter.value() );
   }
 
