@@ -1,7 +1,7 @@
 /*
  * This file is part of the syndication library
  *
- * Copyright (C) 2006 Frank Osterfeld <frank.osterfeld@kdemail.net>
+ * Copyright (C) 2006 Frank Osterfeld <osterfeld@kde.org>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public
@@ -24,9 +24,9 @@
 
 #include <QtCore/QString>
 
-#include <syndication/sharedptr.h>
+#include <boost/shared_ptr.hpp>
 
-#include "ksyndication.h"
+#include "ksyndication_export.h"
 
 class QDomElement;
 template <class T> class QList;
@@ -293,7 +293,7 @@ class SYNDICATION_EXPORT ElementWrapper
     private:
 
         class ElementWrapperPrivate;
-        SharedPtr<ElementWrapperPrivate> d;
+        boost::shared_ptr<ElementWrapperPrivate> d;
 };
 
 } // namespace Syndication
